!
! ZDPLASKIN version 2.0a
! (c) 2008, Sergey Pancheshnyi (pancheshnyi@gmail.com)
!
! BOLSIG+
! (c) 2005, Gerjan Hagelaar (gerjan.hagelaar@laplace.univ-tlse.fr)
!
! http://www.zdplaskin.laplace.univ-tlse.fr/
! This software is provided "as is" without warranty and non-commercial use is freely
! granted provided proper reference is made in publications resulting from its use.
! Use of ZDPlasKin in commerical software requires a license.
!
!-----------------------------------------------------------------------------------------------------------------------------------
!
! Wed Nov 22 22:03:34 2023
!
!-----------------------------------------------------------------------------------------------------------------------------------
!
! ELEMENTS: H N O E 
!
!-----------------------------------------------------------------------------------------------------------------------------------
!
! MODULE ZDPlasKin
!
!-----------------------------------------------------------------------------------------------------------------------------------
module ZDPlasKin
  use dvode_f90_m, only : vode_opts
  implicit none
  public
!
! config
!
  integer, parameter :: species_max = 80, species_electrons = 80, species_length = 8, reactions_max = 595, reactions_length = 34
  double precision                          :: density(species_max)
  integer                                   :: species_charge(species_max)
  character(species_length)                 :: species_name(species_max)
  character(reactions_length)               :: reaction_sign(reactions_max)
  logical                                   :: lreaction_block(reactions_max)
!
! internal config
!
  double precision, parameter, private      :: vode_atol = 1.00D-10, vode_rtol = 1.00D-05, cfg_rtol = 1.00D-01
  integer, parameter, private               :: vode_neq = species_max + 1
  type (vode_opts), private                 :: vode_options
  integer, private                          :: vode_itask, vode_istate, ifile_unit = 5
  double precision, private                 :: stat_dens(species_max), stat_src(species_max), stat_rrt(reactions_max), stat_time, &
                                               dens_loc(vode_neq,0:3), rrt_loc(reactions_max), tsav = -huge(tsav), &
                                               mach_accur, mach_tiny
  double precision                          :: rrt(reactions_max), mrtm(species_max, reactions_max), ZDPlasKin_cfg(14)
  logical, private                          :: lZDPlasKin_init = .false., lprint, lstat_accum, ldensity_constant, &
                                               density_constant(species_max), lgas_heating
!
! qtplaskin config
!
  logical, private                          :: lqtplaskin, lqtplaskin_first = .true.
  double precision, parameter, private      :: qtplaskin_atol = 1.00D+00, qtplaskin_rtol = 1.00D-02
  character(32), allocatable                :: qtplaskin_user_names(:)
  double precision, allocatable             :: qtplaskin_user_data(:)
!
! physical constants
!
  double precision, parameter, private      :: eV_to_K = 1.16045052d4, q_elem = 1.60217662d-19, k_B = 1.38064852d-23
!
! bolsig+ config
!
  double precision, parameter, private      :: bolsig_rtol = 1.00D-03, bolsig_rtol_half = 3.16D-02, &
                                               bolsig_field_min = 1.00D-01, bolsig_field_max = 1.00D+03, &
                                               bolsig_eecol_frac_def = 1.00D-05
  double precision, private                 :: bolsig_eecol_frac
  integer, parameter, private               :: bolsig_species_max = 9, bolsig_species_length = 3, bolsig_rates_max = 59 
  character(*), parameter, private          :: bolsigfile = "bolsigdb.dat"
  integer                                   :: bolsig_pointer(bolsig_rates_max) = -1
  integer, private                          :: bolsig_species_index(bolsig_species_max) = -1, bolsig_collisions_max = 0 
  logical, private                          :: lbolsig_ignore_gas_temp, lbolsig_Maxwell_EEDF
  double precision, allocatable             :: bolsig_rates(:)
  character(bolsig_species_length), private :: bolsig_species(bolsig_species_max)
  interface
    subroutine ZDPlasKin_bolsig_Init(a)
      character(*), intent(in) :: a
    end subroutine ZDPlasKin_bolsig_Init
    subroutine ZDPlasKin_bolsig_ReadCollisions(a)
      character(*), intent(in) :: a
    end subroutine ZDPlasKin_bolsig_ReadCollisions
    subroutine ZDPlasKin_bolsig_GetCollisions(i,j)
      integer, intent(out) :: i, j
    end subroutine ZDPlasKin_bolsig_GetCollisions
    subroutine ZDPlasKin_bolsig_GetSpeciesName(a,i)
      integer, intent(in) :: i
      character(*), intent(out) :: a
    end subroutine ZDPlasKin_bolsig_GetSpeciesName
    subroutine ZDPlasKin_bolsig_GetReactionName(a,i)
      integer, intent(in) :: i
      character(*), intent(out) :: a
    end subroutine ZDPlasKin_bolsig_GetReactionName
    subroutine ZDPlasKin_bolsig_SolveBoltzmann(i,a,j,b)
      integer, intent(in) :: i, j
      double precision, intent(in)  :: a(i)
      double precision, intent(out) :: b(j)
    end subroutine ZDPlasKin_bolsig_SolveBoltzmann
    subroutine ZDPlasKin_bolsig_GetEEDF(i,a,b)
      integer, intent(in) :: i
      double precision, intent(out) :: a,b
    end subroutine ZDPlasKin_bolsig_GetEEDF
  end interface
!
! data section
!
  data species_charge(1:species_max) &
  / 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,&
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1,-1, 1,-1, 1,-1, 1,-1, 1, 1, 1, 1, 1, 1, 1, 1, 1,-1/
  data species_name(1:species_max) &
  /"O       ","O2      ","O3      ","H       ","H2      ","OH      ","H2O     ","HO2     ","H2O2    ","N       ","N2      ",&
   "NO      ","NO2     ","N2O     ","NO3     ","NH3     ","NH2     ","NH      ","N2H2    ","NNH     ","N2H3    ","N2H4    ",&
   "H2NN    ","H2NO    ","HON     ","HNO     ","HONO    ","HNOH    ","HNO2    ","HONO2   ","HNO3    ","NH2OH   ","N(2P)   ",&
   "N(2D)   ","O2*     ","O(1D)   ","O(1S)   ","N2(V1)  ","N2(V2)  ","N2(V3)  ","N2(V4)  ","N2(V5)  ","N2(V6)  ","N2(V7)  ",&
   "N2(V8)  ","N2(A)   ","N2(B)   ","N2(A')  ","N2(C)   ","O2(V1)  ","O2(V2)  ","O2(V3)  ","O2(V4)  ","O2(A1)  ","O2(B1)  ",&
   "OH*     ","NH3(V2) ","NH3(V4) ","NH3(V13)","N^+     ","N2^+    ","N3^+    ","N4^+    ","O^-     ","O^+     ","OH^-    ",&
   "O2^+    ","O2^-    ","O4^+    ","O3^-    ","NH4^+   ","NH3^+   ","NH2^+   ","NH^+    ","N2H^+   ","H^+     ","H2^+    ",&
   "H3^+    ","H2O^+   ","E       "/
  data reaction_sign(1:54) &
  /"bolsig:NH3->NH3(V2)               ","bolsig:NH3->NH3(V4)               ","bolsig:NH3->NH3(V13)              ",&
   "bolsig:NH3->NH3^+                 ","bolsig:NH3->H+NH2^+               ","bolsig:NH3->H+NH2                 ",&
   "bolsig:NH3->2H+NH                 ","bolsig:NH2->NH2^+                 ","bolsig:NH2->H+NH^+                ",&
   "bolsig:NH2->NH+H                  ","bolsig:NH2->N+2H                  ","bolsig:NH->NH^+                   ",&
   "bolsig:NH->H+N                    ","bolsig:NH->N(2P)+H                ","bolsig:N->N(2D)                   ",&
   "bolsig:N->N(2P)                   ","bolsig:N->N^+                     ","bolsig:N2->N2(V1)                 ",&
   "bolsig:N2->N2(V2)                 ","bolsig:N2->N2(V3)                 ","bolsig:N2->N2(V4)                 ",&
   "bolsig:N2->N2(V5)                 ","bolsig:N2->N2(V6)                 ","bolsig:N2->N2(V7)                 ",&
   "bolsig:N2->N2(V8)                 ","bolsig:N2->N2(A3,V0-4)            ","bolsig:N2->N2(A3,V5-9)            ",&
   "bolsig:N2->N2(A3,V10-)            ","bolsig:N2->N2(B3)                 ","bolsig:N2->N2(W3)                 ",&
   "bolsig:N2->N2(B'3)                ","bolsig:N2->N2(A'1)                ","bolsig:N2->N2(A1)                 ",&
   "bolsig:N2->N2(W1)                 ","bolsig:N2->N2(C3)                 ","bolsig:N2->N2(E3)                 ",&
   "bolsig:N2->N2(A''1)               ","bolsig:N2->N2^+                   ","bolsig:O2->O2(V1)                 ",&
   "bolsig:O2->O2(V2)                 ","bolsig:O2->O2(V3)                 ","bolsig:O2->O2(V4)                 ",&
   "bolsig:O2->O2(A1)                 ","bolsig:O2->O2(B1)                 ","bolsig:O2->O2*                    ",&
   "bolsig:O2->O2^+                   ","bolsig:O2->2O                     ","bolsig:O2->O+O(1D)                ",&
   "bolsig:O2->O+O(1S)                ","bolsig:O2->O^-+O                  ","bolsig:O3->O2^++O                 ",&
   "bolsig:O3->O2+O                   ","bolsig:O3->O2^-+O                 ","bolsig:O3->O2+O^-                 "/
  data reaction_sign(55:108) &
  /"bolsig:O->O(1S)                   ","bolsig:O->O(1D)                   ","bolsig:H2O->H2O^+                 ",&
   "bolsig:H2O->H2+O^-                ","bolsig:H2O->OH^-+H                ","N2(V1)+N2=>N2+N2                  ",&
   "N2(V2)+N2=>N2(V1)+N2              ","N2(V3)+N2=>N2(V2)+N2              ","N2(V4)+N2=>N2(V3)+N2              ",&
   "N2(V5)+N2=>N2(V4)+N2              ","N2(V6)+N2=>N2(V5)+N2              ","N2(V7)+N2=>N2(V6)+N2              ",&
   "N2(V8)+N2=>N2(V7)+N2              ","N2(V1)+O2=>N2+O2                  ","N2(V2)+O2=>N2(V1)+O2              ",&
   "N2(V3)+O2=>N2(V2)+O2              ","N2(V4)+O2=>N2(V3)+O2              ","N2(V5)+O2=>N2(V4)+O2              ",&
   "N2(V6)+O2=>N2(V5)+O2              ","N2(V7)+O2=>N2(V6)+O2              ","N2(V8)+O2=>N2(V7)+O2              ",&
   "N2(V1)+O=>N2+O                    ","N2(V2)+O=>N2(V1)+O                ","N2(V3)+O=>N2(V2)+O                ",&
   "N2(V4)+O=>N2(V3)+O                ","N2(V5)+O=>N2(V4)+O                ","N2(V6)+O=>N2(V5)+O                ",&
   "N2(V7)+O=>N2(V6)+O                ","N2(V8)+O=>N2(V7)+O                ","N2(V1)+N=>N2+N                    ",&
   "N2(V2)+N=>N2(V1)+N                ","N2(V3)+N=>N2(V2)+N                ","N2(V4)+N=>N2(V3)+N                ",&
   "N2(V5)+N=>N2(V4)+N                ","N2(V6)+N=>N2(V5)+N                ","N2(V7)+N=>N2(V6)+N                ",&
   "N2(V8)+N=>N2(V7)+N                ","O2(V1)+N2=>O2+N2                  ","O2(V2)+N2=>O2(V1)+N2              ",&
   "O2(V3)+N2=>O2(V2)+N2              ","O2(V4)+N2=>O2(V3)+N2              ","O2(V1)+O2=>O2+O2                  ",&
   "O2(V2)+O2=>O2(V1)+O2              ","O2(V3)+O2=>O2(V2)+O2              ","O2(V4)+O2=>O2(V3)+O2              ",&
   "O2(V1)+O=>O2+O                    ","O2(V2)+O=>O2(V1)+O                ","O2(V3)+O=>O2(V2)+O                ",&
   "O2(V4)+O=>O2(V3)+O                ","N2(V1)+N2(V1)=>N2+N2(V2)          ","N2(V1)+N2(V2)=>N2+N2(V3)          ",&
   "N2(V1)+N2(V3)=>N2+N2(V4)          ","N2(V1)+N2(V4)=>N2+N2(V5)          ","N2(V1)+N2(V5)=>N2+N2(V6)          "/
  data reaction_sign(109:162) &
  /"N2(V1)+N2(V6)=>N2+N2(V7)          ","N2(V1)+N2(V7)=>N2+N2(V8)          ","N2(V2)+N2=>N2(V1)+N2(V1)          ",&
   "N2(V2)+N2(V2)=>N2(V1)+N2(V3)      ","N2(V2)+N2(V3)=>N2(V1)+N2(V4)      ","N2(V2)+N2(V4)=>N2(V1)+N2(V5)      ",&
   "N2(V2)+N2(V5)=>N2(V1)+N2(V6)      ","N2(V2)+N2(V6)=>N2(V1)+N2(V7)      ","N2(V2)+N2(V7)=>N2(V1)+N2(V8)      ",&
   "N2(V3)+N2=>N2(V2)+N2(V1)          ","N2(V3)+N2(V1)=>N2(V2)+N2(V2)      ","N2(V3)+N2(V3)=>N2(V2)+N2(V4)      ",&
   "N2(V3)+N2(V4)=>N2(V2)+N2(V5)      ","N2(V3)+N2(V5)=>N2(V2)+N2(V6)      ","N2(V3)+N2(V6)=>N2(V2)+N2(V7)      ",&
   "N2(V3)+N2(V7)=>N2(V2)+N2(V8)      ","N2(V4)+N2=>N2(V3)+N2(V1)          ","N2(V4)+N2(V1)=>N2(V3)+N2(V2)      ",&
   "N2(V4)+N2(V2)=>N2(V3)+N2(V3)      ","N2(V4)+N2(V4)=>N2(V3)+N2(V5)      ","N2(V4)+N2(V5)=>N2(V3)+N2(V6)      ",&
   "N2(V4)+N2(V6)=>N2(V3)+N2(V7)      ","N2(V4)+N2(V7)=>N2(V3)+N2(V8)      ","N2(V5)+N2=>N2(V4)+N2(V1)          ",&
   "N2(V5)+N2(V1)=>N2(V4)+N2(V2)      ","N2(V5)+N2(V2)=>N2(V4)+N2(V3)      ","N2(V5)+N2(V3)=>N2(V4)+N2(V4)      ",&
   "N2(V5)+N2(V5)=>N2(V4)+N2(V6)      ","N2(V5)+N2(V6)=>N2(V4)+N2(V7)      ","N2(V5)+N2(V7)=>N2(V4)+N2(V8)      ",&
   "N2(V6)+N2=>N2(V5)+N2(V1)          ","N2(V6)+N2(V1)=>N2(V5)+N2(V2)      ","N2(V6)+N2(V2)=>N2(V5)+N2(V3)      ",&
   "N2(V6)+N2(V3)=>N2(V5)+N2(V4)      ","N2(V6)+N2(V4)=>N2(V5)+N2(V5)      ","N2(V6)+N2(V6)=>N2(V5)+N2(V7)      ",&
   "N2(V6)+N2(V7)=>N2(V5)+N2(V8)      ","N2(V7)+N2=>N2(V6)+N2(V1)          ","N2(V7)+N2(V1)=>N2(V6)+N2(V2)      ",&
   "N2(V7)+N2(V2)=>N2(V6)+N2(V3)      ","N2(V7)+N2(V3)=>N2(V6)+N2(V4)      ","N2(V7)+N2(V4)=>N2(V6)+N2(V5)      ",&
   "N2(V7)+N2(V5)=>N2(V6)+N2(V6)      ","N2(V7)+N2(V7)=>N2(V6)+N2(V8)      ","N2(V8)+N2=>N2(V7)+N2(V1)          ",&
   "N2(V8)+N2(V1)=>N2(V7)+N2(V2)      ","N2(V8)+N2(V2)=>N2(V7)+N2(V3)      ","N2(V8)+N2(V3)=>N2(V7)+N2(V4)      ",&
   "N2(V8)+N2(V4)=>N2(V7)+N2(V5)      ","N2(V8)+N2(V5)=>N2(V7)+N2(V6)      ","N2(V8)+N2(V6)=>N2(V7)+N2(V7)      ",&
   "O2(V1)+O2(V1)=>O2+O2(V2)          ","O2(V1)+O2(V2)=>O2+O2(V3)          ","O2(V1)+O2(V3)=>O2+O2(V4)          "/
  data reaction_sign(163:216) &
  /"O2(V2)+O2=>O2(V1)+O2(V1)          ","O2(V2)+O2(V2)=>O2(V1)+O2(V3)      ","O2(V2)+O2(V3)=>O2(V1)+O2(V4)      ",&
   "O2(V3)+O2=>O2(V2)+O2(V1)          ","O2(V3)+O2(V1)=>O2(V2)+O2(V2)      ","O2(V3)+O2(V3)=>O2(V2)+O2(V4)      ",&
   "O2(V4)+O2=>O2(V3)+O2(V1)          ","O2(V4)+O2(V1)=>O2(V3)+O2(V2)      ","O2(V4)+O2(V2)=>O2(V3)+O2(V3)      ",&
   "NH3(V2)+O2=>NH3+O2                ","NH3(V4)+O2=>NH3(V2)+O2            ","NH3(V13)+O2=>NH3(V4)+O2           ",&
   "NH3(V2)+NH3=>NH3+NH3              ","NH3(V4)+NH3=>NH3(V2)+NH3          ","NH3(V13)+NH3=>NH3(V4)+NH3         ",&
   "H+O2(V1)=>O+OH                    ","H+O2(V2)=>O+OH                    ","H+O2(V3)=>O+OH                    ",&
   "H+O2(V4)=>O+OH                    ","H2O+O2(V1)=>H+OH+O2               ","H2O+O2(V2)=>H+OH+O2               ",&
   "H2O+O2(V3)=>H+OH+O2               ","H2O+O2(V4)=>H+OH+O2               ","H+O+O2(V1)=>OH*+O2                ",&
   "H+O+O2(V2)=>OH*+O2                ","H+O+O2(V3)=>OH*+O2                ","H+O+O2(V4)=>OH*+O2                ",&
   "O2(V1)+H2=>O+O+H2                 ","O2(V1)+H2O=>O+O+H2O               ","O2(V2)+H2=>O+O+H2                 ",&
   "O2(V2)+H2O=>O+O+H2O               ","O2(V3)+H2=>O+O+H2                 ","O2(V3)+H2O=>O+O+H2O               ",&
   "O2(V4)+H2=>O+O+H2                 ","O2(V4)+H2O=>O+O+H2O               ","H+OH+O2(V1)=>H2O+O2               ",&
   "H+OH+O2(V2)=>H2O+O2               ","H+OH+O2(V3)=>H2O+O2               ","H+OH+O2(V4)=>H2O+O2               ",&
   "H2+O2(V1)=>HO2+H                  ","H2+O2(V2)=>HO2+H                  ","H2+O2(V3)=>HO2+H                  ",&
   "H2+O2(V4)=>HO2+H                  ","O2(V1)+OH=>HO2+O                  ","O2(V2)+OH=>HO2+O                  ",&
   "O2(V3)+OH=>HO2+O                  ","O2(V4)+OH=>HO2+O                  ","H2O+O2(V1)=>HO2+OH                ",&
   "H2O+O2(V2)=>HO2+OH                ","H2O+O2(V3)=>HO2+OH                ","H2O+O2(V4)=>HO2+OH                ",&
   "H2O2+O2(V1)=>HO2+HO2              ","H2O2+O2(V2)=>HO2+HO2              ","H2O2+O2(V3)=>HO2+HO2              "/
  data reaction_sign(217:270) &
  /"H2O2+O2(V4)=>HO2+HO2              ","OH*+O2(V1)=>H+O+O2                ","OH*+O2(V2)=>H+O+O2                ",&
   "OH*+O2(V3)=>H+O+O2                ","OH*+O2(V4)=>H+O+O2                ","OH+O2(V1)=>OH*+O2                 ",&
   "OH+O2(V2)=>OH*+O2                 ","OH+O2(V3)=>OH*+O2                 ","OH+O2(V4)=>OH*+O2                 ",&
   "NO+O2(V1)=>NO2+O                  ","NO+O2(V2)=>NO2+O                  ","NO+O2(V3)=>NO2+O                  ",&
   "NO+O2(V4)=>NO2+O                  ","N2+O2(V1)=>N2O+O                  ","N2+O2(V2)=>N2O+O                  ",&
   "N2+O2(V3)=>N2O+O                  ","N2+O2(V4)=>N2O+O                  ","NH2+O2(V1)=>H2NO+O                ",&
   "NH2+O2(V2)=>H2NO+O                ","NH2+O2(V3)=>H2NO+O                ","NH2+O2(V4)=>H2NO+O                ",&
   "NH2+O2(V1)=>HNO+OH                ","NH2+O2(V2)=>HNO+OH                ","NH2+O2(V3)=>HNO+OH                ",&
   "NH2+O2(V4)=>HNO+OH                ","NH+O2(V1)=>HNO+O                  ","NH+O2(V2)=>HNO+O                  ",&
   "NH+O2(V3)=>HNO+O                  ","NH+O2(V4)=>HNO+O                  ","NH+O2(V1)=>NO+OH                  ",&
   "NH+O2(V2)=>NO+OH                  ","NH+O2(V3)=>NO+OH                  ","NH+O2(V4)=>NO+OH                  ",&
   "H2NO+O2(V1)=>HNO+HO2              ","H2NO+O2(V2)=>HNO+HO2              ","H2NO+O2(V3)=>HNO+HO2              ",&
   "H2NO+O2(V4)=>HNO+HO2              ","HNOH+O2(V1)=>HNO+HO2              ","HNOH+O2(V2)=>HNO+HO2              ",&
   "HNOH+O2(V3)=>HNO+HO2              ","HNOH+O2(V4)=>HNO+HO2              ","HON+O2(V1)=>NO2+OH                ",&
   "HON+O2(V2)=>NO2+OH                ","HON+O2(V3)=>NO2+OH                ","HON+O2(V4)=>NO2+OH                ",&
   "N+O2(V1)=>NO+O                    ","N+O2(V2)=>NO+O                    ","N+O2(V3)=>NO+O                    ",&
   "N+O2(V4)=>NO+O                    ","N2(V1)+O=>N+NO                    ","N2(V2)+O=>N+NO                    ",&
   "N2(V3)+O=>N+NO                    ","N2(V4)+O=>N+NO                    ","N2(V5)+O=>N+NO                    "/
  data reaction_sign(271:324) &
  /"N2(V6)+O=>N+NO                    ","N2(V7)+O=>N+NO                    ","N2(V8)+O=>N+NO                    ",&
   "N2(V1)+O2=>N2O+O                  ","N2(V2)+O2=>N2O+O                  ","N2(V3)+O2=>N2O+O                  ",&
   "N2(V4)+O2=>N2O+O                  ","N2(V5)+O2=>N2O+O                  ","N2(V6)+O2=>N2O+O                  ",&
   "N2(V7)+O2=>N2O+O                  ","N2(V8)+O2=>N2O+O                  ","N2(V1)+H2O=>NH2+NO                ",&
   "N2(V2)+H2O=>NH2+NO                ","N2(V3)+H2O=>NH2+NO                ","N2(V4)+H2O=>NH2+NO                ",&
   "N2(V5)+H2O=>NH2+NO                ","N2(V6)+H2O=>NH2+NO                ","N2(V7)+H2O=>NH2+NO                ",&
   "N2(V8)+H2O=>NH2+NO                ","N2(V1)+H=>NH+N                    ","N2(V2)+H=>NH+N                    ",&
   "N2(V3)+H=>NH+N                    ","N2(V4)+H=>NH+N                    ","N2(V5)+H=>NH+N                    ",&
   "N2(V6)+H=>NH+N                    ","N2(V7)+H=>NH+N                    ","N2(V8)+H=>NH+N                    ",&
   "N2(V1)+OH=>NH+NO                  ","N2(V2)+OH=>NH+NO                  ","N2(V3)+OH=>NH+NO                  ",&
   "N2(V4)+OH=>NH+NO                  ","N2(V5)+OH=>NH+NO                  ","N2(V6)+OH=>NH+NO                  ",&
   "N2(V7)+OH=>NH+NO                  ","N2(V8)+OH=>NH+NO                  ","N2(V1)+H2O=>N+N+H2O               ",&
   "N2(V2)+H2O=>N+N+H2O               ","N2(V3)+H2O=>N+N+H2O               ","N2(V4)+H2O=>N+N+H2O               ",&
   "N2(V5)+H2O=>N+N+H2O               ","N2(V6)+H2O=>N+N+H2O               ","N2(V7)+H2O=>N+N+H2O               ",&
   "N2(V8)+H2O=>N+N+H2O               ","N2(V1)+OH=>NNH+O                  ","N2(V2)+OH=>NNH+O                  ",&
   "N2(V3)+OH=>NNH+O                  ","N2(V4)+OH=>NNH+O                  ","N2(V5)+OH=>NNH+O                  ",&
   "N2(V6)+OH=>NNH+O                  ","N2(V7)+OH=>NNH+O                  ","N2(V8)+OH=>NNH+O                  ",&
   "N2(V1)+H2O=>NNH+OH                ","N2(V2)+H2O=>NNH+OH                ","N2(V3)+H2O=>NNH+OH                "/
  data reaction_sign(325:378) &
  /"N2(V4)+H2O=>NNH+OH                ","N2(V5)+H2O=>NNH+OH                ","N2(V6)+H2O=>NNH+OH                ",&
   "N2(V7)+H2O=>NNH+OH                ","N2(V8)+H2O=>NNH+OH                ","N2(V1)+H2=>NNH+H                  ",&
   "N2(V2)+H2=>NNH+H                  ","N2(V3)+H2=>NNH+H                  ","N2(V4)+H2=>NNH+H                  ",&
   "N2(V5)+H2=>NNH+H                  ","N2(V6)+H2=>NNH+H                  ","N2(V7)+H2=>NNH+H                  ",&
   "N2(V8)+H2=>NNH+H                  ","N2(V1)+HO2=>NNH+O2                ","N2(V2)+HO2=>NNH+O2                ",&
   "N2(V3)+HO2=>NNH+O2                ","N2(V4)+HO2=>NNH+O2                ","N2(V5)+HO2=>NNH+O2                ",&
   "N2(V6)+HO2=>NNH+O2                ","N2(V7)+HO2=>NNH+O2                ","N2(V8)+HO2=>NNH+O2                ",&
   "N2(V1)+HNO=>NNH+NO                ","N2(V2)+HNO=>NNH+NO                ","N2(V3)+HNO=>NNH+NO                ",&
   "N2(V4)+HNO=>NNH+NO                ","N2(V5)+HNO=>NNH+NO                ","N2(V6)+HNO=>NNH+NO                ",&
   "N2(V7)+HNO=>NNH+NO                ","N2(V8)+HNO=>NNH+NO                ","N2(V1)+OH=>N2O+H                  ",&
   "N2(V2)+OH=>N2O+H                  ","N2(V3)+OH=>N2O+H                  ","N2(V4)+OH=>N2O+H                  ",&
   "N2(V5)+OH=>N2O+H                  ","N2(V6)+OH=>N2O+H                  ","N2(V7)+OH=>N2O+H                  ",&
   "N2(V8)+OH=>N2O+H                  ","NH3(V2)+O2=>NH2+H+O2              ","NH3(V4)+O2=>NH2+H+O2              ",&
   "NH3(V13)+O2=>NH2+H+O2             ","NH3(V2)+H=>NH2+H2                 ","NH3(V4)+H=>NH2+H2                 ",&
   "NH3(V13)+H=>NH2+H2                ","NH3(V2)+O=>NH2+OH                 ","NH3(V4)+O=>NH2+OH                 ",&
   "NH3(V13)+O=>NH2+OH                ","NH3(V2)+OH=>NH2+H2O               ","NH3(V4)+OH=>NH2+H2O               ",&
   "NH3(V13)+OH=>NH2+H2O              ","NH3(V2)+HO2=>NH2+H2O2             ","NH3(V4)+HO2=>NH2+H2O2             ",&
   "NH3(V13)+HO2=>NH2+H2O2            ","O2(A1)+N=>NO+O                    ","O2(A1)+O2=>O2+O2                  "/
  data reaction_sign(379:432) &
  /"O2(A1)+N2=>O2+N2                  ","O2(A1)+NO=>O2+NO                  ","O2(A1)+O3=>O2+O2+O(1D)            ",&
   "O2(A1)+O2(A1)=>O2+O2(B1)          ","O2(A1)+O2=>O3+O                   ","O2(A1)+O2(A1)=>O2+O2              ",&
   "O+O2(A1)+O2=>O+O2+O2              ","O2(A1)+O=>O2+O                    ","O2(B1)+O=>O2(A1)+O                ",&
   "O2(A1)+H2=>OH+OH                  ","O2(A1)+H2=>O2+H2                  ","O2(A1)+H=>OH+O                    ",&
   "O2(A1)+H=>HO2                     ","O2(A1)+H=>O2+H                    ","O2(A1)+H2=>H+HO2                  ",&
   "O2(A1)+H2O=>OH+HO2                ","O2(A1)+H2=>H2O+O(1D)              ","O2(A1)+OH=>H+O3                   ",&
   "O2(A1)+OH=>O+HO2                  ","O2(A1)+OH=>O2+OH                  ","O2(A1)+H2O2=>O2+H2O2              ",&
   "O2(A1)+HO2=>O2+HO2                ","NH2+O2(A1)=>H2NO+O                ","NH2+O2(A1)=>HNO+OH                ",&
   "H2NO+O2(A1)=>HNO+HO2              ","HNOH+O2(A1)=>HNO+HO2              ","O2(B1)+O=>O2+O(1D)                ",&
   "O2(B1)+O2=>O2(A1)+O2              ","O2(B1)+O3=>O2+O2+O                ","O2(B1)+N2=>O2(A1)+N2              ",&
   "O2(B1)+NO=>O2(A1)+NO              ","O2(B1)+O=>O2+O                    ","O2(B1)+O2(B1)=>O2(A1)+O2          ",&
   "O2(B1)+O3=>O2(A1)+O2+O            ","O2(B1)+O3=>O2+O3                  ","O2(B1)+O3=>O2(A1)+O3              ",&
   "O2(B1)+O2=>O2+O2                  ","O2*+O=>O2+O(1S)                   ","O2*+O2=>O2(B1)+O2(B1)             ",&
   "O2*+N2=>O2(B1)+N2                 ","O2*+O=>O2+O                       ","O2*+O=>O2(A1)+O(1D)               ",&
   "O2*+O=>O2(B1)+O(1D)               ","O2*+O2=>O2(A1)+O2                 ","O2*+O2=>O2(B1)+O2                 ",&
   "O2*+O2=>O2+O2                     ","O(1D)+O=>O+O                      ","O(1D)+O2=>O+O2                    ",&
   "O(1D)+O2=>O+O2(A1)                ","O(1D)+O2=>O+O2(B1)                ","O(1D)+O3=>O2+O+O                  ",&
   "O(1D)+O3=>O2+O2                   ","O(1D)+N2=>O+N2                    ","O(1D)+NO=>O2+N                    "/
  data reaction_sign(433:486) &
  /"O(1D)+N2O=>NO+NO                  ","O(1D)+NH3=>OH+NH2                 ","O(1D)+NH3=>H2O+NH                 ",&
   "O(1D)+NH3=>H2NO+H                 ","N2O+O(1D)=>N2+O2                  ","N2O+O(1S)=>N2+O2                  ",&
   "N2(A)+N=>N2+N                     ","N2(A)+N=>N2+N(2P)                 ","N2(A)+N2=>N2+N2                   ",&
   "N2(A)+N2(A)=>N2+N2(B)             ","N2(A)+N2(A)=>N2+N2(C)             ","N2(A)+O=>NO+N(2D)                 ",&
   "N2(A)+O=>N2+O(1S)                 ","N2(A)+O2=>N2+O2(A1)               ","N2(A)+O2=>N2+O2(B1)               ",&
   "N2(A)+O2=>N2O+O                   ","N2(A)+NO=>N2+NO                   ","N2(A)+N2O=>N2+N+NO                ",&
   "N2(A)+NO2=>N2+O+NO                ","N2(A)+O2=>N2+O+O                  ","N2(B)+N2=>N2(A)+N2                ",&
   "N2(B)+N2=>N2+N2                   ","N2(B)+NO=>N2(A)+NO                ","N2(B)+O2=>N2+O+O                  ",&
   "N2(B)+O=>NO+N(2D)                 ","N2(A')+N2=>N2(B)+N2               ","N2(A')+NO=>N2+N+O                 ",&
   "N2(A')+N2(A)=>N4^++E              ","N2(A')+N2(A')=>N4^++E             ","N2(A')+O2=>N2+O+O(1D)             ",&
   "N2(A')+O=>NO+N(2D)                ","N2(C)+N2=>N2(A')+N2               ","N2(C)+O2=>N2+O+O(1S)              ",&
   "N2(C)+O=>NO+N(2D)                 ","N2(C)+O2=>O+O(1D)+N2              ","N(2D)+H2=>H+NH                    ",&
   "N(2D)+NH3=>NH+NH2                 ","N(2P)+H2=>H+NH                    ","N(2D)+N2=>N+N2                    ",&
   "N(2P)+N=>N+N                      ","N(2P)+N=>N(2D)+N                  ","N(2P)+N2=>N+N2                    ",&
   "N(2P)+N(2D)=>N2^++E               ","N(2P)+NO2=>N2+O2                  ","N(2D)+NO2=>N2+O2                  ",&
   "N(2P)+NO2=>N2+O+O                 ","N(2D)+NO2=>N2+O+O                 ","NO+N(2D)=>N2+O                    ",&
   "NO+N(2P)=>N2+O                    ","N2O+N(2D)=>N2+NO                  ","N2O+N(2P)=>N2+NO                  ",&
   "N+N+N2=>N2(A)+N2                  ","N+N+O2=>N2(A)+O2                  ","N+N+NO=>N2(A)+NO                  "/
  data reaction_sign(487:540) &
  /"N+N+N=>N2(A)+N                    ","N+N+O=>N2(A)+O                    ","N+N+N2=>N2(B)+N2                  ",&
   "N+N+O2=>N2(B)+O2                  ","N+N+NO=>N2(B)+NO                  ","N+N+N=>N2(B)+N                    ",&
   "N+N+O=>N2(B)+O                    ","O^-+O=>O2+E                       ","O^-+O2=>O3+E                      ",&
   "O^-+O2(A1)=>O3+E                  ","O^-+O2(B1)=>O+O2+E                ","O^-+O3=>O2+O2+E                   ",&
   "O^-+O2(A1)=>O2^-+O                ","O^-+O3=>O3^-+O                    ","O^++H=>H^++O                      ",&
   "O^++NH3=>NH3^++O                  ","O2^++O2+O2=>O4^++O2               ","O2^++NH3=>NH3^++O2                ",&
   "O4^++O=>O2^++O3                   ","O4^++O2=>O2^++O2+O2               ","O4^++O(1D)=>O2^++O3               ",&
   "O4^++O(1S)=>O2^++O3               ","O2^-+O=>O3+E                      ","O2^-+O2(A1)=>O2+O2+E              ",&
   "O2^-+O2(B1)=>O2+O2+E              ","O2^-+O=>O^-+O2                    ","O2^-+O3=>O3^-+O2                  ",&
   "O2^-+H2=>H2O2+E                   ","O2^-+H=>HO2+E                     ","O2^-+OH=>OH^-+O2                  ",&
   "O2^-+H=>OH^-+O                    ","O3^-+O=>O2+O2+E                   ","O3^-+O=>O2^-+O2                   ",&
   "H3^++NH3=>NH4^++H2                ","H2^++NH3=>NH3^++H2                ","H2^++NH3=>NH4^++H                 ",&
   "H2^++NH2=>NH2^++H2                ","H2^++NH2=>NH3^++H                 ","H2^++NH=>NH^++H2                  ",&
   "H2^++NH=>NH2^++H                  ","H2^++N2=>N2H^++H                  ","H^++NH=>NH^++H                    ",&
   "H^++NH2=>NH2^++H                  ","H^++NH3=>NH3^++H                  ","N^++NH3=>NH2^++NH                 ",&
   "N^++NH3=>NH3^++N                  ","N^++NH3=>N2H^++H2                 ","N^++H2=>NH^++H                    ",&
   "N2^++NH3=>NH3^++N2                ","N2^++H2=>N2H^++H                  ","N2^++O=>O^++N2                    ",&
   "N2^++N=>N^++N2                    ","N2^++O2=>O2^++N2                  ","N2^++N2+N2=>N4^++N2               "/
  data reaction_sign(541:594) &
  /"N3^++N=>N2^++N2                   ","N4^++N=>N^++N2+N2                 ","N4^++N2=>N2^++N2+N2               ",&
   "N4^++O2=>O2^++N2+N2               ","NH^++NH3=>NH3^++NH                ","NH^++NH3=>NH4^++N                 ",&
   "NH^++N2=>N2H^++N                  ","NH^++H2=>H3^++N                   ","NH^++H2=>NH2^++H                  ",&
   "NH^++O2=>O2^++NH                  ","NH2^++NH3=>NH3^++NH2              ","NH2^++NH3=>NH4^++NH               ",&
   "NH2^++H2=>NH3^++H                 ","NH3^++NH3=>NH4^++NH2              ","NH3^++NH3=>H^++NH2+NH3            ",&
   "NH3^++NH3=>NH2^++H2+NH2           ","NH3^++H2=>NH4^++H                 ","NH3^++H2=>H2^++NH3                ",&
   "NH3^++H2=>H2^++NH2+H              ","NH3^++H2=>H^++NH3+H               ","N2H^++NH3=>NH4^++N2               ",&
   "OH^-+O=>HO2+E                     ","OH^-+H=>H2O+E                     ","E+N2^+=>N+N                       ",&
   "E+N2^+=>N+N(2D)                   ","E+O2^+=>O+O                       ","E+O2^+=>O+O(1D)                   ",&
   "E+O2^+=>O+O(1S)                   ","E+O4^+=>O2+O2                     ","E+N4^+=>N2+N2                     ",&
   "E+O2^++E=>O2+E                    ","E+O2^++O2=>O2+O2                  ","E+O4^++E=>O2+O2+E                 ",&
   "E+NH^+=>N+H                       ","E+NH2^+=>NH+H                     ","E+NH2^+=>N+H+H                    ",&
   "E+NH3^+=>NH+H+H                   ","E+NH3^+=>NH2+H                    ","E+NH4^+=>NH3+H                    ",&
   "E+NH4^+=>NH2+H+H                  ","E+N2H^+=>N2+H                     ","E+H2^+=>H+H                       ",&
   "E+H3^+=>H+H+H                     ","E+H3^+=>H+H2                      ","E+NH4^+=>NH2+H2                   ",&
   "E+N2H^+=>NH+N                     ","E+E+N^+=>N+E                      ","E+N^++ANY_NEUTRAL=>N+ANY_NEUTRAL  ",&
   "E+N2^++E=>N2+E                    ","E+N2^++ANY_NEUTRAL=>N2+ANY_NEUTRAL","E+H2O^+=>OH+H                     ",&
   "E+H2O^+=>O+H2                     ","E+H2O^+=>O+H+H                    ","E+O2+ANY_NEUTRAL=>O2^-+ANY_NEUTRAL"/
  data reaction_sign(595:595) &
  /"E+O+ANY_NEUTRAL=>O^-+ANY_NEUTRAL  "/
  data bolsig_species(1:bolsig_species_max) &
  /"NH3","O2 ","N2 ","H2O","NH2","NH ","N  ","O3 ","O  "/
contains
!-----------------------------------------------------------------------------------------------------------------------------------
!
! initialization
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_init()
  implicit none
  character(256) :: string
  integer :: i, j, k
  write(*,"(/,A)") "ZDPlasKin (version " // "2.0a" // ") INIT:"
  if( lZDPlasKin_init ) call ZDPlasKin_stop("   ERROR: the ZDPlasKin library has been initialized")
  write(string,*) species_max
  write(*,"(2x,A)")  "species        ... " // trim(adjustl(string))
  write(string,*) reactions_max
  write(*,"(2x,A)")  "reactions      ... " // trim(adjustl(string))
  if(species_max<=0 .or. reactions_max<=0) call ZDPlasKin_stop("   ERROR: wrong preconfig data")
  write(*,"(2x,A,$)") "BOLSIG+ loader ... " // trim(adjustl(bolsigfile)) // " : "
  call ZDPlasKin_bolsig_Init(bolsigfile)
  do i = 1, bolsig_species_max
    call ZDPlasKin_bolsig_ReadCollisions(trim(bolsig_species(i)))
    j = bolsig_collisions_max
    call ZDPlasKin_bolsig_GetCollisions(k,bolsig_collisions_max)
    if(bolsig_collisions_max <= j) then
      write(*,*)
      call ZDPlasKin_stop("ERROR: wrong file or missing data " // &
                        "(" // trim(adjustl(bolsigfile)) // ": <" // trim(bolsig_species(i)) // ">).")
    endif
  enddo
  if(bolsig_species_max /= k) then
    write(*,*)
    call ZDPlasKin_stop("ERROR: internal error in BOLSIG+ loader")
  endif
  write(string,*) bolsig_species_max
  write(*,"(A,$)") trim(adjustl(string)) // " species & "
  write(string,*) bolsig_collisions_max
  write(*,"(A)")   trim(adjustl(string)) // " collisions"
  write(*,"(2x,A,$)") "species  link  ... "
  j = 0
  do i = 1, bolsig_species_max
    j = j + 1
    k = 1
    do while(k<=species_max .and. bolsig_species_index(i)<=0)
      call ZDPlasKin_bolsig_GetSpeciesName(string,i)
      if(trim(species_name(k)) == trim(string)) then
        bolsig_species_index(i) = k
      else
        k = k + 1
      endif
    enddo
    if(bolsig_species_index(i) <= 0) call ZDPlasKin_stop("cannot find species link for <" // trim(string) // ">")
  enddo
  write(string,*) j
  write(*,"(A)") trim(adjustl(string))
  write(*,"(2x,A,$)") "process  link  ... "
  i = 1
  j = 1
  do while(i<=reactions_max .and. j<=bolsig_rates_max)
    if(reaction_sign(i)(1:7) == "bolsig:") then
      k = 1
      do while(k<=bolsig_collisions_max .and. bolsig_pointer(j)<=0)
        call ZDPlasKin_bolsig_GetReactionName(string,k)
        if(trim(string) == trim(reaction_sign(i)(8:))) then
          bolsig_pointer(j) = k
        else
          k = k + 1
        endif
      enddo
      if(bolsig_pointer(j) <= 0) call ZDPlasKin_stop("cannot find processes link for <" // trim(reaction_sign(i)) // ">")
      j = j + 1
    endif
    i = i + 1
  enddo
  if(j <= bolsig_rates_max) then
    call ZDPlasKin_stop("internal error")
  else
    write(string,*) bolsig_rates_max
    write(*,"(A)") trim(adjustl(string))
  endif
  i = 0
  do while((1.0d0+10.0d0**(i-1)) /= 1.0d0)
    i = i - 1
  enddo
  mach_accur = 10.0d0**i
  mach_tiny  = sqrt( tiny(mach_tiny) )
  lZDPlasKin_init = .true.
  call ZDPlasKin_reset()
  write(*,"(A,/)") "ZDPlasKin INIT DONE"
  return
end subroutine ZDPlasKin_init
!-----------------------------------------------------------------------------------------------------------------------------------
!
! timestep integration using implicit solver dvode_f90
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_timestep(time,dtime)
  use dvode_f90_m, only : dvode_f90
  implicit none
  double precision, intent(in)    ::  time
  double precision, intent(inout) :: dtime
  double precision, save :: densav(vode_neq) = 0.0d0, cfgsav(3) = 0.0d0
  double precision :: tout
  if(.not. lZDPlasKin_init) call ZDPlasKin_init()
  if( lqtplaskin .and. lqtplaskin_first ) call ZDPlasKin_write_qtplaskin(time)
  if(time < tsav) vode_istate = 1
  tsav = time
  if(dtime > 0.0d0) then
    vode_itask = 1
    tout = time + dtime
    if(dtime < mach_accur*abs(tout)) &
      call ZDPlasKin_stop("ZDPlasKin ERROR: dtime parameter is too small (subroutine ZDPlasKin_timestep)")
  else
    vode_itask = 2
    tout = ( 1.0d0 + mach_accur ) * time + mach_tiny
  endif
  dens_loc(1:species_max,0) = density(:)
  dens_loc(1:species_max,1) = 0.5d0 * ( density(:) + abs( density(:) ) )
  if(any(dens_loc(1:species_max,1) /= densav(1:species_max))) vode_istate = 1
  densav(1:species_max) = dens_loc(1:species_max,1)
  if(vode_istate /= 1 .and. any( abs(cfgsav(:)-ZDPlasKin_cfg(1:3)) > cfg_rtol*abs(cfgsav(:)+ZDPlasKin_cfg(1:3)) )) vode_istate = 1
  cfgsav(:) = ZDPlasKin_cfg(1:3)
  if( lgas_heating ) then
    if(ZDPlasKin_cfg(1) /= densav(species_max+1)) vode_istate = 1
    densav(species_max+1) = ZDPlasKin_cfg(1)
  endif
  call dvode_f90(ZDPlasKin_fex,vode_neq,densav,tsav,tout,vode_itask,vode_istate,vode_options,j_fcn=ZDPlasKin_jex)
  if(vode_istate < 0) then
    write(*,"(A,1pd11.4)") "Tgas   =", ZDPlasKin_cfg(1)
    write(*,"(A,1pd11.4)") "    Te =", ZDPlasKin_cfg(4)
    call ZDPlasKin_stop("ZDPlasKin ERROR: DVODE solver issued an error (subroutine ZDPlasKin_timestep)")
  endif
  if( lgas_heating ) ZDPlasKin_cfg(1) = densav(species_max+1)
  density(:) = dens_loc(1:species_max,0) - dens_loc(1:species_max,1) + densav(1:species_max)
  if(dtime <= 0.0d0) dtime = tsav - time
  if( lstat_accum ) then
    call ZDPlasKin_get_rates(SOURCE_TERMS=dens_loc(1:species_max,0),REACTION_RATES=rrt_loc)
    stat_dens(:) = stat_dens(:) + dtime * density(:)
    stat_src(:)  = stat_src(:)  + dtime * dens_loc(1:species_max,0)
    stat_rrt(:)  = stat_rrt(:)  + dtime * rrt_loc(:)
    stat_time    = stat_time    + dtime
  endif
  if( lqtplaskin ) call ZDPlasKin_write_qtplaskin(time+dtime)
  return
end subroutine ZDPlasKin_timestep
!-----------------------------------------------------------------------------------------------------------------------------------
!
! timestep integration using explicit Euler method
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_timestep_explicit(time,dtime,rtol_loc,atol_loc,switch_implicit)
  implicit none
  double precision, intent(in) ::  time, rtol_loc, atol_loc
  double precision, intent(inout) :: dtime
  double precision, optional, intent(in) :: switch_implicit
  double precision :: time_loc, time_end, dtime_loc, dtime_max
  logical, save :: lwarn = .true.
  if(.not. lZDPlasKin_init) call ZDPlasKin_init()
  if( lqtplaskin .and. lqtplaskin_first ) call ZDPlasKin_write_qtplaskin(time)
  if(rtol_loc <= 0.0d0) call ZDPlasKin_stop("ZDPlasKin ERROR: rtol_loc must be positive (subroutine ZDPlasKin_timestep_explicit)")
  if(atol_loc <= 0.0d0) call ZDPlasKin_stop("ZDPlasKin ERROR: atol_loc must be positive (subroutine ZDPlasKin_timestep_explicit)")
  tsav     = time
  time_loc = 0.0d0
  time_end = 0.5d0 * ( dtime + abs(dtime) ) + mach_tiny
  do while(time_loc < time_end)
    dens_loc(1:species_max,0) = density(:)
    if( lgas_heating ) dens_loc(species_max+1,0) = ZDPlasKin_cfg(1)
    dens_loc(:,1) = 0.5d0 * ( dens_loc(:,0) + abs( dens_loc(:,0) ) )
    call ZDPlasKin_fex(vode_neq,tsav,dens_loc(:,1),dens_loc(:,2))
    where(dens_loc(:,2) >= 0.0d0)
      dens_loc(:,3) = + dens_loc(:,2) /    ( rtol_loc * dens_loc(:,1) + atol_loc ) 
    elsewhere
      dens_loc(:,3) = - dens_loc(:,2) / min( rtol_loc * dens_loc(:,1) + atol_loc , dens_loc(:,1) + mach_tiny )
    endwhere
    dtime_loc = 1.0d0 / ( maxval( dens_loc(:,3) ) + mach_tiny )
    if(dtime > 0.0d0) then
      dtime_max = dtime - time_loc
      dtime_loc = min( dtime_loc , dtime_max )
      if( present(switch_implicit) ) then
        if(dtime_loc*switch_implicit < dtime_max) then
          if(lprint .and. lwarn) then
            write(*,"(A,/,A,1pd9.2,A)") "ZDPlasKin INFO: low efficiency of Euler method (subroutine ZDPlasKin_timestep_explicit)", &
                        "                ZDPlasKin_timestep subroutine will be used in similar conditions (", switch_implicit, ")"
            lwarn = .false.
          endif
          time_loc = tsav
          density(:) = dens_loc(1:species_max,0)
          if( lgas_heating ) ZDPlasKin_cfg(1) = dens_loc(species_max+1,0)
          call ZDPlasKin_timestep(time_loc,dtime_max)
          return
        endif
      endif
    else
      dtime = dtime_loc
    endif
    time_loc = time_loc + dtime_loc
    tsav     = time     +  time_loc
    density(:) = dens_loc(1:species_max,0) + dtime_loc * dens_loc(1:species_max,2)
    if( lgas_heating ) ZDPlasKin_cfg(1) = dens_loc(species_max+1,0) + dtime_loc * dens_loc(species_max+1,2)
  enddo
  if( lstat_accum ) then
    call ZDPlasKin_get_rates(SOURCE_TERMS=dens_loc(1:species_max,0),REACTION_RATES=rrt_loc)
    stat_dens(:) = stat_dens(:) + dtime * density(:)
    stat_src(:)  = stat_src(:)  + dtime * dens_loc(1:species_max,0)
    stat_rrt(:)  = stat_rrt(:)  + dtime * rrt_loc(:)
    stat_time    = stat_time    + dtime
  endif
  if( lqtplaskin ) call ZDPlasKin_write_qtplaskin(time+dtime)
  return
end subroutine ZDPlasKin_timestep_explicit
!-----------------------------------------------------------------------------------------------------------------------------------
!
! update BOLSIG+ solution and get electron parameters
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_bolsig_rates(lbolsig_force)
  implicit none
  logical, optional, intent(in) :: lbolsig_force
  logical :: lforce
  integer :: i, j, k
  integer, save :: bolsig_points_max
  logical, save :: lfirst = .true., leecol = .true.
  double precision :: error, density_loc, cfg_loc(6+bolsig_species_max)
  double precision, save :: low_density_limit = bolsig_rtol, bolsig_mesh_a, bolsig_mesh_b
  double precision, save, allocatable :: bolsig_cfg(:,:), bolsig_reslt(:,:)
  if( lfirst ) then
    if(.not. lZDPlasKin_init) call ZDPlasKin_init()
    bolsig_mesh_a = 1.0d0 / log( 1.0d0 + bolsig_rtol )
    bolsig_mesh_b = bolsig_mesh_a * log( bolsig_field_min ) - 0.5d0
    bolsig_points_max = int( bolsig_mesh_a * log( bolsig_field_max ) - bolsig_mesh_b )
    allocate(bolsig_rates(bolsig_collisions_max), &
             bolsig_cfg(6+bolsig_species_max,0:bolsig_points_max), &
             bolsig_reslt(10+bolsig_collisions_max,0:bolsig_points_max),stat=i)
    if(i /= 0) call ZDPlasKin_stop("ZDPlasKin ERROR: memory allocation error (subroutine ZDPlasKin_bolsig_rates)")
    bolsig_cfg(:,:) = 0.0d0
    lfirst = .false.
  endif
  if( present(lbolsig_force) ) then
    lforce = lbolsig_force
  else
    lforce = .false.
  endif
  if(ZDPlasKin_cfg(1) <= 0.0d0) &
    call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined GAS_TEMPERATURE (subroutine ZDPlasKin_bolsig_rates)")
  if(.not. lbolsig_Maxwell_EEDF ) then
    if(ZDPlasKin_cfg(2) < 0.0d0) &
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined REDUCED_FREQUENCY (subroutine ZDPlasKin_bolsig_rates)")
    if(ZDPlasKin_cfg(3) < 0.0d0) &
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined REDUCED_FIELD (subroutine ZDPlasKin_bolsig_rates)")
    ZDPlasKin_cfg(4) = 0.0d0
  else
    if(ZDPlasKin_cfg(4) <= 0.0d0) then
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined ELECTRON_TEMPERATURE (subroutine ZDPlasKin_bolsig_rates)")
    elseif(lprint .and. ZDPlasKin_cfg(4) < ZDPlasKin_cfg(1)) then
      write(*,"(A)") "ZDPlasKin INFO: ELECTRON_TEMPERATURE is below GAS_TEMPERATURE (subroutine ZDPlasKin_bolsig_rates)"
    endif
    ZDPlasKin_cfg(2:3) = 0.0d0
  endif
  density_loc = 0.5d0 * ( sum(density(bolsig_species_index(:))) + sum(abs(density(bolsig_species_index(:)))) )
  if(density_loc <= mach_tiny) then
    call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined densities configured for BOLSIG+ solver " // &
                                                                     "(subroutine ZDPlasKin_bolsig_rates)")
  elseif( lprint ) then
    call ZDPlasKin_get_density_total(ALL_NEUTRAL=error)
    error = abs( 1.0d0 - density_loc / error )
    if(error > low_density_limit) then
      write(*,"(A,1pd9.2)") "ZDPlasKin INFO: the density of species not configured for BOLSIG+ solver exceeds", error
      low_density_limit = sqrt( low_density_limit )
    endif
  endif
  cfg_loc(1:4) = ZDPlasKin_cfg(1:4)
  cfg_loc(2)   = cfg_loc(2) * 1.0d-6
  cfg_loc(6)   = 0.5d0 * ( density(species_electrons) + abs(density(species_electrons)) )
  cfg_loc(5)   = cfg_loc(6) * 1.0d6
  cfg_loc(6)   = cfg_loc(6) / density_loc
  if(cfg_loc(6) < bolsig_eecol_frac) then
    cfg_loc(6) = 0.0d0
  elseif(lprint .and. leecol) then
    write(*,"(A)") "ZDPlasKin INFO: set electron-electron collisions ON ..."
    leecol = .false.
  endif
  cfg_loc(7:) = 0.5d0 * ( density(bolsig_species_index(:)) + abs(density(bolsig_species_index(:))) ) / density_loc
  if(lbolsig_Maxwell_EEDF .or. bolsig_points_max==0) then
    lforce = .true.
    i = 0
  else
    error = min( max( cfg_loc(3) , bolsig_field_min ) , bolsig_field_max )
    i = int( bolsig_mesh_a * log( error ) - bolsig_mesh_b )
    i = max(0,min(i,bolsig_points_max))
  endif
  if( lforce ) then
    error = 2.0d0
  else
    if(lbolsig_ignore_gas_temp .and. bolsig_cfg(1,i)>0.0d0) then
      cfg_loc(1) = bolsig_cfg(1,i)
      error = 0.0d0
    else
      error = abs( ( cfg_loc(1) - bolsig_cfg(1,i) ) / ( 0.5d0 * ( cfg_loc(1) + bolsig_cfg(1,i) ) + mach_tiny) ) / bolsig_rtol_half
    endif
    if(error <= 1.0d0) then
      error = abs( ( cfg_loc(2) - bolsig_cfg(2,i) ) / ( 0.5d0 * ( cfg_loc(2) + bolsig_cfg(2,i) ) + mach_tiny) ) / bolsig_rtol_half
      if(error <= 1.0d0) then
        error = abs( ( cfg_loc(3) - bolsig_cfg(3,i) ) / ( 0.5d0 * ( cfg_loc(3) + bolsig_cfg(3,i) ) + mach_tiny) ) / bolsig_rtol
        if(error <= 1.0d0) then
          error = abs( ( max(cfg_loc(6),bolsig_eecol_frac) - max(bolsig_cfg(6,i),bolsig_eecol_frac) ) &
           / ( 0.5d0 * ( max(cfg_loc(6),bolsig_eecol_frac) + max(bolsig_cfg(6,i),bolsig_eecol_frac) ) + mach_tiny) ) &
           / bolsig_rtol_half
          if(error <= 1.0d0) error = maxval( abs( cfg_loc(7:) - bolsig_cfg(7:,i) ) ) &
                                     / ( 0.5d0 * maxval( cfg_loc(7:) + bolsig_cfg(7:,i) ) ) / bolsig_rtol
        endif
      endif
    endif
  endif
  if(error > 1.0d0) then
    j = 6 + bolsig_species_max
    k = 10 + bolsig_collisions_max
    bolsig_cfg(:,i) = cfg_loc(:)
    call ZDPlasKin_bolsig_SolveBoltzmann(j,bolsig_cfg(1:j,i),k,bolsig_reslt(1:k,i))
    if(.not. lbolsig_Maxwell_EEDF) then
      bolsig_reslt(2,i) = bolsig_reslt(2, i) * eV_to_K / 1.5d0
    else
      bolsig_reslt(2,i) = cfg_loc(4)
    endif
    bolsig_reslt(3, i) = bolsig_reslt(3, i) * 1.0d-2
    bolsig_reslt(4, i) = bolsig_reslt(4, i) * 1.0d-2 / density_loc
    bolsig_reslt(5, i) = bolsig_reslt(5, i) * 1.0d-2
    bolsig_reslt(6, i) = bolsig_reslt(6, i) * 1.0d-2
    bolsig_reslt(7:,i) = bolsig_reslt(7:,i) * 1.0d6
  endif
  ZDPlasKin_cfg(3:12) = bolsig_reslt(:10,i)
  bolsig_rates(:)     = bolsig_reslt(11:,i)
  return
end subroutine ZDPlasKin_bolsig_rates
!-----------------------------------------------------------------------------------------------------------------------------------
!
! get index of species
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_get_species_index(str,i)
  implicit none
  character(*), intent(in ) :: str
  integer,      intent(out) :: i
  character(species_length) :: string
  integer :: j, istr
  if(.not. lZDPlasKin_init) call ZDPlasKin_init()
  string = trim(adjustl(str))
  istr   = len_trim(string)
  do i = 1, istr
    j = iachar(string(i:i))
    if(j>=97 .and. j<=122) string(i:i) = achar(j-32)
  enddo
  i = 0
  j = 0
  do while(i==0 .and. j<species_max)
    j = j + 1
    if(string(1:istr) == trim(species_name(j))) i = j
  enddo
  if(i <= 0) &
    call ZDPlasKin_stop("ZDPlasKin ERROR: cannot identify species <"//trim(str)//"> (subroutine ZDPlasKin_get_species_index)")
  return
end subroutine ZDPlasKin_get_species_index
!-----------------------------------------------------------------------------------------------------------------------------------
!
! set/get density for species
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_set_density(string,DENS,LDENS_CONST)
  implicit none
  character(*), intent(in) :: string
  logical, optional, intent(in) :: LDENS_CONST
  double precision, optional, intent(in) :: DENS
  integer :: i
  call ZDPlasKin_get_species_index(string,i)
  if( present(DENS) ) density(i) = DENS
  if( present(LDENS_CONST) ) then
    density_constant(i) = LDENS_CONST
    ldensity_constant   = any( density_constant(:) )
  endif
  return
end subroutine ZDPlasKin_set_density
subroutine ZDPlasKin_get_density(string,DENS,LDENS_CONST)
  implicit none
  character(*), intent(in ) :: string
  logical, optional, intent(out) :: LDENS_CONST
  double precision, optional, intent(out) :: DENS
  integer :: i
  call ZDPlasKin_get_species_index(string,i)
  if( present( DENS)       )  DENS       = density(i)
  if( present(LDENS_CONST) ) LDENS_CONST = density_constant(i)
  return
end subroutine ZDPlasKin_get_density
!-----------------------------------------------------------------------------------------------------------------------------------
!
! get total densities
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_get_density_total(ALL_SPECIES,ALL_NEUTRAL,ALL_ION_POSITIVE,ALL_ION_NEGATIVE,ALL_CHARGE)
  double precision, optional, intent(out) :: ALL_SPECIES, ALL_NEUTRAL, ALL_ION_POSITIVE, ALL_ION_NEGATIVE, ALL_CHARGE
  if(.not. lZDPlasKin_init) call ZDPlasKin_init()
  if( present(ALL_SPECIES)      ) ALL_SPECIES      = sum(density(:))
  if( present(ALL_NEUTRAL)      ) ALL_NEUTRAL      = sum(density(:), mask = species_charge(:)==0)
  if( present(ALL_ION_POSITIVE) ) ALL_ION_POSITIVE = sum(density(:), mask = species_charge(:)>0)
  if( present(ALL_ION_NEGATIVE) ) ALL_ION_NEGATIVE = sum(density(:), mask = species_charge(:)<0) - density(species_electrons)
  if( present(ALL_CHARGE)       ) ALL_CHARGE       = sum(density(:) * dble(species_charge(:)))
  return
end subroutine ZDPlasKin_get_density_total
!-----------------------------------------------------------------------------------------------------------------------------------
!
! get species source terms & reaction rates
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_get_rates(SOURCE_TERMS,REACTION_RATES,SOURCE_TERMS_MATRIX,MEAN_DENSITY, &
                               MEAN_SOURCE_TERMS,MEAN_REACTION_RATES,MEAN_SOURCE_TERMS_MATRIX)
  double precision, optional, intent(out) :: SOURCE_TERMS(species_max), REACTION_RATES(reactions_max), &
                                             SOURCE_TERMS_MATRIX(species_max,reactions_max), MEAN_DENSITY(species_max), &
                                             MEAN_SOURCE_TERMS(species_max), MEAN_REACTION_RATES(reactions_max), &
                                             MEAN_SOURCE_TERMS_MATRIX(species_max,reactions_max)
  if(.not. lZDPlasKin_init) call ZDPlasKin_init()
  if(present(SOURCE_TERMS) .or. present(REACTION_RATES) .or. present(SOURCE_TERMS_MATRIX)) then
    dens_loc(1:species_max,0) = 0.5d0 * ( density(:) + abs( density(:) ) )
    if( lgas_heating ) dens_loc(species_max+1,0) = ZDPlasKin_cfg(1)
    call ZDPlasKin_fex(vode_neq,tsav,dens_loc(:,0),dens_loc(:,1))
    if( present(SOURCE_TERMS)                 ) SOURCE_TERMS(:)   = dens_loc(1:species_max,1)
    if( present(REACTION_RATES)               ) REACTION_RATES(:) = rrt(:)
    if( present(SOURCE_TERMS_MATRIX)          ) call ZDPlasKin_reac_source_matrix(rrt(:),SOURCE_TERMS_MATRIX(:,:))
  endif
  if(present(MEAN_DENSITY)        .or. present(MEAN_SOURCE_TERMS) .or. &
     present(MEAN_REACTION_RATES) .or. present(MEAN_SOURCE_TERMS_MATRIX)) then
    if( lstat_accum ) then
      if(stat_time > 0.0d0) then
        if( present(MEAN_DENSITY)             ) MEAN_DENSITY        = stat_dens(:) / stat_time
        if( present(MEAN_SOURCE_TERMS)        ) MEAN_SOURCE_TERMS   = stat_src(:)  / stat_time
        if( present(MEAN_REACTION_RATES)      ) MEAN_REACTION_RATES = stat_rrt(:)  / stat_time
        if( present(MEAN_SOURCE_TERMS_MATRIX) ) then
          call ZDPlasKin_reac_source_matrix(stat_rrt(:),MEAN_SOURCE_TERMS_MATRIX(:,:))
          MEAN_SOURCE_TERMS_MATRIX(:,:)  =  MEAN_SOURCE_TERMS_MATRIX(:,:) / stat_time
        endif
      else
        dens_loc(1:species_max,0) = 0.5d0 * ( density(:) + abs( density(:) ) )
        if( lgas_heating ) dens_loc(species_max+1,0) = ZDPlasKin_cfg(1)
        call ZDPlasKin_fex(vode_neq,tsav,dens_loc(:,0),dens_loc(:,1))
        if( present(MEAN_DENSITY)             ) MEAN_DENSITY        = density(:)
        if( present(MEAN_SOURCE_TERMS)        ) MEAN_SOURCE_TERMS   = dens_loc(1:species_max,1)
        if( present(MEAN_REACTION_RATES)      ) MEAN_REACTION_RATES = rrt(:)
        if( present(MEAN_SOURCE_TERMS_MATRIX) ) call ZDPlasKin_reac_source_matrix(rrt(:),MEAN_SOURCE_TERMS_MATRIX(:,:))
      endif
    else
      call ZDPlasKin_stop("ZDPlasKin ERROR: set statistics acquisition ON before (subroutine ZDPlasKin_get_rates)")
    endif
  endif
  return
end subroutine ZDPlasKin_get_rates
!-----------------------------------------------------------------------------------------------------------------------------------
!
! set config
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_set_config(ATOL,RTOL,SILENCE_MODE,STAT_ACCUM,QTPLASKIN_SAVE,BOLSIG_EE_FRAC,BOLSIG_IGNORE_GAS_TEMPERATURE)
  use dvode_f90_m, only : set_intermediate_opts
  implicit none
  logical, optional, intent(in) :: SILENCE_MODE, STAT_ACCUM, QTPLASKIN_SAVE, BOLSIG_IGNORE_GAS_TEMPERATURE
  double precision, optional, intent(in) :: ATOL, RTOL, BOLSIG_EE_FRAC
  integer :: i
  logical, save :: lfirst = .true.
  integer, save :: bounded_components(vode_neq)
  double precision :: atol_loc, rtol_loc
  double precision, save :: atol_save = -1.0d0, rtol_save = -1.0d0
  if( lfirst ) then
    if(.not. lZDPlasKin_init) call ZDPlasKin_init()
    do i = 1, vode_neq
      bounded_components(i) = i
    enddo
    lfirst = .false.
  endif
  if( present(SILENCE_MODE) ) lprint = ( .not. SILENCE_MODE )
  if( present(BOLSIG_EE_FRAC) ) bolsig_eecol_frac = 0.5d0 * ( BOLSIG_EE_FRAC + abs(BOLSIG_EE_FRAC) )
  if( present(BOLSIG_IGNORE_GAS_TEMPERATURE) ) lbolsig_ignore_gas_temp = BOLSIG_IGNORE_GAS_TEMPERATURE
  if( present(STAT_ACCUM) ) then
    if( lprint ) then
      if(lstat_accum .neqv. STAT_ACCUM) then
        if( STAT_ACCUM ) then
          write(*,"(A)") "ZDPlasKin INFO: set statistic acquisition ON ..."
        else
          write(*,"(A)") "ZDPlasKin INFO: set statistic acquisition OFF ..."
        endif
      elseif( STAT_ACCUM ) then
          write(*,"(A)") "ZDPlasKin INFO: reset statistic acquisition data ..."
      endif
    endif
    stat_dens(:) = 0.0d0
    stat_src(:)  = 0.0d0
    stat_rrt(:)  = 0.0d0
    stat_time    = 0.0d0
    lstat_accum  = STAT_ACCUM
  endif
  if( present(QTPLASKIN_SAVE) ) then
    if( lprint ) then
      if(lqtplaskin .neqv. QTPLASKIN_SAVE) then
        if( QTPLASKIN_SAVE ) then
          write(*,"(A)") "ZDPlasKin INFO: set autosave in QTplaskin format ON ..."
        else
          write(*,"(A)") "ZDPlasKin INFO: set autosave in QTplaskin format OFF ..."
        endif
      endif
    endif
    lqtplaskin = QTPLASKIN_SAVE
  endif
  if( present(ATOL) ) then
    atol_loc = ATOL
  else
    atol_loc = atol_save
  endif
  if( present(RTOL) ) then
    rtol_loc = RTOL
  else
    rtol_loc = rtol_save
  endif
  if(min(atol_loc,rtol_loc)<0.0d0 .or. max(atol_loc,rtol_loc)<=0.0d0) &
    call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined ATOL/RTOL (ZDPlasKin_set_config)")
  if(atol_loc/=atol_save .or. rtol_loc/=rtol_save) then
    atol_save = atol_loc
    rtol_save = rtol_loc
    if( lprint ) write(*,"(2(A,1pd9.2),A)") "ZDPlasKin INFO: set accuracy", atol_save, " (absolute) &", rtol_save, " (relative)"
    dens_loc(:,0) = 0.0d0
    dens_loc(:,1) = huge(dens_loc)
    vode_options  = set_intermediate_opts(abserr=atol_save,relerr=rtol_save, &
                                          dense_j=.true.,user_supplied_jacobian=.true., &
                                          constrained=bounded_components(:),clower=dens_loc(:,0),cupper=dens_loc(:,1))
    if(vode_istate /= 1) vode_istate = 3
  endif
  return
end subroutine ZDPlasKin_set_config
!-----------------------------------------------------------------------------------------------------------------------------------
!
! set/get conditions
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_set_conditions(GAS_TEMPERATURE,REDUCED_FREQUENCY,REDUCED_FIELD, &
                                    ELEC_TEMPERATURE,GAS_HEATING,SPEC_HEAT_RATIO,HEAT_SOURCE,SOFT_RESET)
  implicit none
  double precision, optional, intent(in) :: GAS_TEMPERATURE, REDUCED_FREQUENCY, REDUCED_FIELD, ELEC_TEMPERATURE, &
                                            SPEC_HEAT_RATIO, HEAT_SOURCE
  logical,          optional, intent(in) :: GAS_HEATING, SOFT_RESET
  if(.not. lZDPlasKin_init) call ZDPlasKin_init()
  if( present(GAS_TEMPERATURE) ) then
    if(GAS_TEMPERATURE <= 0.0d0) &
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined GAS_TEMPERATURE (subroutine ZDPlasKin_set_conditions)")
    ZDPlasKin_cfg(1) = GAS_TEMPERATURE
  endif
  if( present(REDUCED_FREQUENCY) ) then
    if(REDUCED_FREQUENCY < 0.0d0) &
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined REDUCED_FREQUENCY (subroutine ZDPlasKin_set_conditions)")
    ZDPlasKin_cfg(2) = REDUCED_FREQUENCY
  endif
  if( present(REDUCED_FIELD) ) then
    if(REDUCED_FIELD < 0.0d0) &
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined REDUCED_FIELD (subroutine ZDPlasKin_set_conditions)")
    ZDPlasKin_cfg(3) = REDUCED_FIELD
  endif
  if( present(SOFT_RESET) ) then
    if( SOFT_RESET ) vode_istate = 1
  endif
  if( present(ELEC_TEMPERATURE) ) then
    if(ELEC_TEMPERATURE < 0.0d0) &
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong or undefined ELEC_TEMPERATURE (subroutine ZDPlasKin_set_conditions)")
    if(ELEC_TEMPERATURE > 0.0d0) then
      lbolsig_Maxwell_EEDF = .true.
    else
      lbolsig_Maxwell_EEDF = .false.
    endif
    ZDPlasKin_cfg(4) = ELEC_TEMPERATURE
  endif
  if( present(GAS_HEATING) ) then
    if(lgas_heating .neqv. GAS_HEATING) then
      if( GAS_HEATING ) then
        if(present(SPEC_HEAT_RATIO) .or. ZDPlasKin_cfg(13)>0.0d0) then
          if( lprint ) write(*,"(A)") "ZDPlasKin INFO: set gas heating ON ..."
        else
          ZDPlasKin_cfg(13) = 2.0d0/3.0d0
          if( lprint ) write(*,"(A,1pd9.2)") "ZDPlasKin INFO: set gas heating ON; specific heat ratio =", ZDPlasKin_cfg(13) + 1.0d0
        endif
      else
        if( lprint ) write(*,"(A)") "ZDPlasKin INFO: set gas heating OFF ..."
      endif
      lgas_heating = GAS_HEATING
    endif
  endif
  if( present(SPEC_HEAT_RATIO) ) then
    if(SPEC_HEAT_RATIO > 1.0d0) then
      ZDPlasKin_cfg(13) = SPEC_HEAT_RATIO - 1.0d0
      if( lprint ) write(*,"(A,1pd9.2)") "ZDPlasKin INFO: set specific heat ratio =", ZDPlasKin_cfg(13) + 1.0d0
    else
      call ZDPlasKin_stop("ZDPlasKin ERROR: wrong value of SPEC_HEAT_RATIO (subroutine ZDPlasKin_set_conditions)")
    endif
  endif
  if( present(HEAT_SOURCE) ) then
    ZDPlasKin_cfg(14) = HEAT_SOURCE
    if( lprint ) write(*,"(A,1pd9.2,A)") "ZDPlasKin INFO: set heat source =", ZDPlasKin_cfg(14), " W/cm3"
  endif
end subroutine ZDPlasKin_set_conditions
subroutine ZDPlasKin_get_conditions(GAS_TEMPERATURE,REDUCED_FREQUENCY,REDUCED_FIELD, &
                                    ELEC_TEMPERATURE,ELEC_DRIFT_VELOCITY,ELEC_DIFF_COEFF,ELEC_MOBILITY_N, &
                                    ELEC_MU_EPS_N,ELEC_DIFF_EPS_N,ELEC_FREQUENCY_N, &
                                    ELEC_POWER_N,ELEC_POWER_ELASTIC_N,ELEC_POWER_INELASTIC_N,ELEC_EEDF)
  implicit none
  double precision, optional, intent(out) :: GAS_TEMPERATURE, REDUCED_FREQUENCY, REDUCED_FIELD, &
                                             ELEC_TEMPERATURE, ELEC_DRIFT_VELOCITY, ELEC_DIFF_COEFF, ELEC_MOBILITY_N, &
                                             ELEC_MU_EPS_N, ELEC_DIFF_EPS_N, ELEC_FREQUENCY_N, &
                                             ELEC_POWER_N, ELEC_POWER_ELASTIC_N, ELEC_POWER_INELASTIC_N
  double precision, optional, dimension(:,:), intent(out) :: ELEC_EEDF
  integer :: i
  double precision :: x,y
  if(.not. lZDPlasKin_init) call ZDPlasKin_init()
  if( present(ELEC_EEDF) ) then
    call ZDPlasKin_bolsig_rates(lbolsig_force=.true.)
  else
    call ZDPlasKin_bolsig_rates()
  endif
  if( present(GAS_TEMPERATURE)        ) GAS_TEMPERATURE        = ZDPlasKin_cfg(1)
  if( present(REDUCED_FREQUENCY)      ) REDUCED_FREQUENCY      = ZDPlasKin_cfg(2)
  if( present(REDUCED_FIELD)          ) REDUCED_FIELD          = ZDPlasKin_cfg(3)
  if( present(ELEC_TEMPERATURE)       ) ELEC_TEMPERATURE       = ZDPlasKin_cfg(4)
  if( present(ELEC_DRIFT_VELOCITY)    ) ELEC_DRIFT_VELOCITY    = ZDPlasKin_cfg(5) * ZDPlasKin_cfg(3) * 1.0d-17
  if( present(ELEC_DIFF_COEFF)        ) ELEC_DIFF_COEFF        = ZDPlasKin_cfg(6)
  if( present(ELEC_MOBILITY_N)        ) ELEC_MOBILITY_N        = ZDPlasKin_cfg(5)
  if( present(ELEC_MU_EPS_N)          ) ELEC_MU_EPS_N          = ZDPlasKin_cfg(7)
  if( present(ELEC_DIFF_EPS_N)        ) ELEC_DIFF_EPS_N        = ZDPlasKin_cfg(8)
  if( present(ELEC_FREQUENCY_N)       ) ELEC_FREQUENCY_N       = ZDPlasKin_cfg(9)
  if( present(ELEC_POWER_N)           ) ELEC_POWER_N           = ZDPlasKin_cfg(10)
  if( present(ELEC_POWER_ELASTIC_N)   ) ELEC_POWER_ELASTIC_N   = ZDPlasKin_cfg(11)
  if( present(ELEC_POWER_INELASTIC_N) ) ELEC_POWER_INELASTIC_N = ZDPlasKin_cfg(12)
  if( present(ELEC_EEDF) ) then
    ELEC_EEDF = 0d0
  	 if( size(ELEC_EEDF,dim=1) < 2 ) then
      if(lprint) write(*,"(A)") &
  	     "ZDPlasKin WARNING: insufficient first dimention of array ELEC_EEDF (subroutine ZDPlasKin_get_conditions)"
  	  else
  		y = 1.0d0
  		do i = 1, size(ELEC_EEDF,dim=2)
  		  call ZDPlasKin_bolsig_GetEEDF(i,x,y)
  		  if( x >= 0d0 .and. y > 0d0) then
  			ELEC_EEDF(1,i) = x
  			ELEC_EEDF(2,i) = y
  		  else
  			exit
  		  endif
  		enddo
  		if(lprint .and. y>0d0) write(*,"(A)") &
  		  "ZDPlasKin WARNING: insufficient second dimention of array ELEC_EEDF (subroutine ZDPlasKin_get_conditions)"
     endif
  endif
end subroutine ZDPlasKin_get_conditions
!-----------------------------------------------------------------------------------------------------------------------------------
!
! reset
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_reset()
  implicit none
  vode_istate         =  1
  density(:)          =  0.0d0
  ZDPlasKin_cfg(:)    =  0.0d0
  ldensity_constant   = .false.
  density_constant(:) = .false.
  lreaction_block(:)  = .false.
  lprint              = .true.
  lstat_accum         = .false.
  lqtplaskin          = .false.
  lgas_heating        = .false.
  bolsig_eecol_frac       = bolsig_eecol_frac_def
  lbolsig_ignore_gas_temp = .false.
  lbolsig_Maxwell_EEDF    = .false.
  write(*,"(A)") "ZDPlasKin INFO: reset data and configuration"
  call ZDPlasKin_set_config(ATOL=vode_atol,RTOL=vode_rtol)
  return
end subroutine ZDPlasKin_reset
!-----------------------------------------------------------------------------------------------------------------------------------
!
! stop
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_stop(string)
  implicit none
  character(*), intent(in) :: string
  if(string /= "") write(*,"(A)") trim(string)
  write(*,"(A,$)") "PRESS ENTER TO EXIT ... "
  read(*,*)
  stop
end subroutine ZDPlasKin_stop
!-----------------------------------------------------------------------------------------------------------------------------------
!
! save data to file
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_write_file(FILE_SPECIES,FILE_REACTIONS,FILE_SOURCE_MATRIX,FILE_UNIT)
  implicit none
  character(*), optional, intent(in) :: FILE_SPECIES, FILE_REACTIONS, FILE_SOURCE_MATRIX
  integer, optional, intent(in) :: FILE_UNIT
  logical :: lerror
  integer :: i
  if( present(FILE_UNIT) ) ifile_unit = FILE_UNIT
  if( present(FILE_SPECIES) ) then
    lerror = .true.
    open(ifile_unit,file=trim(adjustl(FILE_SPECIES)),action="write",err=100)
    do i = 1, species_max
      write(ifile_unit,111,err=100) i, species_name(i)
    enddo
    lerror = .false.
100 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file <" &
                                    // trim(adjustl(FILE_SPECIES)) // "> (subroutine ZDPlasKin_write_file)")
    close(ifile_unit)
111 format(i2,1x,A8)
  endif
  if( present(FILE_REACTIONS) ) then
    lerror = .true.
    open(ifile_unit,file=trim(adjustl(FILE_REACTIONS)),action="write",err=200)
    do i = 1, reactions_max
      write(ifile_unit,211,err=200) i, reaction_sign(i)
    enddo
    lerror = .false.
200 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file <" &
                                    // trim(adjustl(FILE_REACTIONS)) // "> (subroutine ZDPlasKin_write_file)")
    close(ifile_unit)
211 format(i3,1x,A34)
  endif
  if( present(FILE_SOURCE_MATRIX) ) then
    if( lstat_accum ) then
      call ZDPlasKin_reac_source_matrix(stat_rrt(:),mrtm(:,:))
      if(stat_time > 0.0d0) mrtm(:,:) = mrtm(:,:) / stat_time
    else
      call ZDPlasKin_stop("ZDPlasKin ERROR: set statistics acquisition ON before (subroutine ZDPlasKin_write_file)")
    endif
    lerror = .true.
    open(ifile_unit,file=trim(adjustl(FILE_SOURCE_MATRIX)),action="write",err=300)
    write(ifile_unit,311,err=300) ( i, i = 1, species_max )
    write(ifile_unit,312,err=300) "N", "reaction", ( trim(species_name(i)), i = 1, species_max )
    do i = 1, reactions_max
      write(ifile_unit,313,err=300) i, reaction_sign(i), mrtm(:,i)
    enddo
    lerror = .false.
300 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file <" &
                                    // trim(adjustl(FILE_SOURCE_MATRIX)) // "> (subroutine ZDPlasKin_write_file)")
    close(ifile_unit)
311 format(391x,80(1x,i9))
312 format(A3,1x,A34,1x,80(1x,A9))
313 format(i3,1x,A34,1x,80(1x,1pd9.2))
  endif
  return
end subroutine ZDPlasKin_write_file
!-----------------------------------------------------------------------------------------------------------------------------------
!
! save data in qtplaskin format
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_write_qtplaskin(time,LFORCE_WRITE)
  implicit none
  double precision, intent(in) :: time
  logical, optional, intent(in) :: LFORCE_WRITE
  integer, parameter :: idef_data = 5
  character(24), parameter :: qtplaskin_names(idef_data) = (/ "Reduced field [Td]      ", "Gas temperature [K]     ", &
                                  "Electron temperature [K]", "Current density [A/cm2] ", "Power density [W/cm3]   " /)
  double precision, save :: densav(0:species_max,2) = -huge(densav)
  double precision :: rtol, cond(idef_data)
  logical, save :: lfirst = .true.
  logical :: lerror
  integer, save :: iuser_data = 0
  integer :: i
  if( time < densav(0,1) ) lfirst = .true.
  if( lfirst ) then
    call ZDPlasKin_write_file(FILE_SPECIES="qt_species_list.txt",FILE_REACTIONS="qt_reactions_list.txt")
    if( allocated(qtplaskin_user_data) ) then
      iuser_data = size(qtplaskin_user_data)
      iuser_data = min(iuser_data,90)
      if( iuser_data > 0 ) then
        if( allocated(qtplaskin_user_names) ) then
          if( size(qtplaskin_user_names) /= iuser_data ) deallocate(qtplaskin_user_names)
        endif
        if( .not. allocated(qtplaskin_user_names) ) then
          allocate(qtplaskin_user_names(iuser_data))
          do i = 1, iuser_data
            write(qtplaskin_user_names(i),"(A,i2.2)") "user defined #", i
          enddo
        endif
      endif
    endif
    lerror = .true.
    open(ifile_unit,file="qt_conditions_list.txt",action="write",err=100)
    do i = 1, idef_data
      write(ifile_unit,"(i3,1x,A)",err=100) i, trim(adjustl(qtplaskin_names(i)))
    enddo
    if( iuser_data > 0 ) then
      do i = 1, iuser_data
        write(ifile_unit,"(i3,1x,A)",err=100) (i+idef_data), trim(adjustl(qtplaskin_user_names(i)))
      enddo
    endif
    lerror = .false.
100 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file " // &
                                     "<qt_conditions_list.txt> (subroutine writer_save_qtplaskin)")
    close(ifile_unit)
    rrt(:) = 1.0d0
    call ZDPlasKin_reac_source_matrix(rrt(:),mrtm(:,:))
    open(ifile_unit,file="qt_matrix.txt",action="write",err=200)
    do i = 1, species_max
      write(ifile_unit,"(595(i3))",err=200) int(mrtm(i,:))
    enddo
    lerror = .false.
200 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file " // &
                                     "<qt_matrix.txt> (subroutine writer_save_qtplaskin)")
    close(ifile_unit)
    open(ifile_unit,file="qt_densities.txt",action="write",err=300)
    write(ifile_unit,"(1x,A14,80(111x,i2.2))",err=300) "Time_s", ( i, i = 1, species_max )
    lerror = .false.
300 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file " // &
                                     "<qt_densities.txt> (subroutine writer_save_qtplaskin)")
    close(ifile_unit)
    open(ifile_unit,file="qt_conditions.txt",action="write",err=400)
    write(ifile_unit,"(1x,A12,$)",err=400) "Time_s"
    do i = 1, idef_data + iuser_data
      write(ifile_unit,"(11x,i2.2,$)",err=400) i
    enddo
    write(ifile_unit,*,err=400)
    lerror = .false.
400 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file " // &
                                     "<qt_conditions.txt> (subroutine writer_save_qtplaskin)")
    close(ifile_unit)
    open(ifile_unit,file="qt_rates.txt",action="write",err=500)
    write(ifile_unit,"(1x,A12,595(101x,i3.3))",err=500) "Time_s", ( i, i = 1, reactions_max )
    lerror = .false.
500 if( lerror ) call ZDPlasKin_stop("ZDPlasKin ERROR: cannot write to file " // &
                                     "<qt_rates.txt> (subroutine writer_save_qtplaskin)")
    close(ifile_unit)
  endif
  if( present(LFORCE_WRITE) ) then
    if( LFORCE_WRITE ) lfirst = .true.
  endif
  rtol = 10.0d0 ** ( floor( log10( abs(densav(0,1)) + tiny(rtol) ) ) - 6 )
  if( ( time - densav(0,1) ) >= rtol .or. lfirst ) then
    densav(0,2) = time
    densav(1:species_max,2) = density(:)
    where( densav(:,2) < 1.0d-99 ) densav(:,2) = 0.0d0
    if( time > 2.0d0 * densav(0,1) ) then
      rtol = huge(rtol)
    else
      rtol = maxval( abs(densav(1:,1)-densav(1:,2)) / ( abs(densav(1:,1)+densav(1:,2))/2.0d0 + qtplaskin_atol ) )
    endif
    if( rtol > qtplaskin_rtol .or. lfirst ) then
      open(ifile_unit,file="qt_densities.txt",access="append")
      write(ifile_unit,"(1pe15.6,80(1pe13.4))") densav(0,2), densav(1:,2)
      close(ifile_unit)
      open(ifile_unit,file="qt_conditions.txt",access="append")
      cond(1) = ZDPlasKin_cfg(3)
      cond(2) = ZDPlasKin_cfg(1)
      cond(3) = ZDPlasKin_cfg(4)
      cond(4) = q_elem * density(species_electrons) * ZDPlasKin_cfg(5) * ZDPlasKin_cfg(3) * 1.0d-17
      call ZDPlasKin_get_density_total(ALL_NEUTRAL=cond(5))
      cond(5) = cond(4) * cond(5) * ZDPlasKin_cfg(3) * 1.0d-17
      where( abs(cond(:)) < 1.0d-99 ) cond(:) = 0.0d0
      write(ifile_unit,"(6(1pe13.4),$)") densav(0,2), cond(:)
      if( iuser_data > 0 ) then
        where( abs(qtplaskin_user_data(1:iuser_data)) < 1.0d-99 ) qtplaskin_user_data(1:iuser_data) = 0.0d0
        write(ifile_unit,"(90(1pe13.4))") qtplaskin_user_data(1:iuser_data)
      else
        write(ifile_unit,*)
      endif
      close(ifile_unit)
      call ZDPlasKin_get_rates(REACTION_RATES=rrt_loc)
      where( abs(rrt_loc(:)) < 1.0d-99 ) rrt_loc(:) = 0.0d0
      open(ifile_unit,file="qt_rates.txt",access="append")
      write(ifile_unit,"(596(1pe13.4))") densav(0,2), rrt_loc(:)
      close(ifile_unit)
      densav(:,1) = densav(:,2)
    endif
  endif
  lfirst = .false.
  lqtplaskin_first = .false.
  return
end subroutine ZDPlasKin_write_qtplaskin
!-----------------------------------------------------------------------------------------------------------------------------------
!
! reaction sensitivity acquisition
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_reac_source_matrix(reac_rate_local,reac_source_local)
  implicit none
  double precision, intent(in)  :: reac_rate_local(reactions_max)
  double precision, intent(out) :: reac_source_local(species_max,reactions_max)
  reac_source_local(:,:) = 0.0d0
  reac_source_local(16,001) = - reac_rate_local(001) 
  reac_source_local(57,001) = + reac_rate_local(001) 
  reac_source_local(16,002) = - reac_rate_local(002) 
  reac_source_local(58,002) = + reac_rate_local(002) 
  reac_source_local(16,003) = - reac_rate_local(003) 
  reac_source_local(59,003) = + reac_rate_local(003) 
  reac_source_local(16,004) = - reac_rate_local(004) 
  reac_source_local(72,004) = + reac_rate_local(004) 
  reac_source_local(80,004) = + reac_rate_local(004) 
  reac_source_local(04,005) = + reac_rate_local(005) 
  reac_source_local(16,005) = - reac_rate_local(005) 
  reac_source_local(73,005) = + reac_rate_local(005) 
  reac_source_local(80,005) = + reac_rate_local(005) 
  reac_source_local(04,006) = + reac_rate_local(006) 
  reac_source_local(16,006) = - reac_rate_local(006) 
  reac_source_local(17,006) = + reac_rate_local(006) 
  reac_source_local(04,007) = + reac_rate_local(007) * 2.d0
  reac_source_local(16,007) = - reac_rate_local(007) 
  reac_source_local(18,007) = + reac_rate_local(007) 
  reac_source_local(17,008) = - reac_rate_local(008) 
  reac_source_local(73,008) = + reac_rate_local(008) 
  reac_source_local(80,008) = + reac_rate_local(008) 
  reac_source_local(04,009) = + reac_rate_local(009) 
  reac_source_local(17,009) = - reac_rate_local(009) 
  reac_source_local(74,009) = + reac_rate_local(009) 
  reac_source_local(80,009) = + reac_rate_local(009) 
  reac_source_local(04,010) = + reac_rate_local(010) 
  reac_source_local(17,010) = - reac_rate_local(010) 
  reac_source_local(18,010) = + reac_rate_local(010) 
  reac_source_local(04,011) = + reac_rate_local(011) * 2.d0
  reac_source_local(10,011) = + reac_rate_local(011) 
  reac_source_local(17,011) = - reac_rate_local(011) 
  reac_source_local(18,012) = - reac_rate_local(012) 
  reac_source_local(74,012) = + reac_rate_local(012) 
  reac_source_local(80,012) = + reac_rate_local(012) 
  reac_source_local(04,013) = + reac_rate_local(013) 
  reac_source_local(10,013) = + reac_rate_local(013) 
  reac_source_local(18,013) = - reac_rate_local(013) 
  reac_source_local(04,014) = + reac_rate_local(014) 
  reac_source_local(18,014) = - reac_rate_local(014) 
  reac_source_local(33,014) = + reac_rate_local(014) 
  reac_source_local(10,015) = - reac_rate_local(015) 
  reac_source_local(34,015) = + reac_rate_local(015) 
  reac_source_local(10,016) = - reac_rate_local(016) 
  reac_source_local(33,016) = + reac_rate_local(016) 
  reac_source_local(10,017) = - reac_rate_local(017) 
  reac_source_local(60,017) = + reac_rate_local(017) 
  reac_source_local(80,017) = + reac_rate_local(017) 
  reac_source_local(11,018) = - reac_rate_local(018) 
  reac_source_local(38,018) = + reac_rate_local(018) 
  reac_source_local(11,019) = - reac_rate_local(019) 
  reac_source_local(39,019) = + reac_rate_local(019) 
  reac_source_local(11,020) = - reac_rate_local(020) 
  reac_source_local(40,020) = + reac_rate_local(020) 
  reac_source_local(11,021) = - reac_rate_local(021) 
  reac_source_local(41,021) = + reac_rate_local(021) 
  reac_source_local(11,022) = - reac_rate_local(022) 
  reac_source_local(42,022) = + reac_rate_local(022) 
  reac_source_local(11,023) = - reac_rate_local(023) 
  reac_source_local(43,023) = + reac_rate_local(023) 
  reac_source_local(11,024) = - reac_rate_local(024) 
  reac_source_local(44,024) = + reac_rate_local(024) 
  reac_source_local(11,025) = - reac_rate_local(025) 
  reac_source_local(45,025) = + reac_rate_local(025) 
  reac_source_local(11,026) = - reac_rate_local(026) 
  reac_source_local(46,026) = + reac_rate_local(026) 
  reac_source_local(11,027) = - reac_rate_local(027) 
  reac_source_local(46,027) = + reac_rate_local(027) 
  reac_source_local(11,028) = - reac_rate_local(028) 
  reac_source_local(46,028) = + reac_rate_local(028) 
  reac_source_local(11,029) = - reac_rate_local(029) 
  reac_source_local(47,029) = + reac_rate_local(029) 
  reac_source_local(11,030) = - reac_rate_local(030) 
  reac_source_local(47,030) = + reac_rate_local(030) 
  reac_source_local(11,031) = - reac_rate_local(031) 
  reac_source_local(47,031) = + reac_rate_local(031) 
  reac_source_local(11,032) = - reac_rate_local(032) 
  reac_source_local(48,032) = + reac_rate_local(032) 
  reac_source_local(11,033) = - reac_rate_local(033) 
  reac_source_local(48,033) = + reac_rate_local(033) 
  reac_source_local(11,034) = - reac_rate_local(034) 
  reac_source_local(48,034) = + reac_rate_local(034) 
  reac_source_local(11,035) = - reac_rate_local(035) 
  reac_source_local(49,035) = + reac_rate_local(035) 
  reac_source_local(11,036) = - reac_rate_local(036) 
  reac_source_local(49,036) = + reac_rate_local(036) 
  reac_source_local(11,037) = - reac_rate_local(037) 
  reac_source_local(49,037) = + reac_rate_local(037) 
  reac_source_local(11,038) = - reac_rate_local(038) 
  reac_source_local(61,038) = + reac_rate_local(038) 
  reac_source_local(80,038) = + reac_rate_local(038) 
  reac_source_local(02,039) = - reac_rate_local(039) 
  reac_source_local(50,039) = + reac_rate_local(039) 
  reac_source_local(02,040) = - reac_rate_local(040) 
  reac_source_local(51,040) = + reac_rate_local(040) 
  reac_source_local(02,041) = - reac_rate_local(041) 
  reac_source_local(52,041) = + reac_rate_local(041) 
  reac_source_local(02,042) = - reac_rate_local(042) 
  reac_source_local(53,042) = + reac_rate_local(042) 
  reac_source_local(02,043) = - reac_rate_local(043) 
  reac_source_local(54,043) = + reac_rate_local(043) 
  reac_source_local(02,044) = - reac_rate_local(044) 
  reac_source_local(55,044) = + reac_rate_local(044) 
  reac_source_local(02,045) = - reac_rate_local(045) 
  reac_source_local(35,045) = + reac_rate_local(045) 
  reac_source_local(02,046) = - reac_rate_local(046) 
  reac_source_local(67,046) = + reac_rate_local(046) 
  reac_source_local(80,046) = + reac_rate_local(046) 
  reac_source_local(01,047) = + reac_rate_local(047) * 2.d0
  reac_source_local(02,047) = - reac_rate_local(047) 
  reac_source_local(01,048) = + reac_rate_local(048) 
  reac_source_local(02,048) = - reac_rate_local(048) 
  reac_source_local(36,048) = + reac_rate_local(048) 
  reac_source_local(01,049) = + reac_rate_local(049) 
  reac_source_local(02,049) = - reac_rate_local(049) 
  reac_source_local(37,049) = + reac_rate_local(049) 
  reac_source_local(01,050) = + reac_rate_local(050) 
  reac_source_local(02,050) = - reac_rate_local(050) 
  reac_source_local(64,050) = + reac_rate_local(050) 
  reac_source_local(80,050) = - reac_rate_local(050) 
  reac_source_local(01,051) = + reac_rate_local(051) 
  reac_source_local(03,051) = - reac_rate_local(051) 
  reac_source_local(67,051) = + reac_rate_local(051) 
  reac_source_local(80,051) = + reac_rate_local(051) 
  reac_source_local(01,052) = + reac_rate_local(052) 
  reac_source_local(02,052) = + reac_rate_local(052) 
  reac_source_local(03,052) = - reac_rate_local(052) 
  reac_source_local(01,053) = + reac_rate_local(053) 
  reac_source_local(03,053) = - reac_rate_local(053) 
  reac_source_local(68,053) = + reac_rate_local(053) 
  reac_source_local(80,053) = - reac_rate_local(053) 
  reac_source_local(02,054) = + reac_rate_local(054) 
  reac_source_local(03,054) = - reac_rate_local(054) 
  reac_source_local(64,054) = + reac_rate_local(054) 
  reac_source_local(80,054) = - reac_rate_local(054) 
  reac_source_local(01,055) = - reac_rate_local(055) 
  reac_source_local(37,055) = + reac_rate_local(055) 
  reac_source_local(01,056) = - reac_rate_local(056) 
  reac_source_local(36,056) = + reac_rate_local(056) 
  reac_source_local(07,057) = - reac_rate_local(057) 
  reac_source_local(79,057) = + reac_rate_local(057) 
  reac_source_local(80,057) = + reac_rate_local(057) 
  reac_source_local(05,058) = + reac_rate_local(058) 
  reac_source_local(07,058) = - reac_rate_local(058) 
  reac_source_local(64,058) = + reac_rate_local(058) 
  reac_source_local(80,058) = - reac_rate_local(058) 
  reac_source_local(04,059) = + reac_rate_local(059) 
  reac_source_local(07,059) = - reac_rate_local(059) 
  reac_source_local(66,059) = + reac_rate_local(059) 
  reac_source_local(80,059) = - reac_rate_local(059) 
  reac_source_local(11,060) = + reac_rate_local(060) 
  reac_source_local(38,060) = - reac_rate_local(060) 
  reac_source_local(38,061) = + reac_rate_local(061) 
  reac_source_local(39,061) = - reac_rate_local(061) 
  reac_source_local(39,062) = + reac_rate_local(062) 
  reac_source_local(40,062) = - reac_rate_local(062) 
  reac_source_local(40,063) = + reac_rate_local(063) 
  reac_source_local(41,063) = - reac_rate_local(063) 
  reac_source_local(41,064) = + reac_rate_local(064) 
  reac_source_local(42,064) = - reac_rate_local(064) 
  reac_source_local(42,065) = + reac_rate_local(065) 
  reac_source_local(43,065) = - reac_rate_local(065) 
  reac_source_local(43,066) = + reac_rate_local(066) 
  reac_source_local(44,066) = - reac_rate_local(066) 
  reac_source_local(44,067) = + reac_rate_local(067) 
  reac_source_local(45,067) = - reac_rate_local(067) 
  reac_source_local(11,068) = + reac_rate_local(068) 
  reac_source_local(38,068) = - reac_rate_local(068) 
  reac_source_local(38,069) = + reac_rate_local(069) 
  reac_source_local(39,069) = - reac_rate_local(069) 
  reac_source_local(39,070) = + reac_rate_local(070) 
  reac_source_local(40,070) = - reac_rate_local(070) 
  reac_source_local(40,071) = + reac_rate_local(071) 
  reac_source_local(41,071) = - reac_rate_local(071) 
  reac_source_local(41,072) = + reac_rate_local(072) 
  reac_source_local(42,072) = - reac_rate_local(072) 
  reac_source_local(42,073) = + reac_rate_local(073) 
  reac_source_local(43,073) = - reac_rate_local(073) 
  reac_source_local(43,074) = + reac_rate_local(074) 
  reac_source_local(44,074) = - reac_rate_local(074) 
  reac_source_local(44,075) = + reac_rate_local(075) 
  reac_source_local(45,075) = - reac_rate_local(075) 
  reac_source_local(11,076) = + reac_rate_local(076) 
  reac_source_local(38,076) = - reac_rate_local(076) 
  reac_source_local(38,077) = + reac_rate_local(077) 
  reac_source_local(39,077) = - reac_rate_local(077) 
  reac_source_local(39,078) = + reac_rate_local(078) 
  reac_source_local(40,078) = - reac_rate_local(078) 
  reac_source_local(40,079) = + reac_rate_local(079) 
  reac_source_local(41,079) = - reac_rate_local(079) 
  reac_source_local(41,080) = + reac_rate_local(080) 
  reac_source_local(42,080) = - reac_rate_local(080) 
  reac_source_local(42,081) = + reac_rate_local(081) 
  reac_source_local(43,081) = - reac_rate_local(081) 
  reac_source_local(43,082) = + reac_rate_local(082) 
  reac_source_local(44,082) = - reac_rate_local(082) 
  reac_source_local(44,083) = + reac_rate_local(083) 
  reac_source_local(45,083) = - reac_rate_local(083) 
  reac_source_local(11,084) = + reac_rate_local(084) 
  reac_source_local(38,084) = - reac_rate_local(084) 
  reac_source_local(38,085) = + reac_rate_local(085) 
  reac_source_local(39,085) = - reac_rate_local(085) 
  reac_source_local(39,086) = + reac_rate_local(086) 
  reac_source_local(40,086) = - reac_rate_local(086) 
  reac_source_local(40,087) = + reac_rate_local(087) 
  reac_source_local(41,087) = - reac_rate_local(087) 
  reac_source_local(41,088) = + reac_rate_local(088) 
  reac_source_local(42,088) = - reac_rate_local(088) 
  reac_source_local(42,089) = + reac_rate_local(089) 
  reac_source_local(43,089) = - reac_rate_local(089) 
  reac_source_local(43,090) = + reac_rate_local(090) 
  reac_source_local(44,090) = - reac_rate_local(090) 
  reac_source_local(44,091) = + reac_rate_local(091) 
  reac_source_local(45,091) = - reac_rate_local(091) 
  reac_source_local(02,092) = + reac_rate_local(092) 
  reac_source_local(50,092) = - reac_rate_local(092) 
  reac_source_local(50,093) = + reac_rate_local(093) 
  reac_source_local(51,093) = - reac_rate_local(093) 
  reac_source_local(51,094) = + reac_rate_local(094) 
  reac_source_local(52,094) = - reac_rate_local(094) 
  reac_source_local(52,095) = + reac_rate_local(095) 
  reac_source_local(53,095) = - reac_rate_local(095) 
  reac_source_local(02,096) = + reac_rate_local(096) 
  reac_source_local(50,096) = - reac_rate_local(096) 
  reac_source_local(50,097) = + reac_rate_local(097) 
  reac_source_local(51,097) = - reac_rate_local(097) 
  reac_source_local(51,098) = + reac_rate_local(098) 
  reac_source_local(52,098) = - reac_rate_local(098) 
  reac_source_local(52,099) = + reac_rate_local(099) 
  reac_source_local(53,099) = - reac_rate_local(099) 
  reac_source_local(02,100) = + reac_rate_local(100) 
  reac_source_local(50,100) = - reac_rate_local(100) 
  reac_source_local(50,101) = + reac_rate_local(101) 
  reac_source_local(51,101) = - reac_rate_local(101) 
  reac_source_local(51,102) = + reac_rate_local(102) 
  reac_source_local(52,102) = - reac_rate_local(102) 
  reac_source_local(52,103) = + reac_rate_local(103) 
  reac_source_local(53,103) = - reac_rate_local(103) 
  reac_source_local(11,104) = + reac_rate_local(104) 
  reac_source_local(38,104) = - reac_rate_local(104) * 2.d0
  reac_source_local(39,104) = + reac_rate_local(104) 
  reac_source_local(11,105) = + reac_rate_local(105) 
  reac_source_local(38,105) = - reac_rate_local(105) 
  reac_source_local(39,105) = - reac_rate_local(105) 
  reac_source_local(40,105) = + reac_rate_local(105) 
  reac_source_local(11,106) = + reac_rate_local(106) 
  reac_source_local(38,106) = - reac_rate_local(106) 
  reac_source_local(40,106) = - reac_rate_local(106) 
  reac_source_local(41,106) = + reac_rate_local(106) 
  reac_source_local(11,107) = + reac_rate_local(107) 
  reac_source_local(38,107) = - reac_rate_local(107) 
  reac_source_local(41,107) = - reac_rate_local(107) 
  reac_source_local(42,107) = + reac_rate_local(107) 
  reac_source_local(11,108) = + reac_rate_local(108) 
  reac_source_local(38,108) = - reac_rate_local(108) 
  reac_source_local(42,108) = - reac_rate_local(108) 
  reac_source_local(43,108) = + reac_rate_local(108) 
  reac_source_local(11,109) = + reac_rate_local(109) 
  reac_source_local(38,109) = - reac_rate_local(109) 
  reac_source_local(43,109) = - reac_rate_local(109) 
  reac_source_local(44,109) = + reac_rate_local(109) 
  reac_source_local(11,110) = + reac_rate_local(110) 
  reac_source_local(38,110) = - reac_rate_local(110) 
  reac_source_local(44,110) = - reac_rate_local(110) 
  reac_source_local(45,110) = + reac_rate_local(110) 
  reac_source_local(11,111) = - reac_rate_local(111) 
  reac_source_local(38,111) = + reac_rate_local(111) * 2.d0
  reac_source_local(39,111) = - reac_rate_local(111) 
  reac_source_local(38,112) = + reac_rate_local(112) 
  reac_source_local(39,112) = - reac_rate_local(112) * 2.d0
  reac_source_local(40,112) = + reac_rate_local(112) 
  reac_source_local(38,113) = + reac_rate_local(113) 
  reac_source_local(39,113) = - reac_rate_local(113) 
  reac_source_local(40,113) = - reac_rate_local(113) 
  reac_source_local(41,113) = + reac_rate_local(113) 
  reac_source_local(38,114) = + reac_rate_local(114) 
  reac_source_local(39,114) = - reac_rate_local(114) 
  reac_source_local(41,114) = - reac_rate_local(114) 
  reac_source_local(42,114) = + reac_rate_local(114) 
  reac_source_local(38,115) = + reac_rate_local(115) 
  reac_source_local(39,115) = - reac_rate_local(115) 
  reac_source_local(42,115) = - reac_rate_local(115) 
  reac_source_local(43,115) = + reac_rate_local(115) 
  reac_source_local(38,116) = + reac_rate_local(116) 
  reac_source_local(39,116) = - reac_rate_local(116) 
  reac_source_local(43,116) = - reac_rate_local(116) 
  reac_source_local(44,116) = + reac_rate_local(116) 
  reac_source_local(38,117) = + reac_rate_local(117) 
  reac_source_local(39,117) = - reac_rate_local(117) 
  reac_source_local(44,117) = - reac_rate_local(117) 
  reac_source_local(45,117) = + reac_rate_local(117) 
  reac_source_local(11,118) = - reac_rate_local(118) 
  reac_source_local(38,118) = + reac_rate_local(118) 
  reac_source_local(39,118) = + reac_rate_local(118) 
  reac_source_local(40,118) = - reac_rate_local(118) 
  reac_source_local(38,119) = - reac_rate_local(119) 
  reac_source_local(39,119) = + reac_rate_local(119) * 2.d0
  reac_source_local(40,119) = - reac_rate_local(119) 
  reac_source_local(39,120) = + reac_rate_local(120) 
  reac_source_local(40,120) = - reac_rate_local(120) * 2.d0
  reac_source_local(41,120) = + reac_rate_local(120) 
  reac_source_local(39,121) = + reac_rate_local(121) 
  reac_source_local(40,121) = - reac_rate_local(121) 
  reac_source_local(41,121) = - reac_rate_local(121) 
  reac_source_local(42,121) = + reac_rate_local(121) 
  reac_source_local(39,122) = + reac_rate_local(122) 
  reac_source_local(40,122) = - reac_rate_local(122) 
  reac_source_local(42,122) = - reac_rate_local(122) 
  reac_source_local(43,122) = + reac_rate_local(122) 
  reac_source_local(39,123) = + reac_rate_local(123) 
  reac_source_local(40,123) = - reac_rate_local(123) 
  reac_source_local(43,123) = - reac_rate_local(123) 
  reac_source_local(44,123) = + reac_rate_local(123) 
  reac_source_local(39,124) = + reac_rate_local(124) 
  reac_source_local(40,124) = - reac_rate_local(124) 
  reac_source_local(44,124) = - reac_rate_local(124) 
  reac_source_local(45,124) = + reac_rate_local(124) 
  reac_source_local(11,125) = - reac_rate_local(125) 
  reac_source_local(38,125) = + reac_rate_local(125) 
  reac_source_local(40,125) = + reac_rate_local(125) 
  reac_source_local(41,125) = - reac_rate_local(125) 
  reac_source_local(38,126) = - reac_rate_local(126) 
  reac_source_local(39,126) = + reac_rate_local(126) 
  reac_source_local(40,126) = + reac_rate_local(126) 
  reac_source_local(41,126) = - reac_rate_local(126) 
  reac_source_local(39,127) = - reac_rate_local(127) 
  reac_source_local(40,127) = + reac_rate_local(127) * 2.d0
  reac_source_local(41,127) = - reac_rate_local(127) 
  reac_source_local(40,128) = + reac_rate_local(128) 
  reac_source_local(41,128) = - reac_rate_local(128) * 2.d0
  reac_source_local(42,128) = + reac_rate_local(128) 
  reac_source_local(40,129) = + reac_rate_local(129) 
  reac_source_local(41,129) = - reac_rate_local(129) 
  reac_source_local(42,129) = - reac_rate_local(129) 
  reac_source_local(43,129) = + reac_rate_local(129) 
  reac_source_local(40,130) = + reac_rate_local(130) 
  reac_source_local(41,130) = - reac_rate_local(130) 
  reac_source_local(43,130) = - reac_rate_local(130) 
  reac_source_local(44,130) = + reac_rate_local(130) 
  reac_source_local(40,131) = + reac_rate_local(131) 
  reac_source_local(41,131) = - reac_rate_local(131) 
  reac_source_local(44,131) = - reac_rate_local(131) 
  reac_source_local(45,131) = + reac_rate_local(131) 
  reac_source_local(11,132) = - reac_rate_local(132) 
  reac_source_local(38,132) = + reac_rate_local(132) 
  reac_source_local(41,132) = + reac_rate_local(132) 
  reac_source_local(42,132) = - reac_rate_local(132) 
  reac_source_local(38,133) = - reac_rate_local(133) 
  reac_source_local(39,133) = + reac_rate_local(133) 
  reac_source_local(41,133) = + reac_rate_local(133) 
  reac_source_local(42,133) = - reac_rate_local(133) 
  reac_source_local(39,134) = - reac_rate_local(134) 
  reac_source_local(40,134) = + reac_rate_local(134) 
  reac_source_local(41,134) = + reac_rate_local(134) 
  reac_source_local(42,134) = - reac_rate_local(134) 
  reac_source_local(40,135) = - reac_rate_local(135) 
  reac_source_local(41,135) = + reac_rate_local(135) * 2.d0
  reac_source_local(42,135) = - reac_rate_local(135) 
  reac_source_local(41,136) = + reac_rate_local(136) 
  reac_source_local(42,136) = - reac_rate_local(136) * 2.d0
  reac_source_local(43,136) = + reac_rate_local(136) 
  reac_source_local(41,137) = + reac_rate_local(137) 
  reac_source_local(42,137) = - reac_rate_local(137) 
  reac_source_local(43,137) = - reac_rate_local(137) 
  reac_source_local(44,137) = + reac_rate_local(137) 
  reac_source_local(41,138) = + reac_rate_local(138) 
  reac_source_local(42,138) = - reac_rate_local(138) 
  reac_source_local(44,138) = - reac_rate_local(138) 
  reac_source_local(45,138) = + reac_rate_local(138) 
  reac_source_local(11,139) = - reac_rate_local(139) 
  reac_source_local(38,139) = + reac_rate_local(139) 
  reac_source_local(42,139) = + reac_rate_local(139) 
  reac_source_local(43,139) = - reac_rate_local(139) 
  reac_source_local(38,140) = - reac_rate_local(140) 
  reac_source_local(39,140) = + reac_rate_local(140) 
  reac_source_local(42,140) = + reac_rate_local(140) 
  reac_source_local(43,140) = - reac_rate_local(140) 
  reac_source_local(39,141) = - reac_rate_local(141) 
  reac_source_local(40,141) = + reac_rate_local(141) 
  reac_source_local(42,141) = + reac_rate_local(141) 
  reac_source_local(43,141) = - reac_rate_local(141) 
  reac_source_local(40,142) = - reac_rate_local(142) 
  reac_source_local(41,142) = + reac_rate_local(142) 
  reac_source_local(42,142) = + reac_rate_local(142) 
  reac_source_local(43,142) = - reac_rate_local(142) 
  reac_source_local(41,143) = - reac_rate_local(143) 
  reac_source_local(42,143) = + reac_rate_local(143) * 2.d0
  reac_source_local(43,143) = - reac_rate_local(143) 
  reac_source_local(42,144) = + reac_rate_local(144) 
  reac_source_local(43,144) = - reac_rate_local(144) * 2.d0
  reac_source_local(44,144) = + reac_rate_local(144) 
  reac_source_local(42,145) = + reac_rate_local(145) 
  reac_source_local(43,145) = - reac_rate_local(145) 
  reac_source_local(44,145) = - reac_rate_local(145) 
  reac_source_local(45,145) = + reac_rate_local(145) 
  reac_source_local(11,146) = - reac_rate_local(146) 
  reac_source_local(38,146) = + reac_rate_local(146) 
  reac_source_local(43,146) = + reac_rate_local(146) 
  reac_source_local(44,146) = - reac_rate_local(146) 
  reac_source_local(38,147) = - reac_rate_local(147) 
  reac_source_local(39,147) = + reac_rate_local(147) 
  reac_source_local(43,147) = + reac_rate_local(147) 
  reac_source_local(44,147) = - reac_rate_local(147) 
  reac_source_local(39,148) = - reac_rate_local(148) 
  reac_source_local(40,148) = + reac_rate_local(148) 
  reac_source_local(43,148) = + reac_rate_local(148) 
  reac_source_local(44,148) = - reac_rate_local(148) 
  reac_source_local(40,149) = - reac_rate_local(149) 
  reac_source_local(41,149) = + reac_rate_local(149) 
  reac_source_local(43,149) = + reac_rate_local(149) 
  reac_source_local(44,149) = - reac_rate_local(149) 
  reac_source_local(41,150) = - reac_rate_local(150) 
  reac_source_local(42,150) = + reac_rate_local(150) 
  reac_source_local(43,150) = + reac_rate_local(150) 
  reac_source_local(44,150) = - reac_rate_local(150) 
  reac_source_local(42,151) = - reac_rate_local(151) 
  reac_source_local(43,151) = + reac_rate_local(151) * 2.d0
  reac_source_local(44,151) = - reac_rate_local(151) 
  reac_source_local(43,152) = + reac_rate_local(152) 
  reac_source_local(44,152) = - reac_rate_local(152) * 2.d0
  reac_source_local(45,152) = + reac_rate_local(152) 
  reac_source_local(11,153) = - reac_rate_local(153) 
  reac_source_local(38,153) = + reac_rate_local(153) 
  reac_source_local(44,153) = + reac_rate_local(153) 
  reac_source_local(45,153) = - reac_rate_local(153) 
  reac_source_local(38,154) = - reac_rate_local(154) 
  reac_source_local(39,154) = + reac_rate_local(154) 
  reac_source_local(44,154) = + reac_rate_local(154) 
  reac_source_local(45,154) = - reac_rate_local(154) 
  reac_source_local(39,155) = - reac_rate_local(155) 
  reac_source_local(40,155) = + reac_rate_local(155) 
  reac_source_local(44,155) = + reac_rate_local(155) 
  reac_source_local(45,155) = - reac_rate_local(155) 
  reac_source_local(40,156) = - reac_rate_local(156) 
  reac_source_local(41,156) = + reac_rate_local(156) 
  reac_source_local(44,156) = + reac_rate_local(156) 
  reac_source_local(45,156) = - reac_rate_local(156) 
  reac_source_local(41,157) = - reac_rate_local(157) 
  reac_source_local(42,157) = + reac_rate_local(157) 
  reac_source_local(44,157) = + reac_rate_local(157) 
  reac_source_local(45,157) = - reac_rate_local(157) 
  reac_source_local(42,158) = - reac_rate_local(158) 
  reac_source_local(43,158) = + reac_rate_local(158) 
  reac_source_local(44,158) = + reac_rate_local(158) 
  reac_source_local(45,158) = - reac_rate_local(158) 
  reac_source_local(43,159) = - reac_rate_local(159) 
  reac_source_local(44,159) = + reac_rate_local(159) * 2.d0
  reac_source_local(45,159) = - reac_rate_local(159) 
  reac_source_local(02,160) = + reac_rate_local(160) 
  reac_source_local(50,160) = - reac_rate_local(160) * 2.d0
  reac_source_local(51,160) = + reac_rate_local(160) 
  reac_source_local(02,161) = + reac_rate_local(161) 
  reac_source_local(50,161) = - reac_rate_local(161) 
  reac_source_local(51,161) = - reac_rate_local(161) 
  reac_source_local(52,161) = + reac_rate_local(161) 
  reac_source_local(02,162) = + reac_rate_local(162) 
  reac_source_local(50,162) = - reac_rate_local(162) 
  reac_source_local(52,162) = - reac_rate_local(162) 
  reac_source_local(53,162) = + reac_rate_local(162) 
  reac_source_local(02,163) = - reac_rate_local(163) 
  reac_source_local(50,163) = + reac_rate_local(163) * 2.d0
  reac_source_local(51,163) = - reac_rate_local(163) 
  reac_source_local(50,164) = + reac_rate_local(164) 
  reac_source_local(51,164) = - reac_rate_local(164) * 2.d0
  reac_source_local(52,164) = + reac_rate_local(164) 
  reac_source_local(50,165) = + reac_rate_local(165) 
  reac_source_local(51,165) = - reac_rate_local(165) 
  reac_source_local(52,165) = - reac_rate_local(165) 
  reac_source_local(53,165) = + reac_rate_local(165) 
  reac_source_local(02,166) = - reac_rate_local(166) 
  reac_source_local(50,166) = + reac_rate_local(166) 
  reac_source_local(51,166) = + reac_rate_local(166) 
  reac_source_local(52,166) = - reac_rate_local(166) 
  reac_source_local(50,167) = - reac_rate_local(167) 
  reac_source_local(51,167) = + reac_rate_local(167) * 2.d0
  reac_source_local(52,167) = - reac_rate_local(167) 
  reac_source_local(51,168) = + reac_rate_local(168) 
  reac_source_local(52,168) = - reac_rate_local(168) * 2.d0
  reac_source_local(53,168) = + reac_rate_local(168) 
  reac_source_local(02,169) = - reac_rate_local(169) 
  reac_source_local(50,169) = + reac_rate_local(169) 
  reac_source_local(52,169) = + reac_rate_local(169) 
  reac_source_local(53,169) = - reac_rate_local(169) 
  reac_source_local(50,170) = - reac_rate_local(170) 
  reac_source_local(51,170) = + reac_rate_local(170) 
  reac_source_local(52,170) = + reac_rate_local(170) 
  reac_source_local(53,170) = - reac_rate_local(170) 
  reac_source_local(51,171) = - reac_rate_local(171) 
  reac_source_local(52,171) = + reac_rate_local(171) * 2.d0
  reac_source_local(53,171) = - reac_rate_local(171) 
  reac_source_local(16,172) = + reac_rate_local(172) 
  reac_source_local(57,172) = - reac_rate_local(172) 
  reac_source_local(57,173) = + reac_rate_local(173) 
  reac_source_local(58,173) = - reac_rate_local(173) 
  reac_source_local(58,174) = + reac_rate_local(174) 
  reac_source_local(59,174) = - reac_rate_local(174) 
  reac_source_local(16,175) = + reac_rate_local(175) 
  reac_source_local(57,175) = - reac_rate_local(175) 
  reac_source_local(57,176) = + reac_rate_local(176) 
  reac_source_local(58,176) = - reac_rate_local(176) 
  reac_source_local(58,177) = + reac_rate_local(177) 
  reac_source_local(59,177) = - reac_rate_local(177) 
  reac_source_local(01,178) = + reac_rate_local(178) 
  reac_source_local(04,178) = - reac_rate_local(178) 
  reac_source_local(06,178) = + reac_rate_local(178) 
  reac_source_local(50,178) = - reac_rate_local(178) 
  reac_source_local(01,179) = + reac_rate_local(179) 
  reac_source_local(04,179) = - reac_rate_local(179) 
  reac_source_local(06,179) = + reac_rate_local(179) 
  reac_source_local(51,179) = - reac_rate_local(179) 
  reac_source_local(01,180) = + reac_rate_local(180) 
  reac_source_local(04,180) = - reac_rate_local(180) 
  reac_source_local(06,180) = + reac_rate_local(180) 
  reac_source_local(52,180) = - reac_rate_local(180) 
  reac_source_local(01,181) = + reac_rate_local(181) 
  reac_source_local(04,181) = - reac_rate_local(181) 
  reac_source_local(06,181) = + reac_rate_local(181) 
  reac_source_local(53,181) = - reac_rate_local(181) 
  reac_source_local(02,182) = + reac_rate_local(182) 
  reac_source_local(04,182) = + reac_rate_local(182) 
  reac_source_local(06,182) = + reac_rate_local(182) 
  reac_source_local(07,182) = - reac_rate_local(182) 
  reac_source_local(50,182) = - reac_rate_local(182) 
  reac_source_local(02,183) = + reac_rate_local(183) 
  reac_source_local(04,183) = + reac_rate_local(183) 
  reac_source_local(06,183) = + reac_rate_local(183) 
  reac_source_local(07,183) = - reac_rate_local(183) 
  reac_source_local(51,183) = - reac_rate_local(183) 
  reac_source_local(02,184) = + reac_rate_local(184) 
  reac_source_local(04,184) = + reac_rate_local(184) 
  reac_source_local(06,184) = + reac_rate_local(184) 
  reac_source_local(07,184) = - reac_rate_local(184) 
  reac_source_local(52,184) = - reac_rate_local(184) 
  reac_source_local(02,185) = + reac_rate_local(185) 
  reac_source_local(04,185) = + reac_rate_local(185) 
  reac_source_local(06,185) = + reac_rate_local(185) 
  reac_source_local(07,185) = - reac_rate_local(185) 
  reac_source_local(53,185) = - reac_rate_local(185) 
  reac_source_local(01,186) = - reac_rate_local(186) 
  reac_source_local(02,186) = + reac_rate_local(186) 
  reac_source_local(04,186) = - reac_rate_local(186) 
  reac_source_local(50,186) = - reac_rate_local(186) 
  reac_source_local(56,186) = + reac_rate_local(186) 
  reac_source_local(01,187) = - reac_rate_local(187) 
  reac_source_local(02,187) = + reac_rate_local(187) 
  reac_source_local(04,187) = - reac_rate_local(187) 
  reac_source_local(51,187) = - reac_rate_local(187) 
  reac_source_local(56,187) = + reac_rate_local(187) 
  reac_source_local(01,188) = - reac_rate_local(188) 
  reac_source_local(02,188) = + reac_rate_local(188) 
  reac_source_local(04,188) = - reac_rate_local(188) 
  reac_source_local(52,188) = - reac_rate_local(188) 
  reac_source_local(56,188) = + reac_rate_local(188) 
  reac_source_local(01,189) = - reac_rate_local(189) 
  reac_source_local(02,189) = + reac_rate_local(189) 
  reac_source_local(04,189) = - reac_rate_local(189) 
  reac_source_local(53,189) = - reac_rate_local(189) 
  reac_source_local(56,189) = + reac_rate_local(189) 
  reac_source_local(01,190) = + reac_rate_local(190) * 2.d0
  reac_source_local(50,190) = - reac_rate_local(190) 
  reac_source_local(01,191) = + reac_rate_local(191) * 2.d0
  reac_source_local(50,191) = - reac_rate_local(191) 
  reac_source_local(01,192) = + reac_rate_local(192) * 2.d0
  reac_source_local(51,192) = - reac_rate_local(192) 
  reac_source_local(01,193) = + reac_rate_local(193) * 2.d0
  reac_source_local(51,193) = - reac_rate_local(193) 
  reac_source_local(01,194) = + reac_rate_local(194) * 2.d0
  reac_source_local(52,194) = - reac_rate_local(194) 
  reac_source_local(01,195) = + reac_rate_local(195) * 2.d0
  reac_source_local(52,195) = - reac_rate_local(195) 
  reac_source_local(01,196) = + reac_rate_local(196) * 2.d0
  reac_source_local(53,196) = - reac_rate_local(196) 
  reac_source_local(01,197) = + reac_rate_local(197) * 2.d0
  reac_source_local(53,197) = - reac_rate_local(197) 
  reac_source_local(02,198) = + reac_rate_local(198) 
  reac_source_local(04,198) = - reac_rate_local(198) 
  reac_source_local(06,198) = - reac_rate_local(198) 
  reac_source_local(07,198) = + reac_rate_local(198) 
  reac_source_local(50,198) = - reac_rate_local(198) 
  reac_source_local(02,199) = + reac_rate_local(199) 
  reac_source_local(04,199) = - reac_rate_local(199) 
  reac_source_local(06,199) = - reac_rate_local(199) 
  reac_source_local(07,199) = + reac_rate_local(199) 
  reac_source_local(51,199) = - reac_rate_local(199) 
  reac_source_local(02,200) = + reac_rate_local(200) 
  reac_source_local(04,200) = - reac_rate_local(200) 
  reac_source_local(06,200) = - reac_rate_local(200) 
  reac_source_local(07,200) = + reac_rate_local(200) 
  reac_source_local(52,200) = - reac_rate_local(200) 
  reac_source_local(02,201) = + reac_rate_local(201) 
  reac_source_local(04,201) = - reac_rate_local(201) 
  reac_source_local(06,201) = - reac_rate_local(201) 
  reac_source_local(07,201) = + reac_rate_local(201) 
  reac_source_local(53,201) = - reac_rate_local(201) 
  reac_source_local(04,202) = + reac_rate_local(202) 
  reac_source_local(05,202) = - reac_rate_local(202) 
  reac_source_local(08,202) = + reac_rate_local(202) 
  reac_source_local(50,202) = - reac_rate_local(202) 
  reac_source_local(04,203) = + reac_rate_local(203) 
  reac_source_local(05,203) = - reac_rate_local(203) 
  reac_source_local(08,203) = + reac_rate_local(203) 
  reac_source_local(51,203) = - reac_rate_local(203) 
  reac_source_local(04,204) = + reac_rate_local(204) 
  reac_source_local(05,204) = - reac_rate_local(204) 
  reac_source_local(08,204) = + reac_rate_local(204) 
  reac_source_local(52,204) = - reac_rate_local(204) 
  reac_source_local(04,205) = + reac_rate_local(205) 
  reac_source_local(05,205) = - reac_rate_local(205) 
  reac_source_local(08,205) = + reac_rate_local(205) 
  reac_source_local(53,205) = - reac_rate_local(205) 
  reac_source_local(01,206) = + reac_rate_local(206) 
  reac_source_local(06,206) = - reac_rate_local(206) 
  reac_source_local(08,206) = + reac_rate_local(206) 
  reac_source_local(50,206) = - reac_rate_local(206) 
  reac_source_local(01,207) = + reac_rate_local(207) 
  reac_source_local(06,207) = - reac_rate_local(207) 
  reac_source_local(08,207) = + reac_rate_local(207) 
  reac_source_local(51,207) = - reac_rate_local(207) 
  reac_source_local(01,208) = + reac_rate_local(208) 
  reac_source_local(06,208) = - reac_rate_local(208) 
  reac_source_local(08,208) = + reac_rate_local(208) 
  reac_source_local(52,208) = - reac_rate_local(208) 
  reac_source_local(01,209) = + reac_rate_local(209) 
  reac_source_local(06,209) = - reac_rate_local(209) 
  reac_source_local(08,209) = + reac_rate_local(209) 
  reac_source_local(53,209) = - reac_rate_local(209) 
  reac_source_local(06,210) = + reac_rate_local(210) 
  reac_source_local(07,210) = - reac_rate_local(210) 
  reac_source_local(08,210) = + reac_rate_local(210) 
  reac_source_local(50,210) = - reac_rate_local(210) 
  reac_source_local(06,211) = + reac_rate_local(211) 
  reac_source_local(07,211) = - reac_rate_local(211) 
  reac_source_local(08,211) = + reac_rate_local(211) 
  reac_source_local(51,211) = - reac_rate_local(211) 
  reac_source_local(06,212) = + reac_rate_local(212) 
  reac_source_local(07,212) = - reac_rate_local(212) 
  reac_source_local(08,212) = + reac_rate_local(212) 
  reac_source_local(52,212) = - reac_rate_local(212) 
  reac_source_local(06,213) = + reac_rate_local(213) 
  reac_source_local(07,213) = - reac_rate_local(213) 
  reac_source_local(08,213) = + reac_rate_local(213) 
  reac_source_local(53,213) = - reac_rate_local(213) 
  reac_source_local(08,214) = + reac_rate_local(214) * 2.d0
  reac_source_local(09,214) = - reac_rate_local(214) 
  reac_source_local(50,214) = - reac_rate_local(214) 
  reac_source_local(08,215) = + reac_rate_local(215) * 2.d0
  reac_source_local(09,215) = - reac_rate_local(215) 
  reac_source_local(51,215) = - reac_rate_local(215) 
  reac_source_local(08,216) = + reac_rate_local(216) * 2.d0
  reac_source_local(09,216) = - reac_rate_local(216) 
  reac_source_local(52,216) = - reac_rate_local(216) 
  reac_source_local(08,217) = + reac_rate_local(217) * 2.d0
  reac_source_local(09,217) = - reac_rate_local(217) 
  reac_source_local(53,217) = - reac_rate_local(217) 
  reac_source_local(01,218) = + reac_rate_local(218) 
  reac_source_local(02,218) = + reac_rate_local(218) 
  reac_source_local(04,218) = + reac_rate_local(218) 
  reac_source_local(50,218) = - reac_rate_local(218) 
  reac_source_local(56,218) = - reac_rate_local(218) 
  reac_source_local(01,219) = + reac_rate_local(219) 
  reac_source_local(02,219) = + reac_rate_local(219) 
  reac_source_local(04,219) = + reac_rate_local(219) 
  reac_source_local(51,219) = - reac_rate_local(219) 
  reac_source_local(56,219) = - reac_rate_local(219) 
  reac_source_local(01,220) = + reac_rate_local(220) 
  reac_source_local(02,220) = + reac_rate_local(220) 
  reac_source_local(04,220) = + reac_rate_local(220) 
  reac_source_local(52,220) = - reac_rate_local(220) 
  reac_source_local(56,220) = - reac_rate_local(220) 
  reac_source_local(01,221) = + reac_rate_local(221) 
  reac_source_local(02,221) = + reac_rate_local(221) 
  reac_source_local(04,221) = + reac_rate_local(221) 
  reac_source_local(53,221) = - reac_rate_local(221) 
  reac_source_local(56,221) = - reac_rate_local(221) 
  reac_source_local(02,222) = + reac_rate_local(222) 
  reac_source_local(06,222) = - reac_rate_local(222) 
  reac_source_local(50,222) = - reac_rate_local(222) 
  reac_source_local(56,222) = + reac_rate_local(222) 
  reac_source_local(02,223) = + reac_rate_local(223) 
  reac_source_local(06,223) = - reac_rate_local(223) 
  reac_source_local(51,223) = - reac_rate_local(223) 
  reac_source_local(56,223) = + reac_rate_local(223) 
  reac_source_local(02,224) = + reac_rate_local(224) 
  reac_source_local(06,224) = - reac_rate_local(224) 
  reac_source_local(52,224) = - reac_rate_local(224) 
  reac_source_local(56,224) = + reac_rate_local(224) 
  reac_source_local(02,225) = + reac_rate_local(225) 
  reac_source_local(06,225) = - reac_rate_local(225) 
  reac_source_local(53,225) = - reac_rate_local(225) 
  reac_source_local(56,225) = + reac_rate_local(225) 
  reac_source_local(01,226) = + reac_rate_local(226) 
  reac_source_local(12,226) = - reac_rate_local(226) 
  reac_source_local(13,226) = + reac_rate_local(226) 
  reac_source_local(50,226) = - reac_rate_local(226) 
  reac_source_local(01,227) = + reac_rate_local(227) 
  reac_source_local(12,227) = - reac_rate_local(227) 
  reac_source_local(13,227) = + reac_rate_local(227) 
  reac_source_local(51,227) = - reac_rate_local(227) 
  reac_source_local(01,228) = + reac_rate_local(228) 
  reac_source_local(12,228) = - reac_rate_local(228) 
  reac_source_local(13,228) = + reac_rate_local(228) 
  reac_source_local(52,228) = - reac_rate_local(228) 
  reac_source_local(01,229) = + reac_rate_local(229) 
  reac_source_local(12,229) = - reac_rate_local(229) 
  reac_source_local(13,229) = + reac_rate_local(229) 
  reac_source_local(53,229) = - reac_rate_local(229) 
  reac_source_local(01,230) = + reac_rate_local(230) 
  reac_source_local(11,230) = - reac_rate_local(230) 
  reac_source_local(14,230) = + reac_rate_local(230) 
  reac_source_local(50,230) = - reac_rate_local(230) 
  reac_source_local(01,231) = + reac_rate_local(231) 
  reac_source_local(11,231) = - reac_rate_local(231) 
  reac_source_local(14,231) = + reac_rate_local(231) 
  reac_source_local(51,231) = - reac_rate_local(231) 
  reac_source_local(01,232) = + reac_rate_local(232) 
  reac_source_local(11,232) = - reac_rate_local(232) 
  reac_source_local(14,232) = + reac_rate_local(232) 
  reac_source_local(52,232) = - reac_rate_local(232) 
  reac_source_local(01,233) = + reac_rate_local(233) 
  reac_source_local(11,233) = - reac_rate_local(233) 
  reac_source_local(14,233) = + reac_rate_local(233) 
  reac_source_local(53,233) = - reac_rate_local(233) 
  reac_source_local(01,234) = + reac_rate_local(234) 
  reac_source_local(17,234) = - reac_rate_local(234) 
  reac_source_local(24,234) = + reac_rate_local(234) 
  reac_source_local(50,234) = - reac_rate_local(234) 
  reac_source_local(01,235) = + reac_rate_local(235) 
  reac_source_local(17,235) = - reac_rate_local(235) 
  reac_source_local(24,235) = + reac_rate_local(235) 
  reac_source_local(51,235) = - reac_rate_local(235) 
  reac_source_local(01,236) = + reac_rate_local(236) 
  reac_source_local(17,236) = - reac_rate_local(236) 
  reac_source_local(24,236) = + reac_rate_local(236) 
  reac_source_local(52,236) = - reac_rate_local(236) 
  reac_source_local(01,237) = + reac_rate_local(237) 
  reac_source_local(17,237) = - reac_rate_local(237) 
  reac_source_local(24,237) = + reac_rate_local(237) 
  reac_source_local(53,237) = - reac_rate_local(237) 
  reac_source_local(06,238) = + reac_rate_local(238) 
  reac_source_local(17,238) = - reac_rate_local(238) 
  reac_source_local(26,238) = + reac_rate_local(238) 
  reac_source_local(50,238) = - reac_rate_local(238) 
  reac_source_local(06,239) = + reac_rate_local(239) 
  reac_source_local(17,239) = - reac_rate_local(239) 
  reac_source_local(26,239) = + reac_rate_local(239) 
  reac_source_local(51,239) = - reac_rate_local(239) 
  reac_source_local(06,240) = + reac_rate_local(240) 
  reac_source_local(17,240) = - reac_rate_local(240) 
  reac_source_local(26,240) = + reac_rate_local(240) 
  reac_source_local(52,240) = - reac_rate_local(240) 
  reac_source_local(06,241) = + reac_rate_local(241) 
  reac_source_local(17,241) = - reac_rate_local(241) 
  reac_source_local(26,241) = + reac_rate_local(241) 
  reac_source_local(53,241) = - reac_rate_local(241) 
  reac_source_local(01,242) = + reac_rate_local(242) 
  reac_source_local(18,242) = - reac_rate_local(242) 
  reac_source_local(26,242) = + reac_rate_local(242) 
  reac_source_local(50,242) = - reac_rate_local(242) 
  reac_source_local(01,243) = + reac_rate_local(243) 
  reac_source_local(18,243) = - reac_rate_local(243) 
  reac_source_local(26,243) = + reac_rate_local(243) 
  reac_source_local(51,243) = - reac_rate_local(243) 
  reac_source_local(01,244) = + reac_rate_local(244) 
  reac_source_local(18,244) = - reac_rate_local(244) 
  reac_source_local(26,244) = + reac_rate_local(244) 
  reac_source_local(52,244) = - reac_rate_local(244) 
  reac_source_local(01,245) = + reac_rate_local(245) 
  reac_source_local(18,245) = - reac_rate_local(245) 
  reac_source_local(26,245) = + reac_rate_local(245) 
  reac_source_local(53,245) = - reac_rate_local(245) 
  reac_source_local(06,246) = + reac_rate_local(246) 
  reac_source_local(12,246) = + reac_rate_local(246) 
  reac_source_local(18,246) = - reac_rate_local(246) 
  reac_source_local(50,246) = - reac_rate_local(246) 
  reac_source_local(06,247) = + reac_rate_local(247) 
  reac_source_local(12,247) = + reac_rate_local(247) 
  reac_source_local(18,247) = - reac_rate_local(247) 
  reac_source_local(51,247) = - reac_rate_local(247) 
  reac_source_local(06,248) = + reac_rate_local(248) 
  reac_source_local(12,248) = + reac_rate_local(248) 
  reac_source_local(18,248) = - reac_rate_local(248) 
  reac_source_local(52,248) = - reac_rate_local(248) 
  reac_source_local(06,249) = + reac_rate_local(249) 
  reac_source_local(12,249) = + reac_rate_local(249) 
  reac_source_local(18,249) = - reac_rate_local(249) 
  reac_source_local(53,249) = - reac_rate_local(249) 
  reac_source_local(08,250) = + reac_rate_local(250) 
  reac_source_local(24,250) = - reac_rate_local(250) 
  reac_source_local(26,250) = + reac_rate_local(250) 
  reac_source_local(50,250) = - reac_rate_local(250) 
  reac_source_local(08,251) = + reac_rate_local(251) 
  reac_source_local(24,251) = - reac_rate_local(251) 
  reac_source_local(26,251) = + reac_rate_local(251) 
  reac_source_local(51,251) = - reac_rate_local(251) 
  reac_source_local(08,252) = + reac_rate_local(252) 
  reac_source_local(24,252) = - reac_rate_local(252) 
  reac_source_local(26,252) = + reac_rate_local(252) 
  reac_source_local(52,252) = - reac_rate_local(252) 
  reac_source_local(08,253) = + reac_rate_local(253) 
  reac_source_local(24,253) = - reac_rate_local(253) 
  reac_source_local(26,253) = + reac_rate_local(253) 
  reac_source_local(53,253) = - reac_rate_local(253) 
  reac_source_local(08,254) = + reac_rate_local(254) 
  reac_source_local(26,254) = + reac_rate_local(254) 
  reac_source_local(28,254) = - reac_rate_local(254) 
  reac_source_local(50,254) = - reac_rate_local(254) 
  reac_source_local(08,255) = + reac_rate_local(255) 
  reac_source_local(26,255) = + reac_rate_local(255) 
  reac_source_local(28,255) = - reac_rate_local(255) 
  reac_source_local(51,255) = - reac_rate_local(255) 
  reac_source_local(08,256) = + reac_rate_local(256) 
  reac_source_local(26,256) = + reac_rate_local(256) 
  reac_source_local(28,256) = - reac_rate_local(256) 
  reac_source_local(52,256) = - reac_rate_local(256) 
  reac_source_local(08,257) = + reac_rate_local(257) 
  reac_source_local(26,257) = + reac_rate_local(257) 
  reac_source_local(28,257) = - reac_rate_local(257) 
  reac_source_local(53,257) = - reac_rate_local(257) 
  reac_source_local(06,258) = + reac_rate_local(258) 
  reac_source_local(13,258) = + reac_rate_local(258) 
  reac_source_local(25,258) = - reac_rate_local(258) 
  reac_source_local(50,258) = - reac_rate_local(258) 
  reac_source_local(06,259) = + reac_rate_local(259) 
  reac_source_local(13,259) = + reac_rate_local(259) 
  reac_source_local(25,259) = - reac_rate_local(259) 
  reac_source_local(51,259) = - reac_rate_local(259) 
  reac_source_local(06,260) = + reac_rate_local(260) 
  reac_source_local(13,260) = + reac_rate_local(260) 
  reac_source_local(25,260) = - reac_rate_local(260) 
  reac_source_local(52,260) = - reac_rate_local(260) 
  reac_source_local(06,261) = + reac_rate_local(261) 
  reac_source_local(13,261) = + reac_rate_local(261) 
  reac_source_local(25,261) = - reac_rate_local(261) 
  reac_source_local(53,261) = - reac_rate_local(261) 
  reac_source_local(01,262) = + reac_rate_local(262) 
  reac_source_local(10,262) = - reac_rate_local(262) 
  reac_source_local(12,262) = + reac_rate_local(262) 
  reac_source_local(50,262) = - reac_rate_local(262) 
  reac_source_local(01,263) = + reac_rate_local(263) 
  reac_source_local(10,263) = - reac_rate_local(263) 
  reac_source_local(12,263) = + reac_rate_local(263) 
  reac_source_local(51,263) = - reac_rate_local(263) 
  reac_source_local(01,264) = + reac_rate_local(264) 
  reac_source_local(10,264) = - reac_rate_local(264) 
  reac_source_local(12,264) = + reac_rate_local(264) 
  reac_source_local(52,264) = - reac_rate_local(264) 
  reac_source_local(01,265) = + reac_rate_local(265) 
  reac_source_local(10,265) = - reac_rate_local(265) 
  reac_source_local(12,265) = + reac_rate_local(265) 
  reac_source_local(53,265) = - reac_rate_local(265) 
  reac_source_local(01,266) = - reac_rate_local(266) 
  reac_source_local(10,266) = + reac_rate_local(266) 
  reac_source_local(12,266) = + reac_rate_local(266) 
  reac_source_local(38,266) = - reac_rate_local(266) 
  reac_source_local(01,267) = - reac_rate_local(267) 
  reac_source_local(10,267) = + reac_rate_local(267) 
  reac_source_local(12,267) = + reac_rate_local(267) 
  reac_source_local(39,267) = - reac_rate_local(267) 
  reac_source_local(01,268) = - reac_rate_local(268) 
  reac_source_local(10,268) = + reac_rate_local(268) 
  reac_source_local(12,268) = + reac_rate_local(268) 
  reac_source_local(40,268) = - reac_rate_local(268) 
  reac_source_local(01,269) = - reac_rate_local(269) 
  reac_source_local(10,269) = + reac_rate_local(269) 
  reac_source_local(12,269) = + reac_rate_local(269) 
  reac_source_local(41,269) = - reac_rate_local(269) 
  reac_source_local(01,270) = - reac_rate_local(270) 
  reac_source_local(10,270) = + reac_rate_local(270) 
  reac_source_local(12,270) = + reac_rate_local(270) 
  reac_source_local(42,270) = - reac_rate_local(270) 
  reac_source_local(01,271) = - reac_rate_local(271) 
  reac_source_local(10,271) = + reac_rate_local(271) 
  reac_source_local(12,271) = + reac_rate_local(271) 
  reac_source_local(43,271) = - reac_rate_local(271) 
  reac_source_local(01,272) = - reac_rate_local(272) 
  reac_source_local(10,272) = + reac_rate_local(272) 
  reac_source_local(12,272) = + reac_rate_local(272) 
  reac_source_local(44,272) = - reac_rate_local(272) 
  reac_source_local(01,273) = - reac_rate_local(273) 
  reac_source_local(10,273) = + reac_rate_local(273) 
  reac_source_local(12,273) = + reac_rate_local(273) 
  reac_source_local(45,273) = - reac_rate_local(273) 
  reac_source_local(01,274) = + reac_rate_local(274) 
  reac_source_local(02,274) = - reac_rate_local(274) 
  reac_source_local(14,274) = + reac_rate_local(274) 
  reac_source_local(38,274) = - reac_rate_local(274) 
  reac_source_local(01,275) = + reac_rate_local(275) 
  reac_source_local(02,275) = - reac_rate_local(275) 
  reac_source_local(14,275) = + reac_rate_local(275) 
  reac_source_local(39,275) = - reac_rate_local(275) 
  reac_source_local(01,276) = + reac_rate_local(276) 
  reac_source_local(02,276) = - reac_rate_local(276) 
  reac_source_local(14,276) = + reac_rate_local(276) 
  reac_source_local(40,276) = - reac_rate_local(276) 
  reac_source_local(01,277) = + reac_rate_local(277) 
  reac_source_local(02,277) = - reac_rate_local(277) 
  reac_source_local(14,277) = + reac_rate_local(277) 
  reac_source_local(41,277) = - reac_rate_local(277) 
  reac_source_local(01,278) = + reac_rate_local(278) 
  reac_source_local(02,278) = - reac_rate_local(278) 
  reac_source_local(14,278) = + reac_rate_local(278) 
  reac_source_local(42,278) = - reac_rate_local(278) 
  reac_source_local(01,279) = + reac_rate_local(279) 
  reac_source_local(02,279) = - reac_rate_local(279) 
  reac_source_local(14,279) = + reac_rate_local(279) 
  reac_source_local(43,279) = - reac_rate_local(279) 
  reac_source_local(01,280) = + reac_rate_local(280) 
  reac_source_local(02,280) = - reac_rate_local(280) 
  reac_source_local(14,280) = + reac_rate_local(280) 
  reac_source_local(44,280) = - reac_rate_local(280) 
  reac_source_local(01,281) = + reac_rate_local(281) 
  reac_source_local(02,281) = - reac_rate_local(281) 
  reac_source_local(14,281) = + reac_rate_local(281) 
  reac_source_local(45,281) = - reac_rate_local(281) 
  reac_source_local(07,282) = - reac_rate_local(282) 
  reac_source_local(12,282) = + reac_rate_local(282) 
  reac_source_local(17,282) = + reac_rate_local(282) 
  reac_source_local(38,282) = - reac_rate_local(282) 
  reac_source_local(07,283) = - reac_rate_local(283) 
  reac_source_local(12,283) = + reac_rate_local(283) 
  reac_source_local(17,283) = + reac_rate_local(283) 
  reac_source_local(39,283) = - reac_rate_local(283) 
  reac_source_local(07,284) = - reac_rate_local(284) 
  reac_source_local(12,284) = + reac_rate_local(284) 
  reac_source_local(17,284) = + reac_rate_local(284) 
  reac_source_local(40,284) = - reac_rate_local(284) 
  reac_source_local(07,285) = - reac_rate_local(285) 
  reac_source_local(12,285) = + reac_rate_local(285) 
  reac_source_local(17,285) = + reac_rate_local(285) 
  reac_source_local(41,285) = - reac_rate_local(285) 
  reac_source_local(07,286) = - reac_rate_local(286) 
  reac_source_local(12,286) = + reac_rate_local(286) 
  reac_source_local(17,286) = + reac_rate_local(286) 
  reac_source_local(42,286) = - reac_rate_local(286) 
  reac_source_local(07,287) = - reac_rate_local(287) 
  reac_source_local(12,287) = + reac_rate_local(287) 
  reac_source_local(17,287) = + reac_rate_local(287) 
  reac_source_local(43,287) = - reac_rate_local(287) 
  reac_source_local(07,288) = - reac_rate_local(288) 
  reac_source_local(12,288) = + reac_rate_local(288) 
  reac_source_local(17,288) = + reac_rate_local(288) 
  reac_source_local(44,288) = - reac_rate_local(288) 
  reac_source_local(07,289) = - reac_rate_local(289) 
  reac_source_local(12,289) = + reac_rate_local(289) 
  reac_source_local(17,289) = + reac_rate_local(289) 
  reac_source_local(45,289) = - reac_rate_local(289) 
  reac_source_local(04,290) = - reac_rate_local(290) 
  reac_source_local(10,290) = + reac_rate_local(290) 
  reac_source_local(18,290) = + reac_rate_local(290) 
  reac_source_local(38,290) = - reac_rate_local(290) 
  reac_source_local(04,291) = - reac_rate_local(291) 
  reac_source_local(10,291) = + reac_rate_local(291) 
  reac_source_local(18,291) = + reac_rate_local(291) 
  reac_source_local(39,291) = - reac_rate_local(291) 
  reac_source_local(04,292) = - reac_rate_local(292) 
  reac_source_local(10,292) = + reac_rate_local(292) 
  reac_source_local(18,292) = + reac_rate_local(292) 
  reac_source_local(40,292) = - reac_rate_local(292) 
  reac_source_local(04,293) = - reac_rate_local(293) 
  reac_source_local(10,293) = + reac_rate_local(293) 
  reac_source_local(18,293) = + reac_rate_local(293) 
  reac_source_local(41,293) = - reac_rate_local(293) 
  reac_source_local(04,294) = - reac_rate_local(294) 
  reac_source_local(10,294) = + reac_rate_local(294) 
  reac_source_local(18,294) = + reac_rate_local(294) 
  reac_source_local(42,294) = - reac_rate_local(294) 
  reac_source_local(04,295) = - reac_rate_local(295) 
  reac_source_local(10,295) = + reac_rate_local(295) 
  reac_source_local(18,295) = + reac_rate_local(295) 
  reac_source_local(43,295) = - reac_rate_local(295) 
  reac_source_local(04,296) = - reac_rate_local(296) 
  reac_source_local(10,296) = + reac_rate_local(296) 
  reac_source_local(18,296) = + reac_rate_local(296) 
  reac_source_local(44,296) = - reac_rate_local(296) 
  reac_source_local(04,297) = - reac_rate_local(297) 
  reac_source_local(10,297) = + reac_rate_local(297) 
  reac_source_local(18,297) = + reac_rate_local(297) 
  reac_source_local(45,297) = - reac_rate_local(297) 
  reac_source_local(06,298) = - reac_rate_local(298) 
  reac_source_local(12,298) = + reac_rate_local(298) 
  reac_source_local(18,298) = + reac_rate_local(298) 
  reac_source_local(38,298) = - reac_rate_local(298) 
  reac_source_local(06,299) = - reac_rate_local(299) 
  reac_source_local(12,299) = + reac_rate_local(299) 
  reac_source_local(18,299) = + reac_rate_local(299) 
  reac_source_local(39,299) = - reac_rate_local(299) 
  reac_source_local(06,300) = - reac_rate_local(300) 
  reac_source_local(12,300) = + reac_rate_local(300) 
  reac_source_local(18,300) = + reac_rate_local(300) 
  reac_source_local(40,300) = - reac_rate_local(300) 
  reac_source_local(06,301) = - reac_rate_local(301) 
  reac_source_local(12,301) = + reac_rate_local(301) 
  reac_source_local(18,301) = + reac_rate_local(301) 
  reac_source_local(41,301) = - reac_rate_local(301) 
  reac_source_local(06,302) = - reac_rate_local(302) 
  reac_source_local(12,302) = + reac_rate_local(302) 
  reac_source_local(18,302) = + reac_rate_local(302) 
  reac_source_local(42,302) = - reac_rate_local(302) 
  reac_source_local(06,303) = - reac_rate_local(303) 
  reac_source_local(12,303) = + reac_rate_local(303) 
  reac_source_local(18,303) = + reac_rate_local(303) 
  reac_source_local(43,303) = - reac_rate_local(303) 
  reac_source_local(06,304) = - reac_rate_local(304) 
  reac_source_local(12,304) = + reac_rate_local(304) 
  reac_source_local(18,304) = + reac_rate_local(304) 
  reac_source_local(44,304) = - reac_rate_local(304) 
  reac_source_local(06,305) = - reac_rate_local(305) 
  reac_source_local(12,305) = + reac_rate_local(305) 
  reac_source_local(18,305) = + reac_rate_local(305) 
  reac_source_local(45,305) = - reac_rate_local(305) 
  reac_source_local(10,306) = + reac_rate_local(306) * 2.d0
  reac_source_local(38,306) = - reac_rate_local(306) 
  reac_source_local(10,307) = + reac_rate_local(307) * 2.d0
  reac_source_local(39,307) = - reac_rate_local(307) 
  reac_source_local(10,308) = + reac_rate_local(308) * 2.d0
  reac_source_local(40,308) = - reac_rate_local(308) 
  reac_source_local(10,309) = + reac_rate_local(309) * 2.d0
  reac_source_local(41,309) = - reac_rate_local(309) 
  reac_source_local(10,310) = + reac_rate_local(310) * 2.d0
  reac_source_local(42,310) = - reac_rate_local(310) 
  reac_source_local(10,311) = + reac_rate_local(311) * 2.d0
  reac_source_local(43,311) = - reac_rate_local(311) 
  reac_source_local(10,312) = + reac_rate_local(312) * 2.d0
  reac_source_local(44,312) = - reac_rate_local(312) 
  reac_source_local(10,313) = + reac_rate_local(313) * 2.d0
  reac_source_local(45,313) = - reac_rate_local(313) 
  reac_source_local(01,314) = + reac_rate_local(314) 
  reac_source_local(06,314) = - reac_rate_local(314) 
  reac_source_local(20,314) = + reac_rate_local(314) 
  reac_source_local(38,314) = - reac_rate_local(314) 
  reac_source_local(01,315) = + reac_rate_local(315) 
  reac_source_local(06,315) = - reac_rate_local(315) 
  reac_source_local(20,315) = + reac_rate_local(315) 
  reac_source_local(39,315) = - reac_rate_local(315) 
  reac_source_local(01,316) = + reac_rate_local(316) 
  reac_source_local(06,316) = - reac_rate_local(316) 
  reac_source_local(20,316) = + reac_rate_local(316) 
  reac_source_local(40,316) = - reac_rate_local(316) 
  reac_source_local(01,317) = + reac_rate_local(317) 
  reac_source_local(06,317) = - reac_rate_local(317) 
  reac_source_local(20,317) = + reac_rate_local(317) 
  reac_source_local(41,317) = - reac_rate_local(317) 
  reac_source_local(01,318) = + reac_rate_local(318) 
  reac_source_local(06,318) = - reac_rate_local(318) 
  reac_source_local(20,318) = + reac_rate_local(318) 
  reac_source_local(42,318) = - reac_rate_local(318) 
  reac_source_local(01,319) = + reac_rate_local(319) 
  reac_source_local(06,319) = - reac_rate_local(319) 
  reac_source_local(20,319) = + reac_rate_local(319) 
  reac_source_local(43,319) = - reac_rate_local(319) 
  reac_source_local(01,320) = + reac_rate_local(320) 
  reac_source_local(06,320) = - reac_rate_local(320) 
  reac_source_local(20,320) = + reac_rate_local(320) 
  reac_source_local(44,320) = - reac_rate_local(320) 
  reac_source_local(01,321) = + reac_rate_local(321) 
  reac_source_local(06,321) = - reac_rate_local(321) 
  reac_source_local(20,321) = + reac_rate_local(321) 
  reac_source_local(45,321) = - reac_rate_local(321) 
  reac_source_local(06,322) = + reac_rate_local(322) 
  reac_source_local(07,322) = - reac_rate_local(322) 
  reac_source_local(20,322) = + reac_rate_local(322) 
  reac_source_local(38,322) = - reac_rate_local(322) 
  reac_source_local(06,323) = + reac_rate_local(323) 
  reac_source_local(07,323) = - reac_rate_local(323) 
  reac_source_local(20,323) = + reac_rate_local(323) 
  reac_source_local(39,323) = - reac_rate_local(323) 
  reac_source_local(06,324) = + reac_rate_local(324) 
  reac_source_local(07,324) = - reac_rate_local(324) 
  reac_source_local(20,324) = + reac_rate_local(324) 
  reac_source_local(40,324) = - reac_rate_local(324) 
  reac_source_local(06,325) = + reac_rate_local(325) 
  reac_source_local(07,325) = - reac_rate_local(325) 
  reac_source_local(20,325) = + reac_rate_local(325) 
  reac_source_local(41,325) = - reac_rate_local(325) 
  reac_source_local(06,326) = + reac_rate_local(326) 
  reac_source_local(07,326) = - reac_rate_local(326) 
  reac_source_local(20,326) = + reac_rate_local(326) 
  reac_source_local(42,326) = - reac_rate_local(326) 
  reac_source_local(06,327) = + reac_rate_local(327) 
  reac_source_local(07,327) = - reac_rate_local(327) 
  reac_source_local(20,327) = + reac_rate_local(327) 
  reac_source_local(43,327) = - reac_rate_local(327) 
  reac_source_local(06,328) = + reac_rate_local(328) 
  reac_source_local(07,328) = - reac_rate_local(328) 
  reac_source_local(20,328) = + reac_rate_local(328) 
  reac_source_local(44,328) = - reac_rate_local(328) 
  reac_source_local(06,329) = + reac_rate_local(329) 
  reac_source_local(07,329) = - reac_rate_local(329) 
  reac_source_local(20,329) = + reac_rate_local(329) 
  reac_source_local(45,329) = - reac_rate_local(329) 
  reac_source_local(04,330) = + reac_rate_local(330) 
  reac_source_local(05,330) = - reac_rate_local(330) 
  reac_source_local(20,330) = + reac_rate_local(330) 
  reac_source_local(38,330) = - reac_rate_local(330) 
  reac_source_local(04,331) = + reac_rate_local(331) 
  reac_source_local(05,331) = - reac_rate_local(331) 
  reac_source_local(20,331) = + reac_rate_local(331) 
  reac_source_local(39,331) = - reac_rate_local(331) 
  reac_source_local(04,332) = + reac_rate_local(332) 
  reac_source_local(05,332) = - reac_rate_local(332) 
  reac_source_local(20,332) = + reac_rate_local(332) 
  reac_source_local(40,332) = - reac_rate_local(332) 
  reac_source_local(04,333) = + reac_rate_local(333) 
  reac_source_local(05,333) = - reac_rate_local(333) 
  reac_source_local(20,333) = + reac_rate_local(333) 
  reac_source_local(41,333) = - reac_rate_local(333) 
  reac_source_local(04,334) = + reac_rate_local(334) 
  reac_source_local(05,334) = - reac_rate_local(334) 
  reac_source_local(20,334) = + reac_rate_local(334) 
  reac_source_local(42,334) = - reac_rate_local(334) 
  reac_source_local(04,335) = + reac_rate_local(335) 
  reac_source_local(05,335) = - reac_rate_local(335) 
  reac_source_local(20,335) = + reac_rate_local(335) 
  reac_source_local(43,335) = - reac_rate_local(335) 
  reac_source_local(04,336) = + reac_rate_local(336) 
  reac_source_local(05,336) = - reac_rate_local(336) 
  reac_source_local(20,336) = + reac_rate_local(336) 
  reac_source_local(44,336) = - reac_rate_local(336) 
  reac_source_local(04,337) = + reac_rate_local(337) 
  reac_source_local(05,337) = - reac_rate_local(337) 
  reac_source_local(20,337) = + reac_rate_local(337) 
  reac_source_local(45,337) = - reac_rate_local(337) 
  reac_source_local(02,338) = + reac_rate_local(338) 
  reac_source_local(08,338) = - reac_rate_local(338) 
  reac_source_local(20,338) = + reac_rate_local(338) 
  reac_source_local(38,338) = - reac_rate_local(338) 
  reac_source_local(02,339) = + reac_rate_local(339) 
  reac_source_local(08,339) = - reac_rate_local(339) 
  reac_source_local(20,339) = + reac_rate_local(339) 
  reac_source_local(39,339) = - reac_rate_local(339) 
  reac_source_local(02,340) = + reac_rate_local(340) 
  reac_source_local(08,340) = - reac_rate_local(340) 
  reac_source_local(20,340) = + reac_rate_local(340) 
  reac_source_local(40,340) = - reac_rate_local(340) 
  reac_source_local(02,341) = + reac_rate_local(341) 
  reac_source_local(08,341) = - reac_rate_local(341) 
  reac_source_local(20,341) = + reac_rate_local(341) 
  reac_source_local(41,341) = - reac_rate_local(341) 
  reac_source_local(02,342) = + reac_rate_local(342) 
  reac_source_local(08,342) = - reac_rate_local(342) 
  reac_source_local(20,342) = + reac_rate_local(342) 
  reac_source_local(42,342) = - reac_rate_local(342) 
  reac_source_local(02,343) = + reac_rate_local(343) 
  reac_source_local(08,343) = - reac_rate_local(343) 
  reac_source_local(20,343) = + reac_rate_local(343) 
  reac_source_local(43,343) = - reac_rate_local(343) 
  reac_source_local(02,344) = + reac_rate_local(344) 
  reac_source_local(08,344) = - reac_rate_local(344) 
  reac_source_local(20,344) = + reac_rate_local(344) 
  reac_source_local(44,344) = - reac_rate_local(344) 
  reac_source_local(02,345) = + reac_rate_local(345) 
  reac_source_local(08,345) = - reac_rate_local(345) 
  reac_source_local(20,345) = + reac_rate_local(345) 
  reac_source_local(45,345) = - reac_rate_local(345) 
  reac_source_local(12,346) = + reac_rate_local(346) 
  reac_source_local(20,346) = + reac_rate_local(346) 
  reac_source_local(26,346) = - reac_rate_local(346) 
  reac_source_local(38,346) = - reac_rate_local(346) 
  reac_source_local(12,347) = + reac_rate_local(347) 
  reac_source_local(20,347) = + reac_rate_local(347) 
  reac_source_local(26,347) = - reac_rate_local(347) 
  reac_source_local(39,347) = - reac_rate_local(347) 
  reac_source_local(12,348) = + reac_rate_local(348) 
  reac_source_local(20,348) = + reac_rate_local(348) 
  reac_source_local(26,348) = - reac_rate_local(348) 
  reac_source_local(40,348) = - reac_rate_local(348) 
  reac_source_local(12,349) = + reac_rate_local(349) 
  reac_source_local(20,349) = + reac_rate_local(349) 
  reac_source_local(26,349) = - reac_rate_local(349) 
  reac_source_local(41,349) = - reac_rate_local(349) 
  reac_source_local(12,350) = + reac_rate_local(350) 
  reac_source_local(20,350) = + reac_rate_local(350) 
  reac_source_local(26,350) = - reac_rate_local(350) 
  reac_source_local(42,350) = - reac_rate_local(350) 
  reac_source_local(12,351) = + reac_rate_local(351) 
  reac_source_local(20,351) = + reac_rate_local(351) 
  reac_source_local(26,351) = - reac_rate_local(351) 
  reac_source_local(43,351) = - reac_rate_local(351) 
  reac_source_local(12,352) = + reac_rate_local(352) 
  reac_source_local(20,352) = + reac_rate_local(352) 
  reac_source_local(26,352) = - reac_rate_local(352) 
  reac_source_local(44,352) = - reac_rate_local(352) 
  reac_source_local(12,353) = + reac_rate_local(353) 
  reac_source_local(20,353) = + reac_rate_local(353) 
  reac_source_local(26,353) = - reac_rate_local(353) 
  reac_source_local(45,353) = - reac_rate_local(353) 
  reac_source_local(04,354) = + reac_rate_local(354) 
  reac_source_local(06,354) = - reac_rate_local(354) 
  reac_source_local(14,354) = + reac_rate_local(354) 
  reac_source_local(38,354) = - reac_rate_local(354) 
  reac_source_local(04,355) = + reac_rate_local(355) 
  reac_source_local(06,355) = - reac_rate_local(355) 
  reac_source_local(14,355) = + reac_rate_local(355) 
  reac_source_local(39,355) = - reac_rate_local(355) 
  reac_source_local(04,356) = + reac_rate_local(356) 
  reac_source_local(06,356) = - reac_rate_local(356) 
  reac_source_local(14,356) = + reac_rate_local(356) 
  reac_source_local(40,356) = - reac_rate_local(356) 
  reac_source_local(04,357) = + reac_rate_local(357) 
  reac_source_local(06,357) = - reac_rate_local(357) 
  reac_source_local(14,357) = + reac_rate_local(357) 
  reac_source_local(41,357) = - reac_rate_local(357) 
  reac_source_local(04,358) = + reac_rate_local(358) 
  reac_source_local(06,358) = - reac_rate_local(358) 
  reac_source_local(14,358) = + reac_rate_local(358) 
  reac_source_local(42,358) = - reac_rate_local(358) 
  reac_source_local(04,359) = + reac_rate_local(359) 
  reac_source_local(06,359) = - reac_rate_local(359) 
  reac_source_local(14,359) = + reac_rate_local(359) 
  reac_source_local(43,359) = - reac_rate_local(359) 
  reac_source_local(04,360) = + reac_rate_local(360) 
  reac_source_local(06,360) = - reac_rate_local(360) 
  reac_source_local(14,360) = + reac_rate_local(360) 
  reac_source_local(44,360) = - reac_rate_local(360) 
  reac_source_local(04,361) = + reac_rate_local(361) 
  reac_source_local(06,361) = - reac_rate_local(361) 
  reac_source_local(14,361) = + reac_rate_local(361) 
  reac_source_local(45,361) = - reac_rate_local(361) 
  reac_source_local(04,362) = + reac_rate_local(362) 
  reac_source_local(17,362) = + reac_rate_local(362) 
  reac_source_local(57,362) = - reac_rate_local(362) 
  reac_source_local(04,363) = + reac_rate_local(363) 
  reac_source_local(17,363) = + reac_rate_local(363) 
  reac_source_local(58,363) = - reac_rate_local(363) 
  reac_source_local(04,364) = + reac_rate_local(364) 
  reac_source_local(17,364) = + reac_rate_local(364) 
  reac_source_local(59,364) = - reac_rate_local(364) 
  reac_source_local(04,365) = - reac_rate_local(365) 
  reac_source_local(05,365) = + reac_rate_local(365) 
  reac_source_local(17,365) = + reac_rate_local(365) 
  reac_source_local(57,365) = - reac_rate_local(365) 
  reac_source_local(04,366) = - reac_rate_local(366) 
  reac_source_local(05,366) = + reac_rate_local(366) 
  reac_source_local(17,366) = + reac_rate_local(366) 
  reac_source_local(58,366) = - reac_rate_local(366) 
  reac_source_local(04,367) = - reac_rate_local(367) 
  reac_source_local(05,367) = + reac_rate_local(367) 
  reac_source_local(17,367) = + reac_rate_local(367) 
  reac_source_local(59,367) = - reac_rate_local(367) 
  reac_source_local(01,368) = - reac_rate_local(368) 
  reac_source_local(06,368) = + reac_rate_local(368) 
  reac_source_local(17,368) = + reac_rate_local(368) 
  reac_source_local(57,368) = - reac_rate_local(368) 
  reac_source_local(01,369) = - reac_rate_local(369) 
  reac_source_local(06,369) = + reac_rate_local(369) 
  reac_source_local(17,369) = + reac_rate_local(369) 
  reac_source_local(58,369) = - reac_rate_local(369) 
  reac_source_local(01,370) = - reac_rate_local(370) 
  reac_source_local(06,370) = + reac_rate_local(370) 
  reac_source_local(17,370) = + reac_rate_local(370) 
  reac_source_local(59,370) = - reac_rate_local(370) 
  reac_source_local(06,371) = - reac_rate_local(371) 
  reac_source_local(07,371) = + reac_rate_local(371) 
  reac_source_local(17,371) = + reac_rate_local(371) 
  reac_source_local(57,371) = - reac_rate_local(371) 
  reac_source_local(06,372) = - reac_rate_local(372) 
  reac_source_local(07,372) = + reac_rate_local(372) 
  reac_source_local(17,372) = + reac_rate_local(372) 
  reac_source_local(58,372) = - reac_rate_local(372) 
  reac_source_local(06,373) = - reac_rate_local(373) 
  reac_source_local(07,373) = + reac_rate_local(373) 
  reac_source_local(17,373) = + reac_rate_local(373) 
  reac_source_local(59,373) = - reac_rate_local(373) 
  reac_source_local(08,374) = - reac_rate_local(374) 
  reac_source_local(09,374) = + reac_rate_local(374) 
  reac_source_local(17,374) = + reac_rate_local(374) 
  reac_source_local(57,374) = - reac_rate_local(374) 
  reac_source_local(08,375) = - reac_rate_local(375) 
  reac_source_local(09,375) = + reac_rate_local(375) 
  reac_source_local(17,375) = + reac_rate_local(375) 
  reac_source_local(58,375) = - reac_rate_local(375) 
  reac_source_local(08,376) = - reac_rate_local(376) 
  reac_source_local(09,376) = + reac_rate_local(376) 
  reac_source_local(17,376) = + reac_rate_local(376) 
  reac_source_local(59,376) = - reac_rate_local(376) 
  reac_source_local(01,377) = + reac_rate_local(377) 
  reac_source_local(10,377) = - reac_rate_local(377) 
  reac_source_local(12,377) = + reac_rate_local(377) 
  reac_source_local(54,377) = - reac_rate_local(377) 
  reac_source_local(02,378) = + reac_rate_local(378) 
  reac_source_local(54,378) = - reac_rate_local(378) 
  reac_source_local(02,379) = + reac_rate_local(379) 
  reac_source_local(54,379) = - reac_rate_local(379) 
  reac_source_local(02,380) = + reac_rate_local(380) 
  reac_source_local(54,380) = - reac_rate_local(380) 
  reac_source_local(02,381) = + reac_rate_local(381) * 2.d0
  reac_source_local(03,381) = - reac_rate_local(381) 
  reac_source_local(36,381) = + reac_rate_local(381) 
  reac_source_local(54,381) = - reac_rate_local(381) 
  reac_source_local(02,382) = + reac_rate_local(382) 
  reac_source_local(54,382) = - reac_rate_local(382) * 2.d0
  reac_source_local(55,382) = + reac_rate_local(382) 
  reac_source_local(01,383) = + reac_rate_local(383) 
  reac_source_local(02,383) = - reac_rate_local(383) 
  reac_source_local(03,383) = + reac_rate_local(383) 
  reac_source_local(54,383) = - reac_rate_local(383) 
  reac_source_local(02,384) = + reac_rate_local(384) * 2.d0
  reac_source_local(54,384) = - reac_rate_local(384) * 2.d0
  reac_source_local(02,385) = + reac_rate_local(385) 
  reac_source_local(54,385) = - reac_rate_local(385) 
  reac_source_local(02,386) = + reac_rate_local(386) 
  reac_source_local(54,386) = - reac_rate_local(386) 
  reac_source_local(54,387) = + reac_rate_local(387) 
  reac_source_local(55,387) = - reac_rate_local(387) 
  reac_source_local(05,388) = - reac_rate_local(388) 
  reac_source_local(06,388) = + reac_rate_local(388) * 2.d0
  reac_source_local(54,388) = - reac_rate_local(388) 
  reac_source_local(02,389) = + reac_rate_local(389) 
  reac_source_local(54,389) = - reac_rate_local(389) 
  reac_source_local(01,390) = + reac_rate_local(390) 
  reac_source_local(04,390) = - reac_rate_local(390) 
  reac_source_local(06,390) = + reac_rate_local(390) 
  reac_source_local(54,390) = - reac_rate_local(390) 
  reac_source_local(04,391) = - reac_rate_local(391) 
  reac_source_local(08,391) = + reac_rate_local(391) 
  reac_source_local(54,391) = - reac_rate_local(391) 
  reac_source_local(02,392) = + reac_rate_local(392) 
  reac_source_local(54,392) = - reac_rate_local(392) 
  reac_source_local(04,393) = + reac_rate_local(393) 
  reac_source_local(05,393) = - reac_rate_local(393) 
  reac_source_local(08,393) = + reac_rate_local(393) 
  reac_source_local(54,393) = - reac_rate_local(393) 
  reac_source_local(06,394) = + reac_rate_local(394) 
  reac_source_local(07,394) = - reac_rate_local(394) 
  reac_source_local(08,394) = + reac_rate_local(394) 
  reac_source_local(54,394) = - reac_rate_local(394) 
  reac_source_local(05,395) = - reac_rate_local(395) 
  reac_source_local(07,395) = + reac_rate_local(395) 
  reac_source_local(36,395) = + reac_rate_local(395) 
  reac_source_local(54,395) = - reac_rate_local(395) 
  reac_source_local(03,396) = + reac_rate_local(396) 
  reac_source_local(04,396) = + reac_rate_local(396) 
  reac_source_local(06,396) = - reac_rate_local(396) 
  reac_source_local(54,396) = - reac_rate_local(396) 
  reac_source_local(01,397) = + reac_rate_local(397) 
  reac_source_local(06,397) = - reac_rate_local(397) 
  reac_source_local(08,397) = + reac_rate_local(397) 
  reac_source_local(54,397) = - reac_rate_local(397) 
  reac_source_local(02,398) = + reac_rate_local(398) 
  reac_source_local(54,398) = - reac_rate_local(398) 
  reac_source_local(02,399) = + reac_rate_local(399) 
  reac_source_local(54,399) = - reac_rate_local(399) 
  reac_source_local(02,400) = + reac_rate_local(400) 
  reac_source_local(54,400) = - reac_rate_local(400) 
  reac_source_local(01,401) = + reac_rate_local(401) 
  reac_source_local(17,401) = - reac_rate_local(401) 
  reac_source_local(24,401) = + reac_rate_local(401) 
  reac_source_local(54,401) = - reac_rate_local(401) 
  reac_source_local(06,402) = + reac_rate_local(402) 
  reac_source_local(17,402) = - reac_rate_local(402) 
  reac_source_local(26,402) = + reac_rate_local(402) 
  reac_source_local(54,402) = - reac_rate_local(402) 
  reac_source_local(08,403) = + reac_rate_local(403) 
  reac_source_local(24,403) = - reac_rate_local(403) 
  reac_source_local(26,403) = + reac_rate_local(403) 
  reac_source_local(54,403) = - reac_rate_local(403) 
  reac_source_local(08,404) = + reac_rate_local(404) 
  reac_source_local(26,404) = + reac_rate_local(404) 
  reac_source_local(28,404) = - reac_rate_local(404) 
  reac_source_local(54,404) = - reac_rate_local(404) 
  reac_source_local(01,405) = - reac_rate_local(405) 
  reac_source_local(02,405) = + reac_rate_local(405) 
  reac_source_local(36,405) = + reac_rate_local(405) 
  reac_source_local(55,405) = - reac_rate_local(405) 
  reac_source_local(54,406) = + reac_rate_local(406) 
  reac_source_local(55,406) = - reac_rate_local(406) 
  reac_source_local(01,407) = + reac_rate_local(407) 
  reac_source_local(02,407) = + reac_rate_local(407) * 2.d0
  reac_source_local(03,407) = - reac_rate_local(407) 
  reac_source_local(55,407) = - reac_rate_local(407) 
  reac_source_local(54,408) = + reac_rate_local(408) 
  reac_source_local(55,408) = - reac_rate_local(408) 
  reac_source_local(54,409) = + reac_rate_local(409) 
  reac_source_local(55,409) = - reac_rate_local(409) 
  reac_source_local(02,410) = + reac_rate_local(410) 
  reac_source_local(55,410) = - reac_rate_local(410) 
  reac_source_local(02,411) = + reac_rate_local(411) 
  reac_source_local(54,411) = + reac_rate_local(411) 
  reac_source_local(55,411) = - reac_rate_local(411) * 2.d0
  reac_source_local(01,412) = + reac_rate_local(412) 
  reac_source_local(02,412) = + reac_rate_local(412) 
  reac_source_local(03,412) = - reac_rate_local(412) 
  reac_source_local(54,412) = + reac_rate_local(412) 
  reac_source_local(55,412) = - reac_rate_local(412) 
  reac_source_local(02,413) = + reac_rate_local(413) 
  reac_source_local(55,413) = - reac_rate_local(413) 
  reac_source_local(54,414) = + reac_rate_local(414) 
  reac_source_local(55,414) = - reac_rate_local(414) 
  reac_source_local(02,415) = + reac_rate_local(415) 
  reac_source_local(55,415) = - reac_rate_local(415) 
  reac_source_local(01,416) = - reac_rate_local(416) 
  reac_source_local(02,416) = + reac_rate_local(416) 
  reac_source_local(35,416) = - reac_rate_local(416) 
  reac_source_local(37,416) = + reac_rate_local(416) 
  reac_source_local(02,417) = - reac_rate_local(417) 
  reac_source_local(35,417) = - reac_rate_local(417) 
  reac_source_local(55,417) = + reac_rate_local(417) * 2.d0
  reac_source_local(35,418) = - reac_rate_local(418) 
  reac_source_local(55,418) = + reac_rate_local(418) 
  reac_source_local(02,419) = + reac_rate_local(419) 
  reac_source_local(35,419) = - reac_rate_local(419) 
  reac_source_local(01,420) = - reac_rate_local(420) 
  reac_source_local(35,420) = - reac_rate_local(420) 
  reac_source_local(36,420) = + reac_rate_local(420) 
  reac_source_local(54,420) = + reac_rate_local(420) 
  reac_source_local(01,421) = - reac_rate_local(421) 
  reac_source_local(35,421) = - reac_rate_local(421) 
  reac_source_local(36,421) = + reac_rate_local(421) 
  reac_source_local(55,421) = + reac_rate_local(421) 
  reac_source_local(35,422) = - reac_rate_local(422) 
  reac_source_local(54,422) = + reac_rate_local(422) 
  reac_source_local(35,423) = - reac_rate_local(423) 
  reac_source_local(55,423) = + reac_rate_local(423) 
  reac_source_local(02,424) = + reac_rate_local(424) 
  reac_source_local(35,424) = - reac_rate_local(424) 
  reac_source_local(01,425) = + reac_rate_local(425) 
  reac_source_local(36,425) = - reac_rate_local(425) 
  reac_source_local(01,426) = + reac_rate_local(426) 
  reac_source_local(36,426) = - reac_rate_local(426) 
  reac_source_local(01,427) = + reac_rate_local(427) 
  reac_source_local(02,427) = - reac_rate_local(427) 
  reac_source_local(36,427) = - reac_rate_local(427) 
  reac_source_local(54,427) = + reac_rate_local(427) 
  reac_source_local(01,428) = + reac_rate_local(428) 
  reac_source_local(02,428) = - reac_rate_local(428) 
  reac_source_local(36,428) = - reac_rate_local(428) 
  reac_source_local(55,428) = + reac_rate_local(428) 
  reac_source_local(01,429) = + reac_rate_local(429) * 2.d0
  reac_source_local(02,429) = + reac_rate_local(429) 
  reac_source_local(03,429) = - reac_rate_local(429) 
  reac_source_local(36,429) = - reac_rate_local(429) 
  reac_source_local(02,430) = + reac_rate_local(430) * 2.d0
  reac_source_local(03,430) = - reac_rate_local(430) 
  reac_source_local(36,430) = - reac_rate_local(430) 
  reac_source_local(01,431) = + reac_rate_local(431) 
  reac_source_local(36,431) = - reac_rate_local(431) 
  reac_source_local(02,432) = + reac_rate_local(432) 
  reac_source_local(10,432) = + reac_rate_local(432) 
  reac_source_local(12,432) = - reac_rate_local(432) 
  reac_source_local(36,432) = - reac_rate_local(432) 
  reac_source_local(12,433) = + reac_rate_local(433) * 2.d0
  reac_source_local(14,433) = - reac_rate_local(433) 
  reac_source_local(36,433) = - reac_rate_local(433) 
  reac_source_local(06,434) = + reac_rate_local(434) 
  reac_source_local(16,434) = - reac_rate_local(434) 
  reac_source_local(17,434) = + reac_rate_local(434) 
  reac_source_local(36,434) = - reac_rate_local(434) 
  reac_source_local(07,435) = + reac_rate_local(435) 
  reac_source_local(16,435) = - reac_rate_local(435) 
  reac_source_local(18,435) = + reac_rate_local(435) 
  reac_source_local(36,435) = - reac_rate_local(435) 
  reac_source_local(04,436) = + reac_rate_local(436) 
  reac_source_local(16,436) = - reac_rate_local(436) 
  reac_source_local(24,436) = + reac_rate_local(436) 
  reac_source_local(36,436) = - reac_rate_local(436) 
  reac_source_local(02,437) = + reac_rate_local(437) 
  reac_source_local(11,437) = + reac_rate_local(437) 
  reac_source_local(14,437) = - reac_rate_local(437) 
  reac_source_local(36,437) = - reac_rate_local(437) 
  reac_source_local(02,438) = + reac_rate_local(438) 
  reac_source_local(11,438) = + reac_rate_local(438) 
  reac_source_local(14,438) = - reac_rate_local(438) 
  reac_source_local(37,438) = - reac_rate_local(438) 
  reac_source_local(11,439) = + reac_rate_local(439) 
  reac_source_local(46,439) = - reac_rate_local(439) 
  reac_source_local(10,440) = - reac_rate_local(440) 
  reac_source_local(11,440) = + reac_rate_local(440) 
  reac_source_local(33,440) = + reac_rate_local(440) 
  reac_source_local(46,440) = - reac_rate_local(440) 
  reac_source_local(11,441) = + reac_rate_local(441) 
  reac_source_local(46,441) = - reac_rate_local(441) 
  reac_source_local(11,442) = + reac_rate_local(442) 
  reac_source_local(46,442) = - reac_rate_local(442) * 2.d0
  reac_source_local(47,442) = + reac_rate_local(442) 
  reac_source_local(11,443) = + reac_rate_local(443) 
  reac_source_local(46,443) = - reac_rate_local(443) * 2.d0
  reac_source_local(49,443) = + reac_rate_local(443) 
  reac_source_local(01,444) = - reac_rate_local(444) 
  reac_source_local(12,444) = + reac_rate_local(444) 
  reac_source_local(34,444) = + reac_rate_local(444) 
  reac_source_local(46,444) = - reac_rate_local(444) 
  reac_source_local(01,445) = - reac_rate_local(445) 
  reac_source_local(11,445) = + reac_rate_local(445) 
  reac_source_local(37,445) = + reac_rate_local(445) 
  reac_source_local(46,445) = - reac_rate_local(445) 
  reac_source_local(02,446) = - reac_rate_local(446) 
  reac_source_local(11,446) = + reac_rate_local(446) 
  reac_source_local(46,446) = - reac_rate_local(446) 
  reac_source_local(54,446) = + reac_rate_local(446) 
  reac_source_local(02,447) = - reac_rate_local(447) 
  reac_source_local(11,447) = + reac_rate_local(447) 
  reac_source_local(46,447) = - reac_rate_local(447) 
  reac_source_local(55,447) = + reac_rate_local(447) 
  reac_source_local(01,448) = + reac_rate_local(448) 
  reac_source_local(02,448) = - reac_rate_local(448) 
  reac_source_local(14,448) = + reac_rate_local(448) 
  reac_source_local(46,448) = - reac_rate_local(448) 
  reac_source_local(11,449) = + reac_rate_local(449) 
  reac_source_local(46,449) = - reac_rate_local(449) 
  reac_source_local(10,450) = + reac_rate_local(450) 
  reac_source_local(11,450) = + reac_rate_local(450) 
  reac_source_local(12,450) = + reac_rate_local(450) 
  reac_source_local(14,450) = - reac_rate_local(450) 
  reac_source_local(46,450) = - reac_rate_local(450) 
  reac_source_local(01,451) = + reac_rate_local(451) 
  reac_source_local(11,451) = + reac_rate_local(451) 
  reac_source_local(12,451) = + reac_rate_local(451) 
  reac_source_local(13,451) = - reac_rate_local(451) 
  reac_source_local(46,451) = - reac_rate_local(451) 
  reac_source_local(01,452) = + reac_rate_local(452) * 2.d0
  reac_source_local(02,452) = - reac_rate_local(452) 
  reac_source_local(11,452) = + reac_rate_local(452) 
  reac_source_local(46,452) = - reac_rate_local(452) 
  reac_source_local(46,453) = + reac_rate_local(453) 
  reac_source_local(47,453) = - reac_rate_local(453) 
  reac_source_local(11,454) = + reac_rate_local(454) 
  reac_source_local(47,454) = - reac_rate_local(454) 
  reac_source_local(46,455) = + reac_rate_local(455) 
  reac_source_local(47,455) = - reac_rate_local(455) 
  reac_source_local(01,456) = + reac_rate_local(456) * 2.d0
  reac_source_local(02,456) = - reac_rate_local(456) 
  reac_source_local(11,456) = + reac_rate_local(456) 
  reac_source_local(47,456) = - reac_rate_local(456) 
  reac_source_local(01,457) = - reac_rate_local(457) 
  reac_source_local(12,457) = + reac_rate_local(457) 
  reac_source_local(34,457) = + reac_rate_local(457) 
  reac_source_local(47,457) = - reac_rate_local(457) 
  reac_source_local(47,458) = + reac_rate_local(458) 
  reac_source_local(48,458) = - reac_rate_local(458) 
  reac_source_local(01,459) = + reac_rate_local(459) 
  reac_source_local(10,459) = + reac_rate_local(459) 
  reac_source_local(11,459) = + reac_rate_local(459) 
  reac_source_local(12,459) = - reac_rate_local(459) 
  reac_source_local(48,459) = - reac_rate_local(459) 
  reac_source_local(46,460) = - reac_rate_local(460) 
  reac_source_local(48,460) = - reac_rate_local(460) 
  reac_source_local(63,460) = + reac_rate_local(460) 
  reac_source_local(80,460) = + reac_rate_local(460) 
  reac_source_local(48,461) = - reac_rate_local(461) * 2.d0
  reac_source_local(63,461) = + reac_rate_local(461) 
  reac_source_local(80,461) = + reac_rate_local(461) 
  reac_source_local(01,462) = + reac_rate_local(462) 
  reac_source_local(02,462) = - reac_rate_local(462) 
  reac_source_local(11,462) = + reac_rate_local(462) 
  reac_source_local(36,462) = + reac_rate_local(462) 
  reac_source_local(48,462) = - reac_rate_local(462) 
  reac_source_local(01,463) = - reac_rate_local(463) 
  reac_source_local(12,463) = + reac_rate_local(463) 
  reac_source_local(34,463) = + reac_rate_local(463) 
  reac_source_local(48,463) = - reac_rate_local(463) 
  reac_source_local(48,464) = + reac_rate_local(464) 
  reac_source_local(49,464) = - reac_rate_local(464) 
  reac_source_local(01,465) = + reac_rate_local(465) 
  reac_source_local(02,465) = - reac_rate_local(465) 
  reac_source_local(11,465) = + reac_rate_local(465) 
  reac_source_local(37,465) = + reac_rate_local(465) 
  reac_source_local(49,465) = - reac_rate_local(465) 
  reac_source_local(01,466) = - reac_rate_local(466) 
  reac_source_local(12,466) = + reac_rate_local(466) 
  reac_source_local(34,466) = + reac_rate_local(466) 
  reac_source_local(49,466) = - reac_rate_local(466) 
  reac_source_local(01,467) = + reac_rate_local(467) 
  reac_source_local(02,467) = - reac_rate_local(467) 
  reac_source_local(11,467) = + reac_rate_local(467) 
  reac_source_local(36,467) = + reac_rate_local(467) 
  reac_source_local(49,467) = - reac_rate_local(467) 
  reac_source_local(04,468) = + reac_rate_local(468) 
  reac_source_local(05,468) = - reac_rate_local(468) 
  reac_source_local(18,468) = + reac_rate_local(468) 
  reac_source_local(34,468) = - reac_rate_local(468) 
  reac_source_local(16,469) = - reac_rate_local(469) 
  reac_source_local(17,469) = + reac_rate_local(469) 
  reac_source_local(18,469) = + reac_rate_local(469) 
  reac_source_local(34,469) = - reac_rate_local(469) 
  reac_source_local(04,470) = + reac_rate_local(470) 
  reac_source_local(05,470) = - reac_rate_local(470) 
  reac_source_local(18,470) = + reac_rate_local(470) 
  reac_source_local(33,470) = - reac_rate_local(470) 
  reac_source_local(10,471) = + reac_rate_local(471) 
  reac_source_local(34,471) = - reac_rate_local(471) 
  reac_source_local(10,472) = + reac_rate_local(472) 
  reac_source_local(33,472) = - reac_rate_local(472) 
  reac_source_local(33,473) = - reac_rate_local(473) 
  reac_source_local(34,473) = + reac_rate_local(473) 
  reac_source_local(10,474) = + reac_rate_local(474) 
  reac_source_local(33,474) = - reac_rate_local(474) 
  reac_source_local(33,475) = - reac_rate_local(475) 
  reac_source_local(34,475) = - reac_rate_local(475) 
  reac_source_local(61,475) = + reac_rate_local(475) 
  reac_source_local(80,475) = + reac_rate_local(475) 
  reac_source_local(02,476) = + reac_rate_local(476) 
  reac_source_local(11,476) = + reac_rate_local(476) 
  reac_source_local(13,476) = - reac_rate_local(476) 
  reac_source_local(33,476) = - reac_rate_local(476) 
  reac_source_local(02,477) = + reac_rate_local(477) 
  reac_source_local(11,477) = + reac_rate_local(477) 
  reac_source_local(13,477) = - reac_rate_local(477) 
  reac_source_local(34,477) = - reac_rate_local(477) 
  reac_source_local(01,478) = + reac_rate_local(478) * 2.d0
  reac_source_local(11,478) = + reac_rate_local(478) 
  reac_source_local(13,478) = - reac_rate_local(478) 
  reac_source_local(33,478) = - reac_rate_local(478) 
  reac_source_local(01,479) = + reac_rate_local(479) * 2.d0
  reac_source_local(11,479) = + reac_rate_local(479) 
  reac_source_local(13,479) = - reac_rate_local(479) 
  reac_source_local(34,479) = - reac_rate_local(479) 
  reac_source_local(01,480) = + reac_rate_local(480) 
  reac_source_local(11,480) = + reac_rate_local(480) 
  reac_source_local(12,480) = - reac_rate_local(480) 
  reac_source_local(34,480) = - reac_rate_local(480) 
  reac_source_local(01,481) = + reac_rate_local(481) 
  reac_source_local(11,481) = + reac_rate_local(481) 
  reac_source_local(12,481) = - reac_rate_local(481) 
  reac_source_local(33,481) = - reac_rate_local(481) 
  reac_source_local(11,482) = + reac_rate_local(482) 
  reac_source_local(12,482) = + reac_rate_local(482) 
  reac_source_local(14,482) = - reac_rate_local(482) 
  reac_source_local(34,482) = - reac_rate_local(482) 
  reac_source_local(11,483) = + reac_rate_local(483) 
  reac_source_local(12,483) = + reac_rate_local(483) 
  reac_source_local(14,483) = - reac_rate_local(483) 
  reac_source_local(33,483) = - reac_rate_local(483) 
  reac_source_local(10,484) = - reac_rate_local(484) * 2.d0
  reac_source_local(46,484) = + reac_rate_local(484) 
  reac_source_local(10,485) = - reac_rate_local(485) * 2.d0
  reac_source_local(46,485) = + reac_rate_local(485) 
  reac_source_local(10,486) = - reac_rate_local(486) * 2.d0
  reac_source_local(46,486) = + reac_rate_local(486) 
  reac_source_local(10,487) = - reac_rate_local(487) * 2.d0
  reac_source_local(46,487) = + reac_rate_local(487) 
  reac_source_local(10,488) = - reac_rate_local(488) * 2.d0
  reac_source_local(46,488) = + reac_rate_local(488) 
  reac_source_local(10,489) = - reac_rate_local(489) * 2.d0
  reac_source_local(47,489) = + reac_rate_local(489) 
  reac_source_local(10,490) = - reac_rate_local(490) * 2.d0
  reac_source_local(47,490) = + reac_rate_local(490) 
  reac_source_local(10,491) = - reac_rate_local(491) * 2.d0
  reac_source_local(47,491) = + reac_rate_local(491) 
  reac_source_local(10,492) = - reac_rate_local(492) * 2.d0
  reac_source_local(47,492) = + reac_rate_local(492) 
  reac_source_local(10,493) = - reac_rate_local(493) * 2.d0
  reac_source_local(47,493) = + reac_rate_local(493) 
  reac_source_local(01,494) = - reac_rate_local(494) 
  reac_source_local(02,494) = + reac_rate_local(494) 
  reac_source_local(64,494) = - reac_rate_local(494) 
  reac_source_local(80,494) = + reac_rate_local(494) 
  reac_source_local(02,495) = - reac_rate_local(495) 
  reac_source_local(03,495) = + reac_rate_local(495) 
  reac_source_local(64,495) = - reac_rate_local(495) 
  reac_source_local(80,495) = + reac_rate_local(495) 
  reac_source_local(03,496) = + reac_rate_local(496) 
  reac_source_local(54,496) = - reac_rate_local(496) 
  reac_source_local(64,496) = - reac_rate_local(496) 
  reac_source_local(80,496) = + reac_rate_local(496) 
  reac_source_local(01,497) = + reac_rate_local(497) 
  reac_source_local(02,497) = + reac_rate_local(497) 
  reac_source_local(55,497) = - reac_rate_local(497) 
  reac_source_local(64,497) = - reac_rate_local(497) 
  reac_source_local(80,497) = + reac_rate_local(497) 
  reac_source_local(02,498) = + reac_rate_local(498) * 2.d0
  reac_source_local(03,498) = - reac_rate_local(498) 
  reac_source_local(64,498) = - reac_rate_local(498) 
  reac_source_local(80,498) = + reac_rate_local(498) 
  reac_source_local(01,499) = + reac_rate_local(499) 
  reac_source_local(54,499) = - reac_rate_local(499) 
  reac_source_local(64,499) = - reac_rate_local(499) 
  reac_source_local(68,499) = + reac_rate_local(499) 
  reac_source_local(01,500) = + reac_rate_local(500) 
  reac_source_local(03,500) = - reac_rate_local(500) 
  reac_source_local(64,500) = - reac_rate_local(500) 
  reac_source_local(70,500) = + reac_rate_local(500) 
  reac_source_local(01,501) = + reac_rate_local(501) 
  reac_source_local(04,501) = - reac_rate_local(501) 
  reac_source_local(65,501) = - reac_rate_local(501) 
  reac_source_local(76,501) = + reac_rate_local(501) 
  reac_source_local(01,502) = + reac_rate_local(502) 
  reac_source_local(16,502) = - reac_rate_local(502) 
  reac_source_local(65,502) = - reac_rate_local(502) 
  reac_source_local(72,502) = + reac_rate_local(502) 
  reac_source_local(02,503) = - reac_rate_local(503) 
  reac_source_local(67,503) = - reac_rate_local(503) 
  reac_source_local(69,503) = + reac_rate_local(503) 
  reac_source_local(02,504) = + reac_rate_local(504) 
  reac_source_local(16,504) = - reac_rate_local(504) 
  reac_source_local(67,504) = - reac_rate_local(504) 
  reac_source_local(72,504) = + reac_rate_local(504) 
  reac_source_local(01,505) = - reac_rate_local(505) 
  reac_source_local(03,505) = + reac_rate_local(505) 
  reac_source_local(67,505) = + reac_rate_local(505) 
  reac_source_local(69,505) = - reac_rate_local(505) 
  reac_source_local(02,506) = + reac_rate_local(506) 
  reac_source_local(67,506) = + reac_rate_local(506) 
  reac_source_local(69,506) = - reac_rate_local(506) 
  reac_source_local(03,507) = + reac_rate_local(507) 
  reac_source_local(36,507) = - reac_rate_local(507) 
  reac_source_local(67,507) = + reac_rate_local(507) 
  reac_source_local(69,507) = - reac_rate_local(507) 
  reac_source_local(03,508) = + reac_rate_local(508) 
  reac_source_local(37,508) = - reac_rate_local(508) 
  reac_source_local(67,508) = + reac_rate_local(508) 
  reac_source_local(69,508) = - reac_rate_local(508) 
  reac_source_local(01,509) = - reac_rate_local(509) 
  reac_source_local(03,509) = + reac_rate_local(509) 
  reac_source_local(68,509) = - reac_rate_local(509) 
  reac_source_local(80,509) = + reac_rate_local(509) 
  reac_source_local(02,510) = + reac_rate_local(510) * 2.d0
  reac_source_local(54,510) = - reac_rate_local(510) 
  reac_source_local(68,510) = - reac_rate_local(510) 
  reac_source_local(80,510) = + reac_rate_local(510) 
  reac_source_local(02,511) = + reac_rate_local(511) * 2.d0
  reac_source_local(55,511) = - reac_rate_local(511) 
  reac_source_local(68,511) = - reac_rate_local(511) 
  reac_source_local(80,511) = + reac_rate_local(511) 
  reac_source_local(01,512) = - reac_rate_local(512) 
  reac_source_local(02,512) = + reac_rate_local(512) 
  reac_source_local(64,512) = + reac_rate_local(512) 
  reac_source_local(68,512) = - reac_rate_local(512) 
  reac_source_local(02,513) = + reac_rate_local(513) 
  reac_source_local(03,513) = - reac_rate_local(513) 
  reac_source_local(68,513) = - reac_rate_local(513) 
  reac_source_local(70,513) = + reac_rate_local(513) 
  reac_source_local(05,514) = - reac_rate_local(514) 
  reac_source_local(09,514) = + reac_rate_local(514) 
  reac_source_local(68,514) = - reac_rate_local(514) 
  reac_source_local(80,514) = + reac_rate_local(514) 
  reac_source_local(04,515) = - reac_rate_local(515) 
  reac_source_local(08,515) = + reac_rate_local(515) 
  reac_source_local(68,515) = - reac_rate_local(515) 
  reac_source_local(80,515) = + reac_rate_local(515) 
  reac_source_local(02,516) = + reac_rate_local(516) 
  reac_source_local(06,516) = - reac_rate_local(516) 
  reac_source_local(66,516) = + reac_rate_local(516) 
  reac_source_local(68,516) = - reac_rate_local(516) 
  reac_source_local(01,517) = + reac_rate_local(517) 
  reac_source_local(04,517) = - reac_rate_local(517) 
  reac_source_local(66,517) = + reac_rate_local(517) 
  reac_source_local(68,517) = - reac_rate_local(517) 
  reac_source_local(01,518) = - reac_rate_local(518) 
  reac_source_local(02,518) = + reac_rate_local(518) * 2.d0
  reac_source_local(70,518) = - reac_rate_local(518) 
  reac_source_local(80,518) = + reac_rate_local(518) 
  reac_source_local(01,519) = - reac_rate_local(519) 
  reac_source_local(02,519) = + reac_rate_local(519) 
  reac_source_local(68,519) = + reac_rate_local(519) 
  reac_source_local(70,519) = - reac_rate_local(519) 
  reac_source_local(05,520) = + reac_rate_local(520) 
  reac_source_local(16,520) = - reac_rate_local(520) 
  reac_source_local(71,520) = + reac_rate_local(520) 
  reac_source_local(78,520) = - reac_rate_local(520) 
  reac_source_local(05,521) = + reac_rate_local(521) 
  reac_source_local(16,521) = - reac_rate_local(521) 
  reac_source_local(72,521) = + reac_rate_local(521) 
  reac_source_local(77,521) = - reac_rate_local(521) 
  reac_source_local(04,522) = + reac_rate_local(522) 
  reac_source_local(16,522) = - reac_rate_local(522) 
  reac_source_local(71,522) = + reac_rate_local(522) 
  reac_source_local(77,522) = - reac_rate_local(522) 
  reac_source_local(05,523) = + reac_rate_local(523) 
  reac_source_local(17,523) = - reac_rate_local(523) 
  reac_source_local(73,523) = + reac_rate_local(523) 
  reac_source_local(77,523) = - reac_rate_local(523) 
  reac_source_local(04,524) = + reac_rate_local(524) 
  reac_source_local(17,524) = - reac_rate_local(524) 
  reac_source_local(72,524) = + reac_rate_local(524) 
  reac_source_local(77,524) = - reac_rate_local(524) 
  reac_source_local(05,525) = + reac_rate_local(525) 
  reac_source_local(18,525) = - reac_rate_local(525) 
  reac_source_local(74,525) = + reac_rate_local(525) 
  reac_source_local(77,525) = - reac_rate_local(525) 
  reac_source_local(04,526) = + reac_rate_local(526) 
  reac_source_local(18,526) = - reac_rate_local(526) 
  reac_source_local(73,526) = + reac_rate_local(526) 
  reac_source_local(77,526) = - reac_rate_local(526) 
  reac_source_local(04,527) = + reac_rate_local(527) 
  reac_source_local(11,527) = - reac_rate_local(527) 
  reac_source_local(75,527) = + reac_rate_local(527) 
  reac_source_local(77,527) = - reac_rate_local(527) 
  reac_source_local(04,528) = + reac_rate_local(528) 
  reac_source_local(18,528) = - reac_rate_local(528) 
  reac_source_local(74,528) = + reac_rate_local(528) 
  reac_source_local(76,528) = - reac_rate_local(528) 
  reac_source_local(04,529) = + reac_rate_local(529) 
  reac_source_local(17,529) = - reac_rate_local(529) 
  reac_source_local(73,529) = + reac_rate_local(529) 
  reac_source_local(76,529) = - reac_rate_local(529) 
  reac_source_local(04,530) = + reac_rate_local(530) 
  reac_source_local(16,530) = - reac_rate_local(530) 
  reac_source_local(72,530) = + reac_rate_local(530) 
  reac_source_local(76,530) = - reac_rate_local(530) 
  reac_source_local(16,531) = - reac_rate_local(531) 
  reac_source_local(18,531) = + reac_rate_local(531) 
  reac_source_local(60,531) = - reac_rate_local(531) 
  reac_source_local(73,531) = + reac_rate_local(531) 
  reac_source_local(10,532) = + reac_rate_local(532) 
  reac_source_local(16,532) = - reac_rate_local(532) 
  reac_source_local(60,532) = - reac_rate_local(532) 
  reac_source_local(72,532) = + reac_rate_local(532) 
  reac_source_local(05,533) = + reac_rate_local(533) 
  reac_source_local(16,533) = - reac_rate_local(533) 
  reac_source_local(60,533) = - reac_rate_local(533) 
  reac_source_local(75,533) = + reac_rate_local(533) 
  reac_source_local(04,534) = + reac_rate_local(534) 
  reac_source_local(05,534) = - reac_rate_local(534) 
  reac_source_local(60,534) = - reac_rate_local(534) 
  reac_source_local(74,534) = + reac_rate_local(534) 
  reac_source_local(11,535) = + reac_rate_local(535) 
  reac_source_local(16,535) = - reac_rate_local(535) 
  reac_source_local(61,535) = - reac_rate_local(535) 
  reac_source_local(72,535) = + reac_rate_local(535) 
  reac_source_local(04,536) = + reac_rate_local(536) 
  reac_source_local(05,536) = - reac_rate_local(536) 
  reac_source_local(61,536) = - reac_rate_local(536) 
  reac_source_local(75,536) = + reac_rate_local(536) 
  reac_source_local(01,537) = - reac_rate_local(537) 
  reac_source_local(11,537) = + reac_rate_local(537) 
  reac_source_local(61,537) = - reac_rate_local(537) 
  reac_source_local(65,537) = + reac_rate_local(537) 
  reac_source_local(10,538) = - reac_rate_local(538) 
  reac_source_local(11,538) = + reac_rate_local(538) 
  reac_source_local(60,538) = + reac_rate_local(538) 
  reac_source_local(61,538) = - reac_rate_local(538) 
  reac_source_local(02,539) = - reac_rate_local(539) 
  reac_source_local(11,539) = + reac_rate_local(539) 
  reac_source_local(61,539) = - reac_rate_local(539) 
  reac_source_local(67,539) = + reac_rate_local(539) 
  reac_source_local(11,540) = - reac_rate_local(540) 
  reac_source_local(61,540) = - reac_rate_local(540) 
  reac_source_local(63,540) = + reac_rate_local(540) 
  reac_source_local(10,541) = - reac_rate_local(541) 
  reac_source_local(11,541) = + reac_rate_local(541) 
  reac_source_local(61,541) = + reac_rate_local(541) 
  reac_source_local(62,541) = - reac_rate_local(541) 
  reac_source_local(10,542) = - reac_rate_local(542) 
  reac_source_local(11,542) = + reac_rate_local(542) * 2.d0
  reac_source_local(60,542) = + reac_rate_local(542) 
  reac_source_local(63,542) = - reac_rate_local(542) 
  reac_source_local(11,543) = + reac_rate_local(543) 
  reac_source_local(61,543) = + reac_rate_local(543) 
  reac_source_local(63,543) = - reac_rate_local(543) 
  reac_source_local(02,544) = - reac_rate_local(544) 
  reac_source_local(11,544) = + reac_rate_local(544) * 2.d0
  reac_source_local(63,544) = - reac_rate_local(544) 
  reac_source_local(67,544) = + reac_rate_local(544) 
  reac_source_local(16,545) = - reac_rate_local(545) 
  reac_source_local(18,545) = + reac_rate_local(545) 
  reac_source_local(72,545) = + reac_rate_local(545) 
  reac_source_local(74,545) = - reac_rate_local(545) 
  reac_source_local(10,546) = + reac_rate_local(546) 
  reac_source_local(16,546) = - reac_rate_local(546) 
  reac_source_local(71,546) = + reac_rate_local(546) 
  reac_source_local(74,546) = - reac_rate_local(546) 
  reac_source_local(10,547) = + reac_rate_local(547) 
  reac_source_local(11,547) = - reac_rate_local(547) 
  reac_source_local(74,547) = - reac_rate_local(547) 
  reac_source_local(75,547) = + reac_rate_local(547) 
  reac_source_local(05,548) = - reac_rate_local(548) 
  reac_source_local(10,548) = + reac_rate_local(548) 
  reac_source_local(74,548) = - reac_rate_local(548) 
  reac_source_local(78,548) = + reac_rate_local(548) 
  reac_source_local(04,549) = + reac_rate_local(549) 
  reac_source_local(05,549) = - reac_rate_local(549) 
  reac_source_local(73,549) = + reac_rate_local(549) 
  reac_source_local(74,549) = - reac_rate_local(549) 
  reac_source_local(02,550) = - reac_rate_local(550) 
  reac_source_local(18,550) = + reac_rate_local(550) 
  reac_source_local(67,550) = + reac_rate_local(550) 
  reac_source_local(74,550) = - reac_rate_local(550) 
  reac_source_local(16,551) = - reac_rate_local(551) 
  reac_source_local(17,551) = + reac_rate_local(551) 
  reac_source_local(72,551) = + reac_rate_local(551) 
  reac_source_local(73,551) = - reac_rate_local(551) 
  reac_source_local(16,552) = - reac_rate_local(552) 
  reac_source_local(18,552) = + reac_rate_local(552) 
  reac_source_local(71,552) = + reac_rate_local(552) 
  reac_source_local(73,552) = - reac_rate_local(552) 
  reac_source_local(04,553) = + reac_rate_local(553) 
  reac_source_local(05,553) = - reac_rate_local(553) 
  reac_source_local(72,553) = + reac_rate_local(553) 
  reac_source_local(73,553) = - reac_rate_local(553) 
  reac_source_local(16,554) = - reac_rate_local(554) 
  reac_source_local(17,554) = + reac_rate_local(554) 
  reac_source_local(71,554) = + reac_rate_local(554) 
  reac_source_local(72,554) = - reac_rate_local(554) 
  reac_source_local(17,555) = + reac_rate_local(555) 
  reac_source_local(72,555) = - reac_rate_local(555) 
  reac_source_local(76,555) = + reac_rate_local(555) 
  reac_source_local(05,556) = + reac_rate_local(556) 
  reac_source_local(16,556) = - reac_rate_local(556) 
  reac_source_local(17,556) = + reac_rate_local(556) 
  reac_source_local(72,556) = - reac_rate_local(556) 
  reac_source_local(73,556) = + reac_rate_local(556) 
  reac_source_local(04,557) = + reac_rate_local(557) 
  reac_source_local(05,557) = - reac_rate_local(557) 
  reac_source_local(71,557) = + reac_rate_local(557) 
  reac_source_local(72,557) = - reac_rate_local(557) 
  reac_source_local(05,558) = - reac_rate_local(558) 
  reac_source_local(16,558) = + reac_rate_local(558) 
  reac_source_local(72,558) = - reac_rate_local(558) 
  reac_source_local(77,558) = + reac_rate_local(558) 
  reac_source_local(04,559) = + reac_rate_local(559) 
  reac_source_local(05,559) = - reac_rate_local(559) 
  reac_source_local(17,559) = + reac_rate_local(559) 
  reac_source_local(72,559) = - reac_rate_local(559) 
  reac_source_local(77,559) = + reac_rate_local(559) 
  reac_source_local(04,560) = + reac_rate_local(560) 
  reac_source_local(05,560) = - reac_rate_local(560) 
  reac_source_local(16,560) = + reac_rate_local(560) 
  reac_source_local(72,560) = - reac_rate_local(560) 
  reac_source_local(76,560) = + reac_rate_local(560) 
  reac_source_local(11,561) = + reac_rate_local(561) 
  reac_source_local(16,561) = - reac_rate_local(561) 
  reac_source_local(71,561) = + reac_rate_local(561) 
  reac_source_local(75,561) = - reac_rate_local(561) 
  reac_source_local(01,562) = - reac_rate_local(562) 
  reac_source_local(08,562) = + reac_rate_local(562) 
  reac_source_local(66,562) = - reac_rate_local(562) 
  reac_source_local(80,562) = + reac_rate_local(562) 
  reac_source_local(04,563) = - reac_rate_local(563) 
  reac_source_local(07,563) = + reac_rate_local(563) 
  reac_source_local(66,563) = - reac_rate_local(563) 
  reac_source_local(80,563) = + reac_rate_local(563) 
  reac_source_local(10,564) = + reac_rate_local(564) * 2.d0
  reac_source_local(61,564) = - reac_rate_local(564) 
  reac_source_local(80,564) = - reac_rate_local(564) 
  reac_source_local(10,565) = + reac_rate_local(565) 
  reac_source_local(34,565) = + reac_rate_local(565) 
  reac_source_local(61,565) = - reac_rate_local(565) 
  reac_source_local(80,565) = - reac_rate_local(565) 
  reac_source_local(01,566) = + reac_rate_local(566) * 2.d0
  reac_source_local(67,566) = - reac_rate_local(566) 
  reac_source_local(80,566) = - reac_rate_local(566) 
  reac_source_local(01,567) = + reac_rate_local(567) 
  reac_source_local(36,567) = + reac_rate_local(567) 
  reac_source_local(67,567) = - reac_rate_local(567) 
  reac_source_local(80,567) = - reac_rate_local(567) 
  reac_source_local(01,568) = + reac_rate_local(568) 
  reac_source_local(37,568) = + reac_rate_local(568) 
  reac_source_local(67,568) = - reac_rate_local(568) 
  reac_source_local(80,568) = - reac_rate_local(568) 
  reac_source_local(02,569) = + reac_rate_local(569) * 2.d0
  reac_source_local(69,569) = - reac_rate_local(569) 
  reac_source_local(80,569) = - reac_rate_local(569) 
  reac_source_local(11,570) = + reac_rate_local(570) * 2.d0
  reac_source_local(63,570) = - reac_rate_local(570) 
  reac_source_local(80,570) = - reac_rate_local(570) 
  reac_source_local(02,571) = + reac_rate_local(571) 
  reac_source_local(67,571) = - reac_rate_local(571) 
  reac_source_local(80,571) = - reac_rate_local(571) 
  reac_source_local(02,572) = + reac_rate_local(572) 
  reac_source_local(67,572) = - reac_rate_local(572) 
  reac_source_local(80,572) = - reac_rate_local(572) 
  reac_source_local(02,573) = + reac_rate_local(573) * 2.d0
  reac_source_local(69,573) = - reac_rate_local(573) 
  reac_source_local(80,573) = - reac_rate_local(573) 
  reac_source_local(04,574) = + reac_rate_local(574) 
  reac_source_local(10,574) = + reac_rate_local(574) 
  reac_source_local(74,574) = - reac_rate_local(574) 
  reac_source_local(80,574) = - reac_rate_local(574) 
  reac_source_local(04,575) = + reac_rate_local(575) 
  reac_source_local(18,575) = + reac_rate_local(575) 
  reac_source_local(73,575) = - reac_rate_local(575) 
  reac_source_local(80,575) = - reac_rate_local(575) 
  reac_source_local(04,576) = + reac_rate_local(576) * 2.d0
  reac_source_local(10,576) = + reac_rate_local(576) 
  reac_source_local(73,576) = - reac_rate_local(576) 
  reac_source_local(80,576) = - reac_rate_local(576) 
  reac_source_local(04,577) = + reac_rate_local(577) * 2.d0
  reac_source_local(18,577) = + reac_rate_local(577) 
  reac_source_local(72,577) = - reac_rate_local(577) 
  reac_source_local(80,577) = - reac_rate_local(577) 
  reac_source_local(04,578) = + reac_rate_local(578) 
  reac_source_local(17,578) = + reac_rate_local(578) 
  reac_source_local(72,578) = - reac_rate_local(578) 
  reac_source_local(80,578) = - reac_rate_local(578) 
  reac_source_local(04,579) = + reac_rate_local(579) 
  reac_source_local(16,579) = + reac_rate_local(579) 
  reac_source_local(71,579) = - reac_rate_local(579) 
  reac_source_local(80,579) = - reac_rate_local(579) 
  reac_source_local(04,580) = + reac_rate_local(580) * 2.d0
  reac_source_local(17,580) = + reac_rate_local(580) 
  reac_source_local(71,580) = - reac_rate_local(580) 
  reac_source_local(80,580) = - reac_rate_local(580) 
  reac_source_local(04,581) = + reac_rate_local(581) 
  reac_source_local(11,581) = + reac_rate_local(581) 
  reac_source_local(75,581) = - reac_rate_local(581) 
  reac_source_local(80,581) = - reac_rate_local(581) 
  reac_source_local(04,582) = + reac_rate_local(582) * 2.d0
  reac_source_local(77,582) = - reac_rate_local(582) 
  reac_source_local(80,582) = - reac_rate_local(582) 
  reac_source_local(04,583) = + reac_rate_local(583) * 3.d0
  reac_source_local(78,583) = - reac_rate_local(583) 
  reac_source_local(80,583) = - reac_rate_local(583) 
  reac_source_local(04,584) = + reac_rate_local(584) 
  reac_source_local(05,584) = + reac_rate_local(584) 
  reac_source_local(78,584) = - reac_rate_local(584) 
  reac_source_local(80,584) = - reac_rate_local(584) 
  reac_source_local(05,585) = + reac_rate_local(585) 
  reac_source_local(17,585) = + reac_rate_local(585) 
  reac_source_local(71,585) = - reac_rate_local(585) 
  reac_source_local(80,585) = - reac_rate_local(585) 
  reac_source_local(10,586) = + reac_rate_local(586) 
  reac_source_local(18,586) = + reac_rate_local(586) 
  reac_source_local(75,586) = - reac_rate_local(586) 
  reac_source_local(80,586) = - reac_rate_local(586) 
  reac_source_local(10,587) = + reac_rate_local(587) 
  reac_source_local(60,587) = - reac_rate_local(587) 
  reac_source_local(80,587) = - reac_rate_local(587) 
  reac_source_local(10,588) = + reac_rate_local(588) 
  reac_source_local(60,588) = - reac_rate_local(588) 
  reac_source_local(80,588) = - reac_rate_local(588) 
  reac_source_local(11,589) = + reac_rate_local(589) 
  reac_source_local(61,589) = - reac_rate_local(589) 
  reac_source_local(80,589) = - reac_rate_local(589) 
  reac_source_local(11,590) = + reac_rate_local(590) 
  reac_source_local(61,590) = - reac_rate_local(590) 
  reac_source_local(80,590) = - reac_rate_local(590) 
  reac_source_local(04,591) = + reac_rate_local(591) 
  reac_source_local(06,591) = + reac_rate_local(591) 
  reac_source_local(79,591) = - reac_rate_local(591) 
  reac_source_local(80,591) = - reac_rate_local(591) 
  reac_source_local(01,592) = + reac_rate_local(592) 
  reac_source_local(05,592) = + reac_rate_local(592) 
  reac_source_local(79,592) = - reac_rate_local(592) 
  reac_source_local(80,592) = - reac_rate_local(592) 
  reac_source_local(01,593) = + reac_rate_local(593) 
  reac_source_local(04,593) = + reac_rate_local(593) * 2.d0
  reac_source_local(79,593) = - reac_rate_local(593) 
  reac_source_local(80,593) = - reac_rate_local(593) 
  reac_source_local(02,594) = - reac_rate_local(594) 
  reac_source_local(68,594) = + reac_rate_local(594) 
  reac_source_local(80,594) = - reac_rate_local(594) 
  reac_source_local(01,595) = - reac_rate_local(595) 
  reac_source_local(64,595) = + reac_rate_local(595) 
  reac_source_local(80,595) = - reac_rate_local(595) 
  return
end subroutine ZDPlasKin_reac_source_matrix
!-----------------------------------------------------------------------------------------------------------------------------------
!
! reaction source terms
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_fex(neq,t,y,ydot)
  implicit none
  integer,          intent(in)  :: neq
  double precision, intent(in)  :: t, y(neq)
  double precision, intent(out) :: ydot(neq)
  if( lgas_heating ) ZDPlasKin_cfg(1) = y(81)
  density(:) = y(1:species_max)
  call ZDPlasKin_reac_rates(t)
  rrt(001) = rrt(001) * density(16) * density(80) 
  rrt(002) = rrt(002) * density(16) * density(80) 
  rrt(003) = rrt(003) * density(16) * density(80) 
  rrt(004) = rrt(004) * density(16) * density(80) 
  rrt(005) = rrt(005) * density(16) * density(80) 
  rrt(006) = rrt(006) * density(16) * density(80) 
  rrt(007) = rrt(007) * density(16) * density(80) 
  rrt(008) = rrt(008) * density(17) * density(80) 
  rrt(009) = rrt(009) * density(17) * density(80) 
  rrt(010) = rrt(010) * density(17) * density(80) 
  rrt(011) = rrt(011) * density(17) * density(80) 
  rrt(012) = rrt(012) * density(18) * density(80) 
  rrt(013) = rrt(013) * density(18) * density(80) 
  rrt(014) = rrt(014) * density(18) * density(80) 
  rrt(015) = rrt(015) * density(10) * density(80) 
  rrt(016) = rrt(016) * density(10) * density(80) 
  rrt(017) = rrt(017) * density(10) * density(80) 
  rrt(018) = rrt(018) * density(11) * density(80) 
  rrt(019) = rrt(019) * density(11) * density(80) 
  rrt(020) = rrt(020) * density(11) * density(80) 
  rrt(021) = rrt(021) * density(11) * density(80) 
  rrt(022) = rrt(022) * density(11) * density(80) 
  rrt(023) = rrt(023) * density(11) * density(80) 
  rrt(024) = rrt(024) * density(11) * density(80) 
  rrt(025) = rrt(025) * density(11) * density(80) 
  rrt(026) = rrt(026) * density(11) * density(80) 
  rrt(027) = rrt(027) * density(11) * density(80) 
  rrt(028) = rrt(028) * density(11) * density(80) 
  rrt(029) = rrt(029) * density(11) * density(80) 
  rrt(030) = rrt(030) * density(11) * density(80) 
  rrt(031) = rrt(031) * density(11) * density(80) 
  rrt(032) = rrt(032) * density(11) * density(80) 
  rrt(033) = rrt(033) * density(11) * density(80) 
  rrt(034) = rrt(034) * density(11) * density(80) 
  rrt(035) = rrt(035) * density(11) * density(80) 
  rrt(036) = rrt(036) * density(11) * density(80) 
  rrt(037) = rrt(037) * density(11) * density(80) 
  rrt(038) = rrt(038) * density(11) * density(80) 
  rrt(039) = rrt(039) * density(02) * density(80) 
  rrt(040) = rrt(040) * density(02) * density(80) 
  rrt(041) = rrt(041) * density(02) * density(80) 
  rrt(042) = rrt(042) * density(02) * density(80) 
  rrt(043) = rrt(043) * density(02) * density(80) 
  rrt(044) = rrt(044) * density(02) * density(80) 
  rrt(045) = rrt(045) * density(02) * density(80) 
  rrt(046) = rrt(046) * density(02) * density(80) 
  rrt(047) = rrt(047) * density(02) * density(80) 
  rrt(048) = rrt(048) * density(02) * density(80) 
  rrt(049) = rrt(049) * density(02) * density(80) 
  rrt(050) = rrt(050) * density(02) * density(80) 
  rrt(051) = rrt(051) * density(03) * density(80) 
  rrt(052) = rrt(052) * density(03) * density(80) 
  rrt(053) = rrt(053) * density(03) * density(80) 
  rrt(054) = rrt(054) * density(03) * density(80) 
  rrt(055) = rrt(055) * density(01) * density(80) 
  rrt(056) = rrt(056) * density(01) * density(80) 
  rrt(057) = rrt(057) * density(07) * density(80) 
  rrt(058) = rrt(058) * density(07) * density(80) 
  rrt(059) = rrt(059) * density(07) * density(80) 
  rrt(060) = rrt(060) * density(11) * density(38) 
  rrt(061) = rrt(061) * density(11) * density(39) 
  rrt(062) = rrt(062) * density(11) * density(40) 
  rrt(063) = rrt(063) * density(11) * density(41) 
  rrt(064) = rrt(064) * density(11) * density(42) 
  rrt(065) = rrt(065) * density(11) * density(43) 
  rrt(066) = rrt(066) * density(11) * density(44) 
  rrt(067) = rrt(067) * density(11) * density(45) 
  rrt(068) = rrt(068) * density(02) * density(38) 
  rrt(069) = rrt(069) * density(02) * density(39) 
  rrt(070) = rrt(070) * density(02) * density(40) 
  rrt(071) = rrt(071) * density(02) * density(41) 
  rrt(072) = rrt(072) * density(02) * density(42) 
  rrt(073) = rrt(073) * density(02) * density(43) 
  rrt(074) = rrt(074) * density(02) * density(44) 
  rrt(075) = rrt(075) * density(02) * density(45) 
  rrt(076) = rrt(076) * density(01) * density(38) 
  rrt(077) = rrt(077) * density(01) * density(39) 
  rrt(078) = rrt(078) * density(01) * density(40) 
  rrt(079) = rrt(079) * density(01) * density(41) 
  rrt(080) = rrt(080) * density(01) * density(42) 
  rrt(081) = rrt(081) * density(01) * density(43) 
  rrt(082) = rrt(082) * density(01) * density(44) 
  rrt(083) = rrt(083) * density(01) * density(45) 
  rrt(084) = rrt(084) * density(10) * density(38) 
  rrt(085) = rrt(085) * density(10) * density(39) 
  rrt(086) = rrt(086) * density(10) * density(40) 
  rrt(087) = rrt(087) * density(10) * density(41) 
  rrt(088) = rrt(088) * density(10) * density(42) 
  rrt(089) = rrt(089) * density(10) * density(43) 
  rrt(090) = rrt(090) * density(10) * density(44) 
  rrt(091) = rrt(091) * density(10) * density(45) 
  rrt(092) = rrt(092) * density(11) * density(50) 
  rrt(093) = rrt(093) * density(11) * density(51) 
  rrt(094) = rrt(094) * density(11) * density(52) 
  rrt(095) = rrt(095) * density(11) * density(53) 
  rrt(096) = rrt(096) * density(02) * density(50) 
  rrt(097) = rrt(097) * density(02) * density(51) 
  rrt(098) = rrt(098) * density(02) * density(52) 
  rrt(099) = rrt(099) * density(02) * density(53) 
  rrt(100) = rrt(100) * density(01) * density(50) 
  rrt(101) = rrt(101) * density(01) * density(51) 
  rrt(102) = rrt(102) * density(01) * density(52) 
  rrt(103) = rrt(103) * density(01) * density(53) 
  rrt(104) = rrt(104) * density(38)**2 
  rrt(105) = rrt(105) * density(38) * density(39) 
  rrt(106) = rrt(106) * density(38) * density(40) 
  rrt(107) = rrt(107) * density(38) * density(41) 
  rrt(108) = rrt(108) * density(38) * density(42) 
  rrt(109) = rrt(109) * density(38) * density(43) 
  rrt(110) = rrt(110) * density(38) * density(44) 
  rrt(111) = rrt(111) * density(11) * density(39) 
  rrt(112) = rrt(112) * density(39)**2 
  rrt(113) = rrt(113) * density(39) * density(40) 
  rrt(114) = rrt(114) * density(39) * density(41) 
  rrt(115) = rrt(115) * density(39) * density(42) 
  rrt(116) = rrt(116) * density(39) * density(43) 
  rrt(117) = rrt(117) * density(39) * density(44) 
  rrt(118) = rrt(118) * density(11) * density(40) 
  rrt(119) = rrt(119) * density(38) * density(40) 
  rrt(120) = rrt(120) * density(40)**2 
  rrt(121) = rrt(121) * density(40) * density(41) 
  rrt(122) = rrt(122) * density(40) * density(42) 
  rrt(123) = rrt(123) * density(40) * density(43) 
  rrt(124) = rrt(124) * density(40) * density(44) 
  rrt(125) = rrt(125) * density(11) * density(41) 
  rrt(126) = rrt(126) * density(38) * density(41) 
  rrt(127) = rrt(127) * density(39) * density(41) 
  rrt(128) = rrt(128) * density(41)**2 
  rrt(129) = rrt(129) * density(41) * density(42) 
  rrt(130) = rrt(130) * density(41) * density(43) 
  rrt(131) = rrt(131) * density(41) * density(44) 
  rrt(132) = rrt(132) * density(11) * density(42) 
  rrt(133) = rrt(133) * density(38) * density(42) 
  rrt(134) = rrt(134) * density(39) * density(42) 
  rrt(135) = rrt(135) * density(40) * density(42) 
  rrt(136) = rrt(136) * density(42)**2 
  rrt(137) = rrt(137) * density(42) * density(43) 
  rrt(138) = rrt(138) * density(42) * density(44) 
  rrt(139) = rrt(139) * density(11) * density(43) 
  rrt(140) = rrt(140) * density(38) * density(43) 
  rrt(141) = rrt(141) * density(39) * density(43) 
  rrt(142) = rrt(142) * density(40) * density(43) 
  rrt(143) = rrt(143) * density(41) * density(43) 
  rrt(144) = rrt(144) * density(43)**2 
  rrt(145) = rrt(145) * density(43) * density(44) 
  rrt(146) = rrt(146) * density(11) * density(44) 
  rrt(147) = rrt(147) * density(38) * density(44) 
  rrt(148) = rrt(148) * density(39) * density(44) 
  rrt(149) = rrt(149) * density(40) * density(44) 
  rrt(150) = rrt(150) * density(41) * density(44) 
  rrt(151) = rrt(151) * density(42) * density(44) 
  rrt(152) = rrt(152) * density(44)**2 
  rrt(153) = rrt(153) * density(11) * density(45) 
  rrt(154) = rrt(154) * density(38) * density(45) 
  rrt(155) = rrt(155) * density(39) * density(45) 
  rrt(156) = rrt(156) * density(40) * density(45) 
  rrt(157) = rrt(157) * density(41) * density(45) 
  rrt(158) = rrt(158) * density(42) * density(45) 
  rrt(159) = rrt(159) * density(43) * density(45) 
  rrt(160) = rrt(160) * density(50)**2 
  rrt(161) = rrt(161) * density(50) * density(51) 
  rrt(162) = rrt(162) * density(50) * density(52) 
  rrt(163) = rrt(163) * density(02) * density(51) 
  rrt(164) = rrt(164) * density(51)**2 
  rrt(165) = rrt(165) * density(51) * density(52) 
  rrt(166) = rrt(166) * density(02) * density(52) 
  rrt(167) = rrt(167) * density(50) * density(52) 
  rrt(168) = rrt(168) * density(52)**2 
  rrt(169) = rrt(169) * density(02) * density(53) 
  rrt(170) = rrt(170) * density(50) * density(53) 
  rrt(171) = rrt(171) * density(51) * density(53) 
  rrt(172) = rrt(172) * density(02) * density(57) 
  rrt(173) = rrt(173) * density(02) * density(58) 
  rrt(174) = rrt(174) * density(02) * density(59) 
  rrt(175) = rrt(175) * density(16) * density(57) 
  rrt(176) = rrt(176) * density(16) * density(58) 
  rrt(177) = rrt(177) * density(16) * density(59) 
  rrt(178) = rrt(178) * density(04) * density(50) 
  rrt(179) = rrt(179) * density(04) * density(51) 
  rrt(180) = rrt(180) * density(04) * density(52) 
  rrt(181) = rrt(181) * density(04) * density(53) 
  rrt(182) = rrt(182) * density(07) * density(50) 
  rrt(183) = rrt(183) * density(07) * density(51) 
  rrt(184) = rrt(184) * density(07) * density(52) 
  rrt(185) = rrt(185) * density(07) * density(53) 
  rrt(186) = rrt(186) * density(01) * density(04) * density(50) 
  rrt(187) = rrt(187) * density(01) * density(04) * density(51) 
  rrt(188) = rrt(188) * density(01) * density(04) * density(52) 
  rrt(189) = rrt(189) * density(01) * density(04) * density(53) 
  rrt(190) = rrt(190) * density(05) * density(50) 
  rrt(191) = rrt(191) * density(07) * density(50) 
  rrt(192) = rrt(192) * density(05) * density(51) 
  rrt(193) = rrt(193) * density(07) * density(51) 
  rrt(194) = rrt(194) * density(05) * density(52) 
  rrt(195) = rrt(195) * density(07) * density(52) 
  rrt(196) = rrt(196) * density(05) * density(53) 
  rrt(197) = rrt(197) * density(07) * density(53) 
  rrt(198) = rrt(198) * density(04) * density(06) * density(50) 
  rrt(199) = rrt(199) * density(04) * density(06) * density(51) 
  rrt(200) = rrt(200) * density(04) * density(06) * density(52) 
  rrt(201) = rrt(201) * density(04) * density(06) * density(53) 
  rrt(202) = rrt(202) * density(05) * density(50) 
  rrt(203) = rrt(203) * density(05) * density(51) 
  rrt(204) = rrt(204) * density(05) * density(52) 
  rrt(205) = rrt(205) * density(05) * density(53) 
  rrt(206) = rrt(206) * density(06) * density(50) 
  rrt(207) = rrt(207) * density(06) * density(51) 
  rrt(208) = rrt(208) * density(06) * density(52) 
  rrt(209) = rrt(209) * density(06) * density(53) 
  rrt(210) = rrt(210) * density(07) * density(50) 
  rrt(211) = rrt(211) * density(07) * density(51) 
  rrt(212) = rrt(212) * density(07) * density(52) 
  rrt(213) = rrt(213) * density(07) * density(53) 
  rrt(214) = rrt(214) * density(09) * density(50) 
  rrt(215) = rrt(215) * density(09) * density(51) 
  rrt(216) = rrt(216) * density(09) * density(52) 
  rrt(217) = rrt(217) * density(09) * density(53) 
  rrt(218) = rrt(218) * density(50) * density(56) 
  rrt(219) = rrt(219) * density(51) * density(56) 
  rrt(220) = rrt(220) * density(52) * density(56) 
  rrt(221) = rrt(221) * density(53) * density(56) 
  rrt(222) = rrt(222) * density(06) * density(50) 
  rrt(223) = rrt(223) * density(06) * density(51) 
  rrt(224) = rrt(224) * density(06) * density(52) 
  rrt(225) = rrt(225) * density(06) * density(53) 
  rrt(226) = rrt(226) * density(12) * density(50) 
  rrt(227) = rrt(227) * density(12) * density(51) 
  rrt(228) = rrt(228) * density(12) * density(52) 
  rrt(229) = rrt(229) * density(12) * density(53) 
  rrt(230) = rrt(230) * density(11) * density(50) 
  rrt(231) = rrt(231) * density(11) * density(51) 
  rrt(232) = rrt(232) * density(11) * density(52) 
  rrt(233) = rrt(233) * density(11) * density(53) 
  rrt(234) = rrt(234) * density(17) * density(50) 
  rrt(235) = rrt(235) * density(17) * density(51) 
  rrt(236) = rrt(236) * density(17) * density(52) 
  rrt(237) = rrt(237) * density(17) * density(53) 
  rrt(238) = rrt(238) * density(17) * density(50) 
  rrt(239) = rrt(239) * density(17) * density(51) 
  rrt(240) = rrt(240) * density(17) * density(52) 
  rrt(241) = rrt(241) * density(17) * density(53) 
  rrt(242) = rrt(242) * density(18) * density(50) 
  rrt(243) = rrt(243) * density(18) * density(51) 
  rrt(244) = rrt(244) * density(18) * density(52) 
  rrt(245) = rrt(245) * density(18) * density(53) 
  rrt(246) = rrt(246) * density(18) * density(50) 
  rrt(247) = rrt(247) * density(18) * density(51) 
  rrt(248) = rrt(248) * density(18) * density(52) 
  rrt(249) = rrt(249) * density(18) * density(53) 
  rrt(250) = rrt(250) * density(24) * density(50) 
  rrt(251) = rrt(251) * density(24) * density(51) 
  rrt(252) = rrt(252) * density(24) * density(52) 
  rrt(253) = rrt(253) * density(24) * density(53) 
  rrt(254) = rrt(254) * density(28) * density(50) 
  rrt(255) = rrt(255) * density(28) * density(51) 
  rrt(256) = rrt(256) * density(28) * density(52) 
  rrt(257) = rrt(257) * density(28) * density(53) 
  rrt(258) = rrt(258) * density(25) * density(50) 
  rrt(259) = rrt(259) * density(25) * density(51) 
  rrt(260) = rrt(260) * density(25) * density(52) 
  rrt(261) = rrt(261) * density(25) * density(53) 
  rrt(262) = rrt(262) * density(10) * density(50) 
  rrt(263) = rrt(263) * density(10) * density(51) 
  rrt(264) = rrt(264) * density(10) * density(52) 
  rrt(265) = rrt(265) * density(10) * density(53) 
  rrt(266) = rrt(266) * density(01) * density(38) 
  rrt(267) = rrt(267) * density(01) * density(39) 
  rrt(268) = rrt(268) * density(01) * density(40) 
  rrt(269) = rrt(269) * density(01) * density(41) 
  rrt(270) = rrt(270) * density(01) * density(42) 
  rrt(271) = rrt(271) * density(01) * density(43) 
  rrt(272) = rrt(272) * density(01) * density(44) 
  rrt(273) = rrt(273) * density(01) * density(45) 
  rrt(274) = rrt(274) * density(02) * density(38) 
  rrt(275) = rrt(275) * density(02) * density(39) 
  rrt(276) = rrt(276) * density(02) * density(40) 
  rrt(277) = rrt(277) * density(02) * density(41) 
  rrt(278) = rrt(278) * density(02) * density(42) 
  rrt(279) = rrt(279) * density(02) * density(43) 
  rrt(280) = rrt(280) * density(02) * density(44) 
  rrt(281) = rrt(281) * density(02) * density(45) 
  rrt(282) = rrt(282) * density(07) * density(38) 
  rrt(283) = rrt(283) * density(07) * density(39) 
  rrt(284) = rrt(284) * density(07) * density(40) 
  rrt(285) = rrt(285) * density(07) * density(41) 
  rrt(286) = rrt(286) * density(07) * density(42) 
  rrt(287) = rrt(287) * density(07) * density(43) 
  rrt(288) = rrt(288) * density(07) * density(44) 
  rrt(289) = rrt(289) * density(07) * density(45) 
  rrt(290) = rrt(290) * density(04) * density(38) 
  rrt(291) = rrt(291) * density(04) * density(39) 
  rrt(292) = rrt(292) * density(04) * density(40) 
  rrt(293) = rrt(293) * density(04) * density(41) 
  rrt(294) = rrt(294) * density(04) * density(42) 
  rrt(295) = rrt(295) * density(04) * density(43) 
  rrt(296) = rrt(296) * density(04) * density(44) 
  rrt(297) = rrt(297) * density(04) * density(45) 
  rrt(298) = rrt(298) * density(06) * density(38) 
  rrt(299) = rrt(299) * density(06) * density(39) 
  rrt(300) = rrt(300) * density(06) * density(40) 
  rrt(301) = rrt(301) * density(06) * density(41) 
  rrt(302) = rrt(302) * density(06) * density(42) 
  rrt(303) = rrt(303) * density(06) * density(43) 
  rrt(304) = rrt(304) * density(06) * density(44) 
  rrt(305) = rrt(305) * density(06) * density(45) 
  rrt(306) = rrt(306) * density(07) * density(38) 
  rrt(307) = rrt(307) * density(07) * density(39) 
  rrt(308) = rrt(308) * density(07) * density(40) 
  rrt(309) = rrt(309) * density(07) * density(41) 
  rrt(310) = rrt(310) * density(07) * density(42) 
  rrt(311) = rrt(311) * density(07) * density(43) 
  rrt(312) = rrt(312) * density(07) * density(44) 
  rrt(313) = rrt(313) * density(07) * density(45) 
  rrt(314) = rrt(314) * density(06) * density(38) 
  rrt(315) = rrt(315) * density(06) * density(39) 
  rrt(316) = rrt(316) * density(06) * density(40) 
  rrt(317) = rrt(317) * density(06) * density(41) 
  rrt(318) = rrt(318) * density(06) * density(42) 
  rrt(319) = rrt(319) * density(06) * density(43) 
  rrt(320) = rrt(320) * density(06) * density(44) 
  rrt(321) = rrt(321) * density(06) * density(45) 
  rrt(322) = rrt(322) * density(07) * density(38) 
  rrt(323) = rrt(323) * density(07) * density(39) 
  rrt(324) = rrt(324) * density(07) * density(40) 
  rrt(325) = rrt(325) * density(07) * density(41) 
  rrt(326) = rrt(326) * density(07) * density(42) 
  rrt(327) = rrt(327) * density(07) * density(43) 
  rrt(328) = rrt(328) * density(07) * density(44) 
  rrt(329) = rrt(329) * density(07) * density(45) 
  rrt(330) = rrt(330) * density(05) * density(38) 
  rrt(331) = rrt(331) * density(05) * density(39) 
  rrt(332) = rrt(332) * density(05) * density(40) 
  rrt(333) = rrt(333) * density(05) * density(41) 
  rrt(334) = rrt(334) * density(05) * density(42) 
  rrt(335) = rrt(335) * density(05) * density(43) 
  rrt(336) = rrt(336) * density(05) * density(44) 
  rrt(337) = rrt(337) * density(05) * density(45) 
  rrt(338) = rrt(338) * density(08) * density(38) 
  rrt(339) = rrt(339) * density(08) * density(39) 
  rrt(340) = rrt(340) * density(08) * density(40) 
  rrt(341) = rrt(341) * density(08) * density(41) 
  rrt(342) = rrt(342) * density(08) * density(42) 
  rrt(343) = rrt(343) * density(08) * density(43) 
  rrt(344) = rrt(344) * density(08) * density(44) 
  rrt(345) = rrt(345) * density(08) * density(45) 
  rrt(346) = rrt(346) * density(26) * density(38) 
  rrt(347) = rrt(347) * density(26) * density(39) 
  rrt(348) = rrt(348) * density(26) * density(40) 
  rrt(349) = rrt(349) * density(26) * density(41) 
  rrt(350) = rrt(350) * density(26) * density(42) 
  rrt(351) = rrt(351) * density(26) * density(43) 
  rrt(352) = rrt(352) * density(26) * density(44) 
  rrt(353) = rrt(353) * density(26) * density(45) 
  rrt(354) = rrt(354) * density(06) * density(38) 
  rrt(355) = rrt(355) * density(06) * density(39) 
  rrt(356) = rrt(356) * density(06) * density(40) 
  rrt(357) = rrt(357) * density(06) * density(41) 
  rrt(358) = rrt(358) * density(06) * density(42) 
  rrt(359) = rrt(359) * density(06) * density(43) 
  rrt(360) = rrt(360) * density(06) * density(44) 
  rrt(361) = rrt(361) * density(06) * density(45) 
  rrt(362) = rrt(362) * density(02) * density(57) 
  rrt(363) = rrt(363) * density(02) * density(58) 
  rrt(364) = rrt(364) * density(02) * density(59) 
  rrt(365) = rrt(365) * density(04) * density(57) 
  rrt(366) = rrt(366) * density(04) * density(58) 
  rrt(367) = rrt(367) * density(04) * density(59) 
  rrt(368) = rrt(368) * density(01) * density(57) 
  rrt(369) = rrt(369) * density(01) * density(58) 
  rrt(370) = rrt(370) * density(01) * density(59) 
  rrt(371) = rrt(371) * density(06) * density(57) 
  rrt(372) = rrt(372) * density(06) * density(58) 
  rrt(373) = rrt(373) * density(06) * density(59) 
  rrt(374) = rrt(374) * density(08) * density(57) 
  rrt(375) = rrt(375) * density(08) * density(58) 
  rrt(376) = rrt(376) * density(08) * density(59) 
  rrt(377) = rrt(377) * density(10) * density(54) 
  rrt(378) = rrt(378) * density(02) * density(54) 
  rrt(379) = rrt(379) * density(11) * density(54) 
  rrt(380) = rrt(380) * density(12) * density(54) 
  rrt(381) = rrt(381) * density(03) * density(54) 
  rrt(382) = rrt(382) * density(54)**2 
  rrt(383) = rrt(383) * density(02) * density(54) 
  rrt(384) = rrt(384) * density(54)**2 
  rrt(385) = rrt(385) * density(01) * density(02) * density(54) 
  rrt(386) = rrt(386) * density(01) * density(54) 
  rrt(387) = rrt(387) * density(01) * density(55) 
  rrt(388) = rrt(388) * density(05) * density(54) 
  rrt(389) = rrt(389) * density(05) * density(54) 
  rrt(390) = rrt(390) * density(04) * density(54) 
  rrt(391) = rrt(391) * density(04) * density(54) 
  rrt(392) = rrt(392) * density(04) * density(54) 
  rrt(393) = rrt(393) * density(05) * density(54) 
  rrt(394) = rrt(394) * density(07) * density(54) 
  rrt(395) = rrt(395) * density(05) * density(54) 
  rrt(396) = rrt(396) * density(06) * density(54) 
  rrt(397) = rrt(397) * density(06) * density(54) 
  rrt(398) = rrt(398) * density(06) * density(54) 
  rrt(399) = rrt(399) * density(09) * density(54) 
  rrt(400) = rrt(400) * density(08) * density(54) 
  rrt(401) = rrt(401) * density(17) * density(54) 
  rrt(402) = rrt(402) * density(17) * density(54) 
  rrt(403) = rrt(403) * density(24) * density(54) 
  rrt(404) = rrt(404) * density(28) * density(54) 
  rrt(405) = rrt(405) * density(01) * density(55) 
  rrt(406) = rrt(406) * density(02) * density(55) 
  rrt(407) = rrt(407) * density(03) * density(55) 
  rrt(408) = rrt(408) * density(11) * density(55) 
  rrt(409) = rrt(409) * density(12) * density(55) 
  rrt(410) = rrt(410) * density(01) * density(55) 
  rrt(411) = rrt(411) * density(55)**2 
  rrt(412) = rrt(412) * density(03) * density(55) 
  rrt(413) = rrt(413) * density(03) * density(55) 
  rrt(414) = rrt(414) * density(03) * density(55) 
  rrt(415) = rrt(415) * density(02) * density(55) 
  rrt(416) = rrt(416) * density(01) * density(35) 
  rrt(417) = rrt(417) * density(02) * density(35) 
  rrt(418) = rrt(418) * density(11) * density(35) 
  rrt(419) = rrt(419) * density(01) * density(35) 
  rrt(420) = rrt(420) * density(01) * density(35) 
  rrt(421) = rrt(421) * density(01) * density(35) 
  rrt(422) = rrt(422) * density(02) * density(35) 
  rrt(423) = rrt(423) * density(02) * density(35) 
  rrt(424) = rrt(424) * density(02) * density(35) 
  rrt(425) = rrt(425) * density(01) * density(36) 
  rrt(426) = rrt(426) * density(02) * density(36) 
  rrt(427) = rrt(427) * density(02) * density(36) 
  rrt(428) = rrt(428) * density(02) * density(36) 
  rrt(429) = rrt(429) * density(03) * density(36) 
  rrt(430) = rrt(430) * density(03) * density(36) 
  rrt(431) = rrt(431) * density(11) * density(36) 
  rrt(432) = rrt(432) * density(12) * density(36) 
  rrt(433) = rrt(433) * density(14) * density(36) 
  rrt(434) = rrt(434) * density(16) * density(36) 
  rrt(435) = rrt(435) * density(16) * density(36) 
  rrt(436) = rrt(436) * density(16) * density(36) 
  rrt(437) = rrt(437) * density(14) * density(36) 
  rrt(438) = rrt(438) * density(14) * density(37) 
  rrt(439) = rrt(439) * density(10) * density(46) 
  rrt(440) = rrt(440) * density(10) * density(46) 
  rrt(441) = rrt(441) * density(11) * density(46) 
  rrt(442) = rrt(442) * density(46)**2 
  rrt(443) = rrt(443) * density(46)**2 
  rrt(444) = rrt(444) * density(01) * density(46) 
  rrt(445) = rrt(445) * density(01) * density(46) 
  rrt(446) = rrt(446) * density(02) * density(46) 
  rrt(447) = rrt(447) * density(02) * density(46) 
  rrt(448) = rrt(448) * density(02) * density(46) 
  rrt(449) = rrt(449) * density(12) * density(46) 
  rrt(450) = rrt(450) * density(14) * density(46) 
  rrt(451) = rrt(451) * density(13) * density(46) 
  rrt(452) = rrt(452) * density(02) * density(46) 
  rrt(453) = rrt(453) * density(11) * density(47) 
  rrt(454) = rrt(454) * density(11) * density(47) 
  rrt(455) = rrt(455) * density(12) * density(47) 
  rrt(456) = rrt(456) * density(02) * density(47) 
  rrt(457) = rrt(457) * density(01) * density(47) 
  rrt(458) = rrt(458) * density(11) * density(48) 
  rrt(459) = rrt(459) * density(12) * density(48) 
  rrt(460) = rrt(460) * density(46) * density(48) 
  rrt(461) = rrt(461) * density(48)**2 
  rrt(462) = rrt(462) * density(02) * density(48) 
  rrt(463) = rrt(463) * density(01) * density(48) 
  rrt(464) = rrt(464) * density(11) * density(49) 
  rrt(465) = rrt(465) * density(02) * density(49) 
  rrt(466) = rrt(466) * density(01) * density(49) 
  rrt(467) = rrt(467) * density(02) * density(49) 
  rrt(468) = rrt(468) * density(05) * density(34) 
  rrt(469) = rrt(469) * density(16) * density(34) 
  rrt(470) = rrt(470) * density(05) * density(33) 
  rrt(471) = rrt(471) * density(11) * density(34) 
  rrt(472) = rrt(472) * density(10) * density(33) 
  rrt(473) = rrt(473) * density(10) * density(33) 
  rrt(474) = rrt(474) * density(11) * density(33) 
  rrt(475) = rrt(475) * density(33) * density(34) 
  rrt(476) = rrt(476) * density(13) * density(33) 
  rrt(477) = rrt(477) * density(13) * density(34) 
  rrt(478) = rrt(478) * density(13) * density(33) 
  rrt(479) = rrt(479) * density(13) * density(34) 
  rrt(480) = rrt(480) * density(12) * density(34) 
  rrt(481) = rrt(481) * density(12) * density(33) 
  rrt(482) = rrt(482) * density(14) * density(34) 
  rrt(483) = rrt(483) * density(14) * density(33) 
  rrt(484) = rrt(484) * density(10)**2 * density(11) 
  rrt(485) = rrt(485) * density(02) * density(10)**2 
  rrt(486) = rrt(486) * density(10)**2 * density(12) 
  rrt(487) = rrt(487) * density(10)**3 
  rrt(488) = rrt(488) * density(01) * density(10)**2 
  rrt(489) = rrt(489) * density(10)**2 * density(11) 
  rrt(490) = rrt(490) * density(02) * density(10)**2 
  rrt(491) = rrt(491) * density(10)**2 * density(12) 
  rrt(492) = rrt(492) * density(10)**3 
  rrt(493) = rrt(493) * density(01) * density(10)**2 
  rrt(494) = rrt(494) * density(01) * density(64) 
  rrt(495) = rrt(495) * density(02) * density(64) 
  rrt(496) = rrt(496) * density(54) * density(64) 
  rrt(497) = rrt(497) * density(55) * density(64) 
  rrt(498) = rrt(498) * density(03) * density(64) 
  rrt(499) = rrt(499) * density(54) * density(64) 
  rrt(500) = rrt(500) * density(03) * density(64) 
  rrt(501) = rrt(501) * density(04) * density(65) 
  rrt(502) = rrt(502) * density(16) * density(65) 
  rrt(503) = rrt(503) * density(02)**2 * density(67) 
  rrt(504) = rrt(504) * density(16) * density(67) 
  rrt(505) = rrt(505) * density(01) * density(69) 
  rrt(506) = rrt(506) * density(02) * density(69) 
  rrt(507) = rrt(507) * density(36) * density(69) 
  rrt(508) = rrt(508) * density(37) * density(69) 
  rrt(509) = rrt(509) * density(01) * density(68) 
  rrt(510) = rrt(510) * density(54) * density(68) 
  rrt(511) = rrt(511) * density(55) * density(68) 
  rrt(512) = rrt(512) * density(01) * density(68) 
  rrt(513) = rrt(513) * density(03) * density(68) 
  rrt(514) = rrt(514) * density(05) * density(68) 
  rrt(515) = rrt(515) * density(04) * density(68) 
  rrt(516) = rrt(516) * density(06) * density(68) 
  rrt(517) = rrt(517) * density(04) * density(68) 
  rrt(518) = rrt(518) * density(01) * density(70) 
  rrt(519) = rrt(519) * density(01) * density(70) 
  rrt(520) = rrt(520) * density(16) * density(78) 
  rrt(521) = rrt(521) * density(16) * density(77) 
  rrt(522) = rrt(522) * density(16) * density(77) 
  rrt(523) = rrt(523) * density(17) * density(77) 
  rrt(524) = rrt(524) * density(17) * density(77) 
  rrt(525) = rrt(525) * density(18) * density(77) 
  rrt(526) = rrt(526) * density(18) * density(77) 
  rrt(527) = rrt(527) * density(11) * density(77) 
  rrt(528) = rrt(528) * density(18) * density(76) 
  rrt(529) = rrt(529) * density(17) * density(76) 
  rrt(530) = rrt(530) * density(16) * density(76) 
  rrt(531) = rrt(531) * density(16) * density(60) 
  rrt(532) = rrt(532) * density(16) * density(60) 
  rrt(533) = rrt(533) * density(16) * density(60) 
  rrt(534) = rrt(534) * density(05) * density(60) 
  rrt(535) = rrt(535) * density(16) * density(61) 
  rrt(536) = rrt(536) * density(05) * density(61) 
  rrt(537) = rrt(537) * density(01) * density(61) 
  rrt(538) = rrt(538) * density(10) * density(61) 
  rrt(539) = rrt(539) * density(02) * density(61) 
  rrt(540) = rrt(540) * density(11)**2 * density(61) 
  rrt(541) = rrt(541) * density(10) * density(62) 
  rrt(542) = rrt(542) * density(10) * density(63) 
  rrt(543) = rrt(543) * density(11) * density(63) 
  rrt(544) = rrt(544) * density(02) * density(63) 
  rrt(545) = rrt(545) * density(16) * density(74) 
  rrt(546) = rrt(546) * density(16) * density(74) 
  rrt(547) = rrt(547) * density(11) * density(74) 
  rrt(548) = rrt(548) * density(05) * density(74) 
  rrt(549) = rrt(549) * density(05) * density(74) 
  rrt(550) = rrt(550) * density(02) * density(74) 
  rrt(551) = rrt(551) * density(16) * density(73) 
  rrt(552) = rrt(552) * density(16) * density(73) 
  rrt(553) = rrt(553) * density(05) * density(73) 
  rrt(554) = rrt(554) * density(16) * density(72) 
  rrt(555) = rrt(555) * density(16) * density(72) 
  rrt(556) = rrt(556) * density(16) * density(72) 
  rrt(557) = rrt(557) * density(05) * density(72) 
  rrt(558) = rrt(558) * density(05) * density(72) 
  rrt(559) = rrt(559) * density(05) * density(72) 
  rrt(560) = rrt(560) * density(05) * density(72) 
  rrt(561) = rrt(561) * density(16) * density(75) 
  rrt(562) = rrt(562) * density(01) * density(66) 
  rrt(563) = rrt(563) * density(04) * density(66) 
  rrt(564) = rrt(564) * density(61) * density(80) 
  rrt(565) = rrt(565) * density(61) * density(80) 
  rrt(566) = rrt(566) * density(67) * density(80) 
  rrt(567) = rrt(567) * density(67) * density(80) 
  rrt(568) = rrt(568) * density(67) * density(80) 
  rrt(569) = rrt(569) * density(69) * density(80) 
  rrt(570) = rrt(570) * density(63) * density(80) 
  rrt(571) = rrt(571) * density(67) * density(80)**2 
  rrt(572) = rrt(572) * density(02) * density(67) * density(80) 
  rrt(573) = rrt(573) * density(69) * density(80)**2 
  rrt(574) = rrt(574) * density(74) * density(80) 
  rrt(575) = rrt(575) * density(73) * density(80) 
  rrt(576) = rrt(576) * density(73) * density(80) 
  rrt(577) = rrt(577) * density(72) * density(80) 
  rrt(578) = rrt(578) * density(72) * density(80) 
  rrt(579) = rrt(579) * density(71) * density(80) 
  rrt(580) = rrt(580) * density(71) * density(80) 
  rrt(581) = rrt(581) * density(75) * density(80) 
  rrt(582) = rrt(582) * density(77) * density(80) 
  rrt(583) = rrt(583) * density(78) * density(80) 
  rrt(584) = rrt(584) * density(78) * density(80) 
  rrt(585) = rrt(585) * density(71) * density(80) 
  rrt(586) = rrt(586) * density(75) * density(80) 
  rrt(587) = rrt(587) * density(60) * density(80)**2 
  rrt(588) = rrt(588) * density(60) * density(80) 
  rrt(589) = rrt(589) * density(61) * density(80)**2 
  rrt(590) = rrt(590) * density(61) * density(80) 
  rrt(591) = rrt(591) * density(79) * density(80) 
  rrt(592) = rrt(592) * density(79) * density(80) 
  rrt(593) = rrt(593) * density(79) * density(80) 
  rrt(594) = rrt(594) * density(02) * density(80) 
  rrt(595) = rrt(595) * density(01) * density(80) 
  ydot(01) = +  2.d0 * rrt(047)+rrt(048)+rrt(049)+rrt(050)+rrt(051)+rrt(052)+rrt(053)-rrt(055)-rrt(056)+rrt(178)+rrt(179)+rrt(180)&
             +rrt(181)-rrt(186)-rrt(187)-rrt(188)-rrt(189)+  2.d0 * rrt(190)+  2.d0 * rrt(191)+  2.d0 * rrt(192)+  2.d0 * rrt(193)&
             +  2.d0 * rrt(194)+  2.d0 * rrt(195)+  2.d0 * rrt(196)+  2.d0 * rrt(197)+rrt(206)+rrt(207)+rrt(208)+rrt(209)+rrt(218)&
             +rrt(219)+rrt(220)+rrt(221)+rrt(226)+rrt(227)+rrt(228)+rrt(229)+rrt(230)+rrt(231)+rrt(232)+rrt(233)+rrt(234)+rrt(235)&
             +rrt(236)+rrt(237)+rrt(242)+rrt(243)+rrt(244)+rrt(245)+rrt(262)+rrt(263)+rrt(264)+rrt(265)-rrt(266)-rrt(267)-rrt(268)&
             -rrt(269)-rrt(270)-rrt(271)-rrt(272)-rrt(273)+rrt(274)+rrt(275)+rrt(276)+rrt(277)+rrt(278)+rrt(279)+rrt(280)+rrt(281)&
             +rrt(314)+rrt(315)+rrt(316)+rrt(317)+rrt(318)+rrt(319)+rrt(320)+rrt(321)-rrt(368)-rrt(369)-rrt(370)+rrt(377)+rrt(383)&
             +rrt(390)+rrt(397)+rrt(401)-rrt(405)+rrt(407)+rrt(412)-rrt(416)-rrt(420)-rrt(421)+rrt(425)+rrt(426)+rrt(427)+rrt(428)&
             +  2.d0 * rrt(429)+rrt(431)-rrt(444)-rrt(445)+rrt(448)+rrt(451)+  2.d0 * rrt(452)+  2.d0 * rrt(456)-rrt(457)+rrt(459)&
             +rrt(462)-rrt(463)+rrt(465)-rrt(466)+rrt(467)+  2.d0 * rrt(478)+  2.d0 * rrt(479)+rrt(480)+rrt(481)-rrt(494)+rrt(497)&
             +rrt(499)+rrt(500)+rrt(501)+rrt(502)-rrt(505)-rrt(509)-rrt(512)+rrt(517)-rrt(518)-rrt(519)-rrt(537)-rrt(562)&
             +  2.d0 * rrt(566)+rrt(567)+rrt(568)+rrt(592)+rrt(593)-rrt(595) 
  ydot(02) = -rrt(039)-rrt(040)-rrt(041)-rrt(042)-rrt(043)-rrt(044)-rrt(045)-rrt(046)-rrt(047)-rrt(048)-rrt(049)-rrt(050)+rrt(052)&
             +rrt(054)+rrt(092)+rrt(096)+rrt(100)+rrt(160)+rrt(161)+rrt(162)-rrt(163)-rrt(166)-rrt(169)+rrt(182)+rrt(183)+rrt(184)&
             +rrt(185)+rrt(186)+rrt(187)+rrt(188)+rrt(189)+rrt(198)+rrt(199)+rrt(200)+rrt(201)+rrt(218)+rrt(219)+rrt(220)+rrt(221)&
             +rrt(222)+rrt(223)+rrt(224)+rrt(225)-rrt(274)-rrt(275)-rrt(276)-rrt(277)-rrt(278)-rrt(279)-rrt(280)-rrt(281)+rrt(338)&
             +rrt(339)+rrt(340)+rrt(341)+rrt(342)+rrt(343)+rrt(344)+rrt(345)+rrt(378)+rrt(379)+rrt(380)+  2.d0 * rrt(381)+rrt(382)&
             -rrt(383)+  2.d0 * rrt(384)+rrt(385)+rrt(386)+rrt(389)+rrt(392)+rrt(398)+rrt(399)+rrt(400)+rrt(405)+  2.d0 * rrt(407)&
             +rrt(410)+rrt(411)+rrt(412)+rrt(413)+rrt(415)+rrt(416)-rrt(417)+rrt(419)+rrt(424)-rrt(427)-rrt(428)+rrt(429)&
             +  2.d0 * rrt(430)+rrt(432)+rrt(437)+rrt(438)-rrt(446)-rrt(447)-rrt(448)-rrt(452)-rrt(456)-rrt(462)-rrt(465)-rrt(467)&
             +rrt(476)+rrt(477)+rrt(494)-rrt(495)+rrt(497)+  2.d0 * rrt(498)-rrt(503)+rrt(504)+rrt(506)+  2.d0 * rrt(510)&
             +  2.d0 * rrt(511)+rrt(512)+rrt(513)+rrt(516)+  2.d0 * rrt(518)+rrt(519)-rrt(539)-rrt(544)-rrt(550)+  2.d0 * rrt(569)&
             +rrt(571)+rrt(572)+  2.d0 * rrt(573)-rrt(594) 
  ydot(03) = -rrt(051)-rrt(052)-rrt(053)-rrt(054)-rrt(381)+rrt(383)+rrt(396)-rrt(407)-rrt(412)-rrt(429)-rrt(430)+rrt(495)+rrt(496)&
             -rrt(498)-rrt(500)+rrt(505)+rrt(507)+rrt(508)+rrt(509)-rrt(513) 
  ydot(04) = +rrt(005)+rrt(006)+  2.d0 * rrt(007)+rrt(009)+rrt(010)+  2.d0 * rrt(011)+rrt(013)+rrt(014)+rrt(059)-rrt(178)-rrt(179)&
             -rrt(180)-rrt(181)+rrt(182)+rrt(183)+rrt(184)+rrt(185)-rrt(186)-rrt(187)-rrt(188)-rrt(189)-rrt(198)-rrt(199)-rrt(200)&
             -rrt(201)+rrt(202)+rrt(203)+rrt(204)+rrt(205)+rrt(218)+rrt(219)+rrt(220)+rrt(221)-rrt(290)-rrt(291)-rrt(292)-rrt(293)&
             -rrt(294)-rrt(295)-rrt(296)-rrt(297)+rrt(330)+rrt(331)+rrt(332)+rrt(333)+rrt(334)+rrt(335)+rrt(336)+rrt(337)+rrt(354)&
             +rrt(355)+rrt(356)+rrt(357)+rrt(358)+rrt(359)+rrt(360)+rrt(361)+rrt(362)+rrt(363)+rrt(364)-rrt(365)-rrt(366)-rrt(367)&
             -rrt(390)-rrt(391)+rrt(393)+rrt(396)+rrt(436)+rrt(468)+rrt(470)-rrt(501)-rrt(515)-rrt(517)+rrt(522)+rrt(524)+rrt(526)&
             +rrt(527)+rrt(528)+rrt(529)+rrt(530)+rrt(534)+rrt(536)+rrt(549)+rrt(553)+rrt(557)+rrt(559)+rrt(560)-rrt(563)+rrt(574)&
             +rrt(575)+  2.d0 * rrt(576)+  2.d0 * rrt(577)+rrt(578)+rrt(579)+  2.d0 * rrt(580)+rrt(581)+  2.d0 * rrt(582)&
             +  3.d0 * rrt(583)+rrt(584)+rrt(591)+  2.d0 * rrt(593) 
  ydot(05) = +rrt(058)-rrt(202)-rrt(203)-rrt(204)-rrt(205)-rrt(330)-rrt(331)-rrt(332)-rrt(333)-rrt(334)-rrt(335)-rrt(336)-rrt(337)&
             +rrt(365)+rrt(366)+rrt(367)-rrt(388)-rrt(393)-rrt(395)-rrt(468)-rrt(470)-rrt(514)+rrt(520)+rrt(521)+rrt(523)+rrt(525)&
             +rrt(533)-rrt(534)-rrt(536)-rrt(548)-rrt(549)-rrt(553)+rrt(556)-rrt(557)-rrt(558)-rrt(559)-rrt(560)+rrt(584)+rrt(585)&
             +rrt(592) 
  ydot(06) = +rrt(178)+rrt(179)+rrt(180)+rrt(181)+rrt(182)+rrt(183)+rrt(184)+rrt(185)-rrt(198)-rrt(199)-rrt(200)-rrt(201)-rrt(206)&
             -rrt(207)-rrt(208)-rrt(209)+rrt(210)+rrt(211)+rrt(212)+rrt(213)-rrt(222)-rrt(223)-rrt(224)-rrt(225)+rrt(238)+rrt(239)&
             +rrt(240)+rrt(241)+rrt(246)+rrt(247)+rrt(248)+rrt(249)+rrt(258)+rrt(259)+rrt(260)+rrt(261)-rrt(298)-rrt(299)-rrt(300)&
             -rrt(301)-rrt(302)-rrt(303)-rrt(304)-rrt(305)-rrt(314)-rrt(315)-rrt(316)-rrt(317)-rrt(318)-rrt(319)-rrt(320)-rrt(321)&
             +rrt(322)+rrt(323)+rrt(324)+rrt(325)+rrt(326)+rrt(327)+rrt(328)+rrt(329)-rrt(354)-rrt(355)-rrt(356)-rrt(357)-rrt(358)&
             -rrt(359)-rrt(360)-rrt(361)+rrt(368)+rrt(369)+rrt(370)-rrt(371)-rrt(372)-rrt(373)+  2.d0 * rrt(388)+rrt(390)+rrt(394)&
             -rrt(396)-rrt(397)+rrt(402)+rrt(434)-rrt(516)+rrt(591) 
  ydot(07) = -rrt(057)-rrt(058)-rrt(059)-rrt(182)-rrt(183)-rrt(184)-rrt(185)+rrt(198)+rrt(199)+rrt(200)+rrt(201)-rrt(210)-rrt(211)&
             -rrt(212)-rrt(213)-rrt(282)-rrt(283)-rrt(284)-rrt(285)-rrt(286)-rrt(287)-rrt(288)-rrt(289)-rrt(322)-rrt(323)-rrt(324)&
             -rrt(325)-rrt(326)-rrt(327)-rrt(328)-rrt(329)+rrt(371)+rrt(372)+rrt(373)-rrt(394)+rrt(395)+rrt(435)+rrt(563) 
  ydot(08) = +rrt(202)+rrt(203)+rrt(204)+rrt(205)+rrt(206)+rrt(207)+rrt(208)+rrt(209)+rrt(210)+rrt(211)+rrt(212)+rrt(213)&
             +  2.d0 * rrt(214)+  2.d0 * rrt(215)+  2.d0 * rrt(216)+  2.d0 * rrt(217)+rrt(250)+rrt(251)+rrt(252)+rrt(253)+rrt(254)&
             +rrt(255)+rrt(256)+rrt(257)-rrt(338)-rrt(339)-rrt(340)-rrt(341)-rrt(342)-rrt(343)-rrt(344)-rrt(345)-rrt(374)-rrt(375)&
             -rrt(376)+rrt(391)+rrt(393)+rrt(394)+rrt(397)+rrt(403)+rrt(404)+rrt(515)+rrt(562) 
  ydot(09) = -rrt(214)-rrt(215)-rrt(216)-rrt(217)+rrt(374)+rrt(375)+rrt(376)+rrt(514) 
  ydot(10) = +rrt(011)+rrt(013)-rrt(015)-rrt(016)-rrt(017)-rrt(262)-rrt(263)-rrt(264)-rrt(265)+rrt(266)+rrt(267)+rrt(268)+rrt(269)&
             +rrt(270)+rrt(271)+rrt(272)+rrt(273)+rrt(290)+rrt(291)+rrt(292)+rrt(293)+rrt(294)+rrt(295)+rrt(296)+rrt(297)&
             +  2.d0 * rrt(306)+  2.d0 * rrt(307)+  2.d0 * rrt(308)+  2.d0 * rrt(309)+  2.d0 * rrt(310)+  2.d0 * rrt(311)&
             +  2.d0 * rrt(312)+  2.d0 * rrt(313)-rrt(377)+rrt(432)-rrt(440)+rrt(450)+rrt(459)+rrt(471)+rrt(472)+rrt(474)&
             -  2.d0 * rrt(484)-  2.d0 * rrt(485)-  2.d0 * rrt(486)-  2.d0 * rrt(487)-  2.d0 * rrt(488)-  2.d0 * rrt(489)&
             -  2.d0 * rrt(490)-  2.d0 * rrt(491)-  2.d0 * rrt(492)-  2.d0 * rrt(493)+rrt(532)-rrt(538)-rrt(541)-rrt(542)+rrt(546)&
             +rrt(547)+rrt(548)+  2.d0 * rrt(564)+rrt(565)+rrt(574)+rrt(576)+rrt(586)+rrt(587)+rrt(588) 
  ydot(11) = -rrt(018)-rrt(019)-rrt(020)-rrt(021)-rrt(022)-rrt(023)-rrt(024)-rrt(025)-rrt(026)-rrt(027)-rrt(028)-rrt(029)-rrt(030)&
             -rrt(031)-rrt(032)-rrt(033)-rrt(034)-rrt(035)-rrt(036)-rrt(037)-rrt(038)+rrt(060)+rrt(068)+rrt(076)+rrt(084)+rrt(104)&
             +rrt(105)+rrt(106)+rrt(107)+rrt(108)+rrt(109)+rrt(110)-rrt(111)-rrt(118)-rrt(125)-rrt(132)-rrt(139)-rrt(146)-rrt(153)&
             -rrt(230)-rrt(231)-rrt(232)-rrt(233)+rrt(437)+rrt(438)+rrt(439)+rrt(440)+rrt(441)+rrt(442)+rrt(443)+rrt(445)+rrt(446)&
             +rrt(447)+rrt(449)+rrt(450)+rrt(451)+rrt(452)+rrt(454)+rrt(456)+rrt(459)+rrt(462)+rrt(465)+rrt(467)+rrt(476)+rrt(477)&
             +rrt(478)+rrt(479)+rrt(480)+rrt(481)+rrt(482)+rrt(483)-rrt(527)+rrt(535)+rrt(537)+rrt(538)+rrt(539)-rrt(540)+rrt(541)&
             +  2.d0 * rrt(542)+rrt(543)+  2.d0 * rrt(544)-rrt(547)+rrt(561)+  2.d0 * rrt(570)+rrt(581)+rrt(589)+rrt(590) 
  ydot(12) = -rrt(226)-rrt(227)-rrt(228)-rrt(229)+rrt(246)+rrt(247)+rrt(248)+rrt(249)+rrt(262)+rrt(263)+rrt(264)+rrt(265)+rrt(266)&
             +rrt(267)+rrt(268)+rrt(269)+rrt(270)+rrt(271)+rrt(272)+rrt(273)+rrt(282)+rrt(283)+rrt(284)+rrt(285)+rrt(286)+rrt(287)&
             +rrt(288)+rrt(289)+rrt(298)+rrt(299)+rrt(300)+rrt(301)+rrt(302)+rrt(303)+rrt(304)+rrt(305)+rrt(346)+rrt(347)+rrt(348)&
             +rrt(349)+rrt(350)+rrt(351)+rrt(352)+rrt(353)+rrt(377)-rrt(432)+  2.d0 * rrt(433)+rrt(444)+rrt(450)+rrt(451)+rrt(457)&
             -rrt(459)+rrt(463)+rrt(466)-rrt(480)-rrt(481)+rrt(482)+rrt(483) 
  ydot(13) = +rrt(226)+rrt(227)+rrt(228)+rrt(229)+rrt(258)+rrt(259)+rrt(260)+rrt(261)-rrt(451)-rrt(476)-rrt(477)-rrt(478)-rrt(479) 
  ydot(14) = +rrt(230)+rrt(231)+rrt(232)+rrt(233)+rrt(274)+rrt(275)+rrt(276)+rrt(277)+rrt(278)+rrt(279)+rrt(280)+rrt(281)+rrt(354)&
             +rrt(355)+rrt(356)+rrt(357)+rrt(358)+rrt(359)+rrt(360)+rrt(361)-rrt(433)-rrt(437)-rrt(438)+rrt(448)-rrt(450)-rrt(482)&
             -rrt(483) 
  ydot(15) = 0.0d0
  ydot(16) = -rrt(001)-rrt(002)-rrt(003)-rrt(004)-rrt(005)-rrt(006)-rrt(007)+rrt(172)+rrt(175)-rrt(434)-rrt(435)-rrt(436)-rrt(469)&
             -rrt(502)-rrt(504)-rrt(520)-rrt(521)-rrt(522)-rrt(530)-rrt(531)-rrt(532)-rrt(533)-rrt(535)-rrt(545)-rrt(546)-rrt(551)&
             -rrt(552)-rrt(554)-rrt(556)+rrt(558)+rrt(560)-rrt(561)+rrt(579) 
  ydot(17) = +rrt(006)-rrt(008)-rrt(009)-rrt(010)-rrt(011)-rrt(234)-rrt(235)-rrt(236)-rrt(237)-rrt(238)-rrt(239)-rrt(240)-rrt(241)&
             +rrt(282)+rrt(283)+rrt(284)+rrt(285)+rrt(286)+rrt(287)+rrt(288)+rrt(289)+rrt(362)+rrt(363)+rrt(364)+rrt(365)+rrt(366)&
             +rrt(367)+rrt(368)+rrt(369)+rrt(370)+rrt(371)+rrt(372)+rrt(373)+rrt(374)+rrt(375)+rrt(376)-rrt(401)-rrt(402)+rrt(434)&
             +rrt(469)-rrt(523)-rrt(524)-rrt(529)+rrt(551)+rrt(554)+rrt(555)+rrt(556)+rrt(559)+rrt(578)+rrt(580)+rrt(585) 
  ydot(18) = +rrt(007)+rrt(010)-rrt(012)-rrt(013)-rrt(014)-rrt(242)-rrt(243)-rrt(244)-rrt(245)-rrt(246)-rrt(247)-rrt(248)-rrt(249)&
             +rrt(290)+rrt(291)+rrt(292)+rrt(293)+rrt(294)+rrt(295)+rrt(296)+rrt(297)+rrt(298)+rrt(299)+rrt(300)+rrt(301)+rrt(302)&
             +rrt(303)+rrt(304)+rrt(305)+rrt(435)+rrt(468)+rrt(469)+rrt(470)-rrt(525)-rrt(526)-rrt(528)+rrt(531)+rrt(545)+rrt(550)&
             +rrt(552)+rrt(575)+rrt(577)+rrt(586) 
  ydot(19) = 0.0d0
  ydot(20) = +rrt(314)+rrt(315)+rrt(316)+rrt(317)+rrt(318)+rrt(319)+rrt(320)+rrt(321)+rrt(322)+rrt(323)+rrt(324)+rrt(325)+rrt(326)&
             +rrt(327)+rrt(328)+rrt(329)+rrt(330)+rrt(331)+rrt(332)+rrt(333)+rrt(334)+rrt(335)+rrt(336)+rrt(337)+rrt(338)+rrt(339)&
             +rrt(340)+rrt(341)+rrt(342)+rrt(343)+rrt(344)+rrt(345)+rrt(346)+rrt(347)+rrt(348)+rrt(349)+rrt(350)+rrt(351)+rrt(352)&
             +rrt(353) 
  ydot(21) = 0.0d0
  ydot(22) = 0.0d0
  ydot(23) = 0.0d0
  ydot(24) = +rrt(234)+rrt(235)+rrt(236)+rrt(237)-rrt(250)-rrt(251)-rrt(252)-rrt(253)+rrt(401)-rrt(403)+rrt(436) 
  ydot(25) = -rrt(258)-rrt(259)-rrt(260)-rrt(261) 
  ydot(26) = +rrt(238)+rrt(239)+rrt(240)+rrt(241)+rrt(242)+rrt(243)+rrt(244)+rrt(245)+rrt(250)+rrt(251)+rrt(252)+rrt(253)+rrt(254)&
             +rrt(255)+rrt(256)+rrt(257)-rrt(346)-rrt(347)-rrt(348)-rrt(349)-rrt(350)-rrt(351)-rrt(352)-rrt(353)+rrt(402)+rrt(403)&
             +rrt(404) 
  ydot(27) = 0.0d0
  ydot(28) = -rrt(254)-rrt(255)-rrt(256)-rrt(257)-rrt(404) 
  ydot(29) = 0.0d0
  ydot(30) = 0.0d0
  ydot(31) = 0.0d0
  ydot(32) = 0.0d0
  ydot(33) = +rrt(014)+rrt(016)+rrt(440)-rrt(470)-rrt(472)-rrt(473)-rrt(474)-rrt(475)-rrt(476)-rrt(478)-rrt(481)-rrt(483) 
  ydot(34) = +rrt(015)+rrt(444)+rrt(457)+rrt(463)+rrt(466)-rrt(468)-rrt(469)-rrt(471)+rrt(473)-rrt(475)-rrt(477)-rrt(479)-rrt(480)&
             -rrt(482)+rrt(565) 
  ydot(35) = +rrt(045)-rrt(416)-rrt(417)-rrt(418)-rrt(419)-rrt(420)-rrt(421)-rrt(422)-rrt(423)-rrt(424) 
  ydot(36) = +rrt(048)+rrt(056)+rrt(381)+rrt(395)+rrt(405)+rrt(420)+rrt(421)-rrt(425)-rrt(426)-rrt(427)-rrt(428)-rrt(429)-rrt(430)&
             -rrt(431)-rrt(432)-rrt(433)-rrt(434)-rrt(435)-rrt(436)-rrt(437)+rrt(462)+rrt(467)-rrt(507)+rrt(567) 
  ydot(37) = +rrt(049)+rrt(055)+rrt(416)-rrt(438)+rrt(445)+rrt(465)-rrt(508)+rrt(568) 
  ydot(38) = +rrt(018)-rrt(060)+rrt(061)-rrt(068)+rrt(069)-rrt(076)+rrt(077)-rrt(084)+rrt(085)-  2.d0 * rrt(104)-rrt(105)-rrt(106)&
             -rrt(107)-rrt(108)-rrt(109)-rrt(110)+  2.d0 * rrt(111)+rrt(112)+rrt(113)+rrt(114)+rrt(115)+rrt(116)+rrt(117)+rrt(118)&
             -rrt(119)+rrt(125)-rrt(126)+rrt(132)-rrt(133)+rrt(139)-rrt(140)+rrt(146)-rrt(147)+rrt(153)-rrt(154)-rrt(266)-rrt(274)&
             -rrt(282)-rrt(290)-rrt(298)-rrt(306)-rrt(314)-rrt(322)-rrt(330)-rrt(338)-rrt(346)-rrt(354) 
  ydot(39) = +rrt(019)-rrt(061)+rrt(062)-rrt(069)+rrt(070)-rrt(077)+rrt(078)-rrt(085)+rrt(086)+rrt(104)-rrt(105)-rrt(111)&
             -  2.d0 * rrt(112)-rrt(113)-rrt(114)-rrt(115)-rrt(116)-rrt(117)+rrt(118)+  2.d0 * rrt(119)+rrt(120)+rrt(121)+rrt(122)&
             +rrt(123)+rrt(124)+rrt(126)-rrt(127)+rrt(133)-rrt(134)+rrt(140)-rrt(141)+rrt(147)-rrt(148)+rrt(154)-rrt(155)-rrt(267)&
             -rrt(275)-rrt(283)-rrt(291)-rrt(299)-rrt(307)-rrt(315)-rrt(323)-rrt(331)-rrt(339)-rrt(347)-rrt(355) 
  ydot(40) = +rrt(020)-rrt(062)+rrt(063)-rrt(070)+rrt(071)-rrt(078)+rrt(079)-rrt(086)+rrt(087)+rrt(105)-rrt(106)+rrt(112)-rrt(113)&
             -rrt(118)-rrt(119)-  2.d0 * rrt(120)-rrt(121)-rrt(122)-rrt(123)-rrt(124)+rrt(125)+rrt(126)+  2.d0 * rrt(127)+rrt(128)&
             +rrt(129)+rrt(130)+rrt(131)+rrt(134)-rrt(135)+rrt(141)-rrt(142)+rrt(148)-rrt(149)+rrt(155)-rrt(156)-rrt(268)-rrt(276)&
             -rrt(284)-rrt(292)-rrt(300)-rrt(308)-rrt(316)-rrt(324)-rrt(332)-rrt(340)-rrt(348)-rrt(356) 
  ydot(41) = +rrt(021)-rrt(063)+rrt(064)-rrt(071)+rrt(072)-rrt(079)+rrt(080)-rrt(087)+rrt(088)+rrt(106)-rrt(107)+rrt(113)-rrt(114)&
             +rrt(120)-rrt(121)-rrt(125)-rrt(126)-rrt(127)-  2.d0 * rrt(128)-rrt(129)-rrt(130)-rrt(131)+rrt(132)+rrt(133)+rrt(134)&
             +  2.d0 * rrt(135)+rrt(136)+rrt(137)+rrt(138)+rrt(142)-rrt(143)+rrt(149)-rrt(150)+rrt(156)-rrt(157)-rrt(269)-rrt(277)&
             -rrt(285)-rrt(293)-rrt(301)-rrt(309)-rrt(317)-rrt(325)-rrt(333)-rrt(341)-rrt(349)-rrt(357) 
  ydot(42) = +rrt(022)-rrt(064)+rrt(065)-rrt(072)+rrt(073)-rrt(080)+rrt(081)-rrt(088)+rrt(089)+rrt(107)-rrt(108)+rrt(114)-rrt(115)&
             +rrt(121)-rrt(122)+rrt(128)-rrt(129)-rrt(132)-rrt(133)-rrt(134)-rrt(135)-  2.d0 * rrt(136)-rrt(137)-rrt(138)+rrt(139)&
             +rrt(140)+rrt(141)+rrt(142)+  2.d0 * rrt(143)+rrt(144)+rrt(145)+rrt(150)-rrt(151)+rrt(157)-rrt(158)-rrt(270)-rrt(278)&
             -rrt(286)-rrt(294)-rrt(302)-rrt(310)-rrt(318)-rrt(326)-rrt(334)-rrt(342)-rrt(350)-rrt(358) 
  ydot(43) = +rrt(023)-rrt(065)+rrt(066)-rrt(073)+rrt(074)-rrt(081)+rrt(082)-rrt(089)+rrt(090)+rrt(108)-rrt(109)+rrt(115)-rrt(116)&
             +rrt(122)-rrt(123)+rrt(129)-rrt(130)+rrt(136)-rrt(137)-rrt(139)-rrt(140)-rrt(141)-rrt(142)-rrt(143)-  2.d0 * rrt(144)&
             -rrt(145)+rrt(146)+rrt(147)+rrt(148)+rrt(149)+rrt(150)+  2.d0 * rrt(151)+rrt(152)+rrt(158)-rrt(159)-rrt(271)-rrt(279)&
             -rrt(287)-rrt(295)-rrt(303)-rrt(311)-rrt(319)-rrt(327)-rrt(335)-rrt(343)-rrt(351)-rrt(359) 
  ydot(44) = +rrt(024)-rrt(066)+rrt(067)-rrt(074)+rrt(075)-rrt(082)+rrt(083)-rrt(090)+rrt(091)+rrt(109)-rrt(110)+rrt(116)-rrt(117)&
             +rrt(123)-rrt(124)+rrt(130)-rrt(131)+rrt(137)-rrt(138)+rrt(144)-rrt(145)-rrt(146)-rrt(147)-rrt(148)-rrt(149)-rrt(150)&
             -rrt(151)-  2.d0 * rrt(152)+rrt(153)+rrt(154)+rrt(155)+rrt(156)+rrt(157)+rrt(158)+  2.d0 * rrt(159)-rrt(272)-rrt(280)&
             -rrt(288)-rrt(296)-rrt(304)-rrt(312)-rrt(320)-rrt(328)-rrt(336)-rrt(344)-rrt(352)-rrt(360) 
  ydot(45) = +rrt(025)-rrt(067)-rrt(075)-rrt(083)-rrt(091)+rrt(110)+rrt(117)+rrt(124)+rrt(131)+rrt(138)+rrt(145)+rrt(152)-rrt(153)&
             -rrt(154)-rrt(155)-rrt(156)-rrt(157)-rrt(158)-rrt(159)-rrt(273)-rrt(281)-rrt(289)-rrt(297)-rrt(305)-rrt(313)-rrt(321)&
             -rrt(329)-rrt(337)-rrt(345)-rrt(353)-rrt(361) 
  ydot(46) = +rrt(026)+rrt(027)+rrt(028)-rrt(439)-rrt(440)-rrt(441)-  2.d0 * rrt(442)-  2.d0 * rrt(443)-rrt(444)-rrt(445)-rrt(446)&
             -rrt(447)-rrt(448)-rrt(449)-rrt(450)-rrt(451)-rrt(452)+rrt(453)+rrt(455)-rrt(460)+rrt(484)+rrt(485)+rrt(486)+rrt(487)&
             +rrt(488) 
  ydot(47) = +rrt(029)+rrt(030)+rrt(031)+rrt(442)-rrt(453)-rrt(454)-rrt(455)-rrt(456)-rrt(457)+rrt(458)+rrt(489)+rrt(490)+rrt(491)&
             +rrt(492)+rrt(493) 
  ydot(48) = +rrt(032)+rrt(033)+rrt(034)-rrt(458)-rrt(459)-rrt(460)-  2.d0 * rrt(461)-rrt(462)-rrt(463)+rrt(464) 
  ydot(49) = +rrt(035)+rrt(036)+rrt(037)+rrt(443)-rrt(464)-rrt(465)-rrt(466)-rrt(467) 
  ydot(50) = +rrt(039)-rrt(092)+rrt(093)-rrt(096)+rrt(097)-rrt(100)+rrt(101)-  2.d0 * rrt(160)-rrt(161)-rrt(162)+  2.d0 * rrt(163)&
             +rrt(164)+rrt(165)+rrt(166)-rrt(167)+rrt(169)-rrt(170)-rrt(178)-rrt(182)-rrt(186)-rrt(190)-rrt(191)-rrt(198)-rrt(202)&
             -rrt(206)-rrt(210)-rrt(214)-rrt(218)-rrt(222)-rrt(226)-rrt(230)-rrt(234)-rrt(238)-rrt(242)-rrt(246)-rrt(250)-rrt(254)&
             -rrt(258)-rrt(262) 
  ydot(51) = +rrt(040)-rrt(093)+rrt(094)-rrt(097)+rrt(098)-rrt(101)+rrt(102)+rrt(160)-rrt(161)-rrt(163)-  2.d0 * rrt(164)-rrt(165)&
             +rrt(166)+  2.d0 * rrt(167)+rrt(168)+rrt(170)-rrt(171)-rrt(179)-rrt(183)-rrt(187)-rrt(192)-rrt(193)-rrt(199)-rrt(203)&
             -rrt(207)-rrt(211)-rrt(215)-rrt(219)-rrt(223)-rrt(227)-rrt(231)-rrt(235)-rrt(239)-rrt(243)-rrt(247)-rrt(251)-rrt(255)&
             -rrt(259)-rrt(263) 
  ydot(52) = +rrt(041)-rrt(094)+rrt(095)-rrt(098)+rrt(099)-rrt(102)+rrt(103)+rrt(161)-rrt(162)+rrt(164)-rrt(165)-rrt(166)-rrt(167)&
             -  2.d0 * rrt(168)+rrt(169)+rrt(170)+  2.d0 * rrt(171)-rrt(180)-rrt(184)-rrt(188)-rrt(194)-rrt(195)-rrt(200)-rrt(204)&
             -rrt(208)-rrt(212)-rrt(216)-rrt(220)-rrt(224)-rrt(228)-rrt(232)-rrt(236)-rrt(240)-rrt(244)-rrt(248)-rrt(252)-rrt(256)&
             -rrt(260)-rrt(264) 
  ydot(53) = +rrt(042)-rrt(095)-rrt(099)-rrt(103)+rrt(162)+rrt(165)+rrt(168)-rrt(169)-rrt(170)-rrt(171)-rrt(181)-rrt(185)-rrt(189)&
             -rrt(196)-rrt(197)-rrt(201)-rrt(205)-rrt(209)-rrt(213)-rrt(217)-rrt(221)-rrt(225)-rrt(229)-rrt(233)-rrt(237)-rrt(241)&
             -rrt(245)-rrt(249)-rrt(253)-rrt(257)-rrt(261)-rrt(265) 
  ydot(54) = +rrt(043)-rrt(377)-rrt(378)-rrt(379)-rrt(380)-rrt(381)-  2.d0 * rrt(382)-rrt(383)-  2.d0 * rrt(384)-rrt(385)-rrt(386)&
             +rrt(387)-rrt(388)-rrt(389)-rrt(390)-rrt(391)-rrt(392)-rrt(393)-rrt(394)-rrt(395)-rrt(396)-rrt(397)-rrt(398)-rrt(399)&
             -rrt(400)-rrt(401)-rrt(402)-rrt(403)-rrt(404)+rrt(406)+rrt(408)+rrt(409)+rrt(411)+rrt(412)+rrt(414)+rrt(420)+rrt(422)&
             +rrt(427)+rrt(446)-rrt(496)-rrt(499)-rrt(510) 
  ydot(55) = +rrt(044)+rrt(382)-rrt(387)-rrt(405)-rrt(406)-rrt(407)-rrt(408)-rrt(409)-rrt(410)-  2.d0 * rrt(411)-rrt(412)-rrt(413)&
             -rrt(414)-rrt(415)+  2.d0 * rrt(417)+rrt(418)+rrt(421)+rrt(423)+rrt(428)+rrt(447)-rrt(497)-rrt(511) 
  ydot(56) = +rrt(186)+rrt(187)+rrt(188)+rrt(189)-rrt(218)-rrt(219)-rrt(220)-rrt(221)+rrt(222)+rrt(223)+rrt(224)+rrt(225) 
  ydot(57) = +rrt(001)-rrt(172)+rrt(173)-rrt(175)+rrt(176)-rrt(362)-rrt(365)-rrt(368)-rrt(371)-rrt(374) 
  ydot(58) = +rrt(002)-rrt(173)+rrt(174)-rrt(176)+rrt(177)-rrt(363)-rrt(366)-rrt(369)-rrt(372)-rrt(375) 
  ydot(59) = +rrt(003)-rrt(174)-rrt(177)-rrt(364)-rrt(367)-rrt(370)-rrt(373)-rrt(376) 
  ydot(60) = +rrt(017)-rrt(531)-rrt(532)-rrt(533)-rrt(534)+rrt(538)+rrt(542)-rrt(587)-rrt(588) 
  ydot(61) = +rrt(038)+rrt(475)-rrt(535)-rrt(536)-rrt(537)-rrt(538)-rrt(539)-rrt(540)+rrt(541)+rrt(543)-rrt(564)-rrt(565)-rrt(589)&
             -rrt(590) 
  ydot(62) = -rrt(541) 
  ydot(63) = +rrt(460)+rrt(461)+rrt(540)-rrt(542)-rrt(543)-rrt(544)-rrt(570) 
  ydot(64) = +rrt(050)+rrt(054)+rrt(058)-rrt(494)-rrt(495)-rrt(496)-rrt(497)-rrt(498)-rrt(499)-rrt(500)+rrt(512)+rrt(595) 
  ydot(65) = -rrt(501)-rrt(502)+rrt(537) 
  ydot(66) = +rrt(059)+rrt(516)+rrt(517)-rrt(562)-rrt(563) 
  ydot(67) = +rrt(046)+rrt(051)-rrt(503)-rrt(504)+rrt(505)+rrt(506)+rrt(507)+rrt(508)+rrt(539)+rrt(544)+rrt(550)-rrt(566)-rrt(567)&
             -rrt(568)-rrt(571)-rrt(572) 
  ydot(68) = +rrt(053)+rrt(499)-rrt(509)-rrt(510)-rrt(511)-rrt(512)-rrt(513)-rrt(514)-rrt(515)-rrt(516)-rrt(517)+rrt(519)+rrt(594) 
  ydot(69) = +rrt(503)-rrt(505)-rrt(506)-rrt(507)-rrt(508)-rrt(569)-rrt(573) 
  ydot(70) = +rrt(500)+rrt(513)-rrt(518)-rrt(519) 
  ydot(71) = +rrt(520)+rrt(522)+rrt(546)+rrt(552)+rrt(554)+rrt(557)+rrt(561)-rrt(579)-rrt(580)-rrt(585) 
  ydot(72) = +rrt(004)+rrt(502)+rrt(504)+rrt(521)+rrt(524)+rrt(530)+rrt(532)+rrt(535)+rrt(545)+rrt(551)+rrt(553)-rrt(554)-rrt(555)&
             -rrt(556)-rrt(557)-rrt(558)-rrt(559)-rrt(560)-rrt(577)-rrt(578) 
  ydot(73) = +rrt(005)+rrt(008)+rrt(523)+rrt(526)+rrt(529)+rrt(531)+rrt(549)-rrt(551)-rrt(552)-rrt(553)+rrt(556)-rrt(575)-rrt(576) 
  ydot(74) = +rrt(009)+rrt(012)+rrt(525)+rrt(528)+rrt(534)-rrt(545)-rrt(546)-rrt(547)-rrt(548)-rrt(549)-rrt(550)-rrt(574) 
  ydot(75) = +rrt(527)+rrt(533)+rrt(536)+rrt(547)-rrt(561)-rrt(581)-rrt(586) 
  ydot(76) = +rrt(501)-rrt(528)-rrt(529)-rrt(530)+rrt(555)+rrt(560) 
  ydot(77) = -rrt(521)-rrt(522)-rrt(523)-rrt(524)-rrt(525)-rrt(526)-rrt(527)+rrt(558)+rrt(559)-rrt(582) 
  ydot(78) = -rrt(520)+rrt(548)-rrt(583)-rrt(584) 
  ydot(79) = +rrt(057)-rrt(591)-rrt(592)-rrt(593) 
  ydot(80) = +rrt(004)+rrt(005)+rrt(008)+rrt(009)+rrt(012)+rrt(017)+rrt(038)+rrt(046)-rrt(050)+rrt(051)-rrt(053)-rrt(054)+rrt(057)&
             -rrt(058)-rrt(059)+rrt(460)+rrt(461)+rrt(475)+rrt(494)+rrt(495)+rrt(496)+rrt(497)+rrt(498)+rrt(509)+rrt(510)+rrt(511)&
             +rrt(514)+rrt(515)+rrt(518)+rrt(562)+rrt(563)-rrt(564)-rrt(565)-rrt(566)-rrt(567)-rrt(568)-rrt(569)-rrt(570)-rrt(571)&
             -rrt(572)-rrt(573)-rrt(574)-rrt(575)-rrt(576)-rrt(577)-rrt(578)-rrt(579)-rrt(580)-rrt(581)-rrt(582)-rrt(583)-rrt(584)&
             -rrt(585)-rrt(586)-rrt(587)-rrt(588)-rrt(589)-rrt(590)-rrt(591)-rrt(592)-rrt(593)-rrt(594)-rrt(595) 
  if( ldensity_constant ) where( density_constant(:) ) ydot(1:species_max) = 0.0d0
  ydot(81) = 0.0d0
  if( lgas_heating ) then
    ydot(81) = ( ZDPlasKin_cfg(14)/k_B + ydot(81) ) / ( sum(density(1:species_max)) - density(species_electrons) ) &
            + eV_to_K * ZDPlasKin_cfg(11) * density(species_electrons)
    ydot(81) = ydot(81) * ZDPlasKin_cfg(13)
  endif
  return
end subroutine ZDPlasKin_fex
!-----------------------------------------------------------------------------------------------------------------------------------
!
! reaction jacobian
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_jex(neq,t,y,ml,mu,pd,nrpd)
  implicit none
  integer,          intent(in)  :: neq, ml, mu, nrpd
  double precision, intent(in)  :: t, y(neq)
  double precision, intent(out) :: pd(nrpd,neq)
  integer                       :: i
  if( lgas_heating ) ZDPlasKin_cfg(1) = y(81)
  density(:) = y(1:species_max)
  call ZDPlasKin_reac_rates(t)
  pd(16,16) = pd(16,16) - rrt(001) * density(80) 
  pd(16,80) = pd(16,80) - rrt(001) * density(16) 
  pd(57,16) = pd(57,16) + rrt(001) * density(80) 
  pd(57,80) = pd(57,80) + rrt(001) * density(16) 
  pd(16,16) = pd(16,16) - rrt(002) * density(80) 
  pd(16,80) = pd(16,80) - rrt(002) * density(16) 
  pd(58,16) = pd(58,16) + rrt(002) * density(80) 
  pd(58,80) = pd(58,80) + rrt(002) * density(16) 
  pd(16,16) = pd(16,16) - rrt(003) * density(80) 
  pd(16,80) = pd(16,80) - rrt(003) * density(16) 
  pd(59,16) = pd(59,16) + rrt(003) * density(80) 
  pd(59,80) = pd(59,80) + rrt(003) * density(16) 
  pd(16,16) = pd(16,16) - rrt(004) * density(80) 
  pd(16,80) = pd(16,80) - rrt(004) * density(16) 
  pd(72,16) = pd(72,16) + rrt(004) * density(80) 
  pd(72,80) = pd(72,80) + rrt(004) * density(16) 
  pd(80,16) = pd(80,16) + rrt(004) * density(80) 
  pd(80,80) = pd(80,80) + rrt(004) * density(16) 
  pd(04,16) = pd(04,16) + rrt(005) * density(80) 
  pd(04,80) = pd(04,80) + rrt(005) * density(16) 
  pd(16,16) = pd(16,16) - rrt(005) * density(80) 
  pd(16,80) = pd(16,80) - rrt(005) * density(16) 
  pd(73,16) = pd(73,16) + rrt(005) * density(80) 
  pd(73,80) = pd(73,80) + rrt(005) * density(16) 
  pd(80,16) = pd(80,16) + rrt(005) * density(80) 
  pd(80,80) = pd(80,80) + rrt(005) * density(16) 
  pd(04,16) = pd(04,16) + rrt(006) * density(80) 
  pd(04,80) = pd(04,80) + rrt(006) * density(16) 
  pd(16,16) = pd(16,16) - rrt(006) * density(80) 
  pd(16,80) = pd(16,80) - rrt(006) * density(16) 
  pd(17,16) = pd(17,16) + rrt(006) * density(80) 
  pd(17,80) = pd(17,80) + rrt(006) * density(16) 
  pd(04,16) = pd(04,16) + rrt(007) * density(80) * 2.0d0
  pd(04,80) = pd(04,80) + rrt(007) * density(16) * 2.0d0
  pd(16,16) = pd(16,16) - rrt(007) * density(80) 
  pd(16,80) = pd(16,80) - rrt(007) * density(16) 
  pd(18,16) = pd(18,16) + rrt(007) * density(80) 
  pd(18,80) = pd(18,80) + rrt(007) * density(16) 
  pd(17,17) = pd(17,17) - rrt(008) * density(80) 
  pd(17,80) = pd(17,80) - rrt(008) * density(17) 
  pd(73,17) = pd(73,17) + rrt(008) * density(80) 
  pd(73,80) = pd(73,80) + rrt(008) * density(17) 
  pd(80,17) = pd(80,17) + rrt(008) * density(80) 
  pd(80,80) = pd(80,80) + rrt(008) * density(17) 
  pd(04,17) = pd(04,17) + rrt(009) * density(80) 
  pd(04,80) = pd(04,80) + rrt(009) * density(17) 
  pd(17,17) = pd(17,17) - rrt(009) * density(80) 
  pd(17,80) = pd(17,80) - rrt(009) * density(17) 
  pd(74,17) = pd(74,17) + rrt(009) * density(80) 
  pd(74,80) = pd(74,80) + rrt(009) * density(17) 
  pd(80,17) = pd(80,17) + rrt(009) * density(80) 
  pd(80,80) = pd(80,80) + rrt(009) * density(17) 
  pd(04,17) = pd(04,17) + rrt(010) * density(80) 
  pd(04,80) = pd(04,80) + rrt(010) * density(17) 
  pd(17,17) = pd(17,17) - rrt(010) * density(80) 
  pd(17,80) = pd(17,80) - rrt(010) * density(17) 
  pd(18,17) = pd(18,17) + rrt(010) * density(80) 
  pd(18,80) = pd(18,80) + rrt(010) * density(17) 
  pd(04,17) = pd(04,17) + rrt(011) * density(80) * 2.0d0
  pd(04,80) = pd(04,80) + rrt(011) * density(17) * 2.0d0
  pd(10,17) = pd(10,17) + rrt(011) * density(80) 
  pd(10,80) = pd(10,80) + rrt(011) * density(17) 
  pd(17,17) = pd(17,17) - rrt(011) * density(80) 
  pd(17,80) = pd(17,80) - rrt(011) * density(17) 
  pd(18,18) = pd(18,18) - rrt(012) * density(80) 
  pd(18,80) = pd(18,80) - rrt(012) * density(18) 
  pd(74,18) = pd(74,18) + rrt(012) * density(80) 
  pd(74,80) = pd(74,80) + rrt(012) * density(18) 
  pd(80,18) = pd(80,18) + rrt(012) * density(80) 
  pd(80,80) = pd(80,80) + rrt(012) * density(18) 
  pd(04,18) = pd(04,18) + rrt(013) * density(80) 
  pd(04,80) = pd(04,80) + rrt(013) * density(18) 
  pd(10,18) = pd(10,18) + rrt(013) * density(80) 
  pd(10,80) = pd(10,80) + rrt(013) * density(18) 
  pd(18,18) = pd(18,18) - rrt(013) * density(80) 
  pd(18,80) = pd(18,80) - rrt(013) * density(18) 
  pd(04,18) = pd(04,18) + rrt(014) * density(80) 
  pd(04,80) = pd(04,80) + rrt(014) * density(18) 
  pd(18,18) = pd(18,18) - rrt(014) * density(80) 
  pd(18,80) = pd(18,80) - rrt(014) * density(18) 
  pd(33,18) = pd(33,18) + rrt(014) * density(80) 
  pd(33,80) = pd(33,80) + rrt(014) * density(18) 
  pd(10,10) = pd(10,10) - rrt(015) * density(80) 
  pd(10,80) = pd(10,80) - rrt(015) * density(10) 
  pd(34,10) = pd(34,10) + rrt(015) * density(80) 
  pd(34,80) = pd(34,80) + rrt(015) * density(10) 
  pd(10,10) = pd(10,10) - rrt(016) * density(80) 
  pd(10,80) = pd(10,80) - rrt(016) * density(10) 
  pd(33,10) = pd(33,10) + rrt(016) * density(80) 
  pd(33,80) = pd(33,80) + rrt(016) * density(10) 
  pd(10,10) = pd(10,10) - rrt(017) * density(80) 
  pd(10,80) = pd(10,80) - rrt(017) * density(10) 
  pd(60,10) = pd(60,10) + rrt(017) * density(80) 
  pd(60,80) = pd(60,80) + rrt(017) * density(10) 
  pd(80,10) = pd(80,10) + rrt(017) * density(80) 
  pd(80,80) = pd(80,80) + rrt(017) * density(10) 
  pd(11,11) = pd(11,11) - rrt(018) * density(80) 
  pd(11,80) = pd(11,80) - rrt(018) * density(11) 
  pd(38,11) = pd(38,11) + rrt(018) * density(80) 
  pd(38,80) = pd(38,80) + rrt(018) * density(11) 
  pd(11,11) = pd(11,11) - rrt(019) * density(80) 
  pd(11,80) = pd(11,80) - rrt(019) * density(11) 
  pd(39,11) = pd(39,11) + rrt(019) * density(80) 
  pd(39,80) = pd(39,80) + rrt(019) * density(11) 
  pd(11,11) = pd(11,11) - rrt(020) * density(80) 
  pd(11,80) = pd(11,80) - rrt(020) * density(11) 
  pd(40,11) = pd(40,11) + rrt(020) * density(80) 
  pd(40,80) = pd(40,80) + rrt(020) * density(11) 
  pd(11,11) = pd(11,11) - rrt(021) * density(80) 
  pd(11,80) = pd(11,80) - rrt(021) * density(11) 
  pd(41,11) = pd(41,11) + rrt(021) * density(80) 
  pd(41,80) = pd(41,80) + rrt(021) * density(11) 
  pd(11,11) = pd(11,11) - rrt(022) * density(80) 
  pd(11,80) = pd(11,80) - rrt(022) * density(11) 
  pd(42,11) = pd(42,11) + rrt(022) * density(80) 
  pd(42,80) = pd(42,80) + rrt(022) * density(11) 
  pd(11,11) = pd(11,11) - rrt(023) * density(80) 
  pd(11,80) = pd(11,80) - rrt(023) * density(11) 
  pd(43,11) = pd(43,11) + rrt(023) * density(80) 
  pd(43,80) = pd(43,80) + rrt(023) * density(11) 
  pd(11,11) = pd(11,11) - rrt(024) * density(80) 
  pd(11,80) = pd(11,80) - rrt(024) * density(11) 
  pd(44,11) = pd(44,11) + rrt(024) * density(80) 
  pd(44,80) = pd(44,80) + rrt(024) * density(11) 
  pd(11,11) = pd(11,11) - rrt(025) * density(80) 
  pd(11,80) = pd(11,80) - rrt(025) * density(11) 
  pd(45,11) = pd(45,11) + rrt(025) * density(80) 
  pd(45,80) = pd(45,80) + rrt(025) * density(11) 
  pd(11,11) = pd(11,11) - rrt(026) * density(80) 
  pd(11,80) = pd(11,80) - rrt(026) * density(11) 
  pd(46,11) = pd(46,11) + rrt(026) * density(80) 
  pd(46,80) = pd(46,80) + rrt(026) * density(11) 
  pd(11,11) = pd(11,11) - rrt(027) * density(80) 
  pd(11,80) = pd(11,80) - rrt(027) * density(11) 
  pd(46,11) = pd(46,11) + rrt(027) * density(80) 
  pd(46,80) = pd(46,80) + rrt(027) * density(11) 
  pd(11,11) = pd(11,11) - rrt(028) * density(80) 
  pd(11,80) = pd(11,80) - rrt(028) * density(11) 
  pd(46,11) = pd(46,11) + rrt(028) * density(80) 
  pd(46,80) = pd(46,80) + rrt(028) * density(11) 
  pd(11,11) = pd(11,11) - rrt(029) * density(80) 
  pd(11,80) = pd(11,80) - rrt(029) * density(11) 
  pd(47,11) = pd(47,11) + rrt(029) * density(80) 
  pd(47,80) = pd(47,80) + rrt(029) * density(11) 
  pd(11,11) = pd(11,11) - rrt(030) * density(80) 
  pd(11,80) = pd(11,80) - rrt(030) * density(11) 
  pd(47,11) = pd(47,11) + rrt(030) * density(80) 
  pd(47,80) = pd(47,80) + rrt(030) * density(11) 
  pd(11,11) = pd(11,11) - rrt(031) * density(80) 
  pd(11,80) = pd(11,80) - rrt(031) * density(11) 
  pd(47,11) = pd(47,11) + rrt(031) * density(80) 
  pd(47,80) = pd(47,80) + rrt(031) * density(11) 
  pd(11,11) = pd(11,11) - rrt(032) * density(80) 
  pd(11,80) = pd(11,80) - rrt(032) * density(11) 
  pd(48,11) = pd(48,11) + rrt(032) * density(80) 
  pd(48,80) = pd(48,80) + rrt(032) * density(11) 
  pd(11,11) = pd(11,11) - rrt(033) * density(80) 
  pd(11,80) = pd(11,80) - rrt(033) * density(11) 
  pd(48,11) = pd(48,11) + rrt(033) * density(80) 
  pd(48,80) = pd(48,80) + rrt(033) * density(11) 
  pd(11,11) = pd(11,11) - rrt(034) * density(80) 
  pd(11,80) = pd(11,80) - rrt(034) * density(11) 
  pd(48,11) = pd(48,11) + rrt(034) * density(80) 
  pd(48,80) = pd(48,80) + rrt(034) * density(11) 
  pd(11,11) = pd(11,11) - rrt(035) * density(80) 
  pd(11,80) = pd(11,80) - rrt(035) * density(11) 
  pd(49,11) = pd(49,11) + rrt(035) * density(80) 
  pd(49,80) = pd(49,80) + rrt(035) * density(11) 
  pd(11,11) = pd(11,11) - rrt(036) * density(80) 
  pd(11,80) = pd(11,80) - rrt(036) * density(11) 
  pd(49,11) = pd(49,11) + rrt(036) * density(80) 
  pd(49,80) = pd(49,80) + rrt(036) * density(11) 
  pd(11,11) = pd(11,11) - rrt(037) * density(80) 
  pd(11,80) = pd(11,80) - rrt(037) * density(11) 
  pd(49,11) = pd(49,11) + rrt(037) * density(80) 
  pd(49,80) = pd(49,80) + rrt(037) * density(11) 
  pd(11,11) = pd(11,11) - rrt(038) * density(80) 
  pd(11,80) = pd(11,80) - rrt(038) * density(11) 
  pd(61,11) = pd(61,11) + rrt(038) * density(80) 
  pd(61,80) = pd(61,80) + rrt(038) * density(11) 
  pd(80,11) = pd(80,11) + rrt(038) * density(80) 
  pd(80,80) = pd(80,80) + rrt(038) * density(11) 
  pd(02,02) = pd(02,02) - rrt(039) * density(80) 
  pd(02,80) = pd(02,80) - rrt(039) * density(02) 
  pd(50,02) = pd(50,02) + rrt(039) * density(80) 
  pd(50,80) = pd(50,80) + rrt(039) * density(02) 
  pd(02,02) = pd(02,02) - rrt(040) * density(80) 
  pd(02,80) = pd(02,80) - rrt(040) * density(02) 
  pd(51,02) = pd(51,02) + rrt(040) * density(80) 
  pd(51,80) = pd(51,80) + rrt(040) * density(02) 
  pd(02,02) = pd(02,02) - rrt(041) * density(80) 
  pd(02,80) = pd(02,80) - rrt(041) * density(02) 
  pd(52,02) = pd(52,02) + rrt(041) * density(80) 
  pd(52,80) = pd(52,80) + rrt(041) * density(02) 
  pd(02,02) = pd(02,02) - rrt(042) * density(80) 
  pd(02,80) = pd(02,80) - rrt(042) * density(02) 
  pd(53,02) = pd(53,02) + rrt(042) * density(80) 
  pd(53,80) = pd(53,80) + rrt(042) * density(02) 
  pd(02,02) = pd(02,02) - rrt(043) * density(80) 
  pd(02,80) = pd(02,80) - rrt(043) * density(02) 
  pd(54,02) = pd(54,02) + rrt(043) * density(80) 
  pd(54,80) = pd(54,80) + rrt(043) * density(02) 
  pd(02,02) = pd(02,02) - rrt(044) * density(80) 
  pd(02,80) = pd(02,80) - rrt(044) * density(02) 
  pd(55,02) = pd(55,02) + rrt(044) * density(80) 
  pd(55,80) = pd(55,80) + rrt(044) * density(02) 
  pd(02,02) = pd(02,02) - rrt(045) * density(80) 
  pd(02,80) = pd(02,80) - rrt(045) * density(02) 
  pd(35,02) = pd(35,02) + rrt(045) * density(80) 
  pd(35,80) = pd(35,80) + rrt(045) * density(02) 
  pd(02,02) = pd(02,02) - rrt(046) * density(80) 
  pd(02,80) = pd(02,80) - rrt(046) * density(02) 
  pd(67,02) = pd(67,02) + rrt(046) * density(80) 
  pd(67,80) = pd(67,80) + rrt(046) * density(02) 
  pd(80,02) = pd(80,02) + rrt(046) * density(80) 
  pd(80,80) = pd(80,80) + rrt(046) * density(02) 
  pd(01,02) = pd(01,02) + rrt(047) * density(80) * 2.0d0
  pd(01,80) = pd(01,80) + rrt(047) * density(02) * 2.0d0
  pd(02,02) = pd(02,02) - rrt(047) * density(80) 
  pd(02,80) = pd(02,80) - rrt(047) * density(02) 
  pd(01,02) = pd(01,02) + rrt(048) * density(80) 
  pd(01,80) = pd(01,80) + rrt(048) * density(02) 
  pd(02,02) = pd(02,02) - rrt(048) * density(80) 
  pd(02,80) = pd(02,80) - rrt(048) * density(02) 
  pd(36,02) = pd(36,02) + rrt(048) * density(80) 
  pd(36,80) = pd(36,80) + rrt(048) * density(02) 
  pd(01,02) = pd(01,02) + rrt(049) * density(80) 
  pd(01,80) = pd(01,80) + rrt(049) * density(02) 
  pd(02,02) = pd(02,02) - rrt(049) * density(80) 
  pd(02,80) = pd(02,80) - rrt(049) * density(02) 
  pd(37,02) = pd(37,02) + rrt(049) * density(80) 
  pd(37,80) = pd(37,80) + rrt(049) * density(02) 
  pd(01,02) = pd(01,02) + rrt(050) * density(80) 
  pd(01,80) = pd(01,80) + rrt(050) * density(02) 
  pd(02,02) = pd(02,02) - rrt(050) * density(80) 
  pd(02,80) = pd(02,80) - rrt(050) * density(02) 
  pd(64,02) = pd(64,02) + rrt(050) * density(80) 
  pd(64,80) = pd(64,80) + rrt(050) * density(02) 
  pd(80,02) = pd(80,02) - rrt(050) * density(80) 
  pd(80,80) = pd(80,80) - rrt(050) * density(02) 
  pd(01,03) = pd(01,03) + rrt(051) * density(80) 
  pd(01,80) = pd(01,80) + rrt(051) * density(03) 
  pd(03,03) = pd(03,03) - rrt(051) * density(80) 
  pd(03,80) = pd(03,80) - rrt(051) * density(03) 
  pd(67,03) = pd(67,03) + rrt(051) * density(80) 
  pd(67,80) = pd(67,80) + rrt(051) * density(03) 
  pd(80,03) = pd(80,03) + rrt(051) * density(80) 
  pd(80,80) = pd(80,80) + rrt(051) * density(03) 
  pd(01,03) = pd(01,03) + rrt(052) * density(80) 
  pd(01,80) = pd(01,80) + rrt(052) * density(03) 
  pd(02,03) = pd(02,03) + rrt(052) * density(80) 
  pd(02,80) = pd(02,80) + rrt(052) * density(03) 
  pd(03,03) = pd(03,03) - rrt(052) * density(80) 
  pd(03,80) = pd(03,80) - rrt(052) * density(03) 
  pd(01,03) = pd(01,03) + rrt(053) * density(80) 
  pd(01,80) = pd(01,80) + rrt(053) * density(03) 
  pd(03,03) = pd(03,03) - rrt(053) * density(80) 
  pd(03,80) = pd(03,80) - rrt(053) * density(03) 
  pd(68,03) = pd(68,03) + rrt(053) * density(80) 
  pd(68,80) = pd(68,80) + rrt(053) * density(03) 
  pd(80,03) = pd(80,03) - rrt(053) * density(80) 
  pd(80,80) = pd(80,80) - rrt(053) * density(03) 
  pd(02,03) = pd(02,03) + rrt(054) * density(80) 
  pd(02,80) = pd(02,80) + rrt(054) * density(03) 
  pd(03,03) = pd(03,03) - rrt(054) * density(80) 
  pd(03,80) = pd(03,80) - rrt(054) * density(03) 
  pd(64,03) = pd(64,03) + rrt(054) * density(80) 
  pd(64,80) = pd(64,80) + rrt(054) * density(03) 
  pd(80,03) = pd(80,03) - rrt(054) * density(80) 
  pd(80,80) = pd(80,80) - rrt(054) * density(03) 
  pd(01,01) = pd(01,01) - rrt(055) * density(80) 
  pd(01,80) = pd(01,80) - rrt(055) * density(01) 
  pd(37,01) = pd(37,01) + rrt(055) * density(80) 
  pd(37,80) = pd(37,80) + rrt(055) * density(01) 
  pd(01,01) = pd(01,01) - rrt(056) * density(80) 
  pd(01,80) = pd(01,80) - rrt(056) * density(01) 
  pd(36,01) = pd(36,01) + rrt(056) * density(80) 
  pd(36,80) = pd(36,80) + rrt(056) * density(01) 
  pd(07,07) = pd(07,07) - rrt(057) * density(80) 
  pd(07,80) = pd(07,80) - rrt(057) * density(07) 
  pd(79,07) = pd(79,07) + rrt(057) * density(80) 
  pd(79,80) = pd(79,80) + rrt(057) * density(07) 
  pd(80,07) = pd(80,07) + rrt(057) * density(80) 
  pd(80,80) = pd(80,80) + rrt(057) * density(07) 
  pd(05,07) = pd(05,07) + rrt(058) * density(80) 
  pd(05,80) = pd(05,80) + rrt(058) * density(07) 
  pd(07,07) = pd(07,07) - rrt(058) * density(80) 
  pd(07,80) = pd(07,80) - rrt(058) * density(07) 
  pd(64,07) = pd(64,07) + rrt(058) * density(80) 
  pd(64,80) = pd(64,80) + rrt(058) * density(07) 
  pd(80,07) = pd(80,07) - rrt(058) * density(80) 
  pd(80,80) = pd(80,80) - rrt(058) * density(07) 
  pd(04,07) = pd(04,07) + rrt(059) * density(80) 
  pd(04,80) = pd(04,80) + rrt(059) * density(07) 
  pd(07,07) = pd(07,07) - rrt(059) * density(80) 
  pd(07,80) = pd(07,80) - rrt(059) * density(07) 
  pd(66,07) = pd(66,07) + rrt(059) * density(80) 
  pd(66,80) = pd(66,80) + rrt(059) * density(07) 
  pd(80,07) = pd(80,07) - rrt(059) * density(80) 
  pd(80,80) = pd(80,80) - rrt(059) * density(07) 
  pd(11,11) = pd(11,11) + rrt(060) * density(38) 
  pd(11,38) = pd(11,38) + rrt(060) * density(11) 
  pd(38,11) = pd(38,11) - rrt(060) * density(38) 
  pd(38,38) = pd(38,38) - rrt(060) * density(11) 
  pd(38,11) = pd(38,11) + rrt(061) * density(39) 
  pd(38,39) = pd(38,39) + rrt(061) * density(11) 
  pd(39,11) = pd(39,11) - rrt(061) * density(39) 
  pd(39,39) = pd(39,39) - rrt(061) * density(11) 
  pd(39,11) = pd(39,11) + rrt(062) * density(40) 
  pd(39,40) = pd(39,40) + rrt(062) * density(11) 
  pd(40,11) = pd(40,11) - rrt(062) * density(40) 
  pd(40,40) = pd(40,40) - rrt(062) * density(11) 
  pd(40,11) = pd(40,11) + rrt(063) * density(41) 
  pd(40,41) = pd(40,41) + rrt(063) * density(11) 
  pd(41,11) = pd(41,11) - rrt(063) * density(41) 
  pd(41,41) = pd(41,41) - rrt(063) * density(11) 
  pd(41,11) = pd(41,11) + rrt(064) * density(42) 
  pd(41,42) = pd(41,42) + rrt(064) * density(11) 
  pd(42,11) = pd(42,11) - rrt(064) * density(42) 
  pd(42,42) = pd(42,42) - rrt(064) * density(11) 
  pd(42,11) = pd(42,11) + rrt(065) * density(43) 
  pd(42,43) = pd(42,43) + rrt(065) * density(11) 
  pd(43,11) = pd(43,11) - rrt(065) * density(43) 
  pd(43,43) = pd(43,43) - rrt(065) * density(11) 
  pd(43,11) = pd(43,11) + rrt(066) * density(44) 
  pd(43,44) = pd(43,44) + rrt(066) * density(11) 
  pd(44,11) = pd(44,11) - rrt(066) * density(44) 
  pd(44,44) = pd(44,44) - rrt(066) * density(11) 
  pd(44,11) = pd(44,11) + rrt(067) * density(45) 
  pd(44,45) = pd(44,45) + rrt(067) * density(11) 
  pd(45,11) = pd(45,11) - rrt(067) * density(45) 
  pd(45,45) = pd(45,45) - rrt(067) * density(11) 
  pd(11,02) = pd(11,02) + rrt(068) * density(38) 
  pd(11,38) = pd(11,38) + rrt(068) * density(02) 
  pd(38,02) = pd(38,02) - rrt(068) * density(38) 
  pd(38,38) = pd(38,38) - rrt(068) * density(02) 
  pd(38,02) = pd(38,02) + rrt(069) * density(39) 
  pd(38,39) = pd(38,39) + rrt(069) * density(02) 
  pd(39,02) = pd(39,02) - rrt(069) * density(39) 
  pd(39,39) = pd(39,39) - rrt(069) * density(02) 
  pd(39,02) = pd(39,02) + rrt(070) * density(40) 
  pd(39,40) = pd(39,40) + rrt(070) * density(02) 
  pd(40,02) = pd(40,02) - rrt(070) * density(40) 
  pd(40,40) = pd(40,40) - rrt(070) * density(02) 
  pd(40,02) = pd(40,02) + rrt(071) * density(41) 
  pd(40,41) = pd(40,41) + rrt(071) * density(02) 
  pd(41,02) = pd(41,02) - rrt(071) * density(41) 
  pd(41,41) = pd(41,41) - rrt(071) * density(02) 
  pd(41,02) = pd(41,02) + rrt(072) * density(42) 
  pd(41,42) = pd(41,42) + rrt(072) * density(02) 
  pd(42,02) = pd(42,02) - rrt(072) * density(42) 
  pd(42,42) = pd(42,42) - rrt(072) * density(02) 
  pd(42,02) = pd(42,02) + rrt(073) * density(43) 
  pd(42,43) = pd(42,43) + rrt(073) * density(02) 
  pd(43,02) = pd(43,02) - rrt(073) * density(43) 
  pd(43,43) = pd(43,43) - rrt(073) * density(02) 
  pd(43,02) = pd(43,02) + rrt(074) * density(44) 
  pd(43,44) = pd(43,44) + rrt(074) * density(02) 
  pd(44,02) = pd(44,02) - rrt(074) * density(44) 
  pd(44,44) = pd(44,44) - rrt(074) * density(02) 
  pd(44,02) = pd(44,02) + rrt(075) * density(45) 
  pd(44,45) = pd(44,45) + rrt(075) * density(02) 
  pd(45,02) = pd(45,02) - rrt(075) * density(45) 
  pd(45,45) = pd(45,45) - rrt(075) * density(02) 
  pd(11,01) = pd(11,01) + rrt(076) * density(38) 
  pd(11,38) = pd(11,38) + rrt(076) * density(01) 
  pd(38,01) = pd(38,01) - rrt(076) * density(38) 
  pd(38,38) = pd(38,38) - rrt(076) * density(01) 
  pd(38,01) = pd(38,01) + rrt(077) * density(39) 
  pd(38,39) = pd(38,39) + rrt(077) * density(01) 
  pd(39,01) = pd(39,01) - rrt(077) * density(39) 
  pd(39,39) = pd(39,39) - rrt(077) * density(01) 
  pd(39,01) = pd(39,01) + rrt(078) * density(40) 
  pd(39,40) = pd(39,40) + rrt(078) * density(01) 
  pd(40,01) = pd(40,01) - rrt(078) * density(40) 
  pd(40,40) = pd(40,40) - rrt(078) * density(01) 
  pd(40,01) = pd(40,01) + rrt(079) * density(41) 
  pd(40,41) = pd(40,41) + rrt(079) * density(01) 
  pd(41,01) = pd(41,01) - rrt(079) * density(41) 
  pd(41,41) = pd(41,41) - rrt(079) * density(01) 
  pd(41,01) = pd(41,01) + rrt(080) * density(42) 
  pd(41,42) = pd(41,42) + rrt(080) * density(01) 
  pd(42,01) = pd(42,01) - rrt(080) * density(42) 
  pd(42,42) = pd(42,42) - rrt(080) * density(01) 
  pd(42,01) = pd(42,01) + rrt(081) * density(43) 
  pd(42,43) = pd(42,43) + rrt(081) * density(01) 
  pd(43,01) = pd(43,01) - rrt(081) * density(43) 
  pd(43,43) = pd(43,43) - rrt(081) * density(01) 
  pd(43,01) = pd(43,01) + rrt(082) * density(44) 
  pd(43,44) = pd(43,44) + rrt(082) * density(01) 
  pd(44,01) = pd(44,01) - rrt(082) * density(44) 
  pd(44,44) = pd(44,44) - rrt(082) * density(01) 
  pd(44,01) = pd(44,01) + rrt(083) * density(45) 
  pd(44,45) = pd(44,45) + rrt(083) * density(01) 
  pd(45,01) = pd(45,01) - rrt(083) * density(45) 
  pd(45,45) = pd(45,45) - rrt(083) * density(01) 
  pd(11,10) = pd(11,10) + rrt(084) * density(38) 
  pd(11,38) = pd(11,38) + rrt(084) * density(10) 
  pd(38,10) = pd(38,10) - rrt(084) * density(38) 
  pd(38,38) = pd(38,38) - rrt(084) * density(10) 
  pd(38,10) = pd(38,10) + rrt(085) * density(39) 
  pd(38,39) = pd(38,39) + rrt(085) * density(10) 
  pd(39,10) = pd(39,10) - rrt(085) * density(39) 
  pd(39,39) = pd(39,39) - rrt(085) * density(10) 
  pd(39,10) = pd(39,10) + rrt(086) * density(40) 
  pd(39,40) = pd(39,40) + rrt(086) * density(10) 
  pd(40,10) = pd(40,10) - rrt(086) * density(40) 
  pd(40,40) = pd(40,40) - rrt(086) * density(10) 
  pd(40,10) = pd(40,10) + rrt(087) * density(41) 
  pd(40,41) = pd(40,41) + rrt(087) * density(10) 
  pd(41,10) = pd(41,10) - rrt(087) * density(41) 
  pd(41,41) = pd(41,41) - rrt(087) * density(10) 
  pd(41,10) = pd(41,10) + rrt(088) * density(42) 
  pd(41,42) = pd(41,42) + rrt(088) * density(10) 
  pd(42,10) = pd(42,10) - rrt(088) * density(42) 
  pd(42,42) = pd(42,42) - rrt(088) * density(10) 
  pd(42,10) = pd(42,10) + rrt(089) * density(43) 
  pd(42,43) = pd(42,43) + rrt(089) * density(10) 
  pd(43,10) = pd(43,10) - rrt(089) * density(43) 
  pd(43,43) = pd(43,43) - rrt(089) * density(10) 
  pd(43,10) = pd(43,10) + rrt(090) * density(44) 
  pd(43,44) = pd(43,44) + rrt(090) * density(10) 
  pd(44,10) = pd(44,10) - rrt(090) * density(44) 
  pd(44,44) = pd(44,44) - rrt(090) * density(10) 
  pd(44,10) = pd(44,10) + rrt(091) * density(45) 
  pd(44,45) = pd(44,45) + rrt(091) * density(10) 
  pd(45,10) = pd(45,10) - rrt(091) * density(45) 
  pd(45,45) = pd(45,45) - rrt(091) * density(10) 
  pd(02,11) = pd(02,11) + rrt(092) * density(50) 
  pd(02,50) = pd(02,50) + rrt(092) * density(11) 
  pd(50,11) = pd(50,11) - rrt(092) * density(50) 
  pd(50,50) = pd(50,50) - rrt(092) * density(11) 
  pd(50,11) = pd(50,11) + rrt(093) * density(51) 
  pd(50,51) = pd(50,51) + rrt(093) * density(11) 
  pd(51,11) = pd(51,11) - rrt(093) * density(51) 
  pd(51,51) = pd(51,51) - rrt(093) * density(11) 
  pd(51,11) = pd(51,11) + rrt(094) * density(52) 
  pd(51,52) = pd(51,52) + rrt(094) * density(11) 
  pd(52,11) = pd(52,11) - rrt(094) * density(52) 
  pd(52,52) = pd(52,52) - rrt(094) * density(11) 
  pd(52,11) = pd(52,11) + rrt(095) * density(53) 
  pd(52,53) = pd(52,53) + rrt(095) * density(11) 
  pd(53,11) = pd(53,11) - rrt(095) * density(53) 
  pd(53,53) = pd(53,53) - rrt(095) * density(11) 
  pd(02,02) = pd(02,02) + rrt(096) * density(50) 
  pd(02,50) = pd(02,50) + rrt(096) * density(02) 
  pd(50,02) = pd(50,02) - rrt(096) * density(50) 
  pd(50,50) = pd(50,50) - rrt(096) * density(02) 
  pd(50,02) = pd(50,02) + rrt(097) * density(51) 
  pd(50,51) = pd(50,51) + rrt(097) * density(02) 
  pd(51,02) = pd(51,02) - rrt(097) * density(51) 
  pd(51,51) = pd(51,51) - rrt(097) * density(02) 
  pd(51,02) = pd(51,02) + rrt(098) * density(52) 
  pd(51,52) = pd(51,52) + rrt(098) * density(02) 
  pd(52,02) = pd(52,02) - rrt(098) * density(52) 
  pd(52,52) = pd(52,52) - rrt(098) * density(02) 
  pd(52,02) = pd(52,02) + rrt(099) * density(53) 
  pd(52,53) = pd(52,53) + rrt(099) * density(02) 
  pd(53,02) = pd(53,02) - rrt(099) * density(53) 
  pd(53,53) = pd(53,53) - rrt(099) * density(02) 
  pd(02,01) = pd(02,01) + rrt(100) * density(50) 
  pd(02,50) = pd(02,50) + rrt(100) * density(01) 
  pd(50,01) = pd(50,01) - rrt(100) * density(50) 
  pd(50,50) = pd(50,50) - rrt(100) * density(01) 
  pd(50,01) = pd(50,01) + rrt(101) * density(51) 
  pd(50,51) = pd(50,51) + rrt(101) * density(01) 
  pd(51,01) = pd(51,01) - rrt(101) * density(51) 
  pd(51,51) = pd(51,51) - rrt(101) * density(01) 
  pd(51,01) = pd(51,01) + rrt(102) * density(52) 
  pd(51,52) = pd(51,52) + rrt(102) * density(01) 
  pd(52,01) = pd(52,01) - rrt(102) * density(52) 
  pd(52,52) = pd(52,52) - rrt(102) * density(01) 
  pd(52,01) = pd(52,01) + rrt(103) * density(53) 
  pd(52,53) = pd(52,53) + rrt(103) * density(01) 
  pd(53,01) = pd(53,01) - rrt(103) * density(53) 
  pd(53,53) = pd(53,53) - rrt(103) * density(01) 
  pd(11,38) = pd(11,38) + rrt(104) * density(38) * 2.0d0
  pd(38,38) = pd(38,38) - rrt(104) * density(38) * 4.0d0
  pd(39,38) = pd(39,38) + rrt(104) * density(38) * 2.0d0
  pd(11,38) = pd(11,38) + rrt(105) * density(39) 
  pd(11,39) = pd(11,39) + rrt(105) * density(38) 
  pd(38,38) = pd(38,38) - rrt(105) * density(39) 
  pd(38,39) = pd(38,39) - rrt(105) * density(38) 
  pd(39,38) = pd(39,38) - rrt(105) * density(39) 
  pd(39,39) = pd(39,39) - rrt(105) * density(38) 
  pd(40,38) = pd(40,38) + rrt(105) * density(39) 
  pd(40,39) = pd(40,39) + rrt(105) * density(38) 
  pd(11,38) = pd(11,38) + rrt(106) * density(40) 
  pd(11,40) = pd(11,40) + rrt(106) * density(38) 
  pd(38,38) = pd(38,38) - rrt(106) * density(40) 
  pd(38,40) = pd(38,40) - rrt(106) * density(38) 
  pd(40,38) = pd(40,38) - rrt(106) * density(40) 
  pd(40,40) = pd(40,40) - rrt(106) * density(38) 
  pd(41,38) = pd(41,38) + rrt(106) * density(40) 
  pd(41,40) = pd(41,40) + rrt(106) * density(38) 
  pd(11,38) = pd(11,38) + rrt(107) * density(41) 
  pd(11,41) = pd(11,41) + rrt(107) * density(38) 
  pd(38,38) = pd(38,38) - rrt(107) * density(41) 
  pd(38,41) = pd(38,41) - rrt(107) * density(38) 
  pd(41,38) = pd(41,38) - rrt(107) * density(41) 
  pd(41,41) = pd(41,41) - rrt(107) * density(38) 
  pd(42,38) = pd(42,38) + rrt(107) * density(41) 
  pd(42,41) = pd(42,41) + rrt(107) * density(38) 
  pd(11,38) = pd(11,38) + rrt(108) * density(42) 
  pd(11,42) = pd(11,42) + rrt(108) * density(38) 
  pd(38,38) = pd(38,38) - rrt(108) * density(42) 
  pd(38,42) = pd(38,42) - rrt(108) * density(38) 
  pd(42,38) = pd(42,38) - rrt(108) * density(42) 
  pd(42,42) = pd(42,42) - rrt(108) * density(38) 
  pd(43,38) = pd(43,38) + rrt(108) * density(42) 
  pd(43,42) = pd(43,42) + rrt(108) * density(38) 
  pd(11,38) = pd(11,38) + rrt(109) * density(43) 
  pd(11,43) = pd(11,43) + rrt(109) * density(38) 
  pd(38,38) = pd(38,38) - rrt(109) * density(43) 
  pd(38,43) = pd(38,43) - rrt(109) * density(38) 
  pd(43,38) = pd(43,38) - rrt(109) * density(43) 
  pd(43,43) = pd(43,43) - rrt(109) * density(38) 
  pd(44,38) = pd(44,38) + rrt(109) * density(43) 
  pd(44,43) = pd(44,43) + rrt(109) * density(38) 
  pd(11,38) = pd(11,38) + rrt(110) * density(44) 
  pd(11,44) = pd(11,44) + rrt(110) * density(38) 
  pd(38,38) = pd(38,38) - rrt(110) * density(44) 
  pd(38,44) = pd(38,44) - rrt(110) * density(38) 
  pd(44,38) = pd(44,38) - rrt(110) * density(44) 
  pd(44,44) = pd(44,44) - rrt(110) * density(38) 
  pd(45,38) = pd(45,38) + rrt(110) * density(44) 
  pd(45,44) = pd(45,44) + rrt(110) * density(38) 
  pd(11,11) = pd(11,11) - rrt(111) * density(39) 
  pd(11,39) = pd(11,39) - rrt(111) * density(11) 
  pd(38,11) = pd(38,11) + rrt(111) * density(39) * 2.0d0
  pd(38,39) = pd(38,39) + rrt(111) * density(11) * 2.0d0
  pd(39,11) = pd(39,11) - rrt(111) * density(39) 
  pd(39,39) = pd(39,39) - rrt(111) * density(11) 
  pd(38,39) = pd(38,39) + rrt(112) * density(39) * 2.0d0
  pd(39,39) = pd(39,39) - rrt(112) * density(39) * 4.0d0
  pd(40,39) = pd(40,39) + rrt(112) * density(39) * 2.0d0
  pd(38,39) = pd(38,39) + rrt(113) * density(40) 
  pd(38,40) = pd(38,40) + rrt(113) * density(39) 
  pd(39,39) = pd(39,39) - rrt(113) * density(40) 
  pd(39,40) = pd(39,40) - rrt(113) * density(39) 
  pd(40,39) = pd(40,39) - rrt(113) * density(40) 
  pd(40,40) = pd(40,40) - rrt(113) * density(39) 
  pd(41,39) = pd(41,39) + rrt(113) * density(40) 
  pd(41,40) = pd(41,40) + rrt(113) * density(39) 
  pd(38,39) = pd(38,39) + rrt(114) * density(41) 
  pd(38,41) = pd(38,41) + rrt(114) * density(39) 
  pd(39,39) = pd(39,39) - rrt(114) * density(41) 
  pd(39,41) = pd(39,41) - rrt(114) * density(39) 
  pd(41,39) = pd(41,39) - rrt(114) * density(41) 
  pd(41,41) = pd(41,41) - rrt(114) * density(39) 
  pd(42,39) = pd(42,39) + rrt(114) * density(41) 
  pd(42,41) = pd(42,41) + rrt(114) * density(39) 
  pd(38,39) = pd(38,39) + rrt(115) * density(42) 
  pd(38,42) = pd(38,42) + rrt(115) * density(39) 
  pd(39,39) = pd(39,39) - rrt(115) * density(42) 
  pd(39,42) = pd(39,42) - rrt(115) * density(39) 
  pd(42,39) = pd(42,39) - rrt(115) * density(42) 
  pd(42,42) = pd(42,42) - rrt(115) * density(39) 
  pd(43,39) = pd(43,39) + rrt(115) * density(42) 
  pd(43,42) = pd(43,42) + rrt(115) * density(39) 
  pd(38,39) = pd(38,39) + rrt(116) * density(43) 
  pd(38,43) = pd(38,43) + rrt(116) * density(39) 
  pd(39,39) = pd(39,39) - rrt(116) * density(43) 
  pd(39,43) = pd(39,43) - rrt(116) * density(39) 
  pd(43,39) = pd(43,39) - rrt(116) * density(43) 
  pd(43,43) = pd(43,43) - rrt(116) * density(39) 
  pd(44,39) = pd(44,39) + rrt(116) * density(43) 
  pd(44,43) = pd(44,43) + rrt(116) * density(39) 
  pd(38,39) = pd(38,39) + rrt(117) * density(44) 
  pd(38,44) = pd(38,44) + rrt(117) * density(39) 
  pd(39,39) = pd(39,39) - rrt(117) * density(44) 
  pd(39,44) = pd(39,44) - rrt(117) * density(39) 
  pd(44,39) = pd(44,39) - rrt(117) * density(44) 
  pd(44,44) = pd(44,44) - rrt(117) * density(39) 
  pd(45,39) = pd(45,39) + rrt(117) * density(44) 
  pd(45,44) = pd(45,44) + rrt(117) * density(39) 
  pd(11,11) = pd(11,11) - rrt(118) * density(40) 
  pd(11,40) = pd(11,40) - rrt(118) * density(11) 
  pd(38,11) = pd(38,11) + rrt(118) * density(40) 
  pd(38,40) = pd(38,40) + rrt(118) * density(11) 
  pd(39,11) = pd(39,11) + rrt(118) * density(40) 
  pd(39,40) = pd(39,40) + rrt(118) * density(11) 
  pd(40,11) = pd(40,11) - rrt(118) * density(40) 
  pd(40,40) = pd(40,40) - rrt(118) * density(11) 
  pd(38,38) = pd(38,38) - rrt(119) * density(40) 
  pd(38,40) = pd(38,40) - rrt(119) * density(38) 
  pd(39,38) = pd(39,38) + rrt(119) * density(40) * 2.0d0
  pd(39,40) = pd(39,40) + rrt(119) * density(38) * 2.0d0
  pd(40,38) = pd(40,38) - rrt(119) * density(40) 
  pd(40,40) = pd(40,40) - rrt(119) * density(38) 
  pd(39,40) = pd(39,40) + rrt(120) * density(40) * 2.0d0
  pd(40,40) = pd(40,40) - rrt(120) * density(40) * 4.0d0
  pd(41,40) = pd(41,40) + rrt(120) * density(40) * 2.0d0
  pd(39,40) = pd(39,40) + rrt(121) * density(41) 
  pd(39,41) = pd(39,41) + rrt(121) * density(40) 
  pd(40,40) = pd(40,40) - rrt(121) * density(41) 
  pd(40,41) = pd(40,41) - rrt(121) * density(40) 
  pd(41,40) = pd(41,40) - rrt(121) * density(41) 
  pd(41,41) = pd(41,41) - rrt(121) * density(40) 
  pd(42,40) = pd(42,40) + rrt(121) * density(41) 
  pd(42,41) = pd(42,41) + rrt(121) * density(40) 
  pd(39,40) = pd(39,40) + rrt(122) * density(42) 
  pd(39,42) = pd(39,42) + rrt(122) * density(40) 
  pd(40,40) = pd(40,40) - rrt(122) * density(42) 
  pd(40,42) = pd(40,42) - rrt(122) * density(40) 
  pd(42,40) = pd(42,40) - rrt(122) * density(42) 
  pd(42,42) = pd(42,42) - rrt(122) * density(40) 
  pd(43,40) = pd(43,40) + rrt(122) * density(42) 
  pd(43,42) = pd(43,42) + rrt(122) * density(40) 
  pd(39,40) = pd(39,40) + rrt(123) * density(43) 
  pd(39,43) = pd(39,43) + rrt(123) * density(40) 
  pd(40,40) = pd(40,40) - rrt(123) * density(43) 
  pd(40,43) = pd(40,43) - rrt(123) * density(40) 
  pd(43,40) = pd(43,40) - rrt(123) * density(43) 
  pd(43,43) = pd(43,43) - rrt(123) * density(40) 
  pd(44,40) = pd(44,40) + rrt(123) * density(43) 
  pd(44,43) = pd(44,43) + rrt(123) * density(40) 
  pd(39,40) = pd(39,40) + rrt(124) * density(44) 
  pd(39,44) = pd(39,44) + rrt(124) * density(40) 
  pd(40,40) = pd(40,40) - rrt(124) * density(44) 
  pd(40,44) = pd(40,44) - rrt(124) * density(40) 
  pd(44,40) = pd(44,40) - rrt(124) * density(44) 
  pd(44,44) = pd(44,44) - rrt(124) * density(40) 
  pd(45,40) = pd(45,40) + rrt(124) * density(44) 
  pd(45,44) = pd(45,44) + rrt(124) * density(40) 
  pd(11,11) = pd(11,11) - rrt(125) * density(41) 
  pd(11,41) = pd(11,41) - rrt(125) * density(11) 
  pd(38,11) = pd(38,11) + rrt(125) * density(41) 
  pd(38,41) = pd(38,41) + rrt(125) * density(11) 
  pd(40,11) = pd(40,11) + rrt(125) * density(41) 
  pd(40,41) = pd(40,41) + rrt(125) * density(11) 
  pd(41,11) = pd(41,11) - rrt(125) * density(41) 
  pd(41,41) = pd(41,41) - rrt(125) * density(11) 
  pd(38,38) = pd(38,38) - rrt(126) * density(41) 
  pd(38,41) = pd(38,41) - rrt(126) * density(38) 
  pd(39,38) = pd(39,38) + rrt(126) * density(41) 
  pd(39,41) = pd(39,41) + rrt(126) * density(38) 
  pd(40,38) = pd(40,38) + rrt(126) * density(41) 
  pd(40,41) = pd(40,41) + rrt(126) * density(38) 
  pd(41,38) = pd(41,38) - rrt(126) * density(41) 
  pd(41,41) = pd(41,41) - rrt(126) * density(38) 
  pd(39,39) = pd(39,39) - rrt(127) * density(41) 
  pd(39,41) = pd(39,41) - rrt(127) * density(39) 
  pd(40,39) = pd(40,39) + rrt(127) * density(41) * 2.0d0
  pd(40,41) = pd(40,41) + rrt(127) * density(39) * 2.0d0
  pd(41,39) = pd(41,39) - rrt(127) * density(41) 
  pd(41,41) = pd(41,41) - rrt(127) * density(39) 
  pd(40,41) = pd(40,41) + rrt(128) * density(41) * 2.0d0
  pd(41,41) = pd(41,41) - rrt(128) * density(41) * 4.0d0
  pd(42,41) = pd(42,41) + rrt(128) * density(41) * 2.0d0
  pd(40,41) = pd(40,41) + rrt(129) * density(42) 
  pd(40,42) = pd(40,42) + rrt(129) * density(41) 
  pd(41,41) = pd(41,41) - rrt(129) * density(42) 
  pd(41,42) = pd(41,42) - rrt(129) * density(41) 
  pd(42,41) = pd(42,41) - rrt(129) * density(42) 
  pd(42,42) = pd(42,42) - rrt(129) * density(41) 
  pd(43,41) = pd(43,41) + rrt(129) * density(42) 
  pd(43,42) = pd(43,42) + rrt(129) * density(41) 
  pd(40,41) = pd(40,41) + rrt(130) * density(43) 
  pd(40,43) = pd(40,43) + rrt(130) * density(41) 
  pd(41,41) = pd(41,41) - rrt(130) * density(43) 
  pd(41,43) = pd(41,43) - rrt(130) * density(41) 
  pd(43,41) = pd(43,41) - rrt(130) * density(43) 
  pd(43,43) = pd(43,43) - rrt(130) * density(41) 
  pd(44,41) = pd(44,41) + rrt(130) * density(43) 
  pd(44,43) = pd(44,43) + rrt(130) * density(41) 
  pd(40,41) = pd(40,41) + rrt(131) * density(44) 
  pd(40,44) = pd(40,44) + rrt(131) * density(41) 
  pd(41,41) = pd(41,41) - rrt(131) * density(44) 
  pd(41,44) = pd(41,44) - rrt(131) * density(41) 
  pd(44,41) = pd(44,41) - rrt(131) * density(44) 
  pd(44,44) = pd(44,44) - rrt(131) * density(41) 
  pd(45,41) = pd(45,41) + rrt(131) * density(44) 
  pd(45,44) = pd(45,44) + rrt(131) * density(41) 
  pd(11,11) = pd(11,11) - rrt(132) * density(42) 
  pd(11,42) = pd(11,42) - rrt(132) * density(11) 
  pd(38,11) = pd(38,11) + rrt(132) * density(42) 
  pd(38,42) = pd(38,42) + rrt(132) * density(11) 
  pd(41,11) = pd(41,11) + rrt(132) * density(42) 
  pd(41,42) = pd(41,42) + rrt(132) * density(11) 
  pd(42,11) = pd(42,11) - rrt(132) * density(42) 
  pd(42,42) = pd(42,42) - rrt(132) * density(11) 
  pd(38,38) = pd(38,38) - rrt(133) * density(42) 
  pd(38,42) = pd(38,42) - rrt(133) * density(38) 
  pd(39,38) = pd(39,38) + rrt(133) * density(42) 
  pd(39,42) = pd(39,42) + rrt(133) * density(38) 
  pd(41,38) = pd(41,38) + rrt(133) * density(42) 
  pd(41,42) = pd(41,42) + rrt(133) * density(38) 
  pd(42,38) = pd(42,38) - rrt(133) * density(42) 
  pd(42,42) = pd(42,42) - rrt(133) * density(38) 
  pd(39,39) = pd(39,39) - rrt(134) * density(42) 
  pd(39,42) = pd(39,42) - rrt(134) * density(39) 
  pd(40,39) = pd(40,39) + rrt(134) * density(42) 
  pd(40,42) = pd(40,42) + rrt(134) * density(39) 
  pd(41,39) = pd(41,39) + rrt(134) * density(42) 
  pd(41,42) = pd(41,42) + rrt(134) * density(39) 
  pd(42,39) = pd(42,39) - rrt(134) * density(42) 
  pd(42,42) = pd(42,42) - rrt(134) * density(39) 
  pd(40,40) = pd(40,40) - rrt(135) * density(42) 
  pd(40,42) = pd(40,42) - rrt(135) * density(40) 
  pd(41,40) = pd(41,40) + rrt(135) * density(42) * 2.0d0
  pd(41,42) = pd(41,42) + rrt(135) * density(40) * 2.0d0
  pd(42,40) = pd(42,40) - rrt(135) * density(42) 
  pd(42,42) = pd(42,42) - rrt(135) * density(40) 
  pd(41,42) = pd(41,42) + rrt(136) * density(42) * 2.0d0
  pd(42,42) = pd(42,42) - rrt(136) * density(42) * 4.0d0
  pd(43,42) = pd(43,42) + rrt(136) * density(42) * 2.0d0
  pd(41,42) = pd(41,42) + rrt(137) * density(43) 
  pd(41,43) = pd(41,43) + rrt(137) * density(42) 
  pd(42,42) = pd(42,42) - rrt(137) * density(43) 
  pd(42,43) = pd(42,43) - rrt(137) * density(42) 
  pd(43,42) = pd(43,42) - rrt(137) * density(43) 
  pd(43,43) = pd(43,43) - rrt(137) * density(42) 
  pd(44,42) = pd(44,42) + rrt(137) * density(43) 
  pd(44,43) = pd(44,43) + rrt(137) * density(42) 
  pd(41,42) = pd(41,42) + rrt(138) * density(44) 
  pd(41,44) = pd(41,44) + rrt(138) * density(42) 
  pd(42,42) = pd(42,42) - rrt(138) * density(44) 
  pd(42,44) = pd(42,44) - rrt(138) * density(42) 
  pd(44,42) = pd(44,42) - rrt(138) * density(44) 
  pd(44,44) = pd(44,44) - rrt(138) * density(42) 
  pd(45,42) = pd(45,42) + rrt(138) * density(44) 
  pd(45,44) = pd(45,44) + rrt(138) * density(42) 
  pd(11,11) = pd(11,11) - rrt(139) * density(43) 
  pd(11,43) = pd(11,43) - rrt(139) * density(11) 
  pd(38,11) = pd(38,11) + rrt(139) * density(43) 
  pd(38,43) = pd(38,43) + rrt(139) * density(11) 
  pd(42,11) = pd(42,11) + rrt(139) * density(43) 
  pd(42,43) = pd(42,43) + rrt(139) * density(11) 
  pd(43,11) = pd(43,11) - rrt(139) * density(43) 
  pd(43,43) = pd(43,43) - rrt(139) * density(11) 
  pd(38,38) = pd(38,38) - rrt(140) * density(43) 
  pd(38,43) = pd(38,43) - rrt(140) * density(38) 
  pd(39,38) = pd(39,38) + rrt(140) * density(43) 
  pd(39,43) = pd(39,43) + rrt(140) * density(38) 
  pd(42,38) = pd(42,38) + rrt(140) * density(43) 
  pd(42,43) = pd(42,43) + rrt(140) * density(38) 
  pd(43,38) = pd(43,38) - rrt(140) * density(43) 
  pd(43,43) = pd(43,43) - rrt(140) * density(38) 
  pd(39,39) = pd(39,39) - rrt(141) * density(43) 
  pd(39,43) = pd(39,43) - rrt(141) * density(39) 
  pd(40,39) = pd(40,39) + rrt(141) * density(43) 
  pd(40,43) = pd(40,43) + rrt(141) * density(39) 
  pd(42,39) = pd(42,39) + rrt(141) * density(43) 
  pd(42,43) = pd(42,43) + rrt(141) * density(39) 
  pd(43,39) = pd(43,39) - rrt(141) * density(43) 
  pd(43,43) = pd(43,43) - rrt(141) * density(39) 
  pd(40,40) = pd(40,40) - rrt(142) * density(43) 
  pd(40,43) = pd(40,43) - rrt(142) * density(40) 
  pd(41,40) = pd(41,40) + rrt(142) * density(43) 
  pd(41,43) = pd(41,43) + rrt(142) * density(40) 
  pd(42,40) = pd(42,40) + rrt(142) * density(43) 
  pd(42,43) = pd(42,43) + rrt(142) * density(40) 
  pd(43,40) = pd(43,40) - rrt(142) * density(43) 
  pd(43,43) = pd(43,43) - rrt(142) * density(40) 
  pd(41,41) = pd(41,41) - rrt(143) * density(43) 
  pd(41,43) = pd(41,43) - rrt(143) * density(41) 
  pd(42,41) = pd(42,41) + rrt(143) * density(43) * 2.0d0
  pd(42,43) = pd(42,43) + rrt(143) * density(41) * 2.0d0
  pd(43,41) = pd(43,41) - rrt(143) * density(43) 
  pd(43,43) = pd(43,43) - rrt(143) * density(41) 
  pd(42,43) = pd(42,43) + rrt(144) * density(43) * 2.0d0
  pd(43,43) = pd(43,43) - rrt(144) * density(43) * 4.0d0
  pd(44,43) = pd(44,43) + rrt(144) * density(43) * 2.0d0
  pd(42,43) = pd(42,43) + rrt(145) * density(44) 
  pd(42,44) = pd(42,44) + rrt(145) * density(43) 
  pd(43,43) = pd(43,43) - rrt(145) * density(44) 
  pd(43,44) = pd(43,44) - rrt(145) * density(43) 
  pd(44,43) = pd(44,43) - rrt(145) * density(44) 
  pd(44,44) = pd(44,44) - rrt(145) * density(43) 
  pd(45,43) = pd(45,43) + rrt(145) * density(44) 
  pd(45,44) = pd(45,44) + rrt(145) * density(43) 
  pd(11,11) = pd(11,11) - rrt(146) * density(44) 
  pd(11,44) = pd(11,44) - rrt(146) * density(11) 
  pd(38,11) = pd(38,11) + rrt(146) * density(44) 
  pd(38,44) = pd(38,44) + rrt(146) * density(11) 
  pd(43,11) = pd(43,11) + rrt(146) * density(44) 
  pd(43,44) = pd(43,44) + rrt(146) * density(11) 
  pd(44,11) = pd(44,11) - rrt(146) * density(44) 
  pd(44,44) = pd(44,44) - rrt(146) * density(11) 
  pd(38,38) = pd(38,38) - rrt(147) * density(44) 
  pd(38,44) = pd(38,44) - rrt(147) * density(38) 
  pd(39,38) = pd(39,38) + rrt(147) * density(44) 
  pd(39,44) = pd(39,44) + rrt(147) * density(38) 
  pd(43,38) = pd(43,38) + rrt(147) * density(44) 
  pd(43,44) = pd(43,44) + rrt(147) * density(38) 
  pd(44,38) = pd(44,38) - rrt(147) * density(44) 
  pd(44,44) = pd(44,44) - rrt(147) * density(38) 
  pd(39,39) = pd(39,39) - rrt(148) * density(44) 
  pd(39,44) = pd(39,44) - rrt(148) * density(39) 
  pd(40,39) = pd(40,39) + rrt(148) * density(44) 
  pd(40,44) = pd(40,44) + rrt(148) * density(39) 
  pd(43,39) = pd(43,39) + rrt(148) * density(44) 
  pd(43,44) = pd(43,44) + rrt(148) * density(39) 
  pd(44,39) = pd(44,39) - rrt(148) * density(44) 
  pd(44,44) = pd(44,44) - rrt(148) * density(39) 
  pd(40,40) = pd(40,40) - rrt(149) * density(44) 
  pd(40,44) = pd(40,44) - rrt(149) * density(40) 
  pd(41,40) = pd(41,40) + rrt(149) * density(44) 
  pd(41,44) = pd(41,44) + rrt(149) * density(40) 
  pd(43,40) = pd(43,40) + rrt(149) * density(44) 
  pd(43,44) = pd(43,44) + rrt(149) * density(40) 
  pd(44,40) = pd(44,40) - rrt(149) * density(44) 
  pd(44,44) = pd(44,44) - rrt(149) * density(40) 
  pd(41,41) = pd(41,41) - rrt(150) * density(44) 
  pd(41,44) = pd(41,44) - rrt(150) * density(41) 
  pd(42,41) = pd(42,41) + rrt(150) * density(44) 
  pd(42,44) = pd(42,44) + rrt(150) * density(41) 
  pd(43,41) = pd(43,41) + rrt(150) * density(44) 
  pd(43,44) = pd(43,44) + rrt(150) * density(41) 
  pd(44,41) = pd(44,41) - rrt(150) * density(44) 
  pd(44,44) = pd(44,44) - rrt(150) * density(41) 
  pd(42,42) = pd(42,42) - rrt(151) * density(44) 
  pd(42,44) = pd(42,44) - rrt(151) * density(42) 
  pd(43,42) = pd(43,42) + rrt(151) * density(44) * 2.0d0
  pd(43,44) = pd(43,44) + rrt(151) * density(42) * 2.0d0
  pd(44,42) = pd(44,42) - rrt(151) * density(44) 
  pd(44,44) = pd(44,44) - rrt(151) * density(42) 
  pd(43,44) = pd(43,44) + rrt(152) * density(44) * 2.0d0
  pd(44,44) = pd(44,44) - rrt(152) * density(44) * 4.0d0
  pd(45,44) = pd(45,44) + rrt(152) * density(44) * 2.0d0
  pd(11,11) = pd(11,11) - rrt(153) * density(45) 
  pd(11,45) = pd(11,45) - rrt(153) * density(11) 
  pd(38,11) = pd(38,11) + rrt(153) * density(45) 
  pd(38,45) = pd(38,45) + rrt(153) * density(11) 
  pd(44,11) = pd(44,11) + rrt(153) * density(45) 
  pd(44,45) = pd(44,45) + rrt(153) * density(11) 
  pd(45,11) = pd(45,11) - rrt(153) * density(45) 
  pd(45,45) = pd(45,45) - rrt(153) * density(11) 
  pd(38,38) = pd(38,38) - rrt(154) * density(45) 
  pd(38,45) = pd(38,45) - rrt(154) * density(38) 
  pd(39,38) = pd(39,38) + rrt(154) * density(45) 
  pd(39,45) = pd(39,45) + rrt(154) * density(38) 
  pd(44,38) = pd(44,38) + rrt(154) * density(45) 
  pd(44,45) = pd(44,45) + rrt(154) * density(38) 
  pd(45,38) = pd(45,38) - rrt(154) * density(45) 
  pd(45,45) = pd(45,45) - rrt(154) * density(38) 
  pd(39,39) = pd(39,39) - rrt(155) * density(45) 
  pd(39,45) = pd(39,45) - rrt(155) * density(39) 
  pd(40,39) = pd(40,39) + rrt(155) * density(45) 
  pd(40,45) = pd(40,45) + rrt(155) * density(39) 
  pd(44,39) = pd(44,39) + rrt(155) * density(45) 
  pd(44,45) = pd(44,45) + rrt(155) * density(39) 
  pd(45,39) = pd(45,39) - rrt(155) * density(45) 
  pd(45,45) = pd(45,45) - rrt(155) * density(39) 
  pd(40,40) = pd(40,40) - rrt(156) * density(45) 
  pd(40,45) = pd(40,45) - rrt(156) * density(40) 
  pd(41,40) = pd(41,40) + rrt(156) * density(45) 
  pd(41,45) = pd(41,45) + rrt(156) * density(40) 
  pd(44,40) = pd(44,40) + rrt(156) * density(45) 
  pd(44,45) = pd(44,45) + rrt(156) * density(40) 
  pd(45,40) = pd(45,40) - rrt(156) * density(45) 
  pd(45,45) = pd(45,45) - rrt(156) * density(40) 
  pd(41,41) = pd(41,41) - rrt(157) * density(45) 
  pd(41,45) = pd(41,45) - rrt(157) * density(41) 
  pd(42,41) = pd(42,41) + rrt(157) * density(45) 
  pd(42,45) = pd(42,45) + rrt(157) * density(41) 
  pd(44,41) = pd(44,41) + rrt(157) * density(45) 
  pd(44,45) = pd(44,45) + rrt(157) * density(41) 
  pd(45,41) = pd(45,41) - rrt(157) * density(45) 
  pd(45,45) = pd(45,45) - rrt(157) * density(41) 
  pd(42,42) = pd(42,42) - rrt(158) * density(45) 
  pd(42,45) = pd(42,45) - rrt(158) * density(42) 
  pd(43,42) = pd(43,42) + rrt(158) * density(45) 
  pd(43,45) = pd(43,45) + rrt(158) * density(42) 
  pd(44,42) = pd(44,42) + rrt(158) * density(45) 
  pd(44,45) = pd(44,45) + rrt(158) * density(42) 
  pd(45,42) = pd(45,42) - rrt(158) * density(45) 
  pd(45,45) = pd(45,45) - rrt(158) * density(42) 
  pd(43,43) = pd(43,43) - rrt(159) * density(45) 
  pd(43,45) = pd(43,45) - rrt(159) * density(43) 
  pd(44,43) = pd(44,43) + rrt(159) * density(45) * 2.0d0
  pd(44,45) = pd(44,45) + rrt(159) * density(43) * 2.0d0
  pd(45,43) = pd(45,43) - rrt(159) * density(45) 
  pd(45,45) = pd(45,45) - rrt(159) * density(43) 
  pd(02,50) = pd(02,50) + rrt(160) * density(50) * 2.0d0
  pd(50,50) = pd(50,50) - rrt(160) * density(50) * 4.0d0
  pd(51,50) = pd(51,50) + rrt(160) * density(50) * 2.0d0
  pd(02,50) = pd(02,50) + rrt(161) * density(51) 
  pd(02,51) = pd(02,51) + rrt(161) * density(50) 
  pd(50,50) = pd(50,50) - rrt(161) * density(51) 
  pd(50,51) = pd(50,51) - rrt(161) * density(50) 
  pd(51,50) = pd(51,50) - rrt(161) * density(51) 
  pd(51,51) = pd(51,51) - rrt(161) * density(50) 
  pd(52,50) = pd(52,50) + rrt(161) * density(51) 
  pd(52,51) = pd(52,51) + rrt(161) * density(50) 
  pd(02,50) = pd(02,50) + rrt(162) * density(52) 
  pd(02,52) = pd(02,52) + rrt(162) * density(50) 
  pd(50,50) = pd(50,50) - rrt(162) * density(52) 
  pd(50,52) = pd(50,52) - rrt(162) * density(50) 
  pd(52,50) = pd(52,50) - rrt(162) * density(52) 
  pd(52,52) = pd(52,52) - rrt(162) * density(50) 
  pd(53,50) = pd(53,50) + rrt(162) * density(52) 
  pd(53,52) = pd(53,52) + rrt(162) * density(50) 
  pd(02,02) = pd(02,02) - rrt(163) * density(51) 
  pd(02,51) = pd(02,51) - rrt(163) * density(02) 
  pd(50,02) = pd(50,02) + rrt(163) * density(51) * 2.0d0
  pd(50,51) = pd(50,51) + rrt(163) * density(02) * 2.0d0
  pd(51,02) = pd(51,02) - rrt(163) * density(51) 
  pd(51,51) = pd(51,51) - rrt(163) * density(02) 
  pd(50,51) = pd(50,51) + rrt(164) * density(51) * 2.0d0
  pd(51,51) = pd(51,51) - rrt(164) * density(51) * 4.0d0
  pd(52,51) = pd(52,51) + rrt(164) * density(51) * 2.0d0
  pd(50,51) = pd(50,51) + rrt(165) * density(52) 
  pd(50,52) = pd(50,52) + rrt(165) * density(51) 
  pd(51,51) = pd(51,51) - rrt(165) * density(52) 
  pd(51,52) = pd(51,52) - rrt(165) * density(51) 
  pd(52,51) = pd(52,51) - rrt(165) * density(52) 
  pd(52,52) = pd(52,52) - rrt(165) * density(51) 
  pd(53,51) = pd(53,51) + rrt(165) * density(52) 
  pd(53,52) = pd(53,52) + rrt(165) * density(51) 
  pd(02,02) = pd(02,02) - rrt(166) * density(52) 
  pd(02,52) = pd(02,52) - rrt(166) * density(02) 
  pd(50,02) = pd(50,02) + rrt(166) * density(52) 
  pd(50,52) = pd(50,52) + rrt(166) * density(02) 
  pd(51,02) = pd(51,02) + rrt(166) * density(52) 
  pd(51,52) = pd(51,52) + rrt(166) * density(02) 
  pd(52,02) = pd(52,02) - rrt(166) * density(52) 
  pd(52,52) = pd(52,52) - rrt(166) * density(02) 
  pd(50,50) = pd(50,50) - rrt(167) * density(52) 
  pd(50,52) = pd(50,52) - rrt(167) * density(50) 
  pd(51,50) = pd(51,50) + rrt(167) * density(52) * 2.0d0
  pd(51,52) = pd(51,52) + rrt(167) * density(50) * 2.0d0
  pd(52,50) = pd(52,50) - rrt(167) * density(52) 
  pd(52,52) = pd(52,52) - rrt(167) * density(50) 
  pd(51,52) = pd(51,52) + rrt(168) * density(52) * 2.0d0
  pd(52,52) = pd(52,52) - rrt(168) * density(52) * 4.0d0
  pd(53,52) = pd(53,52) + rrt(168) * density(52) * 2.0d0
  pd(02,02) = pd(02,02) - rrt(169) * density(53) 
  pd(02,53) = pd(02,53) - rrt(169) * density(02) 
  pd(50,02) = pd(50,02) + rrt(169) * density(53) 
  pd(50,53) = pd(50,53) + rrt(169) * density(02) 
  pd(52,02) = pd(52,02) + rrt(169) * density(53) 
  pd(52,53) = pd(52,53) + rrt(169) * density(02) 
  pd(53,02) = pd(53,02) - rrt(169) * density(53) 
  pd(53,53) = pd(53,53) - rrt(169) * density(02) 
  pd(50,50) = pd(50,50) - rrt(170) * density(53) 
  pd(50,53) = pd(50,53) - rrt(170) * density(50) 
  pd(51,50) = pd(51,50) + rrt(170) * density(53) 
  pd(51,53) = pd(51,53) + rrt(170) * density(50) 
  pd(52,50) = pd(52,50) + rrt(170) * density(53) 
  pd(52,53) = pd(52,53) + rrt(170) * density(50) 
  pd(53,50) = pd(53,50) - rrt(170) * density(53) 
  pd(53,53) = pd(53,53) - rrt(170) * density(50) 
  pd(51,51) = pd(51,51) - rrt(171) * density(53) 
  pd(51,53) = pd(51,53) - rrt(171) * density(51) 
  pd(52,51) = pd(52,51) + rrt(171) * density(53) * 2.0d0
  pd(52,53) = pd(52,53) + rrt(171) * density(51) * 2.0d0
  pd(53,51) = pd(53,51) - rrt(171) * density(53) 
  pd(53,53) = pd(53,53) - rrt(171) * density(51) 
  pd(16,02) = pd(16,02) + rrt(172) * density(57) 
  pd(16,57) = pd(16,57) + rrt(172) * density(02) 
  pd(57,02) = pd(57,02) - rrt(172) * density(57) 
  pd(57,57) = pd(57,57) - rrt(172) * density(02) 
  pd(57,02) = pd(57,02) + rrt(173) * density(58) 
  pd(57,58) = pd(57,58) + rrt(173) * density(02) 
  pd(58,02) = pd(58,02) - rrt(173) * density(58) 
  pd(58,58) = pd(58,58) - rrt(173) * density(02) 
  pd(58,02) = pd(58,02) + rrt(174) * density(59) 
  pd(58,59) = pd(58,59) + rrt(174) * density(02) 
  pd(59,02) = pd(59,02) - rrt(174) * density(59) 
  pd(59,59) = pd(59,59) - rrt(174) * density(02) 
  pd(16,16) = pd(16,16) + rrt(175) * density(57) 
  pd(16,57) = pd(16,57) + rrt(175) * density(16) 
  pd(57,16) = pd(57,16) - rrt(175) * density(57) 
  pd(57,57) = pd(57,57) - rrt(175) * density(16) 
  pd(57,16) = pd(57,16) + rrt(176) * density(58) 
  pd(57,58) = pd(57,58) + rrt(176) * density(16) 
  pd(58,16) = pd(58,16) - rrt(176) * density(58) 
  pd(58,58) = pd(58,58) - rrt(176) * density(16) 
  pd(58,16) = pd(58,16) + rrt(177) * density(59) 
  pd(58,59) = pd(58,59) + rrt(177) * density(16) 
  pd(59,16) = pd(59,16) - rrt(177) * density(59) 
  pd(59,59) = pd(59,59) - rrt(177) * density(16) 
  pd(01,04) = pd(01,04) + rrt(178) * density(50) 
  pd(01,50) = pd(01,50) + rrt(178) * density(04) 
  pd(04,04) = pd(04,04) - rrt(178) * density(50) 
  pd(04,50) = pd(04,50) - rrt(178) * density(04) 
  pd(06,04) = pd(06,04) + rrt(178) * density(50) 
  pd(06,50) = pd(06,50) + rrt(178) * density(04) 
  pd(50,04) = pd(50,04) - rrt(178) * density(50) 
  pd(50,50) = pd(50,50) - rrt(178) * density(04) 
  pd(01,04) = pd(01,04) + rrt(179) * density(51) 
  pd(01,51) = pd(01,51) + rrt(179) * density(04) 
  pd(04,04) = pd(04,04) - rrt(179) * density(51) 
  pd(04,51) = pd(04,51) - rrt(179) * density(04) 
  pd(06,04) = pd(06,04) + rrt(179) * density(51) 
  pd(06,51) = pd(06,51) + rrt(179) * density(04) 
  pd(51,04) = pd(51,04) - rrt(179) * density(51) 
  pd(51,51) = pd(51,51) - rrt(179) * density(04) 
  pd(01,04) = pd(01,04) + rrt(180) * density(52) 
  pd(01,52) = pd(01,52) + rrt(180) * density(04) 
  pd(04,04) = pd(04,04) - rrt(180) * density(52) 
  pd(04,52) = pd(04,52) - rrt(180) * density(04) 
  pd(06,04) = pd(06,04) + rrt(180) * density(52) 
  pd(06,52) = pd(06,52) + rrt(180) * density(04) 
  pd(52,04) = pd(52,04) - rrt(180) * density(52) 
  pd(52,52) = pd(52,52) - rrt(180) * density(04) 
  pd(01,04) = pd(01,04) + rrt(181) * density(53) 
  pd(01,53) = pd(01,53) + rrt(181) * density(04) 
  pd(04,04) = pd(04,04) - rrt(181) * density(53) 
  pd(04,53) = pd(04,53) - rrt(181) * density(04) 
  pd(06,04) = pd(06,04) + rrt(181) * density(53) 
  pd(06,53) = pd(06,53) + rrt(181) * density(04) 
  pd(53,04) = pd(53,04) - rrt(181) * density(53) 
  pd(53,53) = pd(53,53) - rrt(181) * density(04) 
  pd(02,07) = pd(02,07) + rrt(182) * density(50) 
  pd(02,50) = pd(02,50) + rrt(182) * density(07) 
  pd(04,07) = pd(04,07) + rrt(182) * density(50) 
  pd(04,50) = pd(04,50) + rrt(182) * density(07) 
  pd(06,07) = pd(06,07) + rrt(182) * density(50) 
  pd(06,50) = pd(06,50) + rrt(182) * density(07) 
  pd(07,07) = pd(07,07) - rrt(182) * density(50) 
  pd(07,50) = pd(07,50) - rrt(182) * density(07) 
  pd(50,07) = pd(50,07) - rrt(182) * density(50) 
  pd(50,50) = pd(50,50) - rrt(182) * density(07) 
  pd(02,07) = pd(02,07) + rrt(183) * density(51) 
  pd(02,51) = pd(02,51) + rrt(183) * density(07) 
  pd(04,07) = pd(04,07) + rrt(183) * density(51) 
  pd(04,51) = pd(04,51) + rrt(183) * density(07) 
  pd(06,07) = pd(06,07) + rrt(183) * density(51) 
  pd(06,51) = pd(06,51) + rrt(183) * density(07) 
  pd(07,07) = pd(07,07) - rrt(183) * density(51) 
  pd(07,51) = pd(07,51) - rrt(183) * density(07) 
  pd(51,07) = pd(51,07) - rrt(183) * density(51) 
  pd(51,51) = pd(51,51) - rrt(183) * density(07) 
  pd(02,07) = pd(02,07) + rrt(184) * density(52) 
  pd(02,52) = pd(02,52) + rrt(184) * density(07) 
  pd(04,07) = pd(04,07) + rrt(184) * density(52) 
  pd(04,52) = pd(04,52) + rrt(184) * density(07) 
  pd(06,07) = pd(06,07) + rrt(184) * density(52) 
  pd(06,52) = pd(06,52) + rrt(184) * density(07) 
  pd(07,07) = pd(07,07) - rrt(184) * density(52) 
  pd(07,52) = pd(07,52) - rrt(184) * density(07) 
  pd(52,07) = pd(52,07) - rrt(184) * density(52) 
  pd(52,52) = pd(52,52) - rrt(184) * density(07) 
  pd(02,07) = pd(02,07) + rrt(185) * density(53) 
  pd(02,53) = pd(02,53) + rrt(185) * density(07) 
  pd(04,07) = pd(04,07) + rrt(185) * density(53) 
  pd(04,53) = pd(04,53) + rrt(185) * density(07) 
  pd(06,07) = pd(06,07) + rrt(185) * density(53) 
  pd(06,53) = pd(06,53) + rrt(185) * density(07) 
  pd(07,07) = pd(07,07) - rrt(185) * density(53) 
  pd(07,53) = pd(07,53) - rrt(185) * density(07) 
  pd(53,07) = pd(53,07) - rrt(185) * density(53) 
  pd(53,53) = pd(53,53) - rrt(185) * density(07) 
  pd(01,01) = pd(01,01) - rrt(186) * density(04) * density(50) 
  pd(01,04) = pd(01,04) - rrt(186) * density(01) * density(50) 
  pd(01,50) = pd(01,50) - rrt(186) * density(01) * density(04) 
  pd(02,01) = pd(02,01) + rrt(186) * density(04) * density(50) 
  pd(02,04) = pd(02,04) + rrt(186) * density(01) * density(50) 
  pd(02,50) = pd(02,50) + rrt(186) * density(01) * density(04) 
  pd(04,01) = pd(04,01) - rrt(186) * density(04) * density(50) 
  pd(04,04) = pd(04,04) - rrt(186) * density(01) * density(50) 
  pd(04,50) = pd(04,50) - rrt(186) * density(01) * density(04) 
  pd(50,01) = pd(50,01) - rrt(186) * density(04) * density(50) 
  pd(50,04) = pd(50,04) - rrt(186) * density(01) * density(50) 
  pd(50,50) = pd(50,50) - rrt(186) * density(01) * density(04) 
  pd(56,01) = pd(56,01) + rrt(186) * density(04) * density(50) 
  pd(56,04) = pd(56,04) + rrt(186) * density(01) * density(50) 
  pd(56,50) = pd(56,50) + rrt(186) * density(01) * density(04) 
  pd(01,01) = pd(01,01) - rrt(187) * density(04) * density(51) 
  pd(01,04) = pd(01,04) - rrt(187) * density(01) * density(51) 
  pd(01,51) = pd(01,51) - rrt(187) * density(01) * density(04) 
  pd(02,01) = pd(02,01) + rrt(187) * density(04) * density(51) 
  pd(02,04) = pd(02,04) + rrt(187) * density(01) * density(51) 
  pd(02,51) = pd(02,51) + rrt(187) * density(01) * density(04) 
  pd(04,01) = pd(04,01) - rrt(187) * density(04) * density(51) 
  pd(04,04) = pd(04,04) - rrt(187) * density(01) * density(51) 
  pd(04,51) = pd(04,51) - rrt(187) * density(01) * density(04) 
  pd(51,01) = pd(51,01) - rrt(187) * density(04) * density(51) 
  pd(51,04) = pd(51,04) - rrt(187) * density(01) * density(51) 
  pd(51,51) = pd(51,51) - rrt(187) * density(01) * density(04) 
  pd(56,01) = pd(56,01) + rrt(187) * density(04) * density(51) 
  pd(56,04) = pd(56,04) + rrt(187) * density(01) * density(51) 
  pd(56,51) = pd(56,51) + rrt(187) * density(01) * density(04) 
  pd(01,01) = pd(01,01) - rrt(188) * density(04) * density(52) 
  pd(01,04) = pd(01,04) - rrt(188) * density(01) * density(52) 
  pd(01,52) = pd(01,52) - rrt(188) * density(01) * density(04) 
  pd(02,01) = pd(02,01) + rrt(188) * density(04) * density(52) 
  pd(02,04) = pd(02,04) + rrt(188) * density(01) * density(52) 
  pd(02,52) = pd(02,52) + rrt(188) * density(01) * density(04) 
  pd(04,01) = pd(04,01) - rrt(188) * density(04) * density(52) 
  pd(04,04) = pd(04,04) - rrt(188) * density(01) * density(52) 
  pd(04,52) = pd(04,52) - rrt(188) * density(01) * density(04) 
  pd(52,01) = pd(52,01) - rrt(188) * density(04) * density(52) 
  pd(52,04) = pd(52,04) - rrt(188) * density(01) * density(52) 
  pd(52,52) = pd(52,52) - rrt(188) * density(01) * density(04) 
  pd(56,01) = pd(56,01) + rrt(188) * density(04) * density(52) 
  pd(56,04) = pd(56,04) + rrt(188) * density(01) * density(52) 
  pd(56,52) = pd(56,52) + rrt(188) * density(01) * density(04) 
  pd(01,01) = pd(01,01) - rrt(189) * density(04) * density(53) 
  pd(01,04) = pd(01,04) - rrt(189) * density(01) * density(53) 
  pd(01,53) = pd(01,53) - rrt(189) * density(01) * density(04) 
  pd(02,01) = pd(02,01) + rrt(189) * density(04) * density(53) 
  pd(02,04) = pd(02,04) + rrt(189) * density(01) * density(53) 
  pd(02,53) = pd(02,53) + rrt(189) * density(01) * density(04) 
  pd(04,01) = pd(04,01) - rrt(189) * density(04) * density(53) 
  pd(04,04) = pd(04,04) - rrt(189) * density(01) * density(53) 
  pd(04,53) = pd(04,53) - rrt(189) * density(01) * density(04) 
  pd(53,01) = pd(53,01) - rrt(189) * density(04) * density(53) 
  pd(53,04) = pd(53,04) - rrt(189) * density(01) * density(53) 
  pd(53,53) = pd(53,53) - rrt(189) * density(01) * density(04) 
  pd(56,01) = pd(56,01) + rrt(189) * density(04) * density(53) 
  pd(56,04) = pd(56,04) + rrt(189) * density(01) * density(53) 
  pd(56,53) = pd(56,53) + rrt(189) * density(01) * density(04) 
  pd(01,05) = pd(01,05) + rrt(190) * density(50) * 2.0d0
  pd(01,50) = pd(01,50) + rrt(190) * density(05) * 2.0d0
  pd(50,05) = pd(50,05) - rrt(190) * density(50) 
  pd(50,50) = pd(50,50) - rrt(190) * density(05) 
  pd(01,07) = pd(01,07) + rrt(191) * density(50) * 2.0d0
  pd(01,50) = pd(01,50) + rrt(191) * density(07) * 2.0d0
  pd(50,07) = pd(50,07) - rrt(191) * density(50) 
  pd(50,50) = pd(50,50) - rrt(191) * density(07) 
  pd(01,05) = pd(01,05) + rrt(192) * density(51) * 2.0d0
  pd(01,51) = pd(01,51) + rrt(192) * density(05) * 2.0d0
  pd(51,05) = pd(51,05) - rrt(192) * density(51) 
  pd(51,51) = pd(51,51) - rrt(192) * density(05) 
  pd(01,07) = pd(01,07) + rrt(193) * density(51) * 2.0d0
  pd(01,51) = pd(01,51) + rrt(193) * density(07) * 2.0d0
  pd(51,07) = pd(51,07) - rrt(193) * density(51) 
  pd(51,51) = pd(51,51) - rrt(193) * density(07) 
  pd(01,05) = pd(01,05) + rrt(194) * density(52) * 2.0d0
  pd(01,52) = pd(01,52) + rrt(194) * density(05) * 2.0d0
  pd(52,05) = pd(52,05) - rrt(194) * density(52) 
  pd(52,52) = pd(52,52) - rrt(194) * density(05) 
  pd(01,07) = pd(01,07) + rrt(195) * density(52) * 2.0d0
  pd(01,52) = pd(01,52) + rrt(195) * density(07) * 2.0d0
  pd(52,07) = pd(52,07) - rrt(195) * density(52) 
  pd(52,52) = pd(52,52) - rrt(195) * density(07) 
  pd(01,05) = pd(01,05) + rrt(196) * density(53) * 2.0d0
  pd(01,53) = pd(01,53) + rrt(196) * density(05) * 2.0d0
  pd(53,05) = pd(53,05) - rrt(196) * density(53) 
  pd(53,53) = pd(53,53) - rrt(196) * density(05) 
  pd(01,07) = pd(01,07) + rrt(197) * density(53) * 2.0d0
  pd(01,53) = pd(01,53) + rrt(197) * density(07) * 2.0d0
  pd(53,07) = pd(53,07) - rrt(197) * density(53) 
  pd(53,53) = pd(53,53) - rrt(197) * density(07) 
  pd(02,04) = pd(02,04) + rrt(198) * density(06) * density(50) 
  pd(02,06) = pd(02,06) + rrt(198) * density(04) * density(50) 
  pd(02,50) = pd(02,50) + rrt(198) * density(04) * density(06) 
  pd(04,04) = pd(04,04) - rrt(198) * density(06) * density(50) 
  pd(04,06) = pd(04,06) - rrt(198) * density(04) * density(50) 
  pd(04,50) = pd(04,50) - rrt(198) * density(04) * density(06) 
  pd(06,04) = pd(06,04) - rrt(198) * density(06) * density(50) 
  pd(06,06) = pd(06,06) - rrt(198) * density(04) * density(50) 
  pd(06,50) = pd(06,50) - rrt(198) * density(04) * density(06) 
  pd(07,04) = pd(07,04) + rrt(198) * density(06) * density(50) 
  pd(07,06) = pd(07,06) + rrt(198) * density(04) * density(50) 
  pd(07,50) = pd(07,50) + rrt(198) * density(04) * density(06) 
  pd(50,04) = pd(50,04) - rrt(198) * density(06) * density(50) 
  pd(50,06) = pd(50,06) - rrt(198) * density(04) * density(50) 
  pd(50,50) = pd(50,50) - rrt(198) * density(04) * density(06) 
  pd(02,04) = pd(02,04) + rrt(199) * density(06) * density(51) 
  pd(02,06) = pd(02,06) + rrt(199) * density(04) * density(51) 
  pd(02,51) = pd(02,51) + rrt(199) * density(04) * density(06) 
  pd(04,04) = pd(04,04) - rrt(199) * density(06) * density(51) 
  pd(04,06) = pd(04,06) - rrt(199) * density(04) * density(51) 
  pd(04,51) = pd(04,51) - rrt(199) * density(04) * density(06) 
  pd(06,04) = pd(06,04) - rrt(199) * density(06) * density(51) 
  pd(06,06) = pd(06,06) - rrt(199) * density(04) * density(51) 
  pd(06,51) = pd(06,51) - rrt(199) * density(04) * density(06) 
  pd(07,04) = pd(07,04) + rrt(199) * density(06) * density(51) 
  pd(07,06) = pd(07,06) + rrt(199) * density(04) * density(51) 
  pd(07,51) = pd(07,51) + rrt(199) * density(04) * density(06) 
  pd(51,04) = pd(51,04) - rrt(199) * density(06) * density(51) 
  pd(51,06) = pd(51,06) - rrt(199) * density(04) * density(51) 
  pd(51,51) = pd(51,51) - rrt(199) * density(04) * density(06) 
  pd(02,04) = pd(02,04) + rrt(200) * density(06) * density(52) 
  pd(02,06) = pd(02,06) + rrt(200) * density(04) * density(52) 
  pd(02,52) = pd(02,52) + rrt(200) * density(04) * density(06) 
  pd(04,04) = pd(04,04) - rrt(200) * density(06) * density(52) 
  pd(04,06) = pd(04,06) - rrt(200) * density(04) * density(52) 
  pd(04,52) = pd(04,52) - rrt(200) * density(04) * density(06) 
  pd(06,04) = pd(06,04) - rrt(200) * density(06) * density(52) 
  pd(06,06) = pd(06,06) - rrt(200) * density(04) * density(52) 
  pd(06,52) = pd(06,52) - rrt(200) * density(04) * density(06) 
  pd(07,04) = pd(07,04) + rrt(200) * density(06) * density(52) 
  pd(07,06) = pd(07,06) + rrt(200) * density(04) * density(52) 
  pd(07,52) = pd(07,52) + rrt(200) * density(04) * density(06) 
  pd(52,04) = pd(52,04) - rrt(200) * density(06) * density(52) 
  pd(52,06) = pd(52,06) - rrt(200) * density(04) * density(52) 
  pd(52,52) = pd(52,52) - rrt(200) * density(04) * density(06) 
  pd(02,04) = pd(02,04) + rrt(201) * density(06) * density(53) 
  pd(02,06) = pd(02,06) + rrt(201) * density(04) * density(53) 
  pd(02,53) = pd(02,53) + rrt(201) * density(04) * density(06) 
  pd(04,04) = pd(04,04) - rrt(201) * density(06) * density(53) 
  pd(04,06) = pd(04,06) - rrt(201) * density(04) * density(53) 
  pd(04,53) = pd(04,53) - rrt(201) * density(04) * density(06) 
  pd(06,04) = pd(06,04) - rrt(201) * density(06) * density(53) 
  pd(06,06) = pd(06,06) - rrt(201) * density(04) * density(53) 
  pd(06,53) = pd(06,53) - rrt(201) * density(04) * density(06) 
  pd(07,04) = pd(07,04) + rrt(201) * density(06) * density(53) 
  pd(07,06) = pd(07,06) + rrt(201) * density(04) * density(53) 
  pd(07,53) = pd(07,53) + rrt(201) * density(04) * density(06) 
  pd(53,04) = pd(53,04) - rrt(201) * density(06) * density(53) 
  pd(53,06) = pd(53,06) - rrt(201) * density(04) * density(53) 
  pd(53,53) = pd(53,53) - rrt(201) * density(04) * density(06) 
  pd(04,05) = pd(04,05) + rrt(202) * density(50) 
  pd(04,50) = pd(04,50) + rrt(202) * density(05) 
  pd(05,05) = pd(05,05) - rrt(202) * density(50) 
  pd(05,50) = pd(05,50) - rrt(202) * density(05) 
  pd(08,05) = pd(08,05) + rrt(202) * density(50) 
  pd(08,50) = pd(08,50) + rrt(202) * density(05) 
  pd(50,05) = pd(50,05) - rrt(202) * density(50) 
  pd(50,50) = pd(50,50) - rrt(202) * density(05) 
  pd(04,05) = pd(04,05) + rrt(203) * density(51) 
  pd(04,51) = pd(04,51) + rrt(203) * density(05) 
  pd(05,05) = pd(05,05) - rrt(203) * density(51) 
  pd(05,51) = pd(05,51) - rrt(203) * density(05) 
  pd(08,05) = pd(08,05) + rrt(203) * density(51) 
  pd(08,51) = pd(08,51) + rrt(203) * density(05) 
  pd(51,05) = pd(51,05) - rrt(203) * density(51) 
  pd(51,51) = pd(51,51) - rrt(203) * density(05) 
  pd(04,05) = pd(04,05) + rrt(204) * density(52) 
  pd(04,52) = pd(04,52) + rrt(204) * density(05) 
  pd(05,05) = pd(05,05) - rrt(204) * density(52) 
  pd(05,52) = pd(05,52) - rrt(204) * density(05) 
  pd(08,05) = pd(08,05) + rrt(204) * density(52) 
  pd(08,52) = pd(08,52) + rrt(204) * density(05) 
  pd(52,05) = pd(52,05) - rrt(204) * density(52) 
  pd(52,52) = pd(52,52) - rrt(204) * density(05) 
  pd(04,05) = pd(04,05) + rrt(205) * density(53) 
  pd(04,53) = pd(04,53) + rrt(205) * density(05) 
  pd(05,05) = pd(05,05) - rrt(205) * density(53) 
  pd(05,53) = pd(05,53) - rrt(205) * density(05) 
  pd(08,05) = pd(08,05) + rrt(205) * density(53) 
  pd(08,53) = pd(08,53) + rrt(205) * density(05) 
  pd(53,05) = pd(53,05) - rrt(205) * density(53) 
  pd(53,53) = pd(53,53) - rrt(205) * density(05) 
  pd(01,06) = pd(01,06) + rrt(206) * density(50) 
  pd(01,50) = pd(01,50) + rrt(206) * density(06) 
  pd(06,06) = pd(06,06) - rrt(206) * density(50) 
  pd(06,50) = pd(06,50) - rrt(206) * density(06) 
  pd(08,06) = pd(08,06) + rrt(206) * density(50) 
  pd(08,50) = pd(08,50) + rrt(206) * density(06) 
  pd(50,06) = pd(50,06) - rrt(206) * density(50) 
  pd(50,50) = pd(50,50) - rrt(206) * density(06) 
  pd(01,06) = pd(01,06) + rrt(207) * density(51) 
  pd(01,51) = pd(01,51) + rrt(207) * density(06) 
  pd(06,06) = pd(06,06) - rrt(207) * density(51) 
  pd(06,51) = pd(06,51) - rrt(207) * density(06) 
  pd(08,06) = pd(08,06) + rrt(207) * density(51) 
  pd(08,51) = pd(08,51) + rrt(207) * density(06) 
  pd(51,06) = pd(51,06) - rrt(207) * density(51) 
  pd(51,51) = pd(51,51) - rrt(207) * density(06) 
  pd(01,06) = pd(01,06) + rrt(208) * density(52) 
  pd(01,52) = pd(01,52) + rrt(208) * density(06) 
  pd(06,06) = pd(06,06) - rrt(208) * density(52) 
  pd(06,52) = pd(06,52) - rrt(208) * density(06) 
  pd(08,06) = pd(08,06) + rrt(208) * density(52) 
  pd(08,52) = pd(08,52) + rrt(208) * density(06) 
  pd(52,06) = pd(52,06) - rrt(208) * density(52) 
  pd(52,52) = pd(52,52) - rrt(208) * density(06) 
  pd(01,06) = pd(01,06) + rrt(209) * density(53) 
  pd(01,53) = pd(01,53) + rrt(209) * density(06) 
  pd(06,06) = pd(06,06) - rrt(209) * density(53) 
  pd(06,53) = pd(06,53) - rrt(209) * density(06) 
  pd(08,06) = pd(08,06) + rrt(209) * density(53) 
  pd(08,53) = pd(08,53) + rrt(209) * density(06) 
  pd(53,06) = pd(53,06) - rrt(209) * density(53) 
  pd(53,53) = pd(53,53) - rrt(209) * density(06) 
  pd(06,07) = pd(06,07) + rrt(210) * density(50) 
  pd(06,50) = pd(06,50) + rrt(210) * density(07) 
  pd(07,07) = pd(07,07) - rrt(210) * density(50) 
  pd(07,50) = pd(07,50) - rrt(210) * density(07) 
  pd(08,07) = pd(08,07) + rrt(210) * density(50) 
  pd(08,50) = pd(08,50) + rrt(210) * density(07) 
  pd(50,07) = pd(50,07) - rrt(210) * density(50) 
  pd(50,50) = pd(50,50) - rrt(210) * density(07) 
  pd(06,07) = pd(06,07) + rrt(211) * density(51) 
  pd(06,51) = pd(06,51) + rrt(211) * density(07) 
  pd(07,07) = pd(07,07) - rrt(211) * density(51) 
  pd(07,51) = pd(07,51) - rrt(211) * density(07) 
  pd(08,07) = pd(08,07) + rrt(211) * density(51) 
  pd(08,51) = pd(08,51) + rrt(211) * density(07) 
  pd(51,07) = pd(51,07) - rrt(211) * density(51) 
  pd(51,51) = pd(51,51) - rrt(211) * density(07) 
  pd(06,07) = pd(06,07) + rrt(212) * density(52) 
  pd(06,52) = pd(06,52) + rrt(212) * density(07) 
  pd(07,07) = pd(07,07) - rrt(212) * density(52) 
  pd(07,52) = pd(07,52) - rrt(212) * density(07) 
  pd(08,07) = pd(08,07) + rrt(212) * density(52) 
  pd(08,52) = pd(08,52) + rrt(212) * density(07) 
  pd(52,07) = pd(52,07) - rrt(212) * density(52) 
  pd(52,52) = pd(52,52) - rrt(212) * density(07) 
  pd(06,07) = pd(06,07) + rrt(213) * density(53) 
  pd(06,53) = pd(06,53) + rrt(213) * density(07) 
  pd(07,07) = pd(07,07) - rrt(213) * density(53) 
  pd(07,53) = pd(07,53) - rrt(213) * density(07) 
  pd(08,07) = pd(08,07) + rrt(213) * density(53) 
  pd(08,53) = pd(08,53) + rrt(213) * density(07) 
  pd(53,07) = pd(53,07) - rrt(213) * density(53) 
  pd(53,53) = pd(53,53) - rrt(213) * density(07) 
  pd(08,09) = pd(08,09) + rrt(214) * density(50) * 2.0d0
  pd(08,50) = pd(08,50) + rrt(214) * density(09) * 2.0d0
  pd(09,09) = pd(09,09) - rrt(214) * density(50) 
  pd(09,50) = pd(09,50) - rrt(214) * density(09) 
  pd(50,09) = pd(50,09) - rrt(214) * density(50) 
  pd(50,50) = pd(50,50) - rrt(214) * density(09) 
  pd(08,09) = pd(08,09) + rrt(215) * density(51) * 2.0d0
  pd(08,51) = pd(08,51) + rrt(215) * density(09) * 2.0d0
  pd(09,09) = pd(09,09) - rrt(215) * density(51) 
  pd(09,51) = pd(09,51) - rrt(215) * density(09) 
  pd(51,09) = pd(51,09) - rrt(215) * density(51) 
  pd(51,51) = pd(51,51) - rrt(215) * density(09) 
  pd(08,09) = pd(08,09) + rrt(216) * density(52) * 2.0d0
  pd(08,52) = pd(08,52) + rrt(216) * density(09) * 2.0d0
  pd(09,09) = pd(09,09) - rrt(216) * density(52) 
  pd(09,52) = pd(09,52) - rrt(216) * density(09) 
  pd(52,09) = pd(52,09) - rrt(216) * density(52) 
  pd(52,52) = pd(52,52) - rrt(216) * density(09) 
  pd(08,09) = pd(08,09) + rrt(217) * density(53) * 2.0d0
  pd(08,53) = pd(08,53) + rrt(217) * density(09) * 2.0d0
  pd(09,09) = pd(09,09) - rrt(217) * density(53) 
  pd(09,53) = pd(09,53) - rrt(217) * density(09) 
  pd(53,09) = pd(53,09) - rrt(217) * density(53) 
  pd(53,53) = pd(53,53) - rrt(217) * density(09) 
  pd(01,50) = pd(01,50) + rrt(218) * density(56) 
  pd(01,56) = pd(01,56) + rrt(218) * density(50) 
  pd(02,50) = pd(02,50) + rrt(218) * density(56) 
  pd(02,56) = pd(02,56) + rrt(218) * density(50) 
  pd(04,50) = pd(04,50) + rrt(218) * density(56) 
  pd(04,56) = pd(04,56) + rrt(218) * density(50) 
  pd(50,50) = pd(50,50) - rrt(218) * density(56) 
  pd(50,56) = pd(50,56) - rrt(218) * density(50) 
  pd(56,50) = pd(56,50) - rrt(218) * density(56) 
  pd(56,56) = pd(56,56) - rrt(218) * density(50) 
  pd(01,51) = pd(01,51) + rrt(219) * density(56) 
  pd(01,56) = pd(01,56) + rrt(219) * density(51) 
  pd(02,51) = pd(02,51) + rrt(219) * density(56) 
  pd(02,56) = pd(02,56) + rrt(219) * density(51) 
  pd(04,51) = pd(04,51) + rrt(219) * density(56) 
  pd(04,56) = pd(04,56) + rrt(219) * density(51) 
  pd(51,51) = pd(51,51) - rrt(219) * density(56) 
  pd(51,56) = pd(51,56) - rrt(219) * density(51) 
  pd(56,51) = pd(56,51) - rrt(219) * density(56) 
  pd(56,56) = pd(56,56) - rrt(219) * density(51) 
  pd(01,52) = pd(01,52) + rrt(220) * density(56) 
  pd(01,56) = pd(01,56) + rrt(220) * density(52) 
  pd(02,52) = pd(02,52) + rrt(220) * density(56) 
  pd(02,56) = pd(02,56) + rrt(220) * density(52) 
  pd(04,52) = pd(04,52) + rrt(220) * density(56) 
  pd(04,56) = pd(04,56) + rrt(220) * density(52) 
  pd(52,52) = pd(52,52) - rrt(220) * density(56) 
  pd(52,56) = pd(52,56) - rrt(220) * density(52) 
  pd(56,52) = pd(56,52) - rrt(220) * density(56) 
  pd(56,56) = pd(56,56) - rrt(220) * density(52) 
  pd(01,53) = pd(01,53) + rrt(221) * density(56) 
  pd(01,56) = pd(01,56) + rrt(221) * density(53) 
  pd(02,53) = pd(02,53) + rrt(221) * density(56) 
  pd(02,56) = pd(02,56) + rrt(221) * density(53) 
  pd(04,53) = pd(04,53) + rrt(221) * density(56) 
  pd(04,56) = pd(04,56) + rrt(221) * density(53) 
  pd(53,53) = pd(53,53) - rrt(221) * density(56) 
  pd(53,56) = pd(53,56) - rrt(221) * density(53) 
  pd(56,53) = pd(56,53) - rrt(221) * density(56) 
  pd(56,56) = pd(56,56) - rrt(221) * density(53) 
  pd(02,06) = pd(02,06) + rrt(222) * density(50) 
  pd(02,50) = pd(02,50) + rrt(222) * density(06) 
  pd(06,06) = pd(06,06) - rrt(222) * density(50) 
  pd(06,50) = pd(06,50) - rrt(222) * density(06) 
  pd(50,06) = pd(50,06) - rrt(222) * density(50) 
  pd(50,50) = pd(50,50) - rrt(222) * density(06) 
  pd(56,06) = pd(56,06) + rrt(222) * density(50) 
  pd(56,50) = pd(56,50) + rrt(222) * density(06) 
  pd(02,06) = pd(02,06) + rrt(223) * density(51) 
  pd(02,51) = pd(02,51) + rrt(223) * density(06) 
  pd(06,06) = pd(06,06) - rrt(223) * density(51) 
  pd(06,51) = pd(06,51) - rrt(223) * density(06) 
  pd(51,06) = pd(51,06) - rrt(223) * density(51) 
  pd(51,51) = pd(51,51) - rrt(223) * density(06) 
  pd(56,06) = pd(56,06) + rrt(223) * density(51) 
  pd(56,51) = pd(56,51) + rrt(223) * density(06) 
  pd(02,06) = pd(02,06) + rrt(224) * density(52) 
  pd(02,52) = pd(02,52) + rrt(224) * density(06) 
  pd(06,06) = pd(06,06) - rrt(224) * density(52) 
  pd(06,52) = pd(06,52) - rrt(224) * density(06) 
  pd(52,06) = pd(52,06) - rrt(224) * density(52) 
  pd(52,52) = pd(52,52) - rrt(224) * density(06) 
  pd(56,06) = pd(56,06) + rrt(224) * density(52) 
  pd(56,52) = pd(56,52) + rrt(224) * density(06) 
  pd(02,06) = pd(02,06) + rrt(225) * density(53) 
  pd(02,53) = pd(02,53) + rrt(225) * density(06) 
  pd(06,06) = pd(06,06) - rrt(225) * density(53) 
  pd(06,53) = pd(06,53) - rrt(225) * density(06) 
  pd(53,06) = pd(53,06) - rrt(225) * density(53) 
  pd(53,53) = pd(53,53) - rrt(225) * density(06) 
  pd(56,06) = pd(56,06) + rrt(225) * density(53) 
  pd(56,53) = pd(56,53) + rrt(225) * density(06) 
  pd(01,12) = pd(01,12) + rrt(226) * density(50) 
  pd(01,50) = pd(01,50) + rrt(226) * density(12) 
  pd(12,12) = pd(12,12) - rrt(226) * density(50) 
  pd(12,50) = pd(12,50) - rrt(226) * density(12) 
  pd(13,12) = pd(13,12) + rrt(226) * density(50) 
  pd(13,50) = pd(13,50) + rrt(226) * density(12) 
  pd(50,12) = pd(50,12) - rrt(226) * density(50) 
  pd(50,50) = pd(50,50) - rrt(226) * density(12) 
  pd(01,12) = pd(01,12) + rrt(227) * density(51) 
  pd(01,51) = pd(01,51) + rrt(227) * density(12) 
  pd(12,12) = pd(12,12) - rrt(227) * density(51) 
  pd(12,51) = pd(12,51) - rrt(227) * density(12) 
  pd(13,12) = pd(13,12) + rrt(227) * density(51) 
  pd(13,51) = pd(13,51) + rrt(227) * density(12) 
  pd(51,12) = pd(51,12) - rrt(227) * density(51) 
  pd(51,51) = pd(51,51) - rrt(227) * density(12) 
  pd(01,12) = pd(01,12) + rrt(228) * density(52) 
  pd(01,52) = pd(01,52) + rrt(228) * density(12) 
  pd(12,12) = pd(12,12) - rrt(228) * density(52) 
  pd(12,52) = pd(12,52) - rrt(228) * density(12) 
  pd(13,12) = pd(13,12) + rrt(228) * density(52) 
  pd(13,52) = pd(13,52) + rrt(228) * density(12) 
  pd(52,12) = pd(52,12) - rrt(228) * density(52) 
  pd(52,52) = pd(52,52) - rrt(228) * density(12) 
  pd(01,12) = pd(01,12) + rrt(229) * density(53) 
  pd(01,53) = pd(01,53) + rrt(229) * density(12) 
  pd(12,12) = pd(12,12) - rrt(229) * density(53) 
  pd(12,53) = pd(12,53) - rrt(229) * density(12) 
  pd(13,12) = pd(13,12) + rrt(229) * density(53) 
  pd(13,53) = pd(13,53) + rrt(229) * density(12) 
  pd(53,12) = pd(53,12) - rrt(229) * density(53) 
  pd(53,53) = pd(53,53) - rrt(229) * density(12) 
  pd(01,11) = pd(01,11) + rrt(230) * density(50) 
  pd(01,50) = pd(01,50) + rrt(230) * density(11) 
  pd(11,11) = pd(11,11) - rrt(230) * density(50) 
  pd(11,50) = pd(11,50) - rrt(230) * density(11) 
  pd(14,11) = pd(14,11) + rrt(230) * density(50) 
  pd(14,50) = pd(14,50) + rrt(230) * density(11) 
  pd(50,11) = pd(50,11) - rrt(230) * density(50) 
  pd(50,50) = pd(50,50) - rrt(230) * density(11) 
  pd(01,11) = pd(01,11) + rrt(231) * density(51) 
  pd(01,51) = pd(01,51) + rrt(231) * density(11) 
  pd(11,11) = pd(11,11) - rrt(231) * density(51) 
  pd(11,51) = pd(11,51) - rrt(231) * density(11) 
  pd(14,11) = pd(14,11) + rrt(231) * density(51) 
  pd(14,51) = pd(14,51) + rrt(231) * density(11) 
  pd(51,11) = pd(51,11) - rrt(231) * density(51) 
  pd(51,51) = pd(51,51) - rrt(231) * density(11) 
  pd(01,11) = pd(01,11) + rrt(232) * density(52) 
  pd(01,52) = pd(01,52) + rrt(232) * density(11) 
  pd(11,11) = pd(11,11) - rrt(232) * density(52) 
  pd(11,52) = pd(11,52) - rrt(232) * density(11) 
  pd(14,11) = pd(14,11) + rrt(232) * density(52) 
  pd(14,52) = pd(14,52) + rrt(232) * density(11) 
  pd(52,11) = pd(52,11) - rrt(232) * density(52) 
  pd(52,52) = pd(52,52) - rrt(232) * density(11) 
  pd(01,11) = pd(01,11) + rrt(233) * density(53) 
  pd(01,53) = pd(01,53) + rrt(233) * density(11) 
  pd(11,11) = pd(11,11) - rrt(233) * density(53) 
  pd(11,53) = pd(11,53) - rrt(233) * density(11) 
  pd(14,11) = pd(14,11) + rrt(233) * density(53) 
  pd(14,53) = pd(14,53) + rrt(233) * density(11) 
  pd(53,11) = pd(53,11) - rrt(233) * density(53) 
  pd(53,53) = pd(53,53) - rrt(233) * density(11) 
  pd(01,17) = pd(01,17) + rrt(234) * density(50) 
  pd(01,50) = pd(01,50) + rrt(234) * density(17) 
  pd(17,17) = pd(17,17) - rrt(234) * density(50) 
  pd(17,50) = pd(17,50) - rrt(234) * density(17) 
  pd(24,17) = pd(24,17) + rrt(234) * density(50) 
  pd(24,50) = pd(24,50) + rrt(234) * density(17) 
  pd(50,17) = pd(50,17) - rrt(234) * density(50) 
  pd(50,50) = pd(50,50) - rrt(234) * density(17) 
  pd(01,17) = pd(01,17) + rrt(235) * density(51) 
  pd(01,51) = pd(01,51) + rrt(235) * density(17) 
  pd(17,17) = pd(17,17) - rrt(235) * density(51) 
  pd(17,51) = pd(17,51) - rrt(235) * density(17) 
  pd(24,17) = pd(24,17) + rrt(235) * density(51) 
  pd(24,51) = pd(24,51) + rrt(235) * density(17) 
  pd(51,17) = pd(51,17) - rrt(235) * density(51) 
  pd(51,51) = pd(51,51) - rrt(235) * density(17) 
  pd(01,17) = pd(01,17) + rrt(236) * density(52) 
  pd(01,52) = pd(01,52) + rrt(236) * density(17) 
  pd(17,17) = pd(17,17) - rrt(236) * density(52) 
  pd(17,52) = pd(17,52) - rrt(236) * density(17) 
  pd(24,17) = pd(24,17) + rrt(236) * density(52) 
  pd(24,52) = pd(24,52) + rrt(236) * density(17) 
  pd(52,17) = pd(52,17) - rrt(236) * density(52) 
  pd(52,52) = pd(52,52) - rrt(236) * density(17) 
  pd(01,17) = pd(01,17) + rrt(237) * density(53) 
  pd(01,53) = pd(01,53) + rrt(237) * density(17) 
  pd(17,17) = pd(17,17) - rrt(237) * density(53) 
  pd(17,53) = pd(17,53) - rrt(237) * density(17) 
  pd(24,17) = pd(24,17) + rrt(237) * density(53) 
  pd(24,53) = pd(24,53) + rrt(237) * density(17) 
  pd(53,17) = pd(53,17) - rrt(237) * density(53) 
  pd(53,53) = pd(53,53) - rrt(237) * density(17) 
  pd(06,17) = pd(06,17) + rrt(238) * density(50) 
  pd(06,50) = pd(06,50) + rrt(238) * density(17) 
  pd(17,17) = pd(17,17) - rrt(238) * density(50) 
  pd(17,50) = pd(17,50) - rrt(238) * density(17) 
  pd(26,17) = pd(26,17) + rrt(238) * density(50) 
  pd(26,50) = pd(26,50) + rrt(238) * density(17) 
  pd(50,17) = pd(50,17) - rrt(238) * density(50) 
  pd(50,50) = pd(50,50) - rrt(238) * density(17) 
  pd(06,17) = pd(06,17) + rrt(239) * density(51) 
  pd(06,51) = pd(06,51) + rrt(239) * density(17) 
  pd(17,17) = pd(17,17) - rrt(239) * density(51) 
  pd(17,51) = pd(17,51) - rrt(239) * density(17) 
  pd(26,17) = pd(26,17) + rrt(239) * density(51) 
  pd(26,51) = pd(26,51) + rrt(239) * density(17) 
  pd(51,17) = pd(51,17) - rrt(239) * density(51) 
  pd(51,51) = pd(51,51) - rrt(239) * density(17) 
  pd(06,17) = pd(06,17) + rrt(240) * density(52) 
  pd(06,52) = pd(06,52) + rrt(240) * density(17) 
  pd(17,17) = pd(17,17) - rrt(240) * density(52) 
  pd(17,52) = pd(17,52) - rrt(240) * density(17) 
  pd(26,17) = pd(26,17) + rrt(240) * density(52) 
  pd(26,52) = pd(26,52) + rrt(240) * density(17) 
  pd(52,17) = pd(52,17) - rrt(240) * density(52) 
  pd(52,52) = pd(52,52) - rrt(240) * density(17) 
  pd(06,17) = pd(06,17) + rrt(241) * density(53) 
  pd(06,53) = pd(06,53) + rrt(241) * density(17) 
  pd(17,17) = pd(17,17) - rrt(241) * density(53) 
  pd(17,53) = pd(17,53) - rrt(241) * density(17) 
  pd(26,17) = pd(26,17) + rrt(241) * density(53) 
  pd(26,53) = pd(26,53) + rrt(241) * density(17) 
  pd(53,17) = pd(53,17) - rrt(241) * density(53) 
  pd(53,53) = pd(53,53) - rrt(241) * density(17) 
  pd(01,18) = pd(01,18) + rrt(242) * density(50) 
  pd(01,50) = pd(01,50) + rrt(242) * density(18) 
  pd(18,18) = pd(18,18) - rrt(242) * density(50) 
  pd(18,50) = pd(18,50) - rrt(242) * density(18) 
  pd(26,18) = pd(26,18) + rrt(242) * density(50) 
  pd(26,50) = pd(26,50) + rrt(242) * density(18) 
  pd(50,18) = pd(50,18) - rrt(242) * density(50) 
  pd(50,50) = pd(50,50) - rrt(242) * density(18) 
  pd(01,18) = pd(01,18) + rrt(243) * density(51) 
  pd(01,51) = pd(01,51) + rrt(243) * density(18) 
  pd(18,18) = pd(18,18) - rrt(243) * density(51) 
  pd(18,51) = pd(18,51) - rrt(243) * density(18) 
  pd(26,18) = pd(26,18) + rrt(243) * density(51) 
  pd(26,51) = pd(26,51) + rrt(243) * density(18) 
  pd(51,18) = pd(51,18) - rrt(243) * density(51) 
  pd(51,51) = pd(51,51) - rrt(243) * density(18) 
  pd(01,18) = pd(01,18) + rrt(244) * density(52) 
  pd(01,52) = pd(01,52) + rrt(244) * density(18) 
  pd(18,18) = pd(18,18) - rrt(244) * density(52) 
  pd(18,52) = pd(18,52) - rrt(244) * density(18) 
  pd(26,18) = pd(26,18) + rrt(244) * density(52) 
  pd(26,52) = pd(26,52) + rrt(244) * density(18) 
  pd(52,18) = pd(52,18) - rrt(244) * density(52) 
  pd(52,52) = pd(52,52) - rrt(244) * density(18) 
  pd(01,18) = pd(01,18) + rrt(245) * density(53) 
  pd(01,53) = pd(01,53) + rrt(245) * density(18) 
  pd(18,18) = pd(18,18) - rrt(245) * density(53) 
  pd(18,53) = pd(18,53) - rrt(245) * density(18) 
  pd(26,18) = pd(26,18) + rrt(245) * density(53) 
  pd(26,53) = pd(26,53) + rrt(245) * density(18) 
  pd(53,18) = pd(53,18) - rrt(245) * density(53) 
  pd(53,53) = pd(53,53) - rrt(245) * density(18) 
  pd(06,18) = pd(06,18) + rrt(246) * density(50) 
  pd(06,50) = pd(06,50) + rrt(246) * density(18) 
  pd(12,18) = pd(12,18) + rrt(246) * density(50) 
  pd(12,50) = pd(12,50) + rrt(246) * density(18) 
  pd(18,18) = pd(18,18) - rrt(246) * density(50) 
  pd(18,50) = pd(18,50) - rrt(246) * density(18) 
  pd(50,18) = pd(50,18) - rrt(246) * density(50) 
  pd(50,50) = pd(50,50) - rrt(246) * density(18) 
  pd(06,18) = pd(06,18) + rrt(247) * density(51) 
  pd(06,51) = pd(06,51) + rrt(247) * density(18) 
  pd(12,18) = pd(12,18) + rrt(247) * density(51) 
  pd(12,51) = pd(12,51) + rrt(247) * density(18) 
  pd(18,18) = pd(18,18) - rrt(247) * density(51) 
  pd(18,51) = pd(18,51) - rrt(247) * density(18) 
  pd(51,18) = pd(51,18) - rrt(247) * density(51) 
  pd(51,51) = pd(51,51) - rrt(247) * density(18) 
  pd(06,18) = pd(06,18) + rrt(248) * density(52) 
  pd(06,52) = pd(06,52) + rrt(248) * density(18) 
  pd(12,18) = pd(12,18) + rrt(248) * density(52) 
  pd(12,52) = pd(12,52) + rrt(248) * density(18) 
  pd(18,18) = pd(18,18) - rrt(248) * density(52) 
  pd(18,52) = pd(18,52) - rrt(248) * density(18) 
  pd(52,18) = pd(52,18) - rrt(248) * density(52) 
  pd(52,52) = pd(52,52) - rrt(248) * density(18) 
  pd(06,18) = pd(06,18) + rrt(249) * density(53) 
  pd(06,53) = pd(06,53) + rrt(249) * density(18) 
  pd(12,18) = pd(12,18) + rrt(249) * density(53) 
  pd(12,53) = pd(12,53) + rrt(249) * density(18) 
  pd(18,18) = pd(18,18) - rrt(249) * density(53) 
  pd(18,53) = pd(18,53) - rrt(249) * density(18) 
  pd(53,18) = pd(53,18) - rrt(249) * density(53) 
  pd(53,53) = pd(53,53) - rrt(249) * density(18) 
  pd(08,24) = pd(08,24) + rrt(250) * density(50) 
  pd(08,50) = pd(08,50) + rrt(250) * density(24) 
  pd(24,24) = pd(24,24) - rrt(250) * density(50) 
  pd(24,50) = pd(24,50) - rrt(250) * density(24) 
  pd(26,24) = pd(26,24) + rrt(250) * density(50) 
  pd(26,50) = pd(26,50) + rrt(250) * density(24) 
  pd(50,24) = pd(50,24) - rrt(250) * density(50) 
  pd(50,50) = pd(50,50) - rrt(250) * density(24) 
  pd(08,24) = pd(08,24) + rrt(251) * density(51) 
  pd(08,51) = pd(08,51) + rrt(251) * density(24) 
  pd(24,24) = pd(24,24) - rrt(251) * density(51) 
  pd(24,51) = pd(24,51) - rrt(251) * density(24) 
  pd(26,24) = pd(26,24) + rrt(251) * density(51) 
  pd(26,51) = pd(26,51) + rrt(251) * density(24) 
  pd(51,24) = pd(51,24) - rrt(251) * density(51) 
  pd(51,51) = pd(51,51) - rrt(251) * density(24) 
  pd(08,24) = pd(08,24) + rrt(252) * density(52) 
  pd(08,52) = pd(08,52) + rrt(252) * density(24) 
  pd(24,24) = pd(24,24) - rrt(252) * density(52) 
  pd(24,52) = pd(24,52) - rrt(252) * density(24) 
  pd(26,24) = pd(26,24) + rrt(252) * density(52) 
  pd(26,52) = pd(26,52) + rrt(252) * density(24) 
  pd(52,24) = pd(52,24) - rrt(252) * density(52) 
  pd(52,52) = pd(52,52) - rrt(252) * density(24) 
  pd(08,24) = pd(08,24) + rrt(253) * density(53) 
  pd(08,53) = pd(08,53) + rrt(253) * density(24) 
  pd(24,24) = pd(24,24) - rrt(253) * density(53) 
  pd(24,53) = pd(24,53) - rrt(253) * density(24) 
  pd(26,24) = pd(26,24) + rrt(253) * density(53) 
  pd(26,53) = pd(26,53) + rrt(253) * density(24) 
  pd(53,24) = pd(53,24) - rrt(253) * density(53) 
  pd(53,53) = pd(53,53) - rrt(253) * density(24) 
  pd(08,28) = pd(08,28) + rrt(254) * density(50) 
  pd(08,50) = pd(08,50) + rrt(254) * density(28) 
  pd(26,28) = pd(26,28) + rrt(254) * density(50) 
  pd(26,50) = pd(26,50) + rrt(254) * density(28) 
  pd(28,28) = pd(28,28) - rrt(254) * density(50) 
  pd(28,50) = pd(28,50) - rrt(254) * density(28) 
  pd(50,28) = pd(50,28) - rrt(254) * density(50) 
  pd(50,50) = pd(50,50) - rrt(254) * density(28) 
  pd(08,28) = pd(08,28) + rrt(255) * density(51) 
  pd(08,51) = pd(08,51) + rrt(255) * density(28) 
  pd(26,28) = pd(26,28) + rrt(255) * density(51) 
  pd(26,51) = pd(26,51) + rrt(255) * density(28) 
  pd(28,28) = pd(28,28) - rrt(255) * density(51) 
  pd(28,51) = pd(28,51) - rrt(255) * density(28) 
  pd(51,28) = pd(51,28) - rrt(255) * density(51) 
  pd(51,51) = pd(51,51) - rrt(255) * density(28) 
  pd(08,28) = pd(08,28) + rrt(256) * density(52) 
  pd(08,52) = pd(08,52) + rrt(256) * density(28) 
  pd(26,28) = pd(26,28) + rrt(256) * density(52) 
  pd(26,52) = pd(26,52) + rrt(256) * density(28) 
  pd(28,28) = pd(28,28) - rrt(256) * density(52) 
  pd(28,52) = pd(28,52) - rrt(256) * density(28) 
  pd(52,28) = pd(52,28) - rrt(256) * density(52) 
  pd(52,52) = pd(52,52) - rrt(256) * density(28) 
  pd(08,28) = pd(08,28) + rrt(257) * density(53) 
  pd(08,53) = pd(08,53) + rrt(257) * density(28) 
  pd(26,28) = pd(26,28) + rrt(257) * density(53) 
  pd(26,53) = pd(26,53) + rrt(257) * density(28) 
  pd(28,28) = pd(28,28) - rrt(257) * density(53) 
  pd(28,53) = pd(28,53) - rrt(257) * density(28) 
  pd(53,28) = pd(53,28) - rrt(257) * density(53) 
  pd(53,53) = pd(53,53) - rrt(257) * density(28) 
  pd(06,25) = pd(06,25) + rrt(258) * density(50) 
  pd(06,50) = pd(06,50) + rrt(258) * density(25) 
  pd(13,25) = pd(13,25) + rrt(258) * density(50) 
  pd(13,50) = pd(13,50) + rrt(258) * density(25) 
  pd(25,25) = pd(25,25) - rrt(258) * density(50) 
  pd(25,50) = pd(25,50) - rrt(258) * density(25) 
  pd(50,25) = pd(50,25) - rrt(258) * density(50) 
  pd(50,50) = pd(50,50) - rrt(258) * density(25) 
  pd(06,25) = pd(06,25) + rrt(259) * density(51) 
  pd(06,51) = pd(06,51) + rrt(259) * density(25) 
  pd(13,25) = pd(13,25) + rrt(259) * density(51) 
  pd(13,51) = pd(13,51) + rrt(259) * density(25) 
  pd(25,25) = pd(25,25) - rrt(259) * density(51) 
  pd(25,51) = pd(25,51) - rrt(259) * density(25) 
  pd(51,25) = pd(51,25) - rrt(259) * density(51) 
  pd(51,51) = pd(51,51) - rrt(259) * density(25) 
  pd(06,25) = pd(06,25) + rrt(260) * density(52) 
  pd(06,52) = pd(06,52) + rrt(260) * density(25) 
  pd(13,25) = pd(13,25) + rrt(260) * density(52) 
  pd(13,52) = pd(13,52) + rrt(260) * density(25) 
  pd(25,25) = pd(25,25) - rrt(260) * density(52) 
  pd(25,52) = pd(25,52) - rrt(260) * density(25) 
  pd(52,25) = pd(52,25) - rrt(260) * density(52) 
  pd(52,52) = pd(52,52) - rrt(260) * density(25) 
  pd(06,25) = pd(06,25) + rrt(261) * density(53) 
  pd(06,53) = pd(06,53) + rrt(261) * density(25) 
  pd(13,25) = pd(13,25) + rrt(261) * density(53) 
  pd(13,53) = pd(13,53) + rrt(261) * density(25) 
  pd(25,25) = pd(25,25) - rrt(261) * density(53) 
  pd(25,53) = pd(25,53) - rrt(261) * density(25) 
  pd(53,25) = pd(53,25) - rrt(261) * density(53) 
  pd(53,53) = pd(53,53) - rrt(261) * density(25) 
  pd(01,10) = pd(01,10) + rrt(262) * density(50) 
  pd(01,50) = pd(01,50) + rrt(262) * density(10) 
  pd(10,10) = pd(10,10) - rrt(262) * density(50) 
  pd(10,50) = pd(10,50) - rrt(262) * density(10) 
  pd(12,10) = pd(12,10) + rrt(262) * density(50) 
  pd(12,50) = pd(12,50) + rrt(262) * density(10) 
  pd(50,10) = pd(50,10) - rrt(262) * density(50) 
  pd(50,50) = pd(50,50) - rrt(262) * density(10) 
  pd(01,10) = pd(01,10) + rrt(263) * density(51) 
  pd(01,51) = pd(01,51) + rrt(263) * density(10) 
  pd(10,10) = pd(10,10) - rrt(263) * density(51) 
  pd(10,51) = pd(10,51) - rrt(263) * density(10) 
  pd(12,10) = pd(12,10) + rrt(263) * density(51) 
  pd(12,51) = pd(12,51) + rrt(263) * density(10) 
  pd(51,10) = pd(51,10) - rrt(263) * density(51) 
  pd(51,51) = pd(51,51) - rrt(263) * density(10) 
  pd(01,10) = pd(01,10) + rrt(264) * density(52) 
  pd(01,52) = pd(01,52) + rrt(264) * density(10) 
  pd(10,10) = pd(10,10) - rrt(264) * density(52) 
  pd(10,52) = pd(10,52) - rrt(264) * density(10) 
  pd(12,10) = pd(12,10) + rrt(264) * density(52) 
  pd(12,52) = pd(12,52) + rrt(264) * density(10) 
  pd(52,10) = pd(52,10) - rrt(264) * density(52) 
  pd(52,52) = pd(52,52) - rrt(264) * density(10) 
  pd(01,10) = pd(01,10) + rrt(265) * density(53) 
  pd(01,53) = pd(01,53) + rrt(265) * density(10) 
  pd(10,10) = pd(10,10) - rrt(265) * density(53) 
  pd(10,53) = pd(10,53) - rrt(265) * density(10) 
  pd(12,10) = pd(12,10) + rrt(265) * density(53) 
  pd(12,53) = pd(12,53) + rrt(265) * density(10) 
  pd(53,10) = pd(53,10) - rrt(265) * density(53) 
  pd(53,53) = pd(53,53) - rrt(265) * density(10) 
  pd(01,01) = pd(01,01) - rrt(266) * density(38) 
  pd(01,38) = pd(01,38) - rrt(266) * density(01) 
  pd(10,01) = pd(10,01) + rrt(266) * density(38) 
  pd(10,38) = pd(10,38) + rrt(266) * density(01) 
  pd(12,01) = pd(12,01) + rrt(266) * density(38) 
  pd(12,38) = pd(12,38) + rrt(266) * density(01) 
  pd(38,01) = pd(38,01) - rrt(266) * density(38) 
  pd(38,38) = pd(38,38) - rrt(266) * density(01) 
  pd(01,01) = pd(01,01) - rrt(267) * density(39) 
  pd(01,39) = pd(01,39) - rrt(267) * density(01) 
  pd(10,01) = pd(10,01) + rrt(267) * density(39) 
  pd(10,39) = pd(10,39) + rrt(267) * density(01) 
  pd(12,01) = pd(12,01) + rrt(267) * density(39) 
  pd(12,39) = pd(12,39) + rrt(267) * density(01) 
  pd(39,01) = pd(39,01) - rrt(267) * density(39) 
  pd(39,39) = pd(39,39) - rrt(267) * density(01) 
  pd(01,01) = pd(01,01) - rrt(268) * density(40) 
  pd(01,40) = pd(01,40) - rrt(268) * density(01) 
  pd(10,01) = pd(10,01) + rrt(268) * density(40) 
  pd(10,40) = pd(10,40) + rrt(268) * density(01) 
  pd(12,01) = pd(12,01) + rrt(268) * density(40) 
  pd(12,40) = pd(12,40) + rrt(268) * density(01) 
  pd(40,01) = pd(40,01) - rrt(268) * density(40) 
  pd(40,40) = pd(40,40) - rrt(268) * density(01) 
  pd(01,01) = pd(01,01) - rrt(269) * density(41) 
  pd(01,41) = pd(01,41) - rrt(269) * density(01) 
  pd(10,01) = pd(10,01) + rrt(269) * density(41) 
  pd(10,41) = pd(10,41) + rrt(269) * density(01) 
  pd(12,01) = pd(12,01) + rrt(269) * density(41) 
  pd(12,41) = pd(12,41) + rrt(269) * density(01) 
  pd(41,01) = pd(41,01) - rrt(269) * density(41) 
  pd(41,41) = pd(41,41) - rrt(269) * density(01) 
  pd(01,01) = pd(01,01) - rrt(270) * density(42) 
  pd(01,42) = pd(01,42) - rrt(270) * density(01) 
  pd(10,01) = pd(10,01) + rrt(270) * density(42) 
  pd(10,42) = pd(10,42) + rrt(270) * density(01) 
  pd(12,01) = pd(12,01) + rrt(270) * density(42) 
  pd(12,42) = pd(12,42) + rrt(270) * density(01) 
  pd(42,01) = pd(42,01) - rrt(270) * density(42) 
  pd(42,42) = pd(42,42) - rrt(270) * density(01) 
  pd(01,01) = pd(01,01) - rrt(271) * density(43) 
  pd(01,43) = pd(01,43) - rrt(271) * density(01) 
  pd(10,01) = pd(10,01) + rrt(271) * density(43) 
  pd(10,43) = pd(10,43) + rrt(271) * density(01) 
  pd(12,01) = pd(12,01) + rrt(271) * density(43) 
  pd(12,43) = pd(12,43) + rrt(271) * density(01) 
  pd(43,01) = pd(43,01) - rrt(271) * density(43) 
  pd(43,43) = pd(43,43) - rrt(271) * density(01) 
  pd(01,01) = pd(01,01) - rrt(272) * density(44) 
  pd(01,44) = pd(01,44) - rrt(272) * density(01) 
  pd(10,01) = pd(10,01) + rrt(272) * density(44) 
  pd(10,44) = pd(10,44) + rrt(272) * density(01) 
  pd(12,01) = pd(12,01) + rrt(272) * density(44) 
  pd(12,44) = pd(12,44) + rrt(272) * density(01) 
  pd(44,01) = pd(44,01) - rrt(272) * density(44) 
  pd(44,44) = pd(44,44) - rrt(272) * density(01) 
  pd(01,01) = pd(01,01) - rrt(273) * density(45) 
  pd(01,45) = pd(01,45) - rrt(273) * density(01) 
  pd(10,01) = pd(10,01) + rrt(273) * density(45) 
  pd(10,45) = pd(10,45) + rrt(273) * density(01) 
  pd(12,01) = pd(12,01) + rrt(273) * density(45) 
  pd(12,45) = pd(12,45) + rrt(273) * density(01) 
  pd(45,01) = pd(45,01) - rrt(273) * density(45) 
  pd(45,45) = pd(45,45) - rrt(273) * density(01) 
  pd(01,02) = pd(01,02) + rrt(274) * density(38) 
  pd(01,38) = pd(01,38) + rrt(274) * density(02) 
  pd(02,02) = pd(02,02) - rrt(274) * density(38) 
  pd(02,38) = pd(02,38) - rrt(274) * density(02) 
  pd(14,02) = pd(14,02) + rrt(274) * density(38) 
  pd(14,38) = pd(14,38) + rrt(274) * density(02) 
  pd(38,02) = pd(38,02) - rrt(274) * density(38) 
  pd(38,38) = pd(38,38) - rrt(274) * density(02) 
  pd(01,02) = pd(01,02) + rrt(275) * density(39) 
  pd(01,39) = pd(01,39) + rrt(275) * density(02) 
  pd(02,02) = pd(02,02) - rrt(275) * density(39) 
  pd(02,39) = pd(02,39) - rrt(275) * density(02) 
  pd(14,02) = pd(14,02) + rrt(275) * density(39) 
  pd(14,39) = pd(14,39) + rrt(275) * density(02) 
  pd(39,02) = pd(39,02) - rrt(275) * density(39) 
  pd(39,39) = pd(39,39) - rrt(275) * density(02) 
  pd(01,02) = pd(01,02) + rrt(276) * density(40) 
  pd(01,40) = pd(01,40) + rrt(276) * density(02) 
  pd(02,02) = pd(02,02) - rrt(276) * density(40) 
  pd(02,40) = pd(02,40) - rrt(276) * density(02) 
  pd(14,02) = pd(14,02) + rrt(276) * density(40) 
  pd(14,40) = pd(14,40) + rrt(276) * density(02) 
  pd(40,02) = pd(40,02) - rrt(276) * density(40) 
  pd(40,40) = pd(40,40) - rrt(276) * density(02) 
  pd(01,02) = pd(01,02) + rrt(277) * density(41) 
  pd(01,41) = pd(01,41) + rrt(277) * density(02) 
  pd(02,02) = pd(02,02) - rrt(277) * density(41) 
  pd(02,41) = pd(02,41) - rrt(277) * density(02) 
  pd(14,02) = pd(14,02) + rrt(277) * density(41) 
  pd(14,41) = pd(14,41) + rrt(277) * density(02) 
  pd(41,02) = pd(41,02) - rrt(277) * density(41) 
  pd(41,41) = pd(41,41) - rrt(277) * density(02) 
  pd(01,02) = pd(01,02) + rrt(278) * density(42) 
  pd(01,42) = pd(01,42) + rrt(278) * density(02) 
  pd(02,02) = pd(02,02) - rrt(278) * density(42) 
  pd(02,42) = pd(02,42) - rrt(278) * density(02) 
  pd(14,02) = pd(14,02) + rrt(278) * density(42) 
  pd(14,42) = pd(14,42) + rrt(278) * density(02) 
  pd(42,02) = pd(42,02) - rrt(278) * density(42) 
  pd(42,42) = pd(42,42) - rrt(278) * density(02) 
  pd(01,02) = pd(01,02) + rrt(279) * density(43) 
  pd(01,43) = pd(01,43) + rrt(279) * density(02) 
  pd(02,02) = pd(02,02) - rrt(279) * density(43) 
  pd(02,43) = pd(02,43) - rrt(279) * density(02) 
  pd(14,02) = pd(14,02) + rrt(279) * density(43) 
  pd(14,43) = pd(14,43) + rrt(279) * density(02) 
  pd(43,02) = pd(43,02) - rrt(279) * density(43) 
  pd(43,43) = pd(43,43) - rrt(279) * density(02) 
  pd(01,02) = pd(01,02) + rrt(280) * density(44) 
  pd(01,44) = pd(01,44) + rrt(280) * density(02) 
  pd(02,02) = pd(02,02) - rrt(280) * density(44) 
  pd(02,44) = pd(02,44) - rrt(280) * density(02) 
  pd(14,02) = pd(14,02) + rrt(280) * density(44) 
  pd(14,44) = pd(14,44) + rrt(280) * density(02) 
  pd(44,02) = pd(44,02) - rrt(280) * density(44) 
  pd(44,44) = pd(44,44) - rrt(280) * density(02) 
  pd(01,02) = pd(01,02) + rrt(281) * density(45) 
  pd(01,45) = pd(01,45) + rrt(281) * density(02) 
  pd(02,02) = pd(02,02) - rrt(281) * density(45) 
  pd(02,45) = pd(02,45) - rrt(281) * density(02) 
  pd(14,02) = pd(14,02) + rrt(281) * density(45) 
  pd(14,45) = pd(14,45) + rrt(281) * density(02) 
  pd(45,02) = pd(45,02) - rrt(281) * density(45) 
  pd(45,45) = pd(45,45) - rrt(281) * density(02) 
  pd(07,07) = pd(07,07) - rrt(282) * density(38) 
  pd(07,38) = pd(07,38) - rrt(282) * density(07) 
  pd(12,07) = pd(12,07) + rrt(282) * density(38) 
  pd(12,38) = pd(12,38) + rrt(282) * density(07) 
  pd(17,07) = pd(17,07) + rrt(282) * density(38) 
  pd(17,38) = pd(17,38) + rrt(282) * density(07) 
  pd(38,07) = pd(38,07) - rrt(282) * density(38) 
  pd(38,38) = pd(38,38) - rrt(282) * density(07) 
  pd(07,07) = pd(07,07) - rrt(283) * density(39) 
  pd(07,39) = pd(07,39) - rrt(283) * density(07) 
  pd(12,07) = pd(12,07) + rrt(283) * density(39) 
  pd(12,39) = pd(12,39) + rrt(283) * density(07) 
  pd(17,07) = pd(17,07) + rrt(283) * density(39) 
  pd(17,39) = pd(17,39) + rrt(283) * density(07) 
  pd(39,07) = pd(39,07) - rrt(283) * density(39) 
  pd(39,39) = pd(39,39) - rrt(283) * density(07) 
  pd(07,07) = pd(07,07) - rrt(284) * density(40) 
  pd(07,40) = pd(07,40) - rrt(284) * density(07) 
  pd(12,07) = pd(12,07) + rrt(284) * density(40) 
  pd(12,40) = pd(12,40) + rrt(284) * density(07) 
  pd(17,07) = pd(17,07) + rrt(284) * density(40) 
  pd(17,40) = pd(17,40) + rrt(284) * density(07) 
  pd(40,07) = pd(40,07) - rrt(284) * density(40) 
  pd(40,40) = pd(40,40) - rrt(284) * density(07) 
  pd(07,07) = pd(07,07) - rrt(285) * density(41) 
  pd(07,41) = pd(07,41) - rrt(285) * density(07) 
  pd(12,07) = pd(12,07) + rrt(285) * density(41) 
  pd(12,41) = pd(12,41) + rrt(285) * density(07) 
  pd(17,07) = pd(17,07) + rrt(285) * density(41) 
  pd(17,41) = pd(17,41) + rrt(285) * density(07) 
  pd(41,07) = pd(41,07) - rrt(285) * density(41) 
  pd(41,41) = pd(41,41) - rrt(285) * density(07) 
  pd(07,07) = pd(07,07) - rrt(286) * density(42) 
  pd(07,42) = pd(07,42) - rrt(286) * density(07) 
  pd(12,07) = pd(12,07) + rrt(286) * density(42) 
  pd(12,42) = pd(12,42) + rrt(286) * density(07) 
  pd(17,07) = pd(17,07) + rrt(286) * density(42) 
  pd(17,42) = pd(17,42) + rrt(286) * density(07) 
  pd(42,07) = pd(42,07) - rrt(286) * density(42) 
  pd(42,42) = pd(42,42) - rrt(286) * density(07) 
  pd(07,07) = pd(07,07) - rrt(287) * density(43) 
  pd(07,43) = pd(07,43) - rrt(287) * density(07) 
  pd(12,07) = pd(12,07) + rrt(287) * density(43) 
  pd(12,43) = pd(12,43) + rrt(287) * density(07) 
  pd(17,07) = pd(17,07) + rrt(287) * density(43) 
  pd(17,43) = pd(17,43) + rrt(287) * density(07) 
  pd(43,07) = pd(43,07) - rrt(287) * density(43) 
  pd(43,43) = pd(43,43) - rrt(287) * density(07) 
  pd(07,07) = pd(07,07) - rrt(288) * density(44) 
  pd(07,44) = pd(07,44) - rrt(288) * density(07) 
  pd(12,07) = pd(12,07) + rrt(288) * density(44) 
  pd(12,44) = pd(12,44) + rrt(288) * density(07) 
  pd(17,07) = pd(17,07) + rrt(288) * density(44) 
  pd(17,44) = pd(17,44) + rrt(288) * density(07) 
  pd(44,07) = pd(44,07) - rrt(288) * density(44) 
  pd(44,44) = pd(44,44) - rrt(288) * density(07) 
  pd(07,07) = pd(07,07) - rrt(289) * density(45) 
  pd(07,45) = pd(07,45) - rrt(289) * density(07) 
  pd(12,07) = pd(12,07) + rrt(289) * density(45) 
  pd(12,45) = pd(12,45) + rrt(289) * density(07) 
  pd(17,07) = pd(17,07) + rrt(289) * density(45) 
  pd(17,45) = pd(17,45) + rrt(289) * density(07) 
  pd(45,07) = pd(45,07) - rrt(289) * density(45) 
  pd(45,45) = pd(45,45) - rrt(289) * density(07) 
  pd(04,04) = pd(04,04) - rrt(290) * density(38) 
  pd(04,38) = pd(04,38) - rrt(290) * density(04) 
  pd(10,04) = pd(10,04) + rrt(290) * density(38) 
  pd(10,38) = pd(10,38) + rrt(290) * density(04) 
  pd(18,04) = pd(18,04) + rrt(290) * density(38) 
  pd(18,38) = pd(18,38) + rrt(290) * density(04) 
  pd(38,04) = pd(38,04) - rrt(290) * density(38) 
  pd(38,38) = pd(38,38) - rrt(290) * density(04) 
  pd(04,04) = pd(04,04) - rrt(291) * density(39) 
  pd(04,39) = pd(04,39) - rrt(291) * density(04) 
  pd(10,04) = pd(10,04) + rrt(291) * density(39) 
  pd(10,39) = pd(10,39) + rrt(291) * density(04) 
  pd(18,04) = pd(18,04) + rrt(291) * density(39) 
  pd(18,39) = pd(18,39) + rrt(291) * density(04) 
  pd(39,04) = pd(39,04) - rrt(291) * density(39) 
  pd(39,39) = pd(39,39) - rrt(291) * density(04) 
  pd(04,04) = pd(04,04) - rrt(292) * density(40) 
  pd(04,40) = pd(04,40) - rrt(292) * density(04) 
  pd(10,04) = pd(10,04) + rrt(292) * density(40) 
  pd(10,40) = pd(10,40) + rrt(292) * density(04) 
  pd(18,04) = pd(18,04) + rrt(292) * density(40) 
  pd(18,40) = pd(18,40) + rrt(292) * density(04) 
  pd(40,04) = pd(40,04) - rrt(292) * density(40) 
  pd(40,40) = pd(40,40) - rrt(292) * density(04) 
  pd(04,04) = pd(04,04) - rrt(293) * density(41) 
  pd(04,41) = pd(04,41) - rrt(293) * density(04) 
  pd(10,04) = pd(10,04) + rrt(293) * density(41) 
  pd(10,41) = pd(10,41) + rrt(293) * density(04) 
  pd(18,04) = pd(18,04) + rrt(293) * density(41) 
  pd(18,41) = pd(18,41) + rrt(293) * density(04) 
  pd(41,04) = pd(41,04) - rrt(293) * density(41) 
  pd(41,41) = pd(41,41) - rrt(293) * density(04) 
  pd(04,04) = pd(04,04) - rrt(294) * density(42) 
  pd(04,42) = pd(04,42) - rrt(294) * density(04) 
  pd(10,04) = pd(10,04) + rrt(294) * density(42) 
  pd(10,42) = pd(10,42) + rrt(294) * density(04) 
  pd(18,04) = pd(18,04) + rrt(294) * density(42) 
  pd(18,42) = pd(18,42) + rrt(294) * density(04) 
  pd(42,04) = pd(42,04) - rrt(294) * density(42) 
  pd(42,42) = pd(42,42) - rrt(294) * density(04) 
  pd(04,04) = pd(04,04) - rrt(295) * density(43) 
  pd(04,43) = pd(04,43) - rrt(295) * density(04) 
  pd(10,04) = pd(10,04) + rrt(295) * density(43) 
  pd(10,43) = pd(10,43) + rrt(295) * density(04) 
  pd(18,04) = pd(18,04) + rrt(295) * density(43) 
  pd(18,43) = pd(18,43) + rrt(295) * density(04) 
  pd(43,04) = pd(43,04) - rrt(295) * density(43) 
  pd(43,43) = pd(43,43) - rrt(295) * density(04) 
  pd(04,04) = pd(04,04) - rrt(296) * density(44) 
  pd(04,44) = pd(04,44) - rrt(296) * density(04) 
  pd(10,04) = pd(10,04) + rrt(296) * density(44) 
  pd(10,44) = pd(10,44) + rrt(296) * density(04) 
  pd(18,04) = pd(18,04) + rrt(296) * density(44) 
  pd(18,44) = pd(18,44) + rrt(296) * density(04) 
  pd(44,04) = pd(44,04) - rrt(296) * density(44) 
  pd(44,44) = pd(44,44) - rrt(296) * density(04) 
  pd(04,04) = pd(04,04) - rrt(297) * density(45) 
  pd(04,45) = pd(04,45) - rrt(297) * density(04) 
  pd(10,04) = pd(10,04) + rrt(297) * density(45) 
  pd(10,45) = pd(10,45) + rrt(297) * density(04) 
  pd(18,04) = pd(18,04) + rrt(297) * density(45) 
  pd(18,45) = pd(18,45) + rrt(297) * density(04) 
  pd(45,04) = pd(45,04) - rrt(297) * density(45) 
  pd(45,45) = pd(45,45) - rrt(297) * density(04) 
  pd(06,06) = pd(06,06) - rrt(298) * density(38) 
  pd(06,38) = pd(06,38) - rrt(298) * density(06) 
  pd(12,06) = pd(12,06) + rrt(298) * density(38) 
  pd(12,38) = pd(12,38) + rrt(298) * density(06) 
  pd(18,06) = pd(18,06) + rrt(298) * density(38) 
  pd(18,38) = pd(18,38) + rrt(298) * density(06) 
  pd(38,06) = pd(38,06) - rrt(298) * density(38) 
  pd(38,38) = pd(38,38) - rrt(298) * density(06) 
  pd(06,06) = pd(06,06) - rrt(299) * density(39) 
  pd(06,39) = pd(06,39) - rrt(299) * density(06) 
  pd(12,06) = pd(12,06) + rrt(299) * density(39) 
  pd(12,39) = pd(12,39) + rrt(299) * density(06) 
  pd(18,06) = pd(18,06) + rrt(299) * density(39) 
  pd(18,39) = pd(18,39) + rrt(299) * density(06) 
  pd(39,06) = pd(39,06) - rrt(299) * density(39) 
  pd(39,39) = pd(39,39) - rrt(299) * density(06) 
  pd(06,06) = pd(06,06) - rrt(300) * density(40) 
  pd(06,40) = pd(06,40) - rrt(300) * density(06) 
  pd(12,06) = pd(12,06) + rrt(300) * density(40) 
  pd(12,40) = pd(12,40) + rrt(300) * density(06) 
  pd(18,06) = pd(18,06) + rrt(300) * density(40) 
  pd(18,40) = pd(18,40) + rrt(300) * density(06) 
  pd(40,06) = pd(40,06) - rrt(300) * density(40) 
  pd(40,40) = pd(40,40) - rrt(300) * density(06) 
  pd(06,06) = pd(06,06) - rrt(301) * density(41) 
  pd(06,41) = pd(06,41) - rrt(301) * density(06) 
  pd(12,06) = pd(12,06) + rrt(301) * density(41) 
  pd(12,41) = pd(12,41) + rrt(301) * density(06) 
  pd(18,06) = pd(18,06) + rrt(301) * density(41) 
  pd(18,41) = pd(18,41) + rrt(301) * density(06) 
  pd(41,06) = pd(41,06) - rrt(301) * density(41) 
  pd(41,41) = pd(41,41) - rrt(301) * density(06) 
  pd(06,06) = pd(06,06) - rrt(302) * density(42) 
  pd(06,42) = pd(06,42) - rrt(302) * density(06) 
  pd(12,06) = pd(12,06) + rrt(302) * density(42) 
  pd(12,42) = pd(12,42) + rrt(302) * density(06) 
  pd(18,06) = pd(18,06) + rrt(302) * density(42) 
  pd(18,42) = pd(18,42) + rrt(302) * density(06) 
  pd(42,06) = pd(42,06) - rrt(302) * density(42) 
  pd(42,42) = pd(42,42) - rrt(302) * density(06) 
  pd(06,06) = pd(06,06) - rrt(303) * density(43) 
  pd(06,43) = pd(06,43) - rrt(303) * density(06) 
  pd(12,06) = pd(12,06) + rrt(303) * density(43) 
  pd(12,43) = pd(12,43) + rrt(303) * density(06) 
  pd(18,06) = pd(18,06) + rrt(303) * density(43) 
  pd(18,43) = pd(18,43) + rrt(303) * density(06) 
  pd(43,06) = pd(43,06) - rrt(303) * density(43) 
  pd(43,43) = pd(43,43) - rrt(303) * density(06) 
  pd(06,06) = pd(06,06) - rrt(304) * density(44) 
  pd(06,44) = pd(06,44) - rrt(304) * density(06) 
  pd(12,06) = pd(12,06) + rrt(304) * density(44) 
  pd(12,44) = pd(12,44) + rrt(304) * density(06) 
  pd(18,06) = pd(18,06) + rrt(304) * density(44) 
  pd(18,44) = pd(18,44) + rrt(304) * density(06) 
  pd(44,06) = pd(44,06) - rrt(304) * density(44) 
  pd(44,44) = pd(44,44) - rrt(304) * density(06) 
  pd(06,06) = pd(06,06) - rrt(305) * density(45) 
  pd(06,45) = pd(06,45) - rrt(305) * density(06) 
  pd(12,06) = pd(12,06) + rrt(305) * density(45) 
  pd(12,45) = pd(12,45) + rrt(305) * density(06) 
  pd(18,06) = pd(18,06) + rrt(305) * density(45) 
  pd(18,45) = pd(18,45) + rrt(305) * density(06) 
  pd(45,06) = pd(45,06) - rrt(305) * density(45) 
  pd(45,45) = pd(45,45) - rrt(305) * density(06) 
  pd(10,07) = pd(10,07) + rrt(306) * density(38) * 2.0d0
  pd(10,38) = pd(10,38) + rrt(306) * density(07) * 2.0d0
  pd(38,07) = pd(38,07) - rrt(306) * density(38) 
  pd(38,38) = pd(38,38) - rrt(306) * density(07) 
  pd(10,07) = pd(10,07) + rrt(307) * density(39) * 2.0d0
  pd(10,39) = pd(10,39) + rrt(307) * density(07) * 2.0d0
  pd(39,07) = pd(39,07) - rrt(307) * density(39) 
  pd(39,39) = pd(39,39) - rrt(307) * density(07) 
  pd(10,07) = pd(10,07) + rrt(308) * density(40) * 2.0d0
  pd(10,40) = pd(10,40) + rrt(308) * density(07) * 2.0d0
  pd(40,07) = pd(40,07) - rrt(308) * density(40) 
  pd(40,40) = pd(40,40) - rrt(308) * density(07) 
  pd(10,07) = pd(10,07) + rrt(309) * density(41) * 2.0d0
  pd(10,41) = pd(10,41) + rrt(309) * density(07) * 2.0d0
  pd(41,07) = pd(41,07) - rrt(309) * density(41) 
  pd(41,41) = pd(41,41) - rrt(309) * density(07) 
  pd(10,07) = pd(10,07) + rrt(310) * density(42) * 2.0d0
  pd(10,42) = pd(10,42) + rrt(310) * density(07) * 2.0d0
  pd(42,07) = pd(42,07) - rrt(310) * density(42) 
  pd(42,42) = pd(42,42) - rrt(310) * density(07) 
  pd(10,07) = pd(10,07) + rrt(311) * density(43) * 2.0d0
  pd(10,43) = pd(10,43) + rrt(311) * density(07) * 2.0d0
  pd(43,07) = pd(43,07) - rrt(311) * density(43) 
  pd(43,43) = pd(43,43) - rrt(311) * density(07) 
  pd(10,07) = pd(10,07) + rrt(312) * density(44) * 2.0d0
  pd(10,44) = pd(10,44) + rrt(312) * density(07) * 2.0d0
  pd(44,07) = pd(44,07) - rrt(312) * density(44) 
  pd(44,44) = pd(44,44) - rrt(312) * density(07) 
  pd(10,07) = pd(10,07) + rrt(313) * density(45) * 2.0d0
  pd(10,45) = pd(10,45) + rrt(313) * density(07) * 2.0d0
  pd(45,07) = pd(45,07) - rrt(313) * density(45) 
  pd(45,45) = pd(45,45) - rrt(313) * density(07) 
  pd(01,06) = pd(01,06) + rrt(314) * density(38) 
  pd(01,38) = pd(01,38) + rrt(314) * density(06) 
  pd(06,06) = pd(06,06) - rrt(314) * density(38) 
  pd(06,38) = pd(06,38) - rrt(314) * density(06) 
  pd(20,06) = pd(20,06) + rrt(314) * density(38) 
  pd(20,38) = pd(20,38) + rrt(314) * density(06) 
  pd(38,06) = pd(38,06) - rrt(314) * density(38) 
  pd(38,38) = pd(38,38) - rrt(314) * density(06) 
  pd(01,06) = pd(01,06) + rrt(315) * density(39) 
  pd(01,39) = pd(01,39) + rrt(315) * density(06) 
  pd(06,06) = pd(06,06) - rrt(315) * density(39) 
  pd(06,39) = pd(06,39) - rrt(315) * density(06) 
  pd(20,06) = pd(20,06) + rrt(315) * density(39) 
  pd(20,39) = pd(20,39) + rrt(315) * density(06) 
  pd(39,06) = pd(39,06) - rrt(315) * density(39) 
  pd(39,39) = pd(39,39) - rrt(315) * density(06) 
  pd(01,06) = pd(01,06) + rrt(316) * density(40) 
  pd(01,40) = pd(01,40) + rrt(316) * density(06) 
  pd(06,06) = pd(06,06) - rrt(316) * density(40) 
  pd(06,40) = pd(06,40) - rrt(316) * density(06) 
  pd(20,06) = pd(20,06) + rrt(316) * density(40) 
  pd(20,40) = pd(20,40) + rrt(316) * density(06) 
  pd(40,06) = pd(40,06) - rrt(316) * density(40) 
  pd(40,40) = pd(40,40) - rrt(316) * density(06) 
  pd(01,06) = pd(01,06) + rrt(317) * density(41) 
  pd(01,41) = pd(01,41) + rrt(317) * density(06) 
  pd(06,06) = pd(06,06) - rrt(317) * density(41) 
  pd(06,41) = pd(06,41) - rrt(317) * density(06) 
  pd(20,06) = pd(20,06) + rrt(317) * density(41) 
  pd(20,41) = pd(20,41) + rrt(317) * density(06) 
  pd(41,06) = pd(41,06) - rrt(317) * density(41) 
  pd(41,41) = pd(41,41) - rrt(317) * density(06) 
  pd(01,06) = pd(01,06) + rrt(318) * density(42) 
  pd(01,42) = pd(01,42) + rrt(318) * density(06) 
  pd(06,06) = pd(06,06) - rrt(318) * density(42) 
  pd(06,42) = pd(06,42) - rrt(318) * density(06) 
  pd(20,06) = pd(20,06) + rrt(318) * density(42) 
  pd(20,42) = pd(20,42) + rrt(318) * density(06) 
  pd(42,06) = pd(42,06) - rrt(318) * density(42) 
  pd(42,42) = pd(42,42) - rrt(318) * density(06) 
  pd(01,06) = pd(01,06) + rrt(319) * density(43) 
  pd(01,43) = pd(01,43) + rrt(319) * density(06) 
  pd(06,06) = pd(06,06) - rrt(319) * density(43) 
  pd(06,43) = pd(06,43) - rrt(319) * density(06) 
  pd(20,06) = pd(20,06) + rrt(319) * density(43) 
  pd(20,43) = pd(20,43) + rrt(319) * density(06) 
  pd(43,06) = pd(43,06) - rrt(319) * density(43) 
  pd(43,43) = pd(43,43) - rrt(319) * density(06) 
  pd(01,06) = pd(01,06) + rrt(320) * density(44) 
  pd(01,44) = pd(01,44) + rrt(320) * density(06) 
  pd(06,06) = pd(06,06) - rrt(320) * density(44) 
  pd(06,44) = pd(06,44) - rrt(320) * density(06) 
  pd(20,06) = pd(20,06) + rrt(320) * density(44) 
  pd(20,44) = pd(20,44) + rrt(320) * density(06) 
  pd(44,06) = pd(44,06) - rrt(320) * density(44) 
  pd(44,44) = pd(44,44) - rrt(320) * density(06) 
  pd(01,06) = pd(01,06) + rrt(321) * density(45) 
  pd(01,45) = pd(01,45) + rrt(321) * density(06) 
  pd(06,06) = pd(06,06) - rrt(321) * density(45) 
  pd(06,45) = pd(06,45) - rrt(321) * density(06) 
  pd(20,06) = pd(20,06) + rrt(321) * density(45) 
  pd(20,45) = pd(20,45) + rrt(321) * density(06) 
  pd(45,06) = pd(45,06) - rrt(321) * density(45) 
  pd(45,45) = pd(45,45) - rrt(321) * density(06) 
  pd(06,07) = pd(06,07) + rrt(322) * density(38) 
  pd(06,38) = pd(06,38) + rrt(322) * density(07) 
  pd(07,07) = pd(07,07) - rrt(322) * density(38) 
  pd(07,38) = pd(07,38) - rrt(322) * density(07) 
  pd(20,07) = pd(20,07) + rrt(322) * density(38) 
  pd(20,38) = pd(20,38) + rrt(322) * density(07) 
  pd(38,07) = pd(38,07) - rrt(322) * density(38) 
  pd(38,38) = pd(38,38) - rrt(322) * density(07) 
  pd(06,07) = pd(06,07) + rrt(323) * density(39) 
  pd(06,39) = pd(06,39) + rrt(323) * density(07) 
  pd(07,07) = pd(07,07) - rrt(323) * density(39) 
  pd(07,39) = pd(07,39) - rrt(323) * density(07) 
  pd(20,07) = pd(20,07) + rrt(323) * density(39) 
  pd(20,39) = pd(20,39) + rrt(323) * density(07) 
  pd(39,07) = pd(39,07) - rrt(323) * density(39) 
  pd(39,39) = pd(39,39) - rrt(323) * density(07) 
  pd(06,07) = pd(06,07) + rrt(324) * density(40) 
  pd(06,40) = pd(06,40) + rrt(324) * density(07) 
  pd(07,07) = pd(07,07) - rrt(324) * density(40) 
  pd(07,40) = pd(07,40) - rrt(324) * density(07) 
  pd(20,07) = pd(20,07) + rrt(324) * density(40) 
  pd(20,40) = pd(20,40) + rrt(324) * density(07) 
  pd(40,07) = pd(40,07) - rrt(324) * density(40) 
  pd(40,40) = pd(40,40) - rrt(324) * density(07) 
  pd(06,07) = pd(06,07) + rrt(325) * density(41) 
  pd(06,41) = pd(06,41) + rrt(325) * density(07) 
  pd(07,07) = pd(07,07) - rrt(325) * density(41) 
  pd(07,41) = pd(07,41) - rrt(325) * density(07) 
  pd(20,07) = pd(20,07) + rrt(325) * density(41) 
  pd(20,41) = pd(20,41) + rrt(325) * density(07) 
  pd(41,07) = pd(41,07) - rrt(325) * density(41) 
  pd(41,41) = pd(41,41) - rrt(325) * density(07) 
  pd(06,07) = pd(06,07) + rrt(326) * density(42) 
  pd(06,42) = pd(06,42) + rrt(326) * density(07) 
  pd(07,07) = pd(07,07) - rrt(326) * density(42) 
  pd(07,42) = pd(07,42) - rrt(326) * density(07) 
  pd(20,07) = pd(20,07) + rrt(326) * density(42) 
  pd(20,42) = pd(20,42) + rrt(326) * density(07) 
  pd(42,07) = pd(42,07) - rrt(326) * density(42) 
  pd(42,42) = pd(42,42) - rrt(326) * density(07) 
  pd(06,07) = pd(06,07) + rrt(327) * density(43) 
  pd(06,43) = pd(06,43) + rrt(327) * density(07) 
  pd(07,07) = pd(07,07) - rrt(327) * density(43) 
  pd(07,43) = pd(07,43) - rrt(327) * density(07) 
  pd(20,07) = pd(20,07) + rrt(327) * density(43) 
  pd(20,43) = pd(20,43) + rrt(327) * density(07) 
  pd(43,07) = pd(43,07) - rrt(327) * density(43) 
  pd(43,43) = pd(43,43) - rrt(327) * density(07) 
  pd(06,07) = pd(06,07) + rrt(328) * density(44) 
  pd(06,44) = pd(06,44) + rrt(328) * density(07) 
  pd(07,07) = pd(07,07) - rrt(328) * density(44) 
  pd(07,44) = pd(07,44) - rrt(328) * density(07) 
  pd(20,07) = pd(20,07) + rrt(328) * density(44) 
  pd(20,44) = pd(20,44) + rrt(328) * density(07) 
  pd(44,07) = pd(44,07) - rrt(328) * density(44) 
  pd(44,44) = pd(44,44) - rrt(328) * density(07) 
  pd(06,07) = pd(06,07) + rrt(329) * density(45) 
  pd(06,45) = pd(06,45) + rrt(329) * density(07) 
  pd(07,07) = pd(07,07) - rrt(329) * density(45) 
  pd(07,45) = pd(07,45) - rrt(329) * density(07) 
  pd(20,07) = pd(20,07) + rrt(329) * density(45) 
  pd(20,45) = pd(20,45) + rrt(329) * density(07) 
  pd(45,07) = pd(45,07) - rrt(329) * density(45) 
  pd(45,45) = pd(45,45) - rrt(329) * density(07) 
  pd(04,05) = pd(04,05) + rrt(330) * density(38) 
  pd(04,38) = pd(04,38) + rrt(330) * density(05) 
  pd(05,05) = pd(05,05) - rrt(330) * density(38) 
  pd(05,38) = pd(05,38) - rrt(330) * density(05) 
  pd(20,05) = pd(20,05) + rrt(330) * density(38) 
  pd(20,38) = pd(20,38) + rrt(330) * density(05) 
  pd(38,05) = pd(38,05) - rrt(330) * density(38) 
  pd(38,38) = pd(38,38) - rrt(330) * density(05) 
  pd(04,05) = pd(04,05) + rrt(331) * density(39) 
  pd(04,39) = pd(04,39) + rrt(331) * density(05) 
  pd(05,05) = pd(05,05) - rrt(331) * density(39) 
  pd(05,39) = pd(05,39) - rrt(331) * density(05) 
  pd(20,05) = pd(20,05) + rrt(331) * density(39) 
  pd(20,39) = pd(20,39) + rrt(331) * density(05) 
  pd(39,05) = pd(39,05) - rrt(331) * density(39) 
  pd(39,39) = pd(39,39) - rrt(331) * density(05) 
  pd(04,05) = pd(04,05) + rrt(332) * density(40) 
  pd(04,40) = pd(04,40) + rrt(332) * density(05) 
  pd(05,05) = pd(05,05) - rrt(332) * density(40) 
  pd(05,40) = pd(05,40) - rrt(332) * density(05) 
  pd(20,05) = pd(20,05) + rrt(332) * density(40) 
  pd(20,40) = pd(20,40) + rrt(332) * density(05) 
  pd(40,05) = pd(40,05) - rrt(332) * density(40) 
  pd(40,40) = pd(40,40) - rrt(332) * density(05) 
  pd(04,05) = pd(04,05) + rrt(333) * density(41) 
  pd(04,41) = pd(04,41) + rrt(333) * density(05) 
  pd(05,05) = pd(05,05) - rrt(333) * density(41) 
  pd(05,41) = pd(05,41) - rrt(333) * density(05) 
  pd(20,05) = pd(20,05) + rrt(333) * density(41) 
  pd(20,41) = pd(20,41) + rrt(333) * density(05) 
  pd(41,05) = pd(41,05) - rrt(333) * density(41) 
  pd(41,41) = pd(41,41) - rrt(333) * density(05) 
  pd(04,05) = pd(04,05) + rrt(334) * density(42) 
  pd(04,42) = pd(04,42) + rrt(334) * density(05) 
  pd(05,05) = pd(05,05) - rrt(334) * density(42) 
  pd(05,42) = pd(05,42) - rrt(334) * density(05) 
  pd(20,05) = pd(20,05) + rrt(334) * density(42) 
  pd(20,42) = pd(20,42) + rrt(334) * density(05) 
  pd(42,05) = pd(42,05) - rrt(334) * density(42) 
  pd(42,42) = pd(42,42) - rrt(334) * density(05) 
  pd(04,05) = pd(04,05) + rrt(335) * density(43) 
  pd(04,43) = pd(04,43) + rrt(335) * density(05) 
  pd(05,05) = pd(05,05) - rrt(335) * density(43) 
  pd(05,43) = pd(05,43) - rrt(335) * density(05) 
  pd(20,05) = pd(20,05) + rrt(335) * density(43) 
  pd(20,43) = pd(20,43) + rrt(335) * density(05) 
  pd(43,05) = pd(43,05) - rrt(335) * density(43) 
  pd(43,43) = pd(43,43) - rrt(335) * density(05) 
  pd(04,05) = pd(04,05) + rrt(336) * density(44) 
  pd(04,44) = pd(04,44) + rrt(336) * density(05) 
  pd(05,05) = pd(05,05) - rrt(336) * density(44) 
  pd(05,44) = pd(05,44) - rrt(336) * density(05) 
  pd(20,05) = pd(20,05) + rrt(336) * density(44) 
  pd(20,44) = pd(20,44) + rrt(336) * density(05) 
  pd(44,05) = pd(44,05) - rrt(336) * density(44) 
  pd(44,44) = pd(44,44) - rrt(336) * density(05) 
  pd(04,05) = pd(04,05) + rrt(337) * density(45) 
  pd(04,45) = pd(04,45) + rrt(337) * density(05) 
  pd(05,05) = pd(05,05) - rrt(337) * density(45) 
  pd(05,45) = pd(05,45) - rrt(337) * density(05) 
  pd(20,05) = pd(20,05) + rrt(337) * density(45) 
  pd(20,45) = pd(20,45) + rrt(337) * density(05) 
  pd(45,05) = pd(45,05) - rrt(337) * density(45) 
  pd(45,45) = pd(45,45) - rrt(337) * density(05) 
  pd(02,08) = pd(02,08) + rrt(338) * density(38) 
  pd(02,38) = pd(02,38) + rrt(338) * density(08) 
  pd(08,08) = pd(08,08) - rrt(338) * density(38) 
  pd(08,38) = pd(08,38) - rrt(338) * density(08) 
  pd(20,08) = pd(20,08) + rrt(338) * density(38) 
  pd(20,38) = pd(20,38) + rrt(338) * density(08) 
  pd(38,08) = pd(38,08) - rrt(338) * density(38) 
  pd(38,38) = pd(38,38) - rrt(338) * density(08) 
  pd(02,08) = pd(02,08) + rrt(339) * density(39) 
  pd(02,39) = pd(02,39) + rrt(339) * density(08) 
  pd(08,08) = pd(08,08) - rrt(339) * density(39) 
  pd(08,39) = pd(08,39) - rrt(339) * density(08) 
  pd(20,08) = pd(20,08) + rrt(339) * density(39) 
  pd(20,39) = pd(20,39) + rrt(339) * density(08) 
  pd(39,08) = pd(39,08) - rrt(339) * density(39) 
  pd(39,39) = pd(39,39) - rrt(339) * density(08) 
  pd(02,08) = pd(02,08) + rrt(340) * density(40) 
  pd(02,40) = pd(02,40) + rrt(340) * density(08) 
  pd(08,08) = pd(08,08) - rrt(340) * density(40) 
  pd(08,40) = pd(08,40) - rrt(340) * density(08) 
  pd(20,08) = pd(20,08) + rrt(340) * density(40) 
  pd(20,40) = pd(20,40) + rrt(340) * density(08) 
  pd(40,08) = pd(40,08) - rrt(340) * density(40) 
  pd(40,40) = pd(40,40) - rrt(340) * density(08) 
  pd(02,08) = pd(02,08) + rrt(341) * density(41) 
  pd(02,41) = pd(02,41) + rrt(341) * density(08) 
  pd(08,08) = pd(08,08) - rrt(341) * density(41) 
  pd(08,41) = pd(08,41) - rrt(341) * density(08) 
  pd(20,08) = pd(20,08) + rrt(341) * density(41) 
  pd(20,41) = pd(20,41) + rrt(341) * density(08) 
  pd(41,08) = pd(41,08) - rrt(341) * density(41) 
  pd(41,41) = pd(41,41) - rrt(341) * density(08) 
  pd(02,08) = pd(02,08) + rrt(342) * density(42) 
  pd(02,42) = pd(02,42) + rrt(342) * density(08) 
  pd(08,08) = pd(08,08) - rrt(342) * density(42) 
  pd(08,42) = pd(08,42) - rrt(342) * density(08) 
  pd(20,08) = pd(20,08) + rrt(342) * density(42) 
  pd(20,42) = pd(20,42) + rrt(342) * density(08) 
  pd(42,08) = pd(42,08) - rrt(342) * density(42) 
  pd(42,42) = pd(42,42) - rrt(342) * density(08) 
  pd(02,08) = pd(02,08) + rrt(343) * density(43) 
  pd(02,43) = pd(02,43) + rrt(343) * density(08) 
  pd(08,08) = pd(08,08) - rrt(343) * density(43) 
  pd(08,43) = pd(08,43) - rrt(343) * density(08) 
  pd(20,08) = pd(20,08) + rrt(343) * density(43) 
  pd(20,43) = pd(20,43) + rrt(343) * density(08) 
  pd(43,08) = pd(43,08) - rrt(343) * density(43) 
  pd(43,43) = pd(43,43) - rrt(343) * density(08) 
  pd(02,08) = pd(02,08) + rrt(344) * density(44) 
  pd(02,44) = pd(02,44) + rrt(344) * density(08) 
  pd(08,08) = pd(08,08) - rrt(344) * density(44) 
  pd(08,44) = pd(08,44) - rrt(344) * density(08) 
  pd(20,08) = pd(20,08) + rrt(344) * density(44) 
  pd(20,44) = pd(20,44) + rrt(344) * density(08) 
  pd(44,08) = pd(44,08) - rrt(344) * density(44) 
  pd(44,44) = pd(44,44) - rrt(344) * density(08) 
  pd(02,08) = pd(02,08) + rrt(345) * density(45) 
  pd(02,45) = pd(02,45) + rrt(345) * density(08) 
  pd(08,08) = pd(08,08) - rrt(345) * density(45) 
  pd(08,45) = pd(08,45) - rrt(345) * density(08) 
  pd(20,08) = pd(20,08) + rrt(345) * density(45) 
  pd(20,45) = pd(20,45) + rrt(345) * density(08) 
  pd(45,08) = pd(45,08) - rrt(345) * density(45) 
  pd(45,45) = pd(45,45) - rrt(345) * density(08) 
  pd(12,26) = pd(12,26) + rrt(346) * density(38) 
  pd(12,38) = pd(12,38) + rrt(346) * density(26) 
  pd(20,26) = pd(20,26) + rrt(346) * density(38) 
  pd(20,38) = pd(20,38) + rrt(346) * density(26) 
  pd(26,26) = pd(26,26) - rrt(346) * density(38) 
  pd(26,38) = pd(26,38) - rrt(346) * density(26) 
  pd(38,26) = pd(38,26) - rrt(346) * density(38) 
  pd(38,38) = pd(38,38) - rrt(346) * density(26) 
  pd(12,26) = pd(12,26) + rrt(347) * density(39) 
  pd(12,39) = pd(12,39) + rrt(347) * density(26) 
  pd(20,26) = pd(20,26) + rrt(347) * density(39) 
  pd(20,39) = pd(20,39) + rrt(347) * density(26) 
  pd(26,26) = pd(26,26) - rrt(347) * density(39) 
  pd(26,39) = pd(26,39) - rrt(347) * density(26) 
  pd(39,26) = pd(39,26) - rrt(347) * density(39) 
  pd(39,39) = pd(39,39) - rrt(347) * density(26) 
  pd(12,26) = pd(12,26) + rrt(348) * density(40) 
  pd(12,40) = pd(12,40) + rrt(348) * density(26) 
  pd(20,26) = pd(20,26) + rrt(348) * density(40) 
  pd(20,40) = pd(20,40) + rrt(348) * density(26) 
  pd(26,26) = pd(26,26) - rrt(348) * density(40) 
  pd(26,40) = pd(26,40) - rrt(348) * density(26) 
  pd(40,26) = pd(40,26) - rrt(348) * density(40) 
  pd(40,40) = pd(40,40) - rrt(348) * density(26) 
  pd(12,26) = pd(12,26) + rrt(349) * density(41) 
  pd(12,41) = pd(12,41) + rrt(349) * density(26) 
  pd(20,26) = pd(20,26) + rrt(349) * density(41) 
  pd(20,41) = pd(20,41) + rrt(349) * density(26) 
  pd(26,26) = pd(26,26) - rrt(349) * density(41) 
  pd(26,41) = pd(26,41) - rrt(349) * density(26) 
  pd(41,26) = pd(41,26) - rrt(349) * density(41) 
  pd(41,41) = pd(41,41) - rrt(349) * density(26) 
  pd(12,26) = pd(12,26) + rrt(350) * density(42) 
  pd(12,42) = pd(12,42) + rrt(350) * density(26) 
  pd(20,26) = pd(20,26) + rrt(350) * density(42) 
  pd(20,42) = pd(20,42) + rrt(350) * density(26) 
  pd(26,26) = pd(26,26) - rrt(350) * density(42) 
  pd(26,42) = pd(26,42) - rrt(350) * density(26) 
  pd(42,26) = pd(42,26) - rrt(350) * density(42) 
  pd(42,42) = pd(42,42) - rrt(350) * density(26) 
  pd(12,26) = pd(12,26) + rrt(351) * density(43) 
  pd(12,43) = pd(12,43) + rrt(351) * density(26) 
  pd(20,26) = pd(20,26) + rrt(351) * density(43) 
  pd(20,43) = pd(20,43) + rrt(351) * density(26) 
  pd(26,26) = pd(26,26) - rrt(351) * density(43) 
  pd(26,43) = pd(26,43) - rrt(351) * density(26) 
  pd(43,26) = pd(43,26) - rrt(351) * density(43) 
  pd(43,43) = pd(43,43) - rrt(351) * density(26) 
  pd(12,26) = pd(12,26) + rrt(352) * density(44) 
  pd(12,44) = pd(12,44) + rrt(352) * density(26) 
  pd(20,26) = pd(20,26) + rrt(352) * density(44) 
  pd(20,44) = pd(20,44) + rrt(352) * density(26) 
  pd(26,26) = pd(26,26) - rrt(352) * density(44) 
  pd(26,44) = pd(26,44) - rrt(352) * density(26) 
  pd(44,26) = pd(44,26) - rrt(352) * density(44) 
  pd(44,44) = pd(44,44) - rrt(352) * density(26) 
  pd(12,26) = pd(12,26) + rrt(353) * density(45) 
  pd(12,45) = pd(12,45) + rrt(353) * density(26) 
  pd(20,26) = pd(20,26) + rrt(353) * density(45) 
  pd(20,45) = pd(20,45) + rrt(353) * density(26) 
  pd(26,26) = pd(26,26) - rrt(353) * density(45) 
  pd(26,45) = pd(26,45) - rrt(353) * density(26) 
  pd(45,26) = pd(45,26) - rrt(353) * density(45) 
  pd(45,45) = pd(45,45) - rrt(353) * density(26) 
  pd(04,06) = pd(04,06) + rrt(354) * density(38) 
  pd(04,38) = pd(04,38) + rrt(354) * density(06) 
  pd(06,06) = pd(06,06) - rrt(354) * density(38) 
  pd(06,38) = pd(06,38) - rrt(354) * density(06) 
  pd(14,06) = pd(14,06) + rrt(354) * density(38) 
  pd(14,38) = pd(14,38) + rrt(354) * density(06) 
  pd(38,06) = pd(38,06) - rrt(354) * density(38) 
  pd(38,38) = pd(38,38) - rrt(354) * density(06) 
  pd(04,06) = pd(04,06) + rrt(355) * density(39) 
  pd(04,39) = pd(04,39) + rrt(355) * density(06) 
  pd(06,06) = pd(06,06) - rrt(355) * density(39) 
  pd(06,39) = pd(06,39) - rrt(355) * density(06) 
  pd(14,06) = pd(14,06) + rrt(355) * density(39) 
  pd(14,39) = pd(14,39) + rrt(355) * density(06) 
  pd(39,06) = pd(39,06) - rrt(355) * density(39) 
  pd(39,39) = pd(39,39) - rrt(355) * density(06) 
  pd(04,06) = pd(04,06) + rrt(356) * density(40) 
  pd(04,40) = pd(04,40) + rrt(356) * density(06) 
  pd(06,06) = pd(06,06) - rrt(356) * density(40) 
  pd(06,40) = pd(06,40) - rrt(356) * density(06) 
  pd(14,06) = pd(14,06) + rrt(356) * density(40) 
  pd(14,40) = pd(14,40) + rrt(356) * density(06) 
  pd(40,06) = pd(40,06) - rrt(356) * density(40) 
  pd(40,40) = pd(40,40) - rrt(356) * density(06) 
  pd(04,06) = pd(04,06) + rrt(357) * density(41) 
  pd(04,41) = pd(04,41) + rrt(357) * density(06) 
  pd(06,06) = pd(06,06) - rrt(357) * density(41) 
  pd(06,41) = pd(06,41) - rrt(357) * density(06) 
  pd(14,06) = pd(14,06) + rrt(357) * density(41) 
  pd(14,41) = pd(14,41) + rrt(357) * density(06) 
  pd(41,06) = pd(41,06) - rrt(357) * density(41) 
  pd(41,41) = pd(41,41) - rrt(357) * density(06) 
  pd(04,06) = pd(04,06) + rrt(358) * density(42) 
  pd(04,42) = pd(04,42) + rrt(358) * density(06) 
  pd(06,06) = pd(06,06) - rrt(358) * density(42) 
  pd(06,42) = pd(06,42) - rrt(358) * density(06) 
  pd(14,06) = pd(14,06) + rrt(358) * density(42) 
  pd(14,42) = pd(14,42) + rrt(358) * density(06) 
  pd(42,06) = pd(42,06) - rrt(358) * density(42) 
  pd(42,42) = pd(42,42) - rrt(358) * density(06) 
  pd(04,06) = pd(04,06) + rrt(359) * density(43) 
  pd(04,43) = pd(04,43) + rrt(359) * density(06) 
  pd(06,06) = pd(06,06) - rrt(359) * density(43) 
  pd(06,43) = pd(06,43) - rrt(359) * density(06) 
  pd(14,06) = pd(14,06) + rrt(359) * density(43) 
  pd(14,43) = pd(14,43) + rrt(359) * density(06) 
  pd(43,06) = pd(43,06) - rrt(359) * density(43) 
  pd(43,43) = pd(43,43) - rrt(359) * density(06) 
  pd(04,06) = pd(04,06) + rrt(360) * density(44) 
  pd(04,44) = pd(04,44) + rrt(360) * density(06) 
  pd(06,06) = pd(06,06) - rrt(360) * density(44) 
  pd(06,44) = pd(06,44) - rrt(360) * density(06) 
  pd(14,06) = pd(14,06) + rrt(360) * density(44) 
  pd(14,44) = pd(14,44) + rrt(360) * density(06) 
  pd(44,06) = pd(44,06) - rrt(360) * density(44) 
  pd(44,44) = pd(44,44) - rrt(360) * density(06) 
  pd(04,06) = pd(04,06) + rrt(361) * density(45) 
  pd(04,45) = pd(04,45) + rrt(361) * density(06) 
  pd(06,06) = pd(06,06) - rrt(361) * density(45) 
  pd(06,45) = pd(06,45) - rrt(361) * density(06) 
  pd(14,06) = pd(14,06) + rrt(361) * density(45) 
  pd(14,45) = pd(14,45) + rrt(361) * density(06) 
  pd(45,06) = pd(45,06) - rrt(361) * density(45) 
  pd(45,45) = pd(45,45) - rrt(361) * density(06) 
  pd(04,02) = pd(04,02) + rrt(362) * density(57) 
  pd(04,57) = pd(04,57) + rrt(362) * density(02) 
  pd(17,02) = pd(17,02) + rrt(362) * density(57) 
  pd(17,57) = pd(17,57) + rrt(362) * density(02) 
  pd(57,02) = pd(57,02) - rrt(362) * density(57) 
  pd(57,57) = pd(57,57) - rrt(362) * density(02) 
  pd(04,02) = pd(04,02) + rrt(363) * density(58) 
  pd(04,58) = pd(04,58) + rrt(363) * density(02) 
  pd(17,02) = pd(17,02) + rrt(363) * density(58) 
  pd(17,58) = pd(17,58) + rrt(363) * density(02) 
  pd(58,02) = pd(58,02) - rrt(363) * density(58) 
  pd(58,58) = pd(58,58) - rrt(363) * density(02) 
  pd(04,02) = pd(04,02) + rrt(364) * density(59) 
  pd(04,59) = pd(04,59) + rrt(364) * density(02) 
  pd(17,02) = pd(17,02) + rrt(364) * density(59) 
  pd(17,59) = pd(17,59) + rrt(364) * density(02) 
  pd(59,02) = pd(59,02) - rrt(364) * density(59) 
  pd(59,59) = pd(59,59) - rrt(364) * density(02) 
  pd(04,04) = pd(04,04) - rrt(365) * density(57) 
  pd(04,57) = pd(04,57) - rrt(365) * density(04) 
  pd(05,04) = pd(05,04) + rrt(365) * density(57) 
  pd(05,57) = pd(05,57) + rrt(365) * density(04) 
  pd(17,04) = pd(17,04) + rrt(365) * density(57) 
  pd(17,57) = pd(17,57) + rrt(365) * density(04) 
  pd(57,04) = pd(57,04) - rrt(365) * density(57) 
  pd(57,57) = pd(57,57) - rrt(365) * density(04) 
  pd(04,04) = pd(04,04) - rrt(366) * density(58) 
  pd(04,58) = pd(04,58) - rrt(366) * density(04) 
  pd(05,04) = pd(05,04) + rrt(366) * density(58) 
  pd(05,58) = pd(05,58) + rrt(366) * density(04) 
  pd(17,04) = pd(17,04) + rrt(366) * density(58) 
  pd(17,58) = pd(17,58) + rrt(366) * density(04) 
  pd(58,04) = pd(58,04) - rrt(366) * density(58) 
  pd(58,58) = pd(58,58) - rrt(366) * density(04) 
  pd(04,04) = pd(04,04) - rrt(367) * density(59) 
  pd(04,59) = pd(04,59) - rrt(367) * density(04) 
  pd(05,04) = pd(05,04) + rrt(367) * density(59) 
  pd(05,59) = pd(05,59) + rrt(367) * density(04) 
  pd(17,04) = pd(17,04) + rrt(367) * density(59) 
  pd(17,59) = pd(17,59) + rrt(367) * density(04) 
  pd(59,04) = pd(59,04) - rrt(367) * density(59) 
  pd(59,59) = pd(59,59) - rrt(367) * density(04) 
  pd(01,01) = pd(01,01) - rrt(368) * density(57) 
  pd(01,57) = pd(01,57) - rrt(368) * density(01) 
  pd(06,01) = pd(06,01) + rrt(368) * density(57) 
  pd(06,57) = pd(06,57) + rrt(368) * density(01) 
  pd(17,01) = pd(17,01) + rrt(368) * density(57) 
  pd(17,57) = pd(17,57) + rrt(368) * density(01) 
  pd(57,01) = pd(57,01) - rrt(368) * density(57) 
  pd(57,57) = pd(57,57) - rrt(368) * density(01) 
  pd(01,01) = pd(01,01) - rrt(369) * density(58) 
  pd(01,58) = pd(01,58) - rrt(369) * density(01) 
  pd(06,01) = pd(06,01) + rrt(369) * density(58) 
  pd(06,58) = pd(06,58) + rrt(369) * density(01) 
  pd(17,01) = pd(17,01) + rrt(369) * density(58) 
  pd(17,58) = pd(17,58) + rrt(369) * density(01) 
  pd(58,01) = pd(58,01) - rrt(369) * density(58) 
  pd(58,58) = pd(58,58) - rrt(369) * density(01) 
  pd(01,01) = pd(01,01) - rrt(370) * density(59) 
  pd(01,59) = pd(01,59) - rrt(370) * density(01) 
  pd(06,01) = pd(06,01) + rrt(370) * density(59) 
  pd(06,59) = pd(06,59) + rrt(370) * density(01) 
  pd(17,01) = pd(17,01) + rrt(370) * density(59) 
  pd(17,59) = pd(17,59) + rrt(370) * density(01) 
  pd(59,01) = pd(59,01) - rrt(370) * density(59) 
  pd(59,59) = pd(59,59) - rrt(370) * density(01) 
  pd(06,06) = pd(06,06) - rrt(371) * density(57) 
  pd(06,57) = pd(06,57) - rrt(371) * density(06) 
  pd(07,06) = pd(07,06) + rrt(371) * density(57) 
  pd(07,57) = pd(07,57) + rrt(371) * density(06) 
  pd(17,06) = pd(17,06) + rrt(371) * density(57) 
  pd(17,57) = pd(17,57) + rrt(371) * density(06) 
  pd(57,06) = pd(57,06) - rrt(371) * density(57) 
  pd(57,57) = pd(57,57) - rrt(371) * density(06) 
  pd(06,06) = pd(06,06) - rrt(372) * density(58) 
  pd(06,58) = pd(06,58) - rrt(372) * density(06) 
  pd(07,06) = pd(07,06) + rrt(372) * density(58) 
  pd(07,58) = pd(07,58) + rrt(372) * density(06) 
  pd(17,06) = pd(17,06) + rrt(372) * density(58) 
  pd(17,58) = pd(17,58) + rrt(372) * density(06) 
  pd(58,06) = pd(58,06) - rrt(372) * density(58) 
  pd(58,58) = pd(58,58) - rrt(372) * density(06) 
  pd(06,06) = pd(06,06) - rrt(373) * density(59) 
  pd(06,59) = pd(06,59) - rrt(373) * density(06) 
  pd(07,06) = pd(07,06) + rrt(373) * density(59) 
  pd(07,59) = pd(07,59) + rrt(373) * density(06) 
  pd(17,06) = pd(17,06) + rrt(373) * density(59) 
  pd(17,59) = pd(17,59) + rrt(373) * density(06) 
  pd(59,06) = pd(59,06) - rrt(373) * density(59) 
  pd(59,59) = pd(59,59) - rrt(373) * density(06) 
  pd(08,08) = pd(08,08) - rrt(374) * density(57) 
  pd(08,57) = pd(08,57) - rrt(374) * density(08) 
  pd(09,08) = pd(09,08) + rrt(374) * density(57) 
  pd(09,57) = pd(09,57) + rrt(374) * density(08) 
  pd(17,08) = pd(17,08) + rrt(374) * density(57) 
  pd(17,57) = pd(17,57) + rrt(374) * density(08) 
  pd(57,08) = pd(57,08) - rrt(374) * density(57) 
  pd(57,57) = pd(57,57) - rrt(374) * density(08) 
  pd(08,08) = pd(08,08) - rrt(375) * density(58) 
  pd(08,58) = pd(08,58) - rrt(375) * density(08) 
  pd(09,08) = pd(09,08) + rrt(375) * density(58) 
  pd(09,58) = pd(09,58) + rrt(375) * density(08) 
  pd(17,08) = pd(17,08) + rrt(375) * density(58) 
  pd(17,58) = pd(17,58) + rrt(375) * density(08) 
  pd(58,08) = pd(58,08) - rrt(375) * density(58) 
  pd(58,58) = pd(58,58) - rrt(375) * density(08) 
  pd(08,08) = pd(08,08) - rrt(376) * density(59) 
  pd(08,59) = pd(08,59) - rrt(376) * density(08) 
  pd(09,08) = pd(09,08) + rrt(376) * density(59) 
  pd(09,59) = pd(09,59) + rrt(376) * density(08) 
  pd(17,08) = pd(17,08) + rrt(376) * density(59) 
  pd(17,59) = pd(17,59) + rrt(376) * density(08) 
  pd(59,08) = pd(59,08) - rrt(376) * density(59) 
  pd(59,59) = pd(59,59) - rrt(376) * density(08) 
  pd(01,10) = pd(01,10) + rrt(377) * density(54) 
  pd(01,54) = pd(01,54) + rrt(377) * density(10) 
  pd(10,10) = pd(10,10) - rrt(377) * density(54) 
  pd(10,54) = pd(10,54) - rrt(377) * density(10) 
  pd(12,10) = pd(12,10) + rrt(377) * density(54) 
  pd(12,54) = pd(12,54) + rrt(377) * density(10) 
  pd(54,10) = pd(54,10) - rrt(377) * density(54) 
  pd(54,54) = pd(54,54) - rrt(377) * density(10) 
  pd(02,02) = pd(02,02) + rrt(378) * density(54) 
  pd(02,54) = pd(02,54) + rrt(378) * density(02) 
  pd(54,02) = pd(54,02) - rrt(378) * density(54) 
  pd(54,54) = pd(54,54) - rrt(378) * density(02) 
  pd(02,11) = pd(02,11) + rrt(379) * density(54) 
  pd(02,54) = pd(02,54) + rrt(379) * density(11) 
  pd(54,11) = pd(54,11) - rrt(379) * density(54) 
  pd(54,54) = pd(54,54) - rrt(379) * density(11) 
  pd(02,12) = pd(02,12) + rrt(380) * density(54) 
  pd(02,54) = pd(02,54) + rrt(380) * density(12) 
  pd(54,12) = pd(54,12) - rrt(380) * density(54) 
  pd(54,54) = pd(54,54) - rrt(380) * density(12) 
  pd(02,03) = pd(02,03) + rrt(381) * density(54) * 2.0d0
  pd(02,54) = pd(02,54) + rrt(381) * density(03) * 2.0d0
  pd(03,03) = pd(03,03) - rrt(381) * density(54) 
  pd(03,54) = pd(03,54) - rrt(381) * density(03) 
  pd(36,03) = pd(36,03) + rrt(381) * density(54) 
  pd(36,54) = pd(36,54) + rrt(381) * density(03) 
  pd(54,03) = pd(54,03) - rrt(381) * density(54) 
  pd(54,54) = pd(54,54) - rrt(381) * density(03) 
  pd(02,54) = pd(02,54) + rrt(382) * density(54) * 2.0d0
  pd(54,54) = pd(54,54) - rrt(382) * density(54) * 4.0d0
  pd(55,54) = pd(55,54) + rrt(382) * density(54) * 2.0d0
  pd(01,02) = pd(01,02) + rrt(383) * density(54) 
  pd(01,54) = pd(01,54) + rrt(383) * density(02) 
  pd(02,02) = pd(02,02) - rrt(383) * density(54) 
  pd(02,54) = pd(02,54) - rrt(383) * density(02) 
  pd(03,02) = pd(03,02) + rrt(383) * density(54) 
  pd(03,54) = pd(03,54) + rrt(383) * density(02) 
  pd(54,02) = pd(54,02) - rrt(383) * density(54) 
  pd(54,54) = pd(54,54) - rrt(383) * density(02) 
  pd(02,54) = pd(02,54) + rrt(384) * density(54) * 4.0d0
  pd(54,54) = pd(54,54) - rrt(384) * density(54) * 4.0d0
  pd(02,01) = pd(02,01) + rrt(385) * density(02) * density(54) 
  pd(02,02) = pd(02,02) + rrt(385) * density(01) * density(54) 
  pd(02,54) = pd(02,54) + rrt(385) * density(01) * density(02) 
  pd(54,01) = pd(54,01) - rrt(385) * density(02) * density(54) 
  pd(54,02) = pd(54,02) - rrt(385) * density(01) * density(54) 
  pd(54,54) = pd(54,54) - rrt(385) * density(01) * density(02) 
  pd(02,01) = pd(02,01) + rrt(386) * density(54) 
  pd(02,54) = pd(02,54) + rrt(386) * density(01) 
  pd(54,01) = pd(54,01) - rrt(386) * density(54) 
  pd(54,54) = pd(54,54) - rrt(386) * density(01) 
  pd(54,01) = pd(54,01) + rrt(387) * density(55) 
  pd(54,55) = pd(54,55) + rrt(387) * density(01) 
  pd(55,01) = pd(55,01) - rrt(387) * density(55) 
  pd(55,55) = pd(55,55) - rrt(387) * density(01) 
  pd(05,05) = pd(05,05) - rrt(388) * density(54) 
  pd(05,54) = pd(05,54) - rrt(388) * density(05) 
  pd(06,05) = pd(06,05) + rrt(388) * density(54) * 2.0d0
  pd(06,54) = pd(06,54) + rrt(388) * density(05) * 2.0d0
  pd(54,05) = pd(54,05) - rrt(388) * density(54) 
  pd(54,54) = pd(54,54) - rrt(388) * density(05) 
  pd(02,05) = pd(02,05) + rrt(389) * density(54) 
  pd(02,54) = pd(02,54) + rrt(389) * density(05) 
  pd(54,05) = pd(54,05) - rrt(389) * density(54) 
  pd(54,54) = pd(54,54) - rrt(389) * density(05) 
  pd(01,04) = pd(01,04) + rrt(390) * density(54) 
  pd(01,54) = pd(01,54) + rrt(390) * density(04) 
  pd(04,04) = pd(04,04) - rrt(390) * density(54) 
  pd(04,54) = pd(04,54) - rrt(390) * density(04) 
  pd(06,04) = pd(06,04) + rrt(390) * density(54) 
  pd(06,54) = pd(06,54) + rrt(390) * density(04) 
  pd(54,04) = pd(54,04) - rrt(390) * density(54) 
  pd(54,54) = pd(54,54) - rrt(390) * density(04) 
  pd(04,04) = pd(04,04) - rrt(391) * density(54) 
  pd(04,54) = pd(04,54) - rrt(391) * density(04) 
  pd(08,04) = pd(08,04) + rrt(391) * density(54) 
  pd(08,54) = pd(08,54) + rrt(391) * density(04) 
  pd(54,04) = pd(54,04) - rrt(391) * density(54) 
  pd(54,54) = pd(54,54) - rrt(391) * density(04) 
  pd(02,04) = pd(02,04) + rrt(392) * density(54) 
  pd(02,54) = pd(02,54) + rrt(392) * density(04) 
  pd(54,04) = pd(54,04) - rrt(392) * density(54) 
  pd(54,54) = pd(54,54) - rrt(392) * density(04) 
  pd(04,05) = pd(04,05) + rrt(393) * density(54) 
  pd(04,54) = pd(04,54) + rrt(393) * density(05) 
  pd(05,05) = pd(05,05) - rrt(393) * density(54) 
  pd(05,54) = pd(05,54) - rrt(393) * density(05) 
  pd(08,05) = pd(08,05) + rrt(393) * density(54) 
  pd(08,54) = pd(08,54) + rrt(393) * density(05) 
  pd(54,05) = pd(54,05) - rrt(393) * density(54) 
  pd(54,54) = pd(54,54) - rrt(393) * density(05) 
  pd(06,07) = pd(06,07) + rrt(394) * density(54) 
  pd(06,54) = pd(06,54) + rrt(394) * density(07) 
  pd(07,07) = pd(07,07) - rrt(394) * density(54) 
  pd(07,54) = pd(07,54) - rrt(394) * density(07) 
  pd(08,07) = pd(08,07) + rrt(394) * density(54) 
  pd(08,54) = pd(08,54) + rrt(394) * density(07) 
  pd(54,07) = pd(54,07) - rrt(394) * density(54) 
  pd(54,54) = pd(54,54) - rrt(394) * density(07) 
  pd(05,05) = pd(05,05) - rrt(395) * density(54) 
  pd(05,54) = pd(05,54) - rrt(395) * density(05) 
  pd(07,05) = pd(07,05) + rrt(395) * density(54) 
  pd(07,54) = pd(07,54) + rrt(395) * density(05) 
  pd(36,05) = pd(36,05) + rrt(395) * density(54) 
  pd(36,54) = pd(36,54) + rrt(395) * density(05) 
  pd(54,05) = pd(54,05) - rrt(395) * density(54) 
  pd(54,54) = pd(54,54) - rrt(395) * density(05) 
  pd(03,06) = pd(03,06) + rrt(396) * density(54) 
  pd(03,54) = pd(03,54) + rrt(396) * density(06) 
  pd(04,06) = pd(04,06) + rrt(396) * density(54) 
  pd(04,54) = pd(04,54) + rrt(396) * density(06) 
  pd(06,06) = pd(06,06) - rrt(396) * density(54) 
  pd(06,54) = pd(06,54) - rrt(396) * density(06) 
  pd(54,06) = pd(54,06) - rrt(396) * density(54) 
  pd(54,54) = pd(54,54) - rrt(396) * density(06) 
  pd(01,06) = pd(01,06) + rrt(397) * density(54) 
  pd(01,54) = pd(01,54) + rrt(397) * density(06) 
  pd(06,06) = pd(06,06) - rrt(397) * density(54) 
  pd(06,54) = pd(06,54) - rrt(397) * density(06) 
  pd(08,06) = pd(08,06) + rrt(397) * density(54) 
  pd(08,54) = pd(08,54) + rrt(397) * density(06) 
  pd(54,06) = pd(54,06) - rrt(397) * density(54) 
  pd(54,54) = pd(54,54) - rrt(397) * density(06) 
  pd(02,06) = pd(02,06) + rrt(398) * density(54) 
  pd(02,54) = pd(02,54) + rrt(398) * density(06) 
  pd(54,06) = pd(54,06) - rrt(398) * density(54) 
  pd(54,54) = pd(54,54) - rrt(398) * density(06) 
  pd(02,09) = pd(02,09) + rrt(399) * density(54) 
  pd(02,54) = pd(02,54) + rrt(399) * density(09) 
  pd(54,09) = pd(54,09) - rrt(399) * density(54) 
  pd(54,54) = pd(54,54) - rrt(399) * density(09) 
  pd(02,08) = pd(02,08) + rrt(400) * density(54) 
  pd(02,54) = pd(02,54) + rrt(400) * density(08) 
  pd(54,08) = pd(54,08) - rrt(400) * density(54) 
  pd(54,54) = pd(54,54) - rrt(400) * density(08) 
  pd(01,17) = pd(01,17) + rrt(401) * density(54) 
  pd(01,54) = pd(01,54) + rrt(401) * density(17) 
  pd(17,17) = pd(17,17) - rrt(401) * density(54) 
  pd(17,54) = pd(17,54) - rrt(401) * density(17) 
  pd(24,17) = pd(24,17) + rrt(401) * density(54) 
  pd(24,54) = pd(24,54) + rrt(401) * density(17) 
  pd(54,17) = pd(54,17) - rrt(401) * density(54) 
  pd(54,54) = pd(54,54) - rrt(401) * density(17) 
  pd(06,17) = pd(06,17) + rrt(402) * density(54) 
  pd(06,54) = pd(06,54) + rrt(402) * density(17) 
  pd(17,17) = pd(17,17) - rrt(402) * density(54) 
  pd(17,54) = pd(17,54) - rrt(402) * density(17) 
  pd(26,17) = pd(26,17) + rrt(402) * density(54) 
  pd(26,54) = pd(26,54) + rrt(402) * density(17) 
  pd(54,17) = pd(54,17) - rrt(402) * density(54) 
  pd(54,54) = pd(54,54) - rrt(402) * density(17) 
  pd(08,24) = pd(08,24) + rrt(403) * density(54) 
  pd(08,54) = pd(08,54) + rrt(403) * density(24) 
  pd(24,24) = pd(24,24) - rrt(403) * density(54) 
  pd(24,54) = pd(24,54) - rrt(403) * density(24) 
  pd(26,24) = pd(26,24) + rrt(403) * density(54) 
  pd(26,54) = pd(26,54) + rrt(403) * density(24) 
  pd(54,24) = pd(54,24) - rrt(403) * density(54) 
  pd(54,54) = pd(54,54) - rrt(403) * density(24) 
  pd(08,28) = pd(08,28) + rrt(404) * density(54) 
  pd(08,54) = pd(08,54) + rrt(404) * density(28) 
  pd(26,28) = pd(26,28) + rrt(404) * density(54) 
  pd(26,54) = pd(26,54) + rrt(404) * density(28) 
  pd(28,28) = pd(28,28) - rrt(404) * density(54) 
  pd(28,54) = pd(28,54) - rrt(404) * density(28) 
  pd(54,28) = pd(54,28) - rrt(404) * density(54) 
  pd(54,54) = pd(54,54) - rrt(404) * density(28) 
  pd(01,01) = pd(01,01) - rrt(405) * density(55) 
  pd(01,55) = pd(01,55) - rrt(405) * density(01) 
  pd(02,01) = pd(02,01) + rrt(405) * density(55) 
  pd(02,55) = pd(02,55) + rrt(405) * density(01) 
  pd(36,01) = pd(36,01) + rrt(405) * density(55) 
  pd(36,55) = pd(36,55) + rrt(405) * density(01) 
  pd(55,01) = pd(55,01) - rrt(405) * density(55) 
  pd(55,55) = pd(55,55) - rrt(405) * density(01) 
  pd(54,02) = pd(54,02) + rrt(406) * density(55) 
  pd(54,55) = pd(54,55) + rrt(406) * density(02) 
  pd(55,02) = pd(55,02) - rrt(406) * density(55) 
  pd(55,55) = pd(55,55) - rrt(406) * density(02) 
  pd(01,03) = pd(01,03) + rrt(407) * density(55) 
  pd(01,55) = pd(01,55) + rrt(407) * density(03) 
  pd(02,03) = pd(02,03) + rrt(407) * density(55) * 2.0d0
  pd(02,55) = pd(02,55) + rrt(407) * density(03) * 2.0d0
  pd(03,03) = pd(03,03) - rrt(407) * density(55) 
  pd(03,55) = pd(03,55) - rrt(407) * density(03) 
  pd(55,03) = pd(55,03) - rrt(407) * density(55) 
  pd(55,55) = pd(55,55) - rrt(407) * density(03) 
  pd(54,11) = pd(54,11) + rrt(408) * density(55) 
  pd(54,55) = pd(54,55) + rrt(408) * density(11) 
  pd(55,11) = pd(55,11) - rrt(408) * density(55) 
  pd(55,55) = pd(55,55) - rrt(408) * density(11) 
  pd(54,12) = pd(54,12) + rrt(409) * density(55) 
  pd(54,55) = pd(54,55) + rrt(409) * density(12) 
  pd(55,12) = pd(55,12) - rrt(409) * density(55) 
  pd(55,55) = pd(55,55) - rrt(409) * density(12) 
  pd(02,01) = pd(02,01) + rrt(410) * density(55) 
  pd(02,55) = pd(02,55) + rrt(410) * density(01) 
  pd(55,01) = pd(55,01) - rrt(410) * density(55) 
  pd(55,55) = pd(55,55) - rrt(410) * density(01) 
  pd(02,55) = pd(02,55) + rrt(411) * density(55) * 2.0d0
  pd(54,55) = pd(54,55) + rrt(411) * density(55) * 2.0d0
  pd(55,55) = pd(55,55) - rrt(411) * density(55) * 4.0d0
  pd(01,03) = pd(01,03) + rrt(412) * density(55) 
  pd(01,55) = pd(01,55) + rrt(412) * density(03) 
  pd(02,03) = pd(02,03) + rrt(412) * density(55) 
  pd(02,55) = pd(02,55) + rrt(412) * density(03) 
  pd(03,03) = pd(03,03) - rrt(412) * density(55) 
  pd(03,55) = pd(03,55) - rrt(412) * density(03) 
  pd(54,03) = pd(54,03) + rrt(412) * density(55) 
  pd(54,55) = pd(54,55) + rrt(412) * density(03) 
  pd(55,03) = pd(55,03) - rrt(412) * density(55) 
  pd(55,55) = pd(55,55) - rrt(412) * density(03) 
  pd(02,03) = pd(02,03) + rrt(413) * density(55) 
  pd(02,55) = pd(02,55) + rrt(413) * density(03) 
  pd(55,03) = pd(55,03) - rrt(413) * density(55) 
  pd(55,55) = pd(55,55) - rrt(413) * density(03) 
  pd(54,03) = pd(54,03) + rrt(414) * density(55) 
  pd(54,55) = pd(54,55) + rrt(414) * density(03) 
  pd(55,03) = pd(55,03) - rrt(414) * density(55) 
  pd(55,55) = pd(55,55) - rrt(414) * density(03) 
  pd(02,02) = pd(02,02) + rrt(415) * density(55) 
  pd(02,55) = pd(02,55) + rrt(415) * density(02) 
  pd(55,02) = pd(55,02) - rrt(415) * density(55) 
  pd(55,55) = pd(55,55) - rrt(415) * density(02) 
  pd(01,01) = pd(01,01) - rrt(416) * density(35) 
  pd(01,35) = pd(01,35) - rrt(416) * density(01) 
  pd(02,01) = pd(02,01) + rrt(416) * density(35) 
  pd(02,35) = pd(02,35) + rrt(416) * density(01) 
  pd(35,01) = pd(35,01) - rrt(416) * density(35) 
  pd(35,35) = pd(35,35) - rrt(416) * density(01) 
  pd(37,01) = pd(37,01) + rrt(416) * density(35) 
  pd(37,35) = pd(37,35) + rrt(416) * density(01) 
  pd(02,02) = pd(02,02) - rrt(417) * density(35) 
  pd(02,35) = pd(02,35) - rrt(417) * density(02) 
  pd(35,02) = pd(35,02) - rrt(417) * density(35) 
  pd(35,35) = pd(35,35) - rrt(417) * density(02) 
  pd(55,02) = pd(55,02) + rrt(417) * density(35) * 2.0d0
  pd(55,35) = pd(55,35) + rrt(417) * density(02) * 2.0d0
  pd(35,11) = pd(35,11) - rrt(418) * density(35) 
  pd(35,35) = pd(35,35) - rrt(418) * density(11) 
  pd(55,11) = pd(55,11) + rrt(418) * density(35) 
  pd(55,35) = pd(55,35) + rrt(418) * density(11) 
  pd(02,01) = pd(02,01) + rrt(419) * density(35) 
  pd(02,35) = pd(02,35) + rrt(419) * density(01) 
  pd(35,01) = pd(35,01) - rrt(419) * density(35) 
  pd(35,35) = pd(35,35) - rrt(419) * density(01) 
  pd(01,01) = pd(01,01) - rrt(420) * density(35) 
  pd(01,35) = pd(01,35) - rrt(420) * density(01) 
  pd(35,01) = pd(35,01) - rrt(420) * density(35) 
  pd(35,35) = pd(35,35) - rrt(420) * density(01) 
  pd(36,01) = pd(36,01) + rrt(420) * density(35) 
  pd(36,35) = pd(36,35) + rrt(420) * density(01) 
  pd(54,01) = pd(54,01) + rrt(420) * density(35) 
  pd(54,35) = pd(54,35) + rrt(420) * density(01) 
  pd(01,01) = pd(01,01) - rrt(421) * density(35) 
  pd(01,35) = pd(01,35) - rrt(421) * density(01) 
  pd(35,01) = pd(35,01) - rrt(421) * density(35) 
  pd(35,35) = pd(35,35) - rrt(421) * density(01) 
  pd(36,01) = pd(36,01) + rrt(421) * density(35) 
  pd(36,35) = pd(36,35) + rrt(421) * density(01) 
  pd(55,01) = pd(55,01) + rrt(421) * density(35) 
  pd(55,35) = pd(55,35) + rrt(421) * density(01) 
  pd(35,02) = pd(35,02) - rrt(422) * density(35) 
  pd(35,35) = pd(35,35) - rrt(422) * density(02) 
  pd(54,02) = pd(54,02) + rrt(422) * density(35) 
  pd(54,35) = pd(54,35) + rrt(422) * density(02) 
  pd(35,02) = pd(35,02) - rrt(423) * density(35) 
  pd(35,35) = pd(35,35) - rrt(423) * density(02) 
  pd(55,02) = pd(55,02) + rrt(423) * density(35) 
  pd(55,35) = pd(55,35) + rrt(423) * density(02) 
  pd(02,02) = pd(02,02) + rrt(424) * density(35) 
  pd(02,35) = pd(02,35) + rrt(424) * density(02) 
  pd(35,02) = pd(35,02) - rrt(424) * density(35) 
  pd(35,35) = pd(35,35) - rrt(424) * density(02) 
  pd(01,01) = pd(01,01) + rrt(425) * density(36) 
  pd(01,36) = pd(01,36) + rrt(425) * density(01) 
  pd(36,01) = pd(36,01) - rrt(425) * density(36) 
  pd(36,36) = pd(36,36) - rrt(425) * density(01) 
  pd(01,02) = pd(01,02) + rrt(426) * density(36) 
  pd(01,36) = pd(01,36) + rrt(426) * density(02) 
  pd(36,02) = pd(36,02) - rrt(426) * density(36) 
  pd(36,36) = pd(36,36) - rrt(426) * density(02) 
  pd(01,02) = pd(01,02) + rrt(427) * density(36) 
  pd(01,36) = pd(01,36) + rrt(427) * density(02) 
  pd(02,02) = pd(02,02) - rrt(427) * density(36) 
  pd(02,36) = pd(02,36) - rrt(427) * density(02) 
  pd(36,02) = pd(36,02) - rrt(427) * density(36) 
  pd(36,36) = pd(36,36) - rrt(427) * density(02) 
  pd(54,02) = pd(54,02) + rrt(427) * density(36) 
  pd(54,36) = pd(54,36) + rrt(427) * density(02) 
  pd(01,02) = pd(01,02) + rrt(428) * density(36) 
  pd(01,36) = pd(01,36) + rrt(428) * density(02) 
  pd(02,02) = pd(02,02) - rrt(428) * density(36) 
  pd(02,36) = pd(02,36) - rrt(428) * density(02) 
  pd(36,02) = pd(36,02) - rrt(428) * density(36) 
  pd(36,36) = pd(36,36) - rrt(428) * density(02) 
  pd(55,02) = pd(55,02) + rrt(428) * density(36) 
  pd(55,36) = pd(55,36) + rrt(428) * density(02) 
  pd(01,03) = pd(01,03) + rrt(429) * density(36) * 2.0d0
  pd(01,36) = pd(01,36) + rrt(429) * density(03) * 2.0d0
  pd(02,03) = pd(02,03) + rrt(429) * density(36) 
  pd(02,36) = pd(02,36) + rrt(429) * density(03) 
  pd(03,03) = pd(03,03) - rrt(429) * density(36) 
  pd(03,36) = pd(03,36) - rrt(429) * density(03) 
  pd(36,03) = pd(36,03) - rrt(429) * density(36) 
  pd(36,36) = pd(36,36) - rrt(429) * density(03) 
  pd(02,03) = pd(02,03) + rrt(430) * density(36) * 2.0d0
  pd(02,36) = pd(02,36) + rrt(430) * density(03) * 2.0d0
  pd(03,03) = pd(03,03) - rrt(430) * density(36) 
  pd(03,36) = pd(03,36) - rrt(430) * density(03) 
  pd(36,03) = pd(36,03) - rrt(430) * density(36) 
  pd(36,36) = pd(36,36) - rrt(430) * density(03) 
  pd(01,11) = pd(01,11) + rrt(431) * density(36) 
  pd(01,36) = pd(01,36) + rrt(431) * density(11) 
  pd(36,11) = pd(36,11) - rrt(431) * density(36) 
  pd(36,36) = pd(36,36) - rrt(431) * density(11) 
  pd(02,12) = pd(02,12) + rrt(432) * density(36) 
  pd(02,36) = pd(02,36) + rrt(432) * density(12) 
  pd(10,12) = pd(10,12) + rrt(432) * density(36) 
  pd(10,36) = pd(10,36) + rrt(432) * density(12) 
  pd(12,12) = pd(12,12) - rrt(432) * density(36) 
  pd(12,36) = pd(12,36) - rrt(432) * density(12) 
  pd(36,12) = pd(36,12) - rrt(432) * density(36) 
  pd(36,36) = pd(36,36) - rrt(432) * density(12) 
  pd(12,14) = pd(12,14) + rrt(433) * density(36) * 2.0d0
  pd(12,36) = pd(12,36) + rrt(433) * density(14) * 2.0d0
  pd(14,14) = pd(14,14) - rrt(433) * density(36) 
  pd(14,36) = pd(14,36) - rrt(433) * density(14) 
  pd(36,14) = pd(36,14) - rrt(433) * density(36) 
  pd(36,36) = pd(36,36) - rrt(433) * density(14) 
  pd(06,16) = pd(06,16) + rrt(434) * density(36) 
  pd(06,36) = pd(06,36) + rrt(434) * density(16) 
  pd(16,16) = pd(16,16) - rrt(434) * density(36) 
  pd(16,36) = pd(16,36) - rrt(434) * density(16) 
  pd(17,16) = pd(17,16) + rrt(434) * density(36) 
  pd(17,36) = pd(17,36) + rrt(434) * density(16) 
  pd(36,16) = pd(36,16) - rrt(434) * density(36) 
  pd(36,36) = pd(36,36) - rrt(434) * density(16) 
  pd(07,16) = pd(07,16) + rrt(435) * density(36) 
  pd(07,36) = pd(07,36) + rrt(435) * density(16) 
  pd(16,16) = pd(16,16) - rrt(435) * density(36) 
  pd(16,36) = pd(16,36) - rrt(435) * density(16) 
  pd(18,16) = pd(18,16) + rrt(435) * density(36) 
  pd(18,36) = pd(18,36) + rrt(435) * density(16) 
  pd(36,16) = pd(36,16) - rrt(435) * density(36) 
  pd(36,36) = pd(36,36) - rrt(435) * density(16) 
  pd(04,16) = pd(04,16) + rrt(436) * density(36) 
  pd(04,36) = pd(04,36) + rrt(436) * density(16) 
  pd(16,16) = pd(16,16) - rrt(436) * density(36) 
  pd(16,36) = pd(16,36) - rrt(436) * density(16) 
  pd(24,16) = pd(24,16) + rrt(436) * density(36) 
  pd(24,36) = pd(24,36) + rrt(436) * density(16) 
  pd(36,16) = pd(36,16) - rrt(436) * density(36) 
  pd(36,36) = pd(36,36) - rrt(436) * density(16) 
  pd(02,14) = pd(02,14) + rrt(437) * density(36) 
  pd(02,36) = pd(02,36) + rrt(437) * density(14) 
  pd(11,14) = pd(11,14) + rrt(437) * density(36) 
  pd(11,36) = pd(11,36) + rrt(437) * density(14) 
  pd(14,14) = pd(14,14) - rrt(437) * density(36) 
  pd(14,36) = pd(14,36) - rrt(437) * density(14) 
  pd(36,14) = pd(36,14) - rrt(437) * density(36) 
  pd(36,36) = pd(36,36) - rrt(437) * density(14) 
  pd(02,14) = pd(02,14) + rrt(438) * density(37) 
  pd(02,37) = pd(02,37) + rrt(438) * density(14) 
  pd(11,14) = pd(11,14) + rrt(438) * density(37) 
  pd(11,37) = pd(11,37) + rrt(438) * density(14) 
  pd(14,14) = pd(14,14) - rrt(438) * density(37) 
  pd(14,37) = pd(14,37) - rrt(438) * density(14) 
  pd(37,14) = pd(37,14) - rrt(438) * density(37) 
  pd(37,37) = pd(37,37) - rrt(438) * density(14) 
  pd(11,10) = pd(11,10) + rrt(439) * density(46) 
  pd(11,46) = pd(11,46) + rrt(439) * density(10) 
  pd(46,10) = pd(46,10) - rrt(439) * density(46) 
  pd(46,46) = pd(46,46) - rrt(439) * density(10) 
  pd(10,10) = pd(10,10) - rrt(440) * density(46) 
  pd(10,46) = pd(10,46) - rrt(440) * density(10) 
  pd(11,10) = pd(11,10) + rrt(440) * density(46) 
  pd(11,46) = pd(11,46) + rrt(440) * density(10) 
  pd(33,10) = pd(33,10) + rrt(440) * density(46) 
  pd(33,46) = pd(33,46) + rrt(440) * density(10) 
  pd(46,10) = pd(46,10) - rrt(440) * density(46) 
  pd(46,46) = pd(46,46) - rrt(440) * density(10) 
  pd(11,11) = pd(11,11) + rrt(441) * density(46) 
  pd(11,46) = pd(11,46) + rrt(441) * density(11) 
  pd(46,11) = pd(46,11) - rrt(441) * density(46) 
  pd(46,46) = pd(46,46) - rrt(441) * density(11) 
  pd(11,46) = pd(11,46) + rrt(442) * density(46) * 2.0d0
  pd(46,46) = pd(46,46) - rrt(442) * density(46) * 4.0d0
  pd(47,46) = pd(47,46) + rrt(442) * density(46) * 2.0d0
  pd(11,46) = pd(11,46) + rrt(443) * density(46) * 2.0d0
  pd(46,46) = pd(46,46) - rrt(443) * density(46) * 4.0d0
  pd(49,46) = pd(49,46) + rrt(443) * density(46) * 2.0d0
  pd(01,01) = pd(01,01) - rrt(444) * density(46) 
  pd(01,46) = pd(01,46) - rrt(444) * density(01) 
  pd(12,01) = pd(12,01) + rrt(444) * density(46) 
  pd(12,46) = pd(12,46) + rrt(444) * density(01) 
  pd(34,01) = pd(34,01) + rrt(444) * density(46) 
  pd(34,46) = pd(34,46) + rrt(444) * density(01) 
  pd(46,01) = pd(46,01) - rrt(444) * density(46) 
  pd(46,46) = pd(46,46) - rrt(444) * density(01) 
  pd(01,01) = pd(01,01) - rrt(445) * density(46) 
  pd(01,46) = pd(01,46) - rrt(445) * density(01) 
  pd(11,01) = pd(11,01) + rrt(445) * density(46) 
  pd(11,46) = pd(11,46) + rrt(445) * density(01) 
  pd(37,01) = pd(37,01) + rrt(445) * density(46) 
  pd(37,46) = pd(37,46) + rrt(445) * density(01) 
  pd(46,01) = pd(46,01) - rrt(445) * density(46) 
  pd(46,46) = pd(46,46) - rrt(445) * density(01) 
  pd(02,02) = pd(02,02) - rrt(446) * density(46) 
  pd(02,46) = pd(02,46) - rrt(446) * density(02) 
  pd(11,02) = pd(11,02) + rrt(446) * density(46) 
  pd(11,46) = pd(11,46) + rrt(446) * density(02) 
  pd(46,02) = pd(46,02) - rrt(446) * density(46) 
  pd(46,46) = pd(46,46) - rrt(446) * density(02) 
  pd(54,02) = pd(54,02) + rrt(446) * density(46) 
  pd(54,46) = pd(54,46) + rrt(446) * density(02) 
  pd(02,02) = pd(02,02) - rrt(447) * density(46) 
  pd(02,46) = pd(02,46) - rrt(447) * density(02) 
  pd(11,02) = pd(11,02) + rrt(447) * density(46) 
  pd(11,46) = pd(11,46) + rrt(447) * density(02) 
  pd(46,02) = pd(46,02) - rrt(447) * density(46) 
  pd(46,46) = pd(46,46) - rrt(447) * density(02) 
  pd(55,02) = pd(55,02) + rrt(447) * density(46) 
  pd(55,46) = pd(55,46) + rrt(447) * density(02) 
  pd(01,02) = pd(01,02) + rrt(448) * density(46) 
  pd(01,46) = pd(01,46) + rrt(448) * density(02) 
  pd(02,02) = pd(02,02) - rrt(448) * density(46) 
  pd(02,46) = pd(02,46) - rrt(448) * density(02) 
  pd(14,02) = pd(14,02) + rrt(448) * density(46) 
  pd(14,46) = pd(14,46) + rrt(448) * density(02) 
  pd(46,02) = pd(46,02) - rrt(448) * density(46) 
  pd(46,46) = pd(46,46) - rrt(448) * density(02) 
  pd(11,12) = pd(11,12) + rrt(449) * density(46) 
  pd(11,46) = pd(11,46) + rrt(449) * density(12) 
  pd(46,12) = pd(46,12) - rrt(449) * density(46) 
  pd(46,46) = pd(46,46) - rrt(449) * density(12) 
  pd(10,14) = pd(10,14) + rrt(450) * density(46) 
  pd(10,46) = pd(10,46) + rrt(450) * density(14) 
  pd(11,14) = pd(11,14) + rrt(450) * density(46) 
  pd(11,46) = pd(11,46) + rrt(450) * density(14) 
  pd(12,14) = pd(12,14) + rrt(450) * density(46) 
  pd(12,46) = pd(12,46) + rrt(450) * density(14) 
  pd(14,14) = pd(14,14) - rrt(450) * density(46) 
  pd(14,46) = pd(14,46) - rrt(450) * density(14) 
  pd(46,14) = pd(46,14) - rrt(450) * density(46) 
  pd(46,46) = pd(46,46) - rrt(450) * density(14) 
  pd(01,13) = pd(01,13) + rrt(451) * density(46) 
  pd(01,46) = pd(01,46) + rrt(451) * density(13) 
  pd(11,13) = pd(11,13) + rrt(451) * density(46) 
  pd(11,46) = pd(11,46) + rrt(451) * density(13) 
  pd(12,13) = pd(12,13) + rrt(451) * density(46) 
  pd(12,46) = pd(12,46) + rrt(451) * density(13) 
  pd(13,13) = pd(13,13) - rrt(451) * density(46) 
  pd(13,46) = pd(13,46) - rrt(451) * density(13) 
  pd(46,13) = pd(46,13) - rrt(451) * density(46) 
  pd(46,46) = pd(46,46) - rrt(451) * density(13) 
  pd(01,02) = pd(01,02) + rrt(452) * density(46) * 2.0d0
  pd(01,46) = pd(01,46) + rrt(452) * density(02) * 2.0d0
  pd(02,02) = pd(02,02) - rrt(452) * density(46) 
  pd(02,46) = pd(02,46) - rrt(452) * density(02) 
  pd(11,02) = pd(11,02) + rrt(452) * density(46) 
  pd(11,46) = pd(11,46) + rrt(452) * density(02) 
  pd(46,02) = pd(46,02) - rrt(452) * density(46) 
  pd(46,46) = pd(46,46) - rrt(452) * density(02) 
  pd(46,11) = pd(46,11) + rrt(453) * density(47) 
  pd(46,47) = pd(46,47) + rrt(453) * density(11) 
  pd(47,11) = pd(47,11) - rrt(453) * density(47) 
  pd(47,47) = pd(47,47) - rrt(453) * density(11) 
  pd(11,11) = pd(11,11) + rrt(454) * density(47) 
  pd(11,47) = pd(11,47) + rrt(454) * density(11) 
  pd(47,11) = pd(47,11) - rrt(454) * density(47) 
  pd(47,47) = pd(47,47) - rrt(454) * density(11) 
  pd(46,12) = pd(46,12) + rrt(455) * density(47) 
  pd(46,47) = pd(46,47) + rrt(455) * density(12) 
  pd(47,12) = pd(47,12) - rrt(455) * density(47) 
  pd(47,47) = pd(47,47) - rrt(455) * density(12) 
  pd(01,02) = pd(01,02) + rrt(456) * density(47) * 2.0d0
  pd(01,47) = pd(01,47) + rrt(456) * density(02) * 2.0d0
  pd(02,02) = pd(02,02) - rrt(456) * density(47) 
  pd(02,47) = pd(02,47) - rrt(456) * density(02) 
  pd(11,02) = pd(11,02) + rrt(456) * density(47) 
  pd(11,47) = pd(11,47) + rrt(456) * density(02) 
  pd(47,02) = pd(47,02) - rrt(456) * density(47) 
  pd(47,47) = pd(47,47) - rrt(456) * density(02) 
  pd(01,01) = pd(01,01) - rrt(457) * density(47) 
  pd(01,47) = pd(01,47) - rrt(457) * density(01) 
  pd(12,01) = pd(12,01) + rrt(457) * density(47) 
  pd(12,47) = pd(12,47) + rrt(457) * density(01) 
  pd(34,01) = pd(34,01) + rrt(457) * density(47) 
  pd(34,47) = pd(34,47) + rrt(457) * density(01) 
  pd(47,01) = pd(47,01) - rrt(457) * density(47) 
  pd(47,47) = pd(47,47) - rrt(457) * density(01) 
  pd(47,11) = pd(47,11) + rrt(458) * density(48) 
  pd(47,48) = pd(47,48) + rrt(458) * density(11) 
  pd(48,11) = pd(48,11) - rrt(458) * density(48) 
  pd(48,48) = pd(48,48) - rrt(458) * density(11) 
  pd(01,12) = pd(01,12) + rrt(459) * density(48) 
  pd(01,48) = pd(01,48) + rrt(459) * density(12) 
  pd(10,12) = pd(10,12) + rrt(459) * density(48) 
  pd(10,48) = pd(10,48) + rrt(459) * density(12) 
  pd(11,12) = pd(11,12) + rrt(459) * density(48) 
  pd(11,48) = pd(11,48) + rrt(459) * density(12) 
  pd(12,12) = pd(12,12) - rrt(459) * density(48) 
  pd(12,48) = pd(12,48) - rrt(459) * density(12) 
  pd(48,12) = pd(48,12) - rrt(459) * density(48) 
  pd(48,48) = pd(48,48) - rrt(459) * density(12) 
  pd(46,46) = pd(46,46) - rrt(460) * density(48) 
  pd(46,48) = pd(46,48) - rrt(460) * density(46) 
  pd(48,46) = pd(48,46) - rrt(460) * density(48) 
  pd(48,48) = pd(48,48) - rrt(460) * density(46) 
  pd(63,46) = pd(63,46) + rrt(460) * density(48) 
  pd(63,48) = pd(63,48) + rrt(460) * density(46) 
  pd(80,46) = pd(80,46) + rrt(460) * density(48) 
  pd(80,48) = pd(80,48) + rrt(460) * density(46) 
  pd(48,48) = pd(48,48) - rrt(461) * density(48) * 4.0d0
  pd(63,48) = pd(63,48) + rrt(461) * density(48) * 2.0d0
  pd(80,48) = pd(80,48) + rrt(461) * density(48) * 2.0d0
  pd(01,02) = pd(01,02) + rrt(462) * density(48) 
  pd(01,48) = pd(01,48) + rrt(462) * density(02) 
  pd(02,02) = pd(02,02) - rrt(462) * density(48) 
  pd(02,48) = pd(02,48) - rrt(462) * density(02) 
  pd(11,02) = pd(11,02) + rrt(462) * density(48) 
  pd(11,48) = pd(11,48) + rrt(462) * density(02) 
  pd(36,02) = pd(36,02) + rrt(462) * density(48) 
  pd(36,48) = pd(36,48) + rrt(462) * density(02) 
  pd(48,02) = pd(48,02) - rrt(462) * density(48) 
  pd(48,48) = pd(48,48) - rrt(462) * density(02) 
  pd(01,01) = pd(01,01) - rrt(463) * density(48) 
  pd(01,48) = pd(01,48) - rrt(463) * density(01) 
  pd(12,01) = pd(12,01) + rrt(463) * density(48) 
  pd(12,48) = pd(12,48) + rrt(463) * density(01) 
  pd(34,01) = pd(34,01) + rrt(463) * density(48) 
  pd(34,48) = pd(34,48) + rrt(463) * density(01) 
  pd(48,01) = pd(48,01) - rrt(463) * density(48) 
  pd(48,48) = pd(48,48) - rrt(463) * density(01) 
  pd(48,11) = pd(48,11) + rrt(464) * density(49) 
  pd(48,49) = pd(48,49) + rrt(464) * density(11) 
  pd(49,11) = pd(49,11) - rrt(464) * density(49) 
  pd(49,49) = pd(49,49) - rrt(464) * density(11) 
  pd(01,02) = pd(01,02) + rrt(465) * density(49) 
  pd(01,49) = pd(01,49) + rrt(465) * density(02) 
  pd(02,02) = pd(02,02) - rrt(465) * density(49) 
  pd(02,49) = pd(02,49) - rrt(465) * density(02) 
  pd(11,02) = pd(11,02) + rrt(465) * density(49) 
  pd(11,49) = pd(11,49) + rrt(465) * density(02) 
  pd(37,02) = pd(37,02) + rrt(465) * density(49) 
  pd(37,49) = pd(37,49) + rrt(465) * density(02) 
  pd(49,02) = pd(49,02) - rrt(465) * density(49) 
  pd(49,49) = pd(49,49) - rrt(465) * density(02) 
  pd(01,01) = pd(01,01) - rrt(466) * density(49) 
  pd(01,49) = pd(01,49) - rrt(466) * density(01) 
  pd(12,01) = pd(12,01) + rrt(466) * density(49) 
  pd(12,49) = pd(12,49) + rrt(466) * density(01) 
  pd(34,01) = pd(34,01) + rrt(466) * density(49) 
  pd(34,49) = pd(34,49) + rrt(466) * density(01) 
  pd(49,01) = pd(49,01) - rrt(466) * density(49) 
  pd(49,49) = pd(49,49) - rrt(466) * density(01) 
  pd(01,02) = pd(01,02) + rrt(467) * density(49) 
  pd(01,49) = pd(01,49) + rrt(467) * density(02) 
  pd(02,02) = pd(02,02) - rrt(467) * density(49) 
  pd(02,49) = pd(02,49) - rrt(467) * density(02) 
  pd(11,02) = pd(11,02) + rrt(467) * density(49) 
  pd(11,49) = pd(11,49) + rrt(467) * density(02) 
  pd(36,02) = pd(36,02) + rrt(467) * density(49) 
  pd(36,49) = pd(36,49) + rrt(467) * density(02) 
  pd(49,02) = pd(49,02) - rrt(467) * density(49) 
  pd(49,49) = pd(49,49) - rrt(467) * density(02) 
  pd(04,05) = pd(04,05) + rrt(468) * density(34) 
  pd(04,34) = pd(04,34) + rrt(468) * density(05) 
  pd(05,05) = pd(05,05) - rrt(468) * density(34) 
  pd(05,34) = pd(05,34) - rrt(468) * density(05) 
  pd(18,05) = pd(18,05) + rrt(468) * density(34) 
  pd(18,34) = pd(18,34) + rrt(468) * density(05) 
  pd(34,05) = pd(34,05) - rrt(468) * density(34) 
  pd(34,34) = pd(34,34) - rrt(468) * density(05) 
  pd(16,16) = pd(16,16) - rrt(469) * density(34) 
  pd(16,34) = pd(16,34) - rrt(469) * density(16) 
  pd(17,16) = pd(17,16) + rrt(469) * density(34) 
  pd(17,34) = pd(17,34) + rrt(469) * density(16) 
  pd(18,16) = pd(18,16) + rrt(469) * density(34) 
  pd(18,34) = pd(18,34) + rrt(469) * density(16) 
  pd(34,16) = pd(34,16) - rrt(469) * density(34) 
  pd(34,34) = pd(34,34) - rrt(469) * density(16) 
  pd(04,05) = pd(04,05) + rrt(470) * density(33) 
  pd(04,33) = pd(04,33) + rrt(470) * density(05) 
  pd(05,05) = pd(05,05) - rrt(470) * density(33) 
  pd(05,33) = pd(05,33) - rrt(470) * density(05) 
  pd(18,05) = pd(18,05) + rrt(470) * density(33) 
  pd(18,33) = pd(18,33) + rrt(470) * density(05) 
  pd(33,05) = pd(33,05) - rrt(470) * density(33) 
  pd(33,33) = pd(33,33) - rrt(470) * density(05) 
  pd(10,11) = pd(10,11) + rrt(471) * density(34) 
  pd(10,34) = pd(10,34) + rrt(471) * density(11) 
  pd(34,11) = pd(34,11) - rrt(471) * density(34) 
  pd(34,34) = pd(34,34) - rrt(471) * density(11) 
  pd(10,10) = pd(10,10) + rrt(472) * density(33) 
  pd(10,33) = pd(10,33) + rrt(472) * density(10) 
  pd(33,10) = pd(33,10) - rrt(472) * density(33) 
  pd(33,33) = pd(33,33) - rrt(472) * density(10) 
  pd(33,10) = pd(33,10) - rrt(473) * density(33) 
  pd(33,33) = pd(33,33) - rrt(473) * density(10) 
  pd(34,10) = pd(34,10) + rrt(473) * density(33) 
  pd(34,33) = pd(34,33) + rrt(473) * density(10) 
  pd(10,11) = pd(10,11) + rrt(474) * density(33) 
  pd(10,33) = pd(10,33) + rrt(474) * density(11) 
  pd(33,11) = pd(33,11) - rrt(474) * density(33) 
  pd(33,33) = pd(33,33) - rrt(474) * density(11) 
  pd(33,33) = pd(33,33) - rrt(475) * density(34) 
  pd(33,34) = pd(33,34) - rrt(475) * density(33) 
  pd(34,33) = pd(34,33) - rrt(475) * density(34) 
  pd(34,34) = pd(34,34) - rrt(475) * density(33) 
  pd(61,33) = pd(61,33) + rrt(475) * density(34) 
  pd(61,34) = pd(61,34) + rrt(475) * density(33) 
  pd(80,33) = pd(80,33) + rrt(475) * density(34) 
  pd(80,34) = pd(80,34) + rrt(475) * density(33) 
  pd(02,13) = pd(02,13) + rrt(476) * density(33) 
  pd(02,33) = pd(02,33) + rrt(476) * density(13) 
  pd(11,13) = pd(11,13) + rrt(476) * density(33) 
  pd(11,33) = pd(11,33) + rrt(476) * density(13) 
  pd(13,13) = pd(13,13) - rrt(476) * density(33) 
  pd(13,33) = pd(13,33) - rrt(476) * density(13) 
  pd(33,13) = pd(33,13) - rrt(476) * density(33) 
  pd(33,33) = pd(33,33) - rrt(476) * density(13) 
  pd(02,13) = pd(02,13) + rrt(477) * density(34) 
  pd(02,34) = pd(02,34) + rrt(477) * density(13) 
  pd(11,13) = pd(11,13) + rrt(477) * density(34) 
  pd(11,34) = pd(11,34) + rrt(477) * density(13) 
  pd(13,13) = pd(13,13) - rrt(477) * density(34) 
  pd(13,34) = pd(13,34) - rrt(477) * density(13) 
  pd(34,13) = pd(34,13) - rrt(477) * density(34) 
  pd(34,34) = pd(34,34) - rrt(477) * density(13) 
  pd(01,13) = pd(01,13) + rrt(478) * density(33) * 2.0d0
  pd(01,33) = pd(01,33) + rrt(478) * density(13) * 2.0d0
  pd(11,13) = pd(11,13) + rrt(478) * density(33) 
  pd(11,33) = pd(11,33) + rrt(478) * density(13) 
  pd(13,13) = pd(13,13) - rrt(478) * density(33) 
  pd(13,33) = pd(13,33) - rrt(478) * density(13) 
  pd(33,13) = pd(33,13) - rrt(478) * density(33) 
  pd(33,33) = pd(33,33) - rrt(478) * density(13) 
  pd(01,13) = pd(01,13) + rrt(479) * density(34) * 2.0d0
  pd(01,34) = pd(01,34) + rrt(479) * density(13) * 2.0d0
  pd(11,13) = pd(11,13) + rrt(479) * density(34) 
  pd(11,34) = pd(11,34) + rrt(479) * density(13) 
  pd(13,13) = pd(13,13) - rrt(479) * density(34) 
  pd(13,34) = pd(13,34) - rrt(479) * density(13) 
  pd(34,13) = pd(34,13) - rrt(479) * density(34) 
  pd(34,34) = pd(34,34) - rrt(479) * density(13) 
  pd(01,12) = pd(01,12) + rrt(480) * density(34) 
  pd(01,34) = pd(01,34) + rrt(480) * density(12) 
  pd(11,12) = pd(11,12) + rrt(480) * density(34) 
  pd(11,34) = pd(11,34) + rrt(480) * density(12) 
  pd(12,12) = pd(12,12) - rrt(480) * density(34) 
  pd(12,34) = pd(12,34) - rrt(480) * density(12) 
  pd(34,12) = pd(34,12) - rrt(480) * density(34) 
  pd(34,34) = pd(34,34) - rrt(480) * density(12) 
  pd(01,12) = pd(01,12) + rrt(481) * density(33) 
  pd(01,33) = pd(01,33) + rrt(481) * density(12) 
  pd(11,12) = pd(11,12) + rrt(481) * density(33) 
  pd(11,33) = pd(11,33) + rrt(481) * density(12) 
  pd(12,12) = pd(12,12) - rrt(481) * density(33) 
  pd(12,33) = pd(12,33) - rrt(481) * density(12) 
  pd(33,12) = pd(33,12) - rrt(481) * density(33) 
  pd(33,33) = pd(33,33) - rrt(481) * density(12) 
  pd(11,14) = pd(11,14) + rrt(482) * density(34) 
  pd(11,34) = pd(11,34) + rrt(482) * density(14) 
  pd(12,14) = pd(12,14) + rrt(482) * density(34) 
  pd(12,34) = pd(12,34) + rrt(482) * density(14) 
  pd(14,14) = pd(14,14) - rrt(482) * density(34) 
  pd(14,34) = pd(14,34) - rrt(482) * density(14) 
  pd(34,14) = pd(34,14) - rrt(482) * density(34) 
  pd(34,34) = pd(34,34) - rrt(482) * density(14) 
  pd(11,14) = pd(11,14) + rrt(483) * density(33) 
  pd(11,33) = pd(11,33) + rrt(483) * density(14) 
  pd(12,14) = pd(12,14) + rrt(483) * density(33) 
  pd(12,33) = pd(12,33) + rrt(483) * density(14) 
  pd(14,14) = pd(14,14) - rrt(483) * density(33) 
  pd(14,33) = pd(14,33) - rrt(483) * density(14) 
  pd(33,14) = pd(33,14) - rrt(483) * density(33) 
  pd(33,33) = pd(33,33) - rrt(483) * density(14) 
  pd(10,10) = pd(10,10) - rrt(484) * density(10) * density(11) * 4.0d0
  pd(10,11) = pd(10,11) - rrt(484) * density(10)**2 * 2.0d0
  pd(46,10) = pd(46,10) + rrt(484) * density(10) * density(11) * 2.0d0
  pd(46,11) = pd(46,11) + rrt(484) * density(10)**2 
  pd(10,02) = pd(10,02) - rrt(485) * density(10)**2 * 2.0d0
  pd(10,10) = pd(10,10) - rrt(485) * density(02) * density(10) * 4.0d0
  pd(46,02) = pd(46,02) + rrt(485) * density(10)**2 
  pd(46,10) = pd(46,10) + rrt(485) * density(02) * density(10) * 2.0d0
  pd(10,10) = pd(10,10) - rrt(486) * density(10) * density(12) * 4.0d0
  pd(10,12) = pd(10,12) - rrt(486) * density(10)**2 * 2.0d0
  pd(46,10) = pd(46,10) + rrt(486) * density(10) * density(12) * 2.0d0
  pd(46,12) = pd(46,12) + rrt(486) * density(10)**2 
  pd(10,10) = pd(10,10) - rrt(487) * density(10)**2 * 6.0d0
  pd(46,10) = pd(46,10) + rrt(487) * density(10)**2 * 3.0d0
  pd(10,01) = pd(10,01) - rrt(488) * density(10)**2 * 2.0d0
  pd(10,10) = pd(10,10) - rrt(488) * density(01) * density(10) * 4.0d0
  pd(46,01) = pd(46,01) + rrt(488) * density(10)**2 
  pd(46,10) = pd(46,10) + rrt(488) * density(01) * density(10) * 2.0d0
  pd(10,10) = pd(10,10) - rrt(489) * density(10) * density(11) * 4.0d0
  pd(10,11) = pd(10,11) - rrt(489) * density(10)**2 * 2.0d0
  pd(47,10) = pd(47,10) + rrt(489) * density(10) * density(11) * 2.0d0
  pd(47,11) = pd(47,11) + rrt(489) * density(10)**2 
  pd(10,02) = pd(10,02) - rrt(490) * density(10)**2 * 2.0d0
  pd(10,10) = pd(10,10) - rrt(490) * density(02) * density(10) * 4.0d0
  pd(47,02) = pd(47,02) + rrt(490) * density(10)**2 
  pd(47,10) = pd(47,10) + rrt(490) * density(02) * density(10) * 2.0d0
  pd(10,10) = pd(10,10) - rrt(491) * density(10) * density(12) * 4.0d0
  pd(10,12) = pd(10,12) - rrt(491) * density(10)**2 * 2.0d0
  pd(47,10) = pd(47,10) + rrt(491) * density(10) * density(12) * 2.0d0
  pd(47,12) = pd(47,12) + rrt(491) * density(10)**2 
  pd(10,10) = pd(10,10) - rrt(492) * density(10)**2 * 6.0d0
  pd(47,10) = pd(47,10) + rrt(492) * density(10)**2 * 3.0d0
  pd(10,01) = pd(10,01) - rrt(493) * density(10)**2 * 2.0d0
  pd(10,10) = pd(10,10) - rrt(493) * density(01) * density(10) * 4.0d0
  pd(47,01) = pd(47,01) + rrt(493) * density(10)**2 
  pd(47,10) = pd(47,10) + rrt(493) * density(01) * density(10) * 2.0d0
  pd(01,01) = pd(01,01) - rrt(494) * density(64) 
  pd(01,64) = pd(01,64) - rrt(494) * density(01) 
  pd(02,01) = pd(02,01) + rrt(494) * density(64) 
  pd(02,64) = pd(02,64) + rrt(494) * density(01) 
  pd(64,01) = pd(64,01) - rrt(494) * density(64) 
  pd(64,64) = pd(64,64) - rrt(494) * density(01) 
  pd(80,01) = pd(80,01) + rrt(494) * density(64) 
  pd(80,64) = pd(80,64) + rrt(494) * density(01) 
  pd(02,02) = pd(02,02) - rrt(495) * density(64) 
  pd(02,64) = pd(02,64) - rrt(495) * density(02) 
  pd(03,02) = pd(03,02) + rrt(495) * density(64) 
  pd(03,64) = pd(03,64) + rrt(495) * density(02) 
  pd(64,02) = pd(64,02) - rrt(495) * density(64) 
  pd(64,64) = pd(64,64) - rrt(495) * density(02) 
  pd(80,02) = pd(80,02) + rrt(495) * density(64) 
  pd(80,64) = pd(80,64) + rrt(495) * density(02) 
  pd(03,54) = pd(03,54) + rrt(496) * density(64) 
  pd(03,64) = pd(03,64) + rrt(496) * density(54) 
  pd(54,54) = pd(54,54) - rrt(496) * density(64) 
  pd(54,64) = pd(54,64) - rrt(496) * density(54) 
  pd(64,54) = pd(64,54) - rrt(496) * density(64) 
  pd(64,64) = pd(64,64) - rrt(496) * density(54) 
  pd(80,54) = pd(80,54) + rrt(496) * density(64) 
  pd(80,64) = pd(80,64) + rrt(496) * density(54) 
  pd(01,55) = pd(01,55) + rrt(497) * density(64) 
  pd(01,64) = pd(01,64) + rrt(497) * density(55) 
  pd(02,55) = pd(02,55) + rrt(497) * density(64) 
  pd(02,64) = pd(02,64) + rrt(497) * density(55) 
  pd(55,55) = pd(55,55) - rrt(497) * density(64) 
  pd(55,64) = pd(55,64) - rrt(497) * density(55) 
  pd(64,55) = pd(64,55) - rrt(497) * density(64) 
  pd(64,64) = pd(64,64) - rrt(497) * density(55) 
  pd(80,55) = pd(80,55) + rrt(497) * density(64) 
  pd(80,64) = pd(80,64) + rrt(497) * density(55) 
  pd(02,03) = pd(02,03) + rrt(498) * density(64) * 2.0d0
  pd(02,64) = pd(02,64) + rrt(498) * density(03) * 2.0d0
  pd(03,03) = pd(03,03) - rrt(498) * density(64) 
  pd(03,64) = pd(03,64) - rrt(498) * density(03) 
  pd(64,03) = pd(64,03) - rrt(498) * density(64) 
  pd(64,64) = pd(64,64) - rrt(498) * density(03) 
  pd(80,03) = pd(80,03) + rrt(498) * density(64) 
  pd(80,64) = pd(80,64) + rrt(498) * density(03) 
  pd(01,54) = pd(01,54) + rrt(499) * density(64) 
  pd(01,64) = pd(01,64) + rrt(499) * density(54) 
  pd(54,54) = pd(54,54) - rrt(499) * density(64) 
  pd(54,64) = pd(54,64) - rrt(499) * density(54) 
  pd(64,54) = pd(64,54) - rrt(499) * density(64) 
  pd(64,64) = pd(64,64) - rrt(499) * density(54) 
  pd(68,54) = pd(68,54) + rrt(499) * density(64) 
  pd(68,64) = pd(68,64) + rrt(499) * density(54) 
  pd(01,03) = pd(01,03) + rrt(500) * density(64) 
  pd(01,64) = pd(01,64) + rrt(500) * density(03) 
  pd(03,03) = pd(03,03) - rrt(500) * density(64) 
  pd(03,64) = pd(03,64) - rrt(500) * density(03) 
  pd(64,03) = pd(64,03) - rrt(500) * density(64) 
  pd(64,64) = pd(64,64) - rrt(500) * density(03) 
  pd(70,03) = pd(70,03) + rrt(500) * density(64) 
  pd(70,64) = pd(70,64) + rrt(500) * density(03) 
  pd(01,04) = pd(01,04) + rrt(501) * density(65) 
  pd(01,65) = pd(01,65) + rrt(501) * density(04) 
  pd(04,04) = pd(04,04) - rrt(501) * density(65) 
  pd(04,65) = pd(04,65) - rrt(501) * density(04) 
  pd(65,04) = pd(65,04) - rrt(501) * density(65) 
  pd(65,65) = pd(65,65) - rrt(501) * density(04) 
  pd(76,04) = pd(76,04) + rrt(501) * density(65) 
  pd(76,65) = pd(76,65) + rrt(501) * density(04) 
  pd(01,16) = pd(01,16) + rrt(502) * density(65) 
  pd(01,65) = pd(01,65) + rrt(502) * density(16) 
  pd(16,16) = pd(16,16) - rrt(502) * density(65) 
  pd(16,65) = pd(16,65) - rrt(502) * density(16) 
  pd(65,16) = pd(65,16) - rrt(502) * density(65) 
  pd(65,65) = pd(65,65) - rrt(502) * density(16) 
  pd(72,16) = pd(72,16) + rrt(502) * density(65) 
  pd(72,65) = pd(72,65) + rrt(502) * density(16) 
  pd(02,02) = pd(02,02) - rrt(503) * density(02) * density(67) * 2.0d0
  pd(02,67) = pd(02,67) - rrt(503) * density(02)**2 
  pd(67,02) = pd(67,02) - rrt(503) * density(02) * density(67) * 2.0d0
  pd(67,67) = pd(67,67) - rrt(503) * density(02)**2 
  pd(69,02) = pd(69,02) + rrt(503) * density(02) * density(67) * 2.0d0
  pd(69,67) = pd(69,67) + rrt(503) * density(02)**2 
  pd(02,16) = pd(02,16) + rrt(504) * density(67) 
  pd(02,67) = pd(02,67) + rrt(504) * density(16) 
  pd(16,16) = pd(16,16) - rrt(504) * density(67) 
  pd(16,67) = pd(16,67) - rrt(504) * density(16) 
  pd(67,16) = pd(67,16) - rrt(504) * density(67) 
  pd(67,67) = pd(67,67) - rrt(504) * density(16) 
  pd(72,16) = pd(72,16) + rrt(504) * density(67) 
  pd(72,67) = pd(72,67) + rrt(504) * density(16) 
  pd(01,01) = pd(01,01) - rrt(505) * density(69) 
  pd(01,69) = pd(01,69) - rrt(505) * density(01) 
  pd(03,01) = pd(03,01) + rrt(505) * density(69) 
  pd(03,69) = pd(03,69) + rrt(505) * density(01) 
  pd(67,01) = pd(67,01) + rrt(505) * density(69) 
  pd(67,69) = pd(67,69) + rrt(505) * density(01) 
  pd(69,01) = pd(69,01) - rrt(505) * density(69) 
  pd(69,69) = pd(69,69) - rrt(505) * density(01) 
  pd(02,02) = pd(02,02) + rrt(506) * density(69) 
  pd(02,69) = pd(02,69) + rrt(506) * density(02) 
  pd(67,02) = pd(67,02) + rrt(506) * density(69) 
  pd(67,69) = pd(67,69) + rrt(506) * density(02) 
  pd(69,02) = pd(69,02) - rrt(506) * density(69) 
  pd(69,69) = pd(69,69) - rrt(506) * density(02) 
  pd(03,36) = pd(03,36) + rrt(507) * density(69) 
  pd(03,69) = pd(03,69) + rrt(507) * density(36) 
  pd(36,36) = pd(36,36) - rrt(507) * density(69) 
  pd(36,69) = pd(36,69) - rrt(507) * density(36) 
  pd(67,36) = pd(67,36) + rrt(507) * density(69) 
  pd(67,69) = pd(67,69) + rrt(507) * density(36) 
  pd(69,36) = pd(69,36) - rrt(507) * density(69) 
  pd(69,69) = pd(69,69) - rrt(507) * density(36) 
  pd(03,37) = pd(03,37) + rrt(508) * density(69) 
  pd(03,69) = pd(03,69) + rrt(508) * density(37) 
  pd(37,37) = pd(37,37) - rrt(508) * density(69) 
  pd(37,69) = pd(37,69) - rrt(508) * density(37) 
  pd(67,37) = pd(67,37) + rrt(508) * density(69) 
  pd(67,69) = pd(67,69) + rrt(508) * density(37) 
  pd(69,37) = pd(69,37) - rrt(508) * density(69) 
  pd(69,69) = pd(69,69) - rrt(508) * density(37) 
  pd(01,01) = pd(01,01) - rrt(509) * density(68) 
  pd(01,68) = pd(01,68) - rrt(509) * density(01) 
  pd(03,01) = pd(03,01) + rrt(509) * density(68) 
  pd(03,68) = pd(03,68) + rrt(509) * density(01) 
  pd(68,01) = pd(68,01) - rrt(509) * density(68) 
  pd(68,68) = pd(68,68) - rrt(509) * density(01) 
  pd(80,01) = pd(80,01) + rrt(509) * density(68) 
  pd(80,68) = pd(80,68) + rrt(509) * density(01) 
  pd(02,54) = pd(02,54) + rrt(510) * density(68) * 2.0d0
  pd(02,68) = pd(02,68) + rrt(510) * density(54) * 2.0d0
  pd(54,54) = pd(54,54) - rrt(510) * density(68) 
  pd(54,68) = pd(54,68) - rrt(510) * density(54) 
  pd(68,54) = pd(68,54) - rrt(510) * density(68) 
  pd(68,68) = pd(68,68) - rrt(510) * density(54) 
  pd(80,54) = pd(80,54) + rrt(510) * density(68) 
  pd(80,68) = pd(80,68) + rrt(510) * density(54) 
  pd(02,55) = pd(02,55) + rrt(511) * density(68) * 2.0d0
  pd(02,68) = pd(02,68) + rrt(511) * density(55) * 2.0d0
  pd(55,55) = pd(55,55) - rrt(511) * density(68) 
  pd(55,68) = pd(55,68) - rrt(511) * density(55) 
  pd(68,55) = pd(68,55) - rrt(511) * density(68) 
  pd(68,68) = pd(68,68) - rrt(511) * density(55) 
  pd(80,55) = pd(80,55) + rrt(511) * density(68) 
  pd(80,68) = pd(80,68) + rrt(511) * density(55) 
  pd(01,01) = pd(01,01) - rrt(512) * density(68) 
  pd(01,68) = pd(01,68) - rrt(512) * density(01) 
  pd(02,01) = pd(02,01) + rrt(512) * density(68) 
  pd(02,68) = pd(02,68) + rrt(512) * density(01) 
  pd(64,01) = pd(64,01) + rrt(512) * density(68) 
  pd(64,68) = pd(64,68) + rrt(512) * density(01) 
  pd(68,01) = pd(68,01) - rrt(512) * density(68) 
  pd(68,68) = pd(68,68) - rrt(512) * density(01) 
  pd(02,03) = pd(02,03) + rrt(513) * density(68) 
  pd(02,68) = pd(02,68) + rrt(513) * density(03) 
  pd(03,03) = pd(03,03) - rrt(513) * density(68) 
  pd(03,68) = pd(03,68) - rrt(513) * density(03) 
  pd(68,03) = pd(68,03) - rrt(513) * density(68) 
  pd(68,68) = pd(68,68) - rrt(513) * density(03) 
  pd(70,03) = pd(70,03) + rrt(513) * density(68) 
  pd(70,68) = pd(70,68) + rrt(513) * density(03) 
  pd(05,05) = pd(05,05) - rrt(514) * density(68) 
  pd(05,68) = pd(05,68) - rrt(514) * density(05) 
  pd(09,05) = pd(09,05) + rrt(514) * density(68) 
  pd(09,68) = pd(09,68) + rrt(514) * density(05) 
  pd(68,05) = pd(68,05) - rrt(514) * density(68) 
  pd(68,68) = pd(68,68) - rrt(514) * density(05) 
  pd(80,05) = pd(80,05) + rrt(514) * density(68) 
  pd(80,68) = pd(80,68) + rrt(514) * density(05) 
  pd(04,04) = pd(04,04) - rrt(515) * density(68) 
  pd(04,68) = pd(04,68) - rrt(515) * density(04) 
  pd(08,04) = pd(08,04) + rrt(515) * density(68) 
  pd(08,68) = pd(08,68) + rrt(515) * density(04) 
  pd(68,04) = pd(68,04) - rrt(515) * density(68) 
  pd(68,68) = pd(68,68) - rrt(515) * density(04) 
  pd(80,04) = pd(80,04) + rrt(515) * density(68) 
  pd(80,68) = pd(80,68) + rrt(515) * density(04) 
  pd(02,06) = pd(02,06) + rrt(516) * density(68) 
  pd(02,68) = pd(02,68) + rrt(516) * density(06) 
  pd(06,06) = pd(06,06) - rrt(516) * density(68) 
  pd(06,68) = pd(06,68) - rrt(516) * density(06) 
  pd(66,06) = pd(66,06) + rrt(516) * density(68) 
  pd(66,68) = pd(66,68) + rrt(516) * density(06) 
  pd(68,06) = pd(68,06) - rrt(516) * density(68) 
  pd(68,68) = pd(68,68) - rrt(516) * density(06) 
  pd(01,04) = pd(01,04) + rrt(517) * density(68) 
  pd(01,68) = pd(01,68) + rrt(517) * density(04) 
  pd(04,04) = pd(04,04) - rrt(517) * density(68) 
  pd(04,68) = pd(04,68) - rrt(517) * density(04) 
  pd(66,04) = pd(66,04) + rrt(517) * density(68) 
  pd(66,68) = pd(66,68) + rrt(517) * density(04) 
  pd(68,04) = pd(68,04) - rrt(517) * density(68) 
  pd(68,68) = pd(68,68) - rrt(517) * density(04) 
  pd(01,01) = pd(01,01) - rrt(518) * density(70) 
  pd(01,70) = pd(01,70) - rrt(518) * density(01) 
  pd(02,01) = pd(02,01) + rrt(518) * density(70) * 2.0d0
  pd(02,70) = pd(02,70) + rrt(518) * density(01) * 2.0d0
  pd(70,01) = pd(70,01) - rrt(518) * density(70) 
  pd(70,70) = pd(70,70) - rrt(518) * density(01) 
  pd(80,01) = pd(80,01) + rrt(518) * density(70) 
  pd(80,70) = pd(80,70) + rrt(518) * density(01) 
  pd(01,01) = pd(01,01) - rrt(519) * density(70) 
  pd(01,70) = pd(01,70) - rrt(519) * density(01) 
  pd(02,01) = pd(02,01) + rrt(519) * density(70) 
  pd(02,70) = pd(02,70) + rrt(519) * density(01) 
  pd(68,01) = pd(68,01) + rrt(519) * density(70) 
  pd(68,70) = pd(68,70) + rrt(519) * density(01) 
  pd(70,01) = pd(70,01) - rrt(519) * density(70) 
  pd(70,70) = pd(70,70) - rrt(519) * density(01) 
  pd(05,16) = pd(05,16) + rrt(520) * density(78) 
  pd(05,78) = pd(05,78) + rrt(520) * density(16) 
  pd(16,16) = pd(16,16) - rrt(520) * density(78) 
  pd(16,78) = pd(16,78) - rrt(520) * density(16) 
  pd(71,16) = pd(71,16) + rrt(520) * density(78) 
  pd(71,78) = pd(71,78) + rrt(520) * density(16) 
  pd(78,16) = pd(78,16) - rrt(520) * density(78) 
  pd(78,78) = pd(78,78) - rrt(520) * density(16) 
  pd(05,16) = pd(05,16) + rrt(521) * density(77) 
  pd(05,77) = pd(05,77) + rrt(521) * density(16) 
  pd(16,16) = pd(16,16) - rrt(521) * density(77) 
  pd(16,77) = pd(16,77) - rrt(521) * density(16) 
  pd(72,16) = pd(72,16) + rrt(521) * density(77) 
  pd(72,77) = pd(72,77) + rrt(521) * density(16) 
  pd(77,16) = pd(77,16) - rrt(521) * density(77) 
  pd(77,77) = pd(77,77) - rrt(521) * density(16) 
  pd(04,16) = pd(04,16) + rrt(522) * density(77) 
  pd(04,77) = pd(04,77) + rrt(522) * density(16) 
  pd(16,16) = pd(16,16) - rrt(522) * density(77) 
  pd(16,77) = pd(16,77) - rrt(522) * density(16) 
  pd(71,16) = pd(71,16) + rrt(522) * density(77) 
  pd(71,77) = pd(71,77) + rrt(522) * density(16) 
  pd(77,16) = pd(77,16) - rrt(522) * density(77) 
  pd(77,77) = pd(77,77) - rrt(522) * density(16) 
  pd(05,17) = pd(05,17) + rrt(523) * density(77) 
  pd(05,77) = pd(05,77) + rrt(523) * density(17) 
  pd(17,17) = pd(17,17) - rrt(523) * density(77) 
  pd(17,77) = pd(17,77) - rrt(523) * density(17) 
  pd(73,17) = pd(73,17) + rrt(523) * density(77) 
  pd(73,77) = pd(73,77) + rrt(523) * density(17) 
  pd(77,17) = pd(77,17) - rrt(523) * density(77) 
  pd(77,77) = pd(77,77) - rrt(523) * density(17) 
  pd(04,17) = pd(04,17) + rrt(524) * density(77) 
  pd(04,77) = pd(04,77) + rrt(524) * density(17) 
  pd(17,17) = pd(17,17) - rrt(524) * density(77) 
  pd(17,77) = pd(17,77) - rrt(524) * density(17) 
  pd(72,17) = pd(72,17) + rrt(524) * density(77) 
  pd(72,77) = pd(72,77) + rrt(524) * density(17) 
  pd(77,17) = pd(77,17) - rrt(524) * density(77) 
  pd(77,77) = pd(77,77) - rrt(524) * density(17) 
  pd(05,18) = pd(05,18) + rrt(525) * density(77) 
  pd(05,77) = pd(05,77) + rrt(525) * density(18) 
  pd(18,18) = pd(18,18) - rrt(525) * density(77) 
  pd(18,77) = pd(18,77) - rrt(525) * density(18) 
  pd(74,18) = pd(74,18) + rrt(525) * density(77) 
  pd(74,77) = pd(74,77) + rrt(525) * density(18) 
  pd(77,18) = pd(77,18) - rrt(525) * density(77) 
  pd(77,77) = pd(77,77) - rrt(525) * density(18) 
  pd(04,18) = pd(04,18) + rrt(526) * density(77) 
  pd(04,77) = pd(04,77) + rrt(526) * density(18) 
  pd(18,18) = pd(18,18) - rrt(526) * density(77) 
  pd(18,77) = pd(18,77) - rrt(526) * density(18) 
  pd(73,18) = pd(73,18) + rrt(526) * density(77) 
  pd(73,77) = pd(73,77) + rrt(526) * density(18) 
  pd(77,18) = pd(77,18) - rrt(526) * density(77) 
  pd(77,77) = pd(77,77) - rrt(526) * density(18) 
  pd(04,11) = pd(04,11) + rrt(527) * density(77) 
  pd(04,77) = pd(04,77) + rrt(527) * density(11) 
  pd(11,11) = pd(11,11) - rrt(527) * density(77) 
  pd(11,77) = pd(11,77) - rrt(527) * density(11) 
  pd(75,11) = pd(75,11) + rrt(527) * density(77) 
  pd(75,77) = pd(75,77) + rrt(527) * density(11) 
  pd(77,11) = pd(77,11) - rrt(527) * density(77) 
  pd(77,77) = pd(77,77) - rrt(527) * density(11) 
  pd(04,18) = pd(04,18) + rrt(528) * density(76) 
  pd(04,76) = pd(04,76) + rrt(528) * density(18) 
  pd(18,18) = pd(18,18) - rrt(528) * density(76) 
  pd(18,76) = pd(18,76) - rrt(528) * density(18) 
  pd(74,18) = pd(74,18) + rrt(528) * density(76) 
  pd(74,76) = pd(74,76) + rrt(528) * density(18) 
  pd(76,18) = pd(76,18) - rrt(528) * density(76) 
  pd(76,76) = pd(76,76) - rrt(528) * density(18) 
  pd(04,17) = pd(04,17) + rrt(529) * density(76) 
  pd(04,76) = pd(04,76) + rrt(529) * density(17) 
  pd(17,17) = pd(17,17) - rrt(529) * density(76) 
  pd(17,76) = pd(17,76) - rrt(529) * density(17) 
  pd(73,17) = pd(73,17) + rrt(529) * density(76) 
  pd(73,76) = pd(73,76) + rrt(529) * density(17) 
  pd(76,17) = pd(76,17) - rrt(529) * density(76) 
  pd(76,76) = pd(76,76) - rrt(529) * density(17) 
  pd(04,16) = pd(04,16) + rrt(530) * density(76) 
  pd(04,76) = pd(04,76) + rrt(530) * density(16) 
  pd(16,16) = pd(16,16) - rrt(530) * density(76) 
  pd(16,76) = pd(16,76) - rrt(530) * density(16) 
  pd(72,16) = pd(72,16) + rrt(530) * density(76) 
  pd(72,76) = pd(72,76) + rrt(530) * density(16) 
  pd(76,16) = pd(76,16) - rrt(530) * density(76) 
  pd(76,76) = pd(76,76) - rrt(530) * density(16) 
  pd(16,16) = pd(16,16) - rrt(531) * density(60) 
  pd(16,60) = pd(16,60) - rrt(531) * density(16) 
  pd(18,16) = pd(18,16) + rrt(531) * density(60) 
  pd(18,60) = pd(18,60) + rrt(531) * density(16) 
  pd(60,16) = pd(60,16) - rrt(531) * density(60) 
  pd(60,60) = pd(60,60) - rrt(531) * density(16) 
  pd(73,16) = pd(73,16) + rrt(531) * density(60) 
  pd(73,60) = pd(73,60) + rrt(531) * density(16) 
  pd(10,16) = pd(10,16) + rrt(532) * density(60) 
  pd(10,60) = pd(10,60) + rrt(532) * density(16) 
  pd(16,16) = pd(16,16) - rrt(532) * density(60) 
  pd(16,60) = pd(16,60) - rrt(532) * density(16) 
  pd(60,16) = pd(60,16) - rrt(532) * density(60) 
  pd(60,60) = pd(60,60) - rrt(532) * density(16) 
  pd(72,16) = pd(72,16) + rrt(532) * density(60) 
  pd(72,60) = pd(72,60) + rrt(532) * density(16) 
  pd(05,16) = pd(05,16) + rrt(533) * density(60) 
  pd(05,60) = pd(05,60) + rrt(533) * density(16) 
  pd(16,16) = pd(16,16) - rrt(533) * density(60) 
  pd(16,60) = pd(16,60) - rrt(533) * density(16) 
  pd(60,16) = pd(60,16) - rrt(533) * density(60) 
  pd(60,60) = pd(60,60) - rrt(533) * density(16) 
  pd(75,16) = pd(75,16) + rrt(533) * density(60) 
  pd(75,60) = pd(75,60) + rrt(533) * density(16) 
  pd(04,05) = pd(04,05) + rrt(534) * density(60) 
  pd(04,60) = pd(04,60) + rrt(534) * density(05) 
  pd(05,05) = pd(05,05) - rrt(534) * density(60) 
  pd(05,60) = pd(05,60) - rrt(534) * density(05) 
  pd(60,05) = pd(60,05) - rrt(534) * density(60) 
  pd(60,60) = pd(60,60) - rrt(534) * density(05) 
  pd(74,05) = pd(74,05) + rrt(534) * density(60) 
  pd(74,60) = pd(74,60) + rrt(534) * density(05) 
  pd(11,16) = pd(11,16) + rrt(535) * density(61) 
  pd(11,61) = pd(11,61) + rrt(535) * density(16) 
  pd(16,16) = pd(16,16) - rrt(535) * density(61) 
  pd(16,61) = pd(16,61) - rrt(535) * density(16) 
  pd(61,16) = pd(61,16) - rrt(535) * density(61) 
  pd(61,61) = pd(61,61) - rrt(535) * density(16) 
  pd(72,16) = pd(72,16) + rrt(535) * density(61) 
  pd(72,61) = pd(72,61) + rrt(535) * density(16) 
  pd(04,05) = pd(04,05) + rrt(536) * density(61) 
  pd(04,61) = pd(04,61) + rrt(536) * density(05) 
  pd(05,05) = pd(05,05) - rrt(536) * density(61) 
  pd(05,61) = pd(05,61) - rrt(536) * density(05) 
  pd(61,05) = pd(61,05) - rrt(536) * density(61) 
  pd(61,61) = pd(61,61) - rrt(536) * density(05) 
  pd(75,05) = pd(75,05) + rrt(536) * density(61) 
  pd(75,61) = pd(75,61) + rrt(536) * density(05) 
  pd(01,01) = pd(01,01) - rrt(537) * density(61) 
  pd(01,61) = pd(01,61) - rrt(537) * density(01) 
  pd(11,01) = pd(11,01) + rrt(537) * density(61) 
  pd(11,61) = pd(11,61) + rrt(537) * density(01) 
  pd(61,01) = pd(61,01) - rrt(537) * density(61) 
  pd(61,61) = pd(61,61) - rrt(537) * density(01) 
  pd(65,01) = pd(65,01) + rrt(537) * density(61) 
  pd(65,61) = pd(65,61) + rrt(537) * density(01) 
  pd(10,10) = pd(10,10) - rrt(538) * density(61) 
  pd(10,61) = pd(10,61) - rrt(538) * density(10) 
  pd(11,10) = pd(11,10) + rrt(538) * density(61) 
  pd(11,61) = pd(11,61) + rrt(538) * density(10) 
  pd(60,10) = pd(60,10) + rrt(538) * density(61) 
  pd(60,61) = pd(60,61) + rrt(538) * density(10) 
  pd(61,10) = pd(61,10) - rrt(538) * density(61) 
  pd(61,61) = pd(61,61) - rrt(538) * density(10) 
  pd(02,02) = pd(02,02) - rrt(539) * density(61) 
  pd(02,61) = pd(02,61) - rrt(539) * density(02) 
  pd(11,02) = pd(11,02) + rrt(539) * density(61) 
  pd(11,61) = pd(11,61) + rrt(539) * density(02) 
  pd(61,02) = pd(61,02) - rrt(539) * density(61) 
  pd(61,61) = pd(61,61) - rrt(539) * density(02) 
  pd(67,02) = pd(67,02) + rrt(539) * density(61) 
  pd(67,61) = pd(67,61) + rrt(539) * density(02) 
  pd(11,11) = pd(11,11) - rrt(540) * density(11) * density(61) * 2.0d0
  pd(11,61) = pd(11,61) - rrt(540) * density(11)**2 
  pd(61,11) = pd(61,11) - rrt(540) * density(11) * density(61) * 2.0d0
  pd(61,61) = pd(61,61) - rrt(540) * density(11)**2 
  pd(63,11) = pd(63,11) + rrt(540) * density(11) * density(61) * 2.0d0
  pd(63,61) = pd(63,61) + rrt(540) * density(11)**2 
  pd(10,10) = pd(10,10) - rrt(541) * density(62) 
  pd(10,62) = pd(10,62) - rrt(541) * density(10) 
  pd(11,10) = pd(11,10) + rrt(541) * density(62) 
  pd(11,62) = pd(11,62) + rrt(541) * density(10) 
  pd(61,10) = pd(61,10) + rrt(541) * density(62) 
  pd(61,62) = pd(61,62) + rrt(541) * density(10) 
  pd(62,10) = pd(62,10) - rrt(541) * density(62) 
  pd(62,62) = pd(62,62) - rrt(541) * density(10) 
  pd(10,10) = pd(10,10) - rrt(542) * density(63) 
  pd(10,63) = pd(10,63) - rrt(542) * density(10) 
  pd(11,10) = pd(11,10) + rrt(542) * density(63) * 2.0d0
  pd(11,63) = pd(11,63) + rrt(542) * density(10) * 2.0d0
  pd(60,10) = pd(60,10) + rrt(542) * density(63) 
  pd(60,63) = pd(60,63) + rrt(542) * density(10) 
  pd(63,10) = pd(63,10) - rrt(542) * density(63) 
  pd(63,63) = pd(63,63) - rrt(542) * density(10) 
  pd(11,11) = pd(11,11) + rrt(543) * density(63) 
  pd(11,63) = pd(11,63) + rrt(543) * density(11) 
  pd(61,11) = pd(61,11) + rrt(543) * density(63) 
  pd(61,63) = pd(61,63) + rrt(543) * density(11) 
  pd(63,11) = pd(63,11) - rrt(543) * density(63) 
  pd(63,63) = pd(63,63) - rrt(543) * density(11) 
  pd(02,02) = pd(02,02) - rrt(544) * density(63) 
  pd(02,63) = pd(02,63) - rrt(544) * density(02) 
  pd(11,02) = pd(11,02) + rrt(544) * density(63) * 2.0d0
  pd(11,63) = pd(11,63) + rrt(544) * density(02) * 2.0d0
  pd(63,02) = pd(63,02) - rrt(544) * density(63) 
  pd(63,63) = pd(63,63) - rrt(544) * density(02) 
  pd(67,02) = pd(67,02) + rrt(544) * density(63) 
  pd(67,63) = pd(67,63) + rrt(544) * density(02) 
  pd(16,16) = pd(16,16) - rrt(545) * density(74) 
  pd(16,74) = pd(16,74) - rrt(545) * density(16) 
  pd(18,16) = pd(18,16) + rrt(545) * density(74) 
  pd(18,74) = pd(18,74) + rrt(545) * density(16) 
  pd(72,16) = pd(72,16) + rrt(545) * density(74) 
  pd(72,74) = pd(72,74) + rrt(545) * density(16) 
  pd(74,16) = pd(74,16) - rrt(545) * density(74) 
  pd(74,74) = pd(74,74) - rrt(545) * density(16) 
  pd(10,16) = pd(10,16) + rrt(546) * density(74) 
  pd(10,74) = pd(10,74) + rrt(546) * density(16) 
  pd(16,16) = pd(16,16) - rrt(546) * density(74) 
  pd(16,74) = pd(16,74) - rrt(546) * density(16) 
  pd(71,16) = pd(71,16) + rrt(546) * density(74) 
  pd(71,74) = pd(71,74) + rrt(546) * density(16) 
  pd(74,16) = pd(74,16) - rrt(546) * density(74) 
  pd(74,74) = pd(74,74) - rrt(546) * density(16) 
  pd(10,11) = pd(10,11) + rrt(547) * density(74) 
  pd(10,74) = pd(10,74) + rrt(547) * density(11) 
  pd(11,11) = pd(11,11) - rrt(547) * density(74) 
  pd(11,74) = pd(11,74) - rrt(547) * density(11) 
  pd(74,11) = pd(74,11) - rrt(547) * density(74) 
  pd(74,74) = pd(74,74) - rrt(547) * density(11) 
  pd(75,11) = pd(75,11) + rrt(547) * density(74) 
  pd(75,74) = pd(75,74) + rrt(547) * density(11) 
  pd(05,05) = pd(05,05) - rrt(548) * density(74) 
  pd(05,74) = pd(05,74) - rrt(548) * density(05) 
  pd(10,05) = pd(10,05) + rrt(548) * density(74) 
  pd(10,74) = pd(10,74) + rrt(548) * density(05) 
  pd(74,05) = pd(74,05) - rrt(548) * density(74) 
  pd(74,74) = pd(74,74) - rrt(548) * density(05) 
  pd(78,05) = pd(78,05) + rrt(548) * density(74) 
  pd(78,74) = pd(78,74) + rrt(548) * density(05) 
  pd(04,05) = pd(04,05) + rrt(549) * density(74) 
  pd(04,74) = pd(04,74) + rrt(549) * density(05) 
  pd(05,05) = pd(05,05) - rrt(549) * density(74) 
  pd(05,74) = pd(05,74) - rrt(549) * density(05) 
  pd(73,05) = pd(73,05) + rrt(549) * density(74) 
  pd(73,74) = pd(73,74) + rrt(549) * density(05) 
  pd(74,05) = pd(74,05) - rrt(549) * density(74) 
  pd(74,74) = pd(74,74) - rrt(549) * density(05) 
  pd(02,02) = pd(02,02) - rrt(550) * density(74) 
  pd(02,74) = pd(02,74) - rrt(550) * density(02) 
  pd(18,02) = pd(18,02) + rrt(550) * density(74) 
  pd(18,74) = pd(18,74) + rrt(550) * density(02) 
  pd(67,02) = pd(67,02) + rrt(550) * density(74) 
  pd(67,74) = pd(67,74) + rrt(550) * density(02) 
  pd(74,02) = pd(74,02) - rrt(550) * density(74) 
  pd(74,74) = pd(74,74) - rrt(550) * density(02) 
  pd(16,16) = pd(16,16) - rrt(551) * density(73) 
  pd(16,73) = pd(16,73) - rrt(551) * density(16) 
  pd(17,16) = pd(17,16) + rrt(551) * density(73) 
  pd(17,73) = pd(17,73) + rrt(551) * density(16) 
  pd(72,16) = pd(72,16) + rrt(551) * density(73) 
  pd(72,73) = pd(72,73) + rrt(551) * density(16) 
  pd(73,16) = pd(73,16) - rrt(551) * density(73) 
  pd(73,73) = pd(73,73) - rrt(551) * density(16) 
  pd(16,16) = pd(16,16) - rrt(552) * density(73) 
  pd(16,73) = pd(16,73) - rrt(552) * density(16) 
  pd(18,16) = pd(18,16) + rrt(552) * density(73) 
  pd(18,73) = pd(18,73) + rrt(552) * density(16) 
  pd(71,16) = pd(71,16) + rrt(552) * density(73) 
  pd(71,73) = pd(71,73) + rrt(552) * density(16) 
  pd(73,16) = pd(73,16) - rrt(552) * density(73) 
  pd(73,73) = pd(73,73) - rrt(552) * density(16) 
  pd(04,05) = pd(04,05) + rrt(553) * density(73) 
  pd(04,73) = pd(04,73) + rrt(553) * density(05) 
  pd(05,05) = pd(05,05) - rrt(553) * density(73) 
  pd(05,73) = pd(05,73) - rrt(553) * density(05) 
  pd(72,05) = pd(72,05) + rrt(553) * density(73) 
  pd(72,73) = pd(72,73) + rrt(553) * density(05) 
  pd(73,05) = pd(73,05) - rrt(553) * density(73) 
  pd(73,73) = pd(73,73) - rrt(553) * density(05) 
  pd(16,16) = pd(16,16) - rrt(554) * density(72) 
  pd(16,72) = pd(16,72) - rrt(554) * density(16) 
  pd(17,16) = pd(17,16) + rrt(554) * density(72) 
  pd(17,72) = pd(17,72) + rrt(554) * density(16) 
  pd(71,16) = pd(71,16) + rrt(554) * density(72) 
  pd(71,72) = pd(71,72) + rrt(554) * density(16) 
  pd(72,16) = pd(72,16) - rrt(554) * density(72) 
  pd(72,72) = pd(72,72) - rrt(554) * density(16) 
  pd(17,16) = pd(17,16) + rrt(555) * density(72) 
  pd(17,72) = pd(17,72) + rrt(555) * density(16) 
  pd(72,16) = pd(72,16) - rrt(555) * density(72) 
  pd(72,72) = pd(72,72) - rrt(555) * density(16) 
  pd(76,16) = pd(76,16) + rrt(555) * density(72) 
  pd(76,72) = pd(76,72) + rrt(555) * density(16) 
  pd(05,16) = pd(05,16) + rrt(556) * density(72) 
  pd(05,72) = pd(05,72) + rrt(556) * density(16) 
  pd(16,16) = pd(16,16) - rrt(556) * density(72) 
  pd(16,72) = pd(16,72) - rrt(556) * density(16) 
  pd(17,16) = pd(17,16) + rrt(556) * density(72) 
  pd(17,72) = pd(17,72) + rrt(556) * density(16) 
  pd(72,16) = pd(72,16) - rrt(556) * density(72) 
  pd(72,72) = pd(72,72) - rrt(556) * density(16) 
  pd(73,16) = pd(73,16) + rrt(556) * density(72) 
  pd(73,72) = pd(73,72) + rrt(556) * density(16) 
  pd(04,05) = pd(04,05) + rrt(557) * density(72) 
  pd(04,72) = pd(04,72) + rrt(557) * density(05) 
  pd(05,05) = pd(05,05) - rrt(557) * density(72) 
  pd(05,72) = pd(05,72) - rrt(557) * density(05) 
  pd(71,05) = pd(71,05) + rrt(557) * density(72) 
  pd(71,72) = pd(71,72) + rrt(557) * density(05) 
  pd(72,05) = pd(72,05) - rrt(557) * density(72) 
  pd(72,72) = pd(72,72) - rrt(557) * density(05) 
  pd(05,05) = pd(05,05) - rrt(558) * density(72) 
  pd(05,72) = pd(05,72) - rrt(558) * density(05) 
  pd(16,05) = pd(16,05) + rrt(558) * density(72) 
  pd(16,72) = pd(16,72) + rrt(558) * density(05) 
  pd(72,05) = pd(72,05) - rrt(558) * density(72) 
  pd(72,72) = pd(72,72) - rrt(558) * density(05) 
  pd(77,05) = pd(77,05) + rrt(558) * density(72) 
  pd(77,72) = pd(77,72) + rrt(558) * density(05) 
  pd(04,05) = pd(04,05) + rrt(559) * density(72) 
  pd(04,72) = pd(04,72) + rrt(559) * density(05) 
  pd(05,05) = pd(05,05) - rrt(559) * density(72) 
  pd(05,72) = pd(05,72) - rrt(559) * density(05) 
  pd(17,05) = pd(17,05) + rrt(559) * density(72) 
  pd(17,72) = pd(17,72) + rrt(559) * density(05) 
  pd(72,05) = pd(72,05) - rrt(559) * density(72) 
  pd(72,72) = pd(72,72) - rrt(559) * density(05) 
  pd(77,05) = pd(77,05) + rrt(559) * density(72) 
  pd(77,72) = pd(77,72) + rrt(559) * density(05) 
  pd(04,05) = pd(04,05) + rrt(560) * density(72) 
  pd(04,72) = pd(04,72) + rrt(560) * density(05) 
  pd(05,05) = pd(05,05) - rrt(560) * density(72) 
  pd(05,72) = pd(05,72) - rrt(560) * density(05) 
  pd(16,05) = pd(16,05) + rrt(560) * density(72) 
  pd(16,72) = pd(16,72) + rrt(560) * density(05) 
  pd(72,05) = pd(72,05) - rrt(560) * density(72) 
  pd(72,72) = pd(72,72) - rrt(560) * density(05) 
  pd(76,05) = pd(76,05) + rrt(560) * density(72) 
  pd(76,72) = pd(76,72) + rrt(560) * density(05) 
  pd(11,16) = pd(11,16) + rrt(561) * density(75) 
  pd(11,75) = pd(11,75) + rrt(561) * density(16) 
  pd(16,16) = pd(16,16) - rrt(561) * density(75) 
  pd(16,75) = pd(16,75) - rrt(561) * density(16) 
  pd(71,16) = pd(71,16) + rrt(561) * density(75) 
  pd(71,75) = pd(71,75) + rrt(561) * density(16) 
  pd(75,16) = pd(75,16) - rrt(561) * density(75) 
  pd(75,75) = pd(75,75) - rrt(561) * density(16) 
  pd(01,01) = pd(01,01) - rrt(562) * density(66) 
  pd(01,66) = pd(01,66) - rrt(562) * density(01) 
  pd(08,01) = pd(08,01) + rrt(562) * density(66) 
  pd(08,66) = pd(08,66) + rrt(562) * density(01) 
  pd(66,01) = pd(66,01) - rrt(562) * density(66) 
  pd(66,66) = pd(66,66) - rrt(562) * density(01) 
  pd(80,01) = pd(80,01) + rrt(562) * density(66) 
  pd(80,66) = pd(80,66) + rrt(562) * density(01) 
  pd(04,04) = pd(04,04) - rrt(563) * density(66) 
  pd(04,66) = pd(04,66) - rrt(563) * density(04) 
  pd(07,04) = pd(07,04) + rrt(563) * density(66) 
  pd(07,66) = pd(07,66) + rrt(563) * density(04) 
  pd(66,04) = pd(66,04) - rrt(563) * density(66) 
  pd(66,66) = pd(66,66) - rrt(563) * density(04) 
  pd(80,04) = pd(80,04) + rrt(563) * density(66) 
  pd(80,66) = pd(80,66) + rrt(563) * density(04) 
  pd(10,61) = pd(10,61) + rrt(564) * density(80) * 2.0d0
  pd(10,80) = pd(10,80) + rrt(564) * density(61) * 2.0d0
  pd(61,61) = pd(61,61) - rrt(564) * density(80) 
  pd(61,80) = pd(61,80) - rrt(564) * density(61) 
  pd(80,61) = pd(80,61) - rrt(564) * density(80) 
  pd(80,80) = pd(80,80) - rrt(564) * density(61) 
  pd(10,61) = pd(10,61) + rrt(565) * density(80) 
  pd(10,80) = pd(10,80) + rrt(565) * density(61) 
  pd(34,61) = pd(34,61) + rrt(565) * density(80) 
  pd(34,80) = pd(34,80) + rrt(565) * density(61) 
  pd(61,61) = pd(61,61) - rrt(565) * density(80) 
  pd(61,80) = pd(61,80) - rrt(565) * density(61) 
  pd(80,61) = pd(80,61) - rrt(565) * density(80) 
  pd(80,80) = pd(80,80) - rrt(565) * density(61) 
  pd(01,67) = pd(01,67) + rrt(566) * density(80) * 2.0d0
  pd(01,80) = pd(01,80) + rrt(566) * density(67) * 2.0d0
  pd(67,67) = pd(67,67) - rrt(566) * density(80) 
  pd(67,80) = pd(67,80) - rrt(566) * density(67) 
  pd(80,67) = pd(80,67) - rrt(566) * density(80) 
  pd(80,80) = pd(80,80) - rrt(566) * density(67) 
  pd(01,67) = pd(01,67) + rrt(567) * density(80) 
  pd(01,80) = pd(01,80) + rrt(567) * density(67) 
  pd(36,67) = pd(36,67) + rrt(567) * density(80) 
  pd(36,80) = pd(36,80) + rrt(567) * density(67) 
  pd(67,67) = pd(67,67) - rrt(567) * density(80) 
  pd(67,80) = pd(67,80) - rrt(567) * density(67) 
  pd(80,67) = pd(80,67) - rrt(567) * density(80) 
  pd(80,80) = pd(80,80) - rrt(567) * density(67) 
  pd(01,67) = pd(01,67) + rrt(568) * density(80) 
  pd(01,80) = pd(01,80) + rrt(568) * density(67) 
  pd(37,67) = pd(37,67) + rrt(568) * density(80) 
  pd(37,80) = pd(37,80) + rrt(568) * density(67) 
  pd(67,67) = pd(67,67) - rrt(568) * density(80) 
  pd(67,80) = pd(67,80) - rrt(568) * density(67) 
  pd(80,67) = pd(80,67) - rrt(568) * density(80) 
  pd(80,80) = pd(80,80) - rrt(568) * density(67) 
  pd(02,69) = pd(02,69) + rrt(569) * density(80) * 2.0d0
  pd(02,80) = pd(02,80) + rrt(569) * density(69) * 2.0d0
  pd(69,69) = pd(69,69) - rrt(569) * density(80) 
  pd(69,80) = pd(69,80) - rrt(569) * density(69) 
  pd(80,69) = pd(80,69) - rrt(569) * density(80) 
  pd(80,80) = pd(80,80) - rrt(569) * density(69) 
  pd(11,63) = pd(11,63) + rrt(570) * density(80) * 2.0d0
  pd(11,80) = pd(11,80) + rrt(570) * density(63) * 2.0d0
  pd(63,63) = pd(63,63) - rrt(570) * density(80) 
  pd(63,80) = pd(63,80) - rrt(570) * density(63) 
  pd(80,63) = pd(80,63) - rrt(570) * density(80) 
  pd(80,80) = pd(80,80) - rrt(570) * density(63) 
  pd(02,67) = pd(02,67) + rrt(571) * density(80)**2 
  pd(02,80) = pd(02,80) + rrt(571) * density(67) * density(80) * 2.0d0
  pd(67,67) = pd(67,67) - rrt(571) * density(80)**2 
  pd(67,80) = pd(67,80) - rrt(571) * density(67) * density(80) * 2.0d0
  pd(80,67) = pd(80,67) - rrt(571) * density(80)**2 
  pd(80,80) = pd(80,80) - rrt(571) * density(67) * density(80) * 2.0d0
  pd(02,02) = pd(02,02) + rrt(572) * density(67) * density(80) 
  pd(02,67) = pd(02,67) + rrt(572) * density(02) * density(80) 
  pd(02,80) = pd(02,80) + rrt(572) * density(02) * density(67) 
  pd(67,02) = pd(67,02) - rrt(572) * density(67) * density(80) 
  pd(67,67) = pd(67,67) - rrt(572) * density(02) * density(80) 
  pd(67,80) = pd(67,80) - rrt(572) * density(02) * density(67) 
  pd(80,02) = pd(80,02) - rrt(572) * density(67) * density(80) 
  pd(80,67) = pd(80,67) - rrt(572) * density(02) * density(80) 
  pd(80,80) = pd(80,80) - rrt(572) * density(02) * density(67) 
  pd(02,69) = pd(02,69) + rrt(573) * density(80)**2 * 2.0d0
  pd(02,80) = pd(02,80) + rrt(573) * density(69) * density(80) * 4.0d0
  pd(69,69) = pd(69,69) - rrt(573) * density(80)**2 
  pd(69,80) = pd(69,80) - rrt(573) * density(69) * density(80) * 2.0d0
  pd(80,69) = pd(80,69) - rrt(573) * density(80)**2 
  pd(80,80) = pd(80,80) - rrt(573) * density(69) * density(80) * 2.0d0
  pd(04,74) = pd(04,74) + rrt(574) * density(80) 
  pd(04,80) = pd(04,80) + rrt(574) * density(74) 
  pd(10,74) = pd(10,74) + rrt(574) * density(80) 
  pd(10,80) = pd(10,80) + rrt(574) * density(74) 
  pd(74,74) = pd(74,74) - rrt(574) * density(80) 
  pd(74,80) = pd(74,80) - rrt(574) * density(74) 
  pd(80,74) = pd(80,74) - rrt(574) * density(80) 
  pd(80,80) = pd(80,80) - rrt(574) * density(74) 
  pd(04,73) = pd(04,73) + rrt(575) * density(80) 
  pd(04,80) = pd(04,80) + rrt(575) * density(73) 
  pd(18,73) = pd(18,73) + rrt(575) * density(80) 
  pd(18,80) = pd(18,80) + rrt(575) * density(73) 
  pd(73,73) = pd(73,73) - rrt(575) * density(80) 
  pd(73,80) = pd(73,80) - rrt(575) * density(73) 
  pd(80,73) = pd(80,73) - rrt(575) * density(80) 
  pd(80,80) = pd(80,80) - rrt(575) * density(73) 
  pd(04,73) = pd(04,73) + rrt(576) * density(80) * 2.0d0
  pd(04,80) = pd(04,80) + rrt(576) * density(73) * 2.0d0
  pd(10,73) = pd(10,73) + rrt(576) * density(80) 
  pd(10,80) = pd(10,80) + rrt(576) * density(73) 
  pd(73,73) = pd(73,73) - rrt(576) * density(80) 
  pd(73,80) = pd(73,80) - rrt(576) * density(73) 
  pd(80,73) = pd(80,73) - rrt(576) * density(80) 
  pd(80,80) = pd(80,80) - rrt(576) * density(73) 
  pd(04,72) = pd(04,72) + rrt(577) * density(80) * 2.0d0
  pd(04,80) = pd(04,80) + rrt(577) * density(72) * 2.0d0
  pd(18,72) = pd(18,72) + rrt(577) * density(80) 
  pd(18,80) = pd(18,80) + rrt(577) * density(72) 
  pd(72,72) = pd(72,72) - rrt(577) * density(80) 
  pd(72,80) = pd(72,80) - rrt(577) * density(72) 
  pd(80,72) = pd(80,72) - rrt(577) * density(80) 
  pd(80,80) = pd(80,80) - rrt(577) * density(72) 
  pd(04,72) = pd(04,72) + rrt(578) * density(80) 
  pd(04,80) = pd(04,80) + rrt(578) * density(72) 
  pd(17,72) = pd(17,72) + rrt(578) * density(80) 
  pd(17,80) = pd(17,80) + rrt(578) * density(72) 
  pd(72,72) = pd(72,72) - rrt(578) * density(80) 
  pd(72,80) = pd(72,80) - rrt(578) * density(72) 
  pd(80,72) = pd(80,72) - rrt(578) * density(80) 
  pd(80,80) = pd(80,80) - rrt(578) * density(72) 
  pd(04,71) = pd(04,71) + rrt(579) * density(80) 
  pd(04,80) = pd(04,80) + rrt(579) * density(71) 
  pd(16,71) = pd(16,71) + rrt(579) * density(80) 
  pd(16,80) = pd(16,80) + rrt(579) * density(71) 
  pd(71,71) = pd(71,71) - rrt(579) * density(80) 
  pd(71,80) = pd(71,80) - rrt(579) * density(71) 
  pd(80,71) = pd(80,71) - rrt(579) * density(80) 
  pd(80,80) = pd(80,80) - rrt(579) * density(71) 
  pd(04,71) = pd(04,71) + rrt(580) * density(80) * 2.0d0
  pd(04,80) = pd(04,80) + rrt(580) * density(71) * 2.0d0
  pd(17,71) = pd(17,71) + rrt(580) * density(80) 
  pd(17,80) = pd(17,80) + rrt(580) * density(71) 
  pd(71,71) = pd(71,71) - rrt(580) * density(80) 
  pd(71,80) = pd(71,80) - rrt(580) * density(71) 
  pd(80,71) = pd(80,71) - rrt(580) * density(80) 
  pd(80,80) = pd(80,80) - rrt(580) * density(71) 
  pd(04,75) = pd(04,75) + rrt(581) * density(80) 
  pd(04,80) = pd(04,80) + rrt(581) * density(75) 
  pd(11,75) = pd(11,75) + rrt(581) * density(80) 
  pd(11,80) = pd(11,80) + rrt(581) * density(75) 
  pd(75,75) = pd(75,75) - rrt(581) * density(80) 
  pd(75,80) = pd(75,80) - rrt(581) * density(75) 
  pd(80,75) = pd(80,75) - rrt(581) * density(80) 
  pd(80,80) = pd(80,80) - rrt(581) * density(75) 
  pd(04,77) = pd(04,77) + rrt(582) * density(80) * 2.0d0
  pd(04,80) = pd(04,80) + rrt(582) * density(77) * 2.0d0
  pd(77,77) = pd(77,77) - rrt(582) * density(80) 
  pd(77,80) = pd(77,80) - rrt(582) * density(77) 
  pd(80,77) = pd(80,77) - rrt(582) * density(80) 
  pd(80,80) = pd(80,80) - rrt(582) * density(77) 
  pd(04,78) = pd(04,78) + rrt(583) * density(80) * 3.0d0
  pd(04,80) = pd(04,80) + rrt(583) * density(78) * 3.0d0
  pd(78,78) = pd(78,78) - rrt(583) * density(80) 
  pd(78,80) = pd(78,80) - rrt(583) * density(78) 
  pd(80,78) = pd(80,78) - rrt(583) * density(80) 
  pd(80,80) = pd(80,80) - rrt(583) * density(78) 
  pd(04,78) = pd(04,78) + rrt(584) * density(80) 
  pd(04,80) = pd(04,80) + rrt(584) * density(78) 
  pd(05,78) = pd(05,78) + rrt(584) * density(80) 
  pd(05,80) = pd(05,80) + rrt(584) * density(78) 
  pd(78,78) = pd(78,78) - rrt(584) * density(80) 
  pd(78,80) = pd(78,80) - rrt(584) * density(78) 
  pd(80,78) = pd(80,78) - rrt(584) * density(80) 
  pd(80,80) = pd(80,80) - rrt(584) * density(78) 
  pd(05,71) = pd(05,71) + rrt(585) * density(80) 
  pd(05,80) = pd(05,80) + rrt(585) * density(71) 
  pd(17,71) = pd(17,71) + rrt(585) * density(80) 
  pd(17,80) = pd(17,80) + rrt(585) * density(71) 
  pd(71,71) = pd(71,71) - rrt(585) * density(80) 
  pd(71,80) = pd(71,80) - rrt(585) * density(71) 
  pd(80,71) = pd(80,71) - rrt(585) * density(80) 
  pd(80,80) = pd(80,80) - rrt(585) * density(71) 
  pd(10,75) = pd(10,75) + rrt(586) * density(80) 
  pd(10,80) = pd(10,80) + rrt(586) * density(75) 
  pd(18,75) = pd(18,75) + rrt(586) * density(80) 
  pd(18,80) = pd(18,80) + rrt(586) * density(75) 
  pd(75,75) = pd(75,75) - rrt(586) * density(80) 
  pd(75,80) = pd(75,80) - rrt(586) * density(75) 
  pd(80,75) = pd(80,75) - rrt(586) * density(80) 
  pd(80,80) = pd(80,80) - rrt(586) * density(75) 
  pd(10,60) = pd(10,60) + rrt(587) * density(80)**2 
  pd(10,80) = pd(10,80) + rrt(587) * density(60) * density(80) * 2.0d0
  pd(60,60) = pd(60,60) - rrt(587) * density(80)**2 
  pd(60,80) = pd(60,80) - rrt(587) * density(60) * density(80) * 2.0d0
  pd(80,60) = pd(80,60) - rrt(587) * density(80)**2 
  pd(80,80) = pd(80,80) - rrt(587) * density(60) * density(80) * 2.0d0
  pd(10,60) = pd(10,60) + rrt(588) * density(80) 
  pd(10,80) = pd(10,80) + rrt(588) * density(60) 
  pd(60,60) = pd(60,60) - rrt(588) * density(80) 
  pd(60,80) = pd(60,80) - rrt(588) * density(60) 
  pd(80,60) = pd(80,60) - rrt(588) * density(80) 
  pd(80,80) = pd(80,80) - rrt(588) * density(60) 
  pd(11,61) = pd(11,61) + rrt(589) * density(80)**2 
  pd(11,80) = pd(11,80) + rrt(589) * density(61) * density(80) * 2.0d0
  pd(61,61) = pd(61,61) - rrt(589) * density(80)**2 
  pd(61,80) = pd(61,80) - rrt(589) * density(61) * density(80) * 2.0d0
  pd(80,61) = pd(80,61) - rrt(589) * density(80)**2 
  pd(80,80) = pd(80,80) - rrt(589) * density(61) * density(80) * 2.0d0
  pd(11,61) = pd(11,61) + rrt(590) * density(80) 
  pd(11,80) = pd(11,80) + rrt(590) * density(61) 
  pd(61,61) = pd(61,61) - rrt(590) * density(80) 
  pd(61,80) = pd(61,80) - rrt(590) * density(61) 
  pd(80,61) = pd(80,61) - rrt(590) * density(80) 
  pd(80,80) = pd(80,80) - rrt(590) * density(61) 
  pd(04,79) = pd(04,79) + rrt(591) * density(80) 
  pd(04,80) = pd(04,80) + rrt(591) * density(79) 
  pd(06,79) = pd(06,79) + rrt(591) * density(80) 
  pd(06,80) = pd(06,80) + rrt(591) * density(79) 
  pd(79,79) = pd(79,79) - rrt(591) * density(80) 
  pd(79,80) = pd(79,80) - rrt(591) * density(79) 
  pd(80,79) = pd(80,79) - rrt(591) * density(80) 
  pd(80,80) = pd(80,80) - rrt(591) * density(79) 
  pd(01,79) = pd(01,79) + rrt(592) * density(80) 
  pd(01,80) = pd(01,80) + rrt(592) * density(79) 
  pd(05,79) = pd(05,79) + rrt(592) * density(80) 
  pd(05,80) = pd(05,80) + rrt(592) * density(79) 
  pd(79,79) = pd(79,79) - rrt(592) * density(80) 
  pd(79,80) = pd(79,80) - rrt(592) * density(79) 
  pd(80,79) = pd(80,79) - rrt(592) * density(80) 
  pd(80,80) = pd(80,80) - rrt(592) * density(79) 
  pd(01,79) = pd(01,79) + rrt(593) * density(80) 
  pd(01,80) = pd(01,80) + rrt(593) * density(79) 
  pd(04,79) = pd(04,79) + rrt(593) * density(80) * 2.0d0
  pd(04,80) = pd(04,80) + rrt(593) * density(79) * 2.0d0
  pd(79,79) = pd(79,79) - rrt(593) * density(80) 
  pd(79,80) = pd(79,80) - rrt(593) * density(79) 
  pd(80,79) = pd(80,79) - rrt(593) * density(80) 
  pd(80,80) = pd(80,80) - rrt(593) * density(79) 
  pd(02,02) = pd(02,02) - rrt(594) * density(80) 
  pd(02,80) = pd(02,80) - rrt(594) * density(02) 
  pd(68,02) = pd(68,02) + rrt(594) * density(80) 
  pd(68,80) = pd(68,80) + rrt(594) * density(02) 
  pd(80,02) = pd(80,02) - rrt(594) * density(80) 
  pd(80,80) = pd(80,80) - rrt(594) * density(02) 
  pd(01,01) = pd(01,01) - rrt(595) * density(80) 
  pd(01,80) = pd(01,80) - rrt(595) * density(01) 
  pd(64,01) = pd(64,01) + rrt(595) * density(80) 
  pd(64,80) = pd(64,80) + rrt(595) * density(01) 
  pd(80,01) = pd(80,01) - rrt(595) * density(80) 
  pd(80,80) = pd(80,80) - rrt(595) * density(01) 
  if( ldensity_constant ) then
    do i = 1, species_max
      if( density_constant(i) ) pd(i,:) = 0.0d0
    enddo
  endif
  if( lgas_heating ) then
    pd(81,4) = eV_to_K * ZDPlasKin_cfg(11)
    pd(81,:) = pd(81,:) * ZDPlasKin_cfg(13)
  endif
  return
end subroutine ZDPlasKin_jex
end module ZDPlasKin
!-----------------------------------------------------------------------------------------------------------------------------------
!
! reaction constant rates
!
!-----------------------------------------------------------------------------------------------------------------------------------
subroutine ZDPlasKin_reac_rates(Time)
  use ZDPlasKin, only : ZDPlasKin_bolsig_rates, bolsig_rates, bolsig_pointer, ZDPlasKin_cfg, ZDPlasKin_get_density_total, &
                        lreaction_block, rrt
  implicit none
  double precision, intent(in) :: Time
  double precision :: Tgas
  double precision :: Te
  double precision :: ANY_NEUTRAL
  DOUBLE PRECISION :: KVT10_O2N2, KVT10_O2O2, KVT10_O2O ! CM3.S-1
  DOUBLE PRECISION :: KVT10_N2N2, KVT10_N2O2, KVT10_N2O, KVT10_N2N ! CM3.S-1
  DOUBLE PRECISION :: KVV10_O2O2, KVV10_N2N2 ! CM3.S-1
  DOUBLE PRECISION :: M ! CM-3
  DOUBLE PRECISION :: KTOT, K0, KR1, KR2, KR3 ! CM3.S-1
  call ZDPlasKin_bolsig_rates()
  Tgas = ZDPlasKin_cfg(1)
  Te  = ZDPlasKin_cfg(4)
  call ZDPlasKin_get_density_total(ALL_NEUTRAL=ANY_NEUTRAL)
  KVT10_O2N2 = EXP(-28.02D0-132.0D0/TGAS**(1.0D0/3.0D0))
  KVT10_O2O2 = EXP(-18.32D0-157.0D0/TGAS**(1.0D0/3.0D0))
  KVT10_O2O = TGAS*EXP(-28.87D0-111.0D0/TGAS**(1.0D0/3.0D0))
  KVT10_N2N2 = TGAS*EXP(-22.86D0-328.9D0/TGAS**(1.0D0/3.0D0)+993.3D0/TGAS**(2.0D0/3.0D0))
  KVT10_N2O2 = TGAS*EXP(-22.86D0-328.9D0/TGAS**(1.0D0/3.0D0)+993.3D0/TGAS**(2.0D0/3.0D0))
  KVT10_N2O = TGAS*EXP(-34.03D0-33.11D0/TGAS**(1.0D0/3.0D0))
  KVT10_N2N = 4.0D-16*(TGAS/300.0D0)**0.5
  KVV10_O2O2 = 0.9D-14*(TGAS/300.0D0)**1.5
  KVV10_N2N2 = 0.9D-14*(TGAS/300.0D0)**1.5
  M = 101325.0D0/1.38064852D-17/TGAS
  KTOT = 3.0D-11*TGAS**0.17*EXP(-2726.0D0/TGAS)
  K0 = 2.2D-37*TGAS**2.34*EXP(-1350.0D0/TGAS)
  KR1 = 6.8D-16*TGAS**1.51*EXP(-3040.0D0/TGAS)
  KR2 = KTOT*(K0*M/(KTOT+K0*M))
  KR3 = KTOT-KR1-KR2
  rrt(001) = bolsig_rates(bolsig_pointer(1))
  rrt(002) = bolsig_rates(bolsig_pointer(2))
  rrt(003) = bolsig_rates(bolsig_pointer(3))
  rrt(004) = bolsig_rates(bolsig_pointer(4))
  rrt(005) = bolsig_rates(bolsig_pointer(5))
  rrt(006) = bolsig_rates(bolsig_pointer(6))
  rrt(007) = bolsig_rates(bolsig_pointer(7))
  rrt(008) = bolsig_rates(bolsig_pointer(8))
  rrt(009) = bolsig_rates(bolsig_pointer(9))
  rrt(010) = bolsig_rates(bolsig_pointer(10))
  rrt(011) = bolsig_rates(bolsig_pointer(11))
  rrt(012) = bolsig_rates(bolsig_pointer(12))
  rrt(013) = bolsig_rates(bolsig_pointer(13))
  rrt(014) = bolsig_rates(bolsig_pointer(14))
  rrt(015) = bolsig_rates(bolsig_pointer(15))
  rrt(016) = bolsig_rates(bolsig_pointer(16))
  rrt(017) = bolsig_rates(bolsig_pointer(17))
  rrt(018) = bolsig_rates(bolsig_pointer(18))
  rrt(019) = bolsig_rates(bolsig_pointer(19))
  rrt(020) = bolsig_rates(bolsig_pointer(20))
  rrt(021) = bolsig_rates(bolsig_pointer(21))
  rrt(022) = bolsig_rates(bolsig_pointer(22))
  rrt(023) = bolsig_rates(bolsig_pointer(23))
  rrt(024) = bolsig_rates(bolsig_pointer(24))
  rrt(025) = bolsig_rates(bolsig_pointer(25))
  rrt(026) = bolsig_rates(bolsig_pointer(26))
  rrt(027) = bolsig_rates(bolsig_pointer(27))
  rrt(028) = bolsig_rates(bolsig_pointer(28))
  rrt(029) = bolsig_rates(bolsig_pointer(29))
  rrt(030) = bolsig_rates(bolsig_pointer(30))
  rrt(031) = bolsig_rates(bolsig_pointer(31))
  rrt(032) = bolsig_rates(bolsig_pointer(32))
  rrt(033) = bolsig_rates(bolsig_pointer(33))
  rrt(034) = bolsig_rates(bolsig_pointer(34))
  rrt(035) = bolsig_rates(bolsig_pointer(35))
  rrt(036) = bolsig_rates(bolsig_pointer(36))
  rrt(037) = bolsig_rates(bolsig_pointer(37))
  rrt(038) = bolsig_rates(bolsig_pointer(38))
  rrt(039) = bolsig_rates(bolsig_pointer(39))
  rrt(040) = bolsig_rates(bolsig_pointer(40))
  rrt(041) = bolsig_rates(bolsig_pointer(41))
  rrt(042) = bolsig_rates(bolsig_pointer(42))
  rrt(043) = bolsig_rates(bolsig_pointer(43))
  rrt(044) = bolsig_rates(bolsig_pointer(44))
  rrt(045) = bolsig_rates(bolsig_pointer(45))
  rrt(046) = bolsig_rates(bolsig_pointer(46))
  rrt(047) = bolsig_rates(bolsig_pointer(47))
  rrt(048) = bolsig_rates(bolsig_pointer(48))
  rrt(049) = bolsig_rates(bolsig_pointer(49))
  rrt(050) = bolsig_rates(bolsig_pointer(50))
  rrt(051) = bolsig_rates(bolsig_pointer(51))
  rrt(052) = bolsig_rates(bolsig_pointer(52))
  rrt(053) = bolsig_rates(bolsig_pointer(53))
  rrt(054) = bolsig_rates(bolsig_pointer(54))
  rrt(055) = bolsig_rates(bolsig_pointer(55))
  rrt(056) = bolsig_rates(bolsig_pointer(56))
  rrt(057) = bolsig_rates(bolsig_pointer(57))
  rrt(058) = bolsig_rates(bolsig_pointer(58))
  rrt(059) = bolsig_rates(bolsig_pointer(59))
  rrt(060) = KVT10_N2N2
  rrt(061) = KVT10_N2N2*2.012*EXP(2.128D0/TGAS**(1.0D0/3.0D0))
  rrt(062) = KVT10_N2N2*3.037*EXP(4.256D0/TGAS**(1.0D0/3.0D0))
  rrt(063) = KVT10_N2N2*4.075*EXP(6.384D0/TGAS**(1.0D0/3.0D0))
  rrt(064) = KVT10_N2N2*5.125*EXP(8.512D0/TGAS**(1.0D0/3.0D0))
  rrt(065) = KVT10_N2N2*6.189*EXP(10.64D0/TGAS**(1.0D0/3.0D0))
  rrt(066) = KVT10_N2N2*7.266*EXP(12.769D0/TGAS**(1.0D0/3.0D0))
  rrt(067) = KVT10_N2N2*8.357*EXP(14.897D0/TGAS**(1.0D0/3.0D0))
  rrt(068) = KVT10_N2O2
  rrt(069) = KVT10_N2O2*2.012*EXP(2.174D0/TGAS**(1.0D0/3.0D0))
  rrt(070) = KVT10_N2O2*3.037*EXP(4.349D0/TGAS**(1.0D0/3.0D0))
  rrt(071) = KVT10_N2O2*4.075*EXP(6.523D0/TGAS**(1.0D0/3.0D0))
  rrt(072) = KVT10_N2O2*5.125*EXP(8.697D0/TGAS**(1.0D0/3.0D0))
  rrt(073) = KVT10_N2O2*6.189*EXP(10.872D0/TGAS**(1.0D0/3.0D0))
  rrt(074) = KVT10_N2O2*7.266*EXP(13.046D0/TGAS**(1.0D0/3.0D0))
  rrt(075) = KVT10_N2O2*8.357*EXP(15.221D0/TGAS**(1.0D0/3.0D0))
  rrt(076) = KVT10_N2O
  rrt(077) = KVT10_N2O*2.012*EXP(1.914D0/TGAS**(1.0D0/3.0D0))
  rrt(078) = KVT10_N2O*3.037*EXP(3.828D0/TGAS**(1.0D0/3.0D0))
  rrt(079) = KVT10_N2O*4.075*EXP(5.741D0/TGAS**(1.0D0/3.0D0))
  rrt(080) = KVT10_N2O*5.125*EXP(7.655D0/TGAS**(1.0D0/3.0D0))
  rrt(081) = KVT10_N2O*6.189*EXP(9.569D0/TGAS**(1.0D0/3.0D0))
  rrt(082) = KVT10_N2O*7.266*EXP(11.483D0/TGAS**(1.0D0/3.0D0))
  rrt(083) = KVT10_N2O*8.357*EXP(13.396D0/TGAS**(1.0D0/3.0D0))
  rrt(084) = KVT10_N2N
  rrt(085) = KVT10_N2N*2.012*EXP(1.859D0/TGAS**(1.0D0/3.0D0))
  rrt(086) = KVT10_N2N*3.037*EXP(3.718D0/TGAS**(1.0D0/3.0D0))
  rrt(087) = KVT10_N2N*4.075*EXP(5.577D0/TGAS**(1.0D0/3.0D0))
  rrt(088) = KVT10_N2N*5.125*EXP(7.436D0/TGAS**(1.0D0/3.0D0))
  rrt(089) = KVT10_N2N*6.189*EXP(9.295D0/TGAS**(1.0D0/3.0D0))
  rrt(090) = KVT10_N2N*7.266*EXP(11.154D0/TGAS**(1.0D0/3.0D0))
  rrt(091) = KVT10_N2N*8.357*EXP(13.013D0/TGAS**(1.0D0/3.0D0))
  rrt(092) = KVT10_O2N2
  rrt(093) = KVT10_O2N2*2.015*EXP(1.45D0*(14.933D0/TGAS)**0.5)
  rrt(094) = KVT10_O2N2*3.047*EXP(2.90D0*(14.933D0/TGAS)**0.5)
  rrt(095) = KVT10_O2N2*4.094*EXP(4.35D0*(14.933D0/TGAS)**0.5)
  rrt(096) = KVT10_O2O2
  rrt(097) = KVT10_O2O2*2.015*EXP(1.45D0*(16.0D0/TGAS)**0.5)
  rrt(098) = KVT10_O2O2*3.047*EXP(2.90D0*(16.0D0/TGAS)**0.5)
  rrt(099) = KVT10_O2O2*4.094*EXP(4.35D0*(16.0D0/TGAS)**0.5)
  rrt(100) = KVT10_O2O
  rrt(101) = KVT10_O2O*2.015*EXP(1.45D0*(10.667D0/TGAS)**0.5)
  rrt(102) = KVT10_O2O*3.047*EXP(2.90D0*(10.667D0/TGAS)**0.5)
  rrt(103) = KVT10_O2O*4.094*EXP(4.35D0*(10.667D0/TGAS)**0.5)
  rrt(104) = KVV10_N2N2*2.012*EXP(6.611D0/TGAS**0.5)*0.92
  rrt(105) = KVV10_N2N2*3.037*EXP(13.223D0/TGAS**0.5)*0.88
  rrt(106) = KVV10_N2N2*4.075*EXP(19.834D0/TGAS**0.5)*0.84
  rrt(107) = KVV10_N2N2*5.125*EXP(26.445D0/TGAS**0.5)*0.8
  rrt(108) = KVV10_N2N2*6.189*EXP(33.057D0/TGAS**0.5)*0.76
  rrt(109) = KVV10_N2N2*7.266*EXP(39.668D0/TGAS**0.5)*0.72
  rrt(110) = KVV10_N2N2*8.357*EXP(46.279D0/TGAS**0.5)*0.68
  rrt(111) = rrt(104)
  rrt(112) = KVV10_N2N2*6.112*EXP(6.611D0/TGAS**0.5)*0.88
  rrt(113) = KVV10_N2N2*8.199*EXP(13.223D0/TGAS**0.5)*0.84
  rrt(114) = KVV10_N2N2*10.314*EXP(19.834D0/TGAS**0.5)*0.8
  rrt(115) = KVV10_N2N2*12.454*EXP(26.445D0/TGAS**0.5)*0.76
  rrt(116) = KVV10_N2N2*14.622*EXP(33.057D0/TGAS**0.5)*0.72
  rrt(117) = KVV10_N2N2*16.818*EXP(39.668D0/TGAS**0.5)*0.68
  rrt(118) = rrt(105)
  rrt(119) = rrt(112)
  rrt(120) = KVV10_N2N2*12.375*EXP(6.611D0/TGAS**0.5)*0.84
  rrt(121) = KVV10_N2N2*15.566*EXP(13.223D0/TGAS**0.5)*0.8
  rrt(122) = KVV10_N2N2*18.797*EXP(19.834D0/TGAS**0.5)*0.76
  rrt(123) = KVV10_N2N2*22.069*EXP(26.445D0/TGAS**0.5)*0.72
  rrt(124) = KVV10_N2N2*25.383*EXP(33.057D0/TGAS**0.5)*0.68
  rrt(125) = rrt(106)
  rrt(126) = rrt(113)
  rrt(127) = rrt(120)
  rrt(128) = KVV10_N2N2*20.884*EXP(6.611D0/TGAS**0.5)*0.8
  rrt(129) = KVV10_N2N2*25.219*EXP(13.223D0/TGAS**0.5)*0.76
  rrt(130) = KVV10_N2N2*29.608*EXP(19.834D0/TGAS**0.5)*0.72
  rrt(131) = KVV10_N2N2*34.054*EXP(26.445D0/TGAS**0.5)*0.68
  rrt(132) = rrt(107)
  rrt(133) = rrt(114)
  rrt(134) = rrt(121)
  rrt(135) = rrt(128)
  rrt(136) = KVV10_N2N2*31.721*EXP(6.611D0/TGAS**0.5)*0.76
  rrt(137) = KVV10_N2N2*37.242*EXP(13.223D0/TGAS**0.5)*0.72
  rrt(138) = KVV10_N2N2*42.834*EXP(19.834D0/TGAS**0.5)*0.68
  rrt(139) = rrt(108)
  rrt(140) = rrt(115)
  rrt(141) = rrt(122)
  rrt(142) = rrt(129)
  rrt(143) = rrt(136)
  rrt(144) = KVV10_N2N2*44.972*EXP(6.611D0/TGAS**0.5)*0.72
  rrt(145) = KVV10_N2N2*51.725*EXP(13.223D0/TGAS**0.5)*0.68
  rrt(146) = rrt(109)
  rrt(147) = rrt(116)
  rrt(148) = rrt(123)
  rrt(149) = rrt(130)
  rrt(150) = rrt(137)
  rrt(151) = rrt(144)
  rrt(152) = KVV10_N2N2*60.729*EXP(6.611D0/TGAS**0.5)*0.68
  rrt(153) = rrt(110)
  rrt(154) = rrt(117)
  rrt(155) = rrt(124)
  rrt(156) = rrt(131)
  rrt(157) = rrt(138)
  rrt(158) = rrt(145)
  rrt(159) = rrt(152)
  rrt(160) = KVV10_O2O2*2.015*EXP(6.378D0/TGAS**0.5)
  rrt(161) = KVV10_O2O2*3.047*EXP(12.756D0/TGAS**0.5)
  rrt(162) = KVV10_O2O2*4.094*EXP(19.134D0/TGAS**0.5)
  rrt(163) = rrt(160)
  rrt(164) = KVV10_O2O2*6.14*EXP(6.378D0/TGAS**0.5)
  rrt(165) = KVV10_O2O2*8.251*EXP(12.756D0/TGAS**0.5)
  rrt(166) = rrt(161)
  rrt(167) = rrt(164)
  rrt(168) = KVV10_O2O2*12.472*EXP(6.378D0/TGAS**0.5)
  rrt(169) = rrt(162)
  rrt(170) = rrt(165)
  rrt(171) = rrt(168)
  rrt(172) = 4.2D-13
  rrt(173) = 8.4D-13
  rrt(174) = 1.68D-12
  rrt(175) = 3.8D-11
  rrt(176) = 7.6D-11
  rrt(177) = 1.52D-10
  rrt(178) = 1.727D-10*EXP(-5488.32D0/TGAS)
  rrt(179) = 1.727D-10*EXP(-3284.44D0/TGAS)
  rrt(180) = 1.727D-10*EXP(-1080.56D0/TGAS)
  rrt(181) = 1.727D-10
  rrt(182) = 1.007D4/TGAS**3.322*EXP(-58615.38D0/TGAS)
  rrt(183) = 1.007D4/TGAS**3.322*EXP(-56446.95D0/TGAS)
  rrt(184) = 1.007D4/TGAS**3.322*EXP(-54278.52D0/TGAS)
  rrt(185) = 1.007D4/TGAS**3.322*EXP(-52224.22D0/TGAS)
  rrt(186) = 1.654D-35*EXP(-2371.05D0/TGAS)
  rrt(187) = 1.654D-35*EXP(-1735.36D0/TGAS)
  rrt(188) = 1.654D-35*EXP(-1099.67D0/TGAS)
  rrt(189) = 1.654D-35*EXP(-497.44D0/TGAS)
  rrt(190) = 1.328D-6/TGAS**0.701*EXP(-57733.5D0/TGAS)*2.5D0
  rrt(191) = 1.328D-6/TGAS**0.701*EXP(-57733.5D0/TGAS)*12.0D0
  rrt(192) = 1.328D-6/TGAS**0.701*EXP(-55529.66D0/TGAS)*2.5D0
  rrt(193) = 1.328D-6/TGAS**0.701*EXP(-55529.66D0/TGAS)*12.0D0
  rrt(194) = 1.328D-6/TGAS**0.701*EXP(-53325.61D0/TGAS)*2.5D0
  rrt(195) = 1.328D-6/TGAS**0.701*EXP(-53325.61D0/TGAS)*12.0D0
  rrt(196) = 1.328D-6/TGAS**0.701*EXP(-51237.75D0/TGAS)*2.5D0
  rrt(197) = 1.328D-6/TGAS**0.701*EXP(-51237.75D0/TGAS)*12.0D0
  rrt(198) = 4.136D-21/TGAS**3.467*EXP(-958.34D0/TGAS)
  rrt(199) = 4.136D-21/TGAS**3.467*EXP(-922.89D0/TGAS)
  rrt(200) = 4.136D-21/TGAS**3.467*EXP(-887.43D0/TGAS)
  rrt(201) = 4.136D-21/TGAS**3.467*EXP(-853.85D0/TGAS)
  rrt(202) = 1.361D-18*TGAS**2.391*EXP(-24763.83D0/TGAS)
  rrt(203) = 1.361D-18*TGAS**2.391*EXP(-22559.98D0/TGAS)
  rrt(204) = 1.361D-18*TGAS**2.391*EXP(-20355.93D0/TGAS)
  rrt(205) = 1.361D-18*TGAS**2.391*EXP(-18268.08D0/TGAS)
  rrt(206) = 1.027D-14*TGAS**1.238*EXP(-24393.23D0/TGAS)
  rrt(207) = 1.027D-14*TGAS**1.238*EXP(-22189.38D0/TGAS)
  rrt(208) = 1.027D-14*TGAS**1.238*EXP(-19985.34D0/TGAS)
  rrt(209) = 1.027D-14*TGAS**1.238*EXP(-17897.48D0/TGAS)
  rrt(210) = 1.245D-10*TGAS**0.212*EXP(-32595.83D0/TGAS)
  rrt(211) = 1.245D-10*TGAS**0.212*EXP(-30391.99D0/TGAS)
  rrt(212) = 1.245D-10*TGAS**0.212*EXP(-28187.94D0/TGAS)
  rrt(213) = 1.245D-10*TGAS**0.212*EXP(-26100.08D0/TGAS)
  rrt(214) = 1.744D-8/TGAS**0.164*EXP(-23549.66D0/TGAS)+5.649D-12/TGAS**0.17*EXP(-16276.44D0/TGAS)
  rrt(215) = 1.744D-8/TGAS**0.164*EXP(-21769.55D0/TGAS)+5.649D-12/TGAS**0.17*EXP(-14072.60D0/TGAS)
  rrt(216) = 1.744D-8/TGAS**0.164*EXP(-19989.28D0/TGAS)+5.649D-12/TGAS**0.17*EXP(-11868.55D0/TGAS)
  rrt(217) = 1.744D-8/TGAS**0.164*EXP(-18302.86D0/TGAS)+5.649D-12/TGAS**0.17*EXP(-9780.69D0/TGAS)
  rrt(218) = 4.982D-11/TGAS**0.069*EXP(-5849.19D0/TGAS)
  rrt(219) = 4.982D-11/TGAS**0.069*EXP(-4281.02D0/TGAS)
  rrt(220) = 4.982D-11/TGAS**0.069*EXP(-2712.71D0/TGAS)
  rrt(221) = 4.982D-11/TGAS**0.069*EXP(-1227.07D0/TGAS)
  rrt(222) = 1.513D-12*TGAS**0.54*EXP(-44844.02D0/TGAS)
  rrt(223) = 1.513D-12*TGAS**0.54*EXP(-42640.17D0/TGAS)
  rrt(224) = 1.513D-12*TGAS**0.54*EXP(-40436.12D0/TGAS)
  rrt(225) = 1.513D-12*TGAS**0.54*EXP(-38348.27D0/TGAS)
  rrt(226) = 2.079D-14*TGAS**0.56D0*EXP(-20425.2D0/TGAS)
  rrt(227) = 2.079D-14*TGAS**0.56D0*EXP(-18117.0D0/TGAS)
  rrt(228) = 2.079D-14*TGAS**0.56D0*EXP(-15808.8D0/TGAS)
  rrt(229) = 2.079D-14*TGAS**0.56D0*EXP(-13500.6D0/TGAS)
  rrt(230) = 3.085D-16*TGAS**1.01D0*EXP(-42737.8D0/TGAS)
  rrt(231) = 3.085D-16*TGAS**1.01D0*EXP(-40694.1D0/TGAS)
  rrt(232) = 3.085D-16*TGAS**1.01D0*EXP(-38650.4D0/TGAS)
  rrt(233) = 3.085D-16*TGAS**1.01D0*EXP(-36606.7D0/TGAS)
  rrt(234) = 4.1528D-13*TGAS**0.48*EXP(-12682.54D0/TGAS)
  rrt(235) = 4.1528D-13*TGAS**0.48*EXP(-10477.79D0/TGAS)
  rrt(236) = 4.1528D-13*TGAS**0.48*EXP(-8273.04D0/TGAS)
  rrt(237) = 4.1528D-13*TGAS**0.48*EXP(-6184.32D0/TGAS)
  rrt(238) = 1.0299D-16*TGAS**1.23*EXP(-16695.18D0/TGAS)
  rrt(239) = 1.0299D-16*TGAS**1.23*EXP(-15728.50D0/TGAS)
  rrt(240) = 1.0299D-16*TGAS**1.23*EXP(-14761.81D0/TGAS)
  rrt(241) = 1.0299D-16*TGAS**1.23*EXP(-13846.01D0/TGAS)
  rrt(242) = 7.6412D-19*TGAS**2.0*EXP(-2217.55D0/TGAS)
  rrt(243) = 7.6412D-19*TGAS**2.0*EXP(-1164.39D0/TGAS)
  rrt(244) = 7.6412D-19*TGAS**2.0*EXP(-111.23D0/TGAS)
  rrt(245) = 7.6412D-19*TGAS**2.0
  rrt(246) = 1.2625D-13*EXP(-711.63D0/TGAS)
  rrt(247) = 1.2625D-13*EXP(-653.38D0/TGAS)
  rrt(248) = 1.2625D-13*EXP(-595.14D0/TGAS)
  rrt(249) = 1.2625D-13*EXP(-539.95D0/TGAS)
  rrt(250) = 4.9834D-12*EXP(-11364.81D0/TGAS)
  rrt(251) = 4.9834D-12*EXP(-10149.94D0/TGAS)
  rrt(252) = 4.9834D-12*EXP(-8935.08D0/TGAS)
  rrt(253) = 4.9834D-12*EXP(-7784.15D0/TGAS)
  rrt(254) = rrt(250)
  rrt(255) = rrt(251)
  rrt(256) = rrt(252)
  rrt(257) = rrt(253)
  rrt(258) = 1.6611D-12*EXP(-1906.96D0/TGAS)
  rrt(259) = 1.6611D-12*EXP(-1314.08D0/TGAS)
  rrt(260) = 1.6611D-12*EXP(-721.21D0/TGAS)
  rrt(261) = 1.6611D-12*EXP(-159.54D0/TGAS)
  rrt(262) = 1.0631D-14*TGAS*EXP(-2845.59D0/TGAS)
  rrt(263) = 1.0631D-14*TGAS*EXP(-2531.17D0/TGAS)
  rrt(264) = 1.0631D-14*TGAS*EXP(-2216.75D0/TGAS)
  rrt(265) = 1.0631D-14*TGAS*EXP(-1918.88D0/TGAS)
  rrt(266) = 9.028D-11*TGAS**0.10D0*EXP(-34647.1D0/TGAS)
  rrt(267) = 9.028D-11*TGAS**0.10D0*EXP(-31305.0D0/TGAS)
  rrt(268) = 9.028D-11*TGAS**0.10D0*EXP(-27975.0D0/TGAS)
  rrt(269) = 9.028D-11*TGAS**0.10D0*EXP(-24632.9D0/TGAS)
  rrt(270) = 9.028D-11*TGAS**0.10D0*EXP(-21290.8D0/TGAS)
  rrt(271) = 9.028D-11*TGAS**0.10D0*EXP(-17948.7D0/TGAS)
  rrt(272) = 9.028D-11*TGAS**0.10D0*EXP(-14606.6D0/TGAS)
  rrt(273) = 9.028D-11*TGAS**0.10D0*EXP(-11271.7D0/TGAS)
  rrt(274) = 3.085D-16*TGAS**1.01D0*EXP(-41764.1D0/TGAS)
  rrt(275) = 3.085D-16*TGAS**1.01D0*EXP(-38758.6D0/TGAS)
  rrt(276) = 3.085D-16*TGAS**1.01D0*EXP(-35741.1D0/TGAS)
  rrt(277) = 3.085D-16*TGAS**1.01D0*EXP(-32723.6D0/TGAS)
  rrt(278) = 3.085D-16*TGAS**1.01D0*EXP(-29706.1D0/TGAS)
  rrt(279) = 3.085D-16*TGAS**1.01D0*EXP(-26700.6D0/TGAS)
  rrt(280) = 3.085D-16*TGAS**1.01D0*EXP(-23683.1D0/TGAS)
  rrt(281) = 3.085D-16*TGAS**1.01D0*EXP(-20665.6D0/TGAS)
  rrt(282) = 7.812669D-4/TGAS**2.369*EXP(-5.9439D4/TGAS)
  rrt(283) = 7.812669D-4/TGAS**2.369*EXP(-5.5993D4/TGAS)
  rrt(284) = 7.812669D-4/TGAS**2.369*EXP(-5.2652D4/TGAS)
  rrt(285) = 7.812669D-4/TGAS**2.369*EXP(-4.9310D4/TGAS)
  rrt(286) = 7.812669D-4/TGAS**2.369*EXP(-4.5853D4/TGAS)
  rrt(287) = 7.812669D-4/TGAS**2.369*EXP(-4.2511D4/TGAS)
  rrt(288) = 7.812669D-4/TGAS**2.369*EXP(-3.9054D4/TGAS)
  rrt(289) = 7.812669D-4/TGAS**2.369*EXP(-3.5712D4/TGAS)
  rrt(290) = 5.18336D-11*TGAS**0.5*EXP(-70447.22D0/TGAS)
  rrt(291) = 5.18336D-11*TGAS**0.5*EXP(-66977.64D0/TGAS)
  rrt(292) = 5.18336D-11*TGAS**0.5*EXP(-63612.49D0/TGAS)
  rrt(293) = 5.18336D-11*TGAS**0.5*EXP(-60247.34D0/TGAS)
  rrt(294) = 5.18336D-11*TGAS**0.5*EXP(-56766.15D0/TGAS)
  rrt(295) = 5.18336D-11*TGAS**0.5*EXP(-53401.01D0/TGAS)
  rrt(296) = 5.18336D-11*TGAS**0.5*EXP(-49919.82D0/TGAS)
  rrt(297) = 5.18336D-11*TGAS**0.5*EXP(-46554.67D0/TGAS)
  rrt(298) = 2.81501D-11/TGAS**0.0721*EXP(-45891.65D0/TGAS)
  rrt(299) = 2.81501D-11/TGAS**0.0721*EXP(-42422.07D0/TGAS)
  rrt(300) = 2.81501D-11/TGAS**0.0721*EXP(-39056.92D0/TGAS)
  rrt(301) = 2.81501D-11/TGAS**0.0721*EXP(-35691.77D0/TGAS)
  rrt(302) = 2.81501D-11/TGAS**0.0721*EXP(-32210.59D0/TGAS)
  rrt(303) = 2.81501D-11/TGAS**0.0721*EXP(-28845.44D0/TGAS)
  rrt(304) = 2.81501D-11/TGAS**0.0721*EXP(-25364.25D0/TGAS)
  rrt(305) = 2.81501D-11/TGAS**0.0721*EXP(-21999.11D0/TGAS)
  rrt(306) = 3.13953D-6/TGAS**0.85*EXP(-109815.16D0/TGAS)
  rrt(307) = 3.13953D-6/TGAS**0.85*EXP(-106345.58D0/TGAS)
  rrt(308) = 3.13953D-6/TGAS**0.85*EXP(-102980.43D0/TGAS)
  rrt(309) = 3.13953D-6/TGAS**0.85*EXP(-99615.28D0/TGAS)
  rrt(310) = 3.13953D-6/TGAS**0.85*EXP(-96134.10D0/TGAS)
  rrt(311) = 3.13953D-6/TGAS**0.85*EXP(-92768.95D0/TGAS)
  rrt(312) = 3.13953D-6/TGAS**0.85*EXP(-89287.76D0/TGAS)
  rrt(313) = 3.13953D-6/TGAS**0.85*EXP(-85922.61D0/TGAS)
  rrt(314) = 4.47198D-11*TGAS**0.145*EXP(-51834.87D0/TGAS)
  rrt(315) = 4.47198D-11*TGAS**0.145*EXP(-48365.29D0/TGAS)
  rrt(316) = 4.47198D-11*TGAS**0.145*EXP(-45000.14D0/TGAS)
  rrt(317) = 4.47198D-11*TGAS**0.145*EXP(-41634.99D0/TGAS)
  rrt(318) = 4.47198D-11*TGAS**0.145*EXP(-38153.80D0/TGAS)
  rrt(319) = 4.47198D-11*TGAS**0.145*EXP(-34788.66D0/TGAS)
  rrt(320) = 4.47198D-11*TGAS**0.145*EXP(-31307.47D0/TGAS)
  rrt(321) = 4.47198D-11*TGAS**0.145*EXP(-27942.32D0/TGAS)
  rrt(322) = 1.86789D-9*EXP(-60158.47D0/TGAS)
  rrt(323) = 1.86789D-9*EXP(-56688.89D0/TGAS)
  rrt(324) = 1.86789D-9*EXP(-53323.74D0/TGAS)
  rrt(325) = 1.86789D-9*EXP(-49958.59D0/TGAS)
  rrt(326) = 1.86789D-9*EXP(-46477.41D0/TGAS)
  rrt(327) = 1.86789D-9*EXP(-43112.26D0/TGAS)
  rrt(328) = 1.86789D-9*EXP(-39631.07D0/TGAS)
  rrt(329) = 1.86789D-9*EXP(-36265.92D0/TGAS)
  rrt(330) = 8.17644D-12*EXP(-52682.71D0/TGAS)
  rrt(331) = 8.17644D-12*EXP(-49213.13D0/TGAS)
  rrt(332) = 8.17644D-12*EXP(-45847.98D0/TGAS)
  rrt(333) = 8.17644D-12*EXP(-42482.83D0/TGAS)
  rrt(334) = 8.17644D-12*EXP(-39001.64D0/TGAS)
  rrt(335) = 8.17644D-12*EXP(-35636.50D0/TGAS)
  rrt(336) = 8.17644D-12*EXP(-32155.31D0/TGAS)
  rrt(337) = 8.17644D-12*EXP(-28790.16D0/TGAS)
  rrt(338) = 2.30704D-9/TGAS**0.385*EXP(-25109.88D0/TGAS)
  rrt(339) = 2.30704D-9/TGAS**0.385*EXP(-21640.30D0/TGAS)
  rrt(340) = 2.30704D-9/TGAS**0.385*EXP(-18275.15D0/TGAS)
  rrt(341) = 2.30704D-9/TGAS**0.385*EXP(-14910.00D0/TGAS)
  rrt(342) = 2.30704D-9/TGAS**0.385*EXP(-11428.81D0/TGAS)
  rrt(343) = 2.30704D-9/TGAS**0.385*EXP(-8063.67D0/TGAS)
  rrt(344) = 2.30704D-9/TGAS**0.385*EXP(-4582.48D0/TGAS)
  rrt(345) = 2.30704D-9/TGAS**0.385*EXP(-1217.33D0/TGAS)
  rrt(346) = 9.86276D-10*EXP(-24634.67D0/TGAS)
  rrt(347) = 9.86276D-10*EXP(-21165.09D0/TGAS)
  rrt(348) = 9.86276D-10*EXP(-17799.94D0/TGAS)
  rrt(349) = 9.86276D-10*EXP(-14434.80D0/TGAS)
  rrt(350) = 9.86276D-10*EXP(-10953.61D0/TGAS)
  rrt(351) = 9.86276D-10*EXP(-7588.46D0/TGAS)
  rrt(352) = 9.86276D-10*EXP(-4107.27D0/TGAS)
  rrt(353) = 9.86276D-10*EXP(-742.13D0/TGAS)
  rrt(354) = 3.91967D-19*TGAS**1.835*EXP(-35253.15D0/TGAS)
  rrt(355) = 3.91967D-19*TGAS**1.835*EXP(-32308.08D0/TGAS)
  rrt(356) = 3.91967D-19*TGAS**1.835*EXP(-29451.66D0/TGAS)
  rrt(357) = 3.91967D-19*TGAS**1.835*EXP(-26595.23D0/TGAS)
  rrt(358) = 3.91967D-19*TGAS**1.835*EXP(-23640.31D0/TGAS)
  rrt(359) = 3.91967D-19*TGAS**1.835*EXP(-20783.89D0/TGAS)
  rrt(360) = 3.91967D-19*TGAS**1.835*EXP(-17828.97D0/TGAS)
  rrt(361) = 3.91967D-19*TGAS**1.835*EXP(-14972.54D0/TGAS)
  rrt(362) = 3.6545D-8*EXP(-45663.62D0/TGAS)
  rrt(363) = 3.6545D-8*EXP(-44688.89D0/TGAS)
  rrt(364) = 3.6545D-8*EXP(-42159.23D0/TGAS)
  rrt(365) = 1.0631D-18*TGAS**2.39*EXP(-4287.36D0/TGAS)
  rrt(366) = 1.0631D-18*TGAS**2.39*EXP(-3696.13D0/TGAS)
  rrt(367) = 1.0631D-18*TGAS**2.39*EXP(-2161.72D0/TGAS)
  rrt(368) = 1.5615D-17*TGAS**1.94*EXP(-2130.30D0/TGAS)
  rrt(369) = 1.5615D-17*TGAS**1.94*EXP(-1332.81D0/TGAS)
  rrt(370) = 1.5615D-17*TGAS**1.94
  rrt(371) = 3.3223D-18*TGAS**2.04*EXP(-221.93D0/TGAS)
  rrt(372) = 3.3223D-18*TGAS**2.04*EXP(-177.17D0/TGAS)
  rrt(373) = 3.3223D-18*TGAS**2.04*EXP(-61.01D0/TGAS)
  rrt(374) = 4.9834D-13*EXP(-9811.98D0/TGAS)
  rrt(375) = 4.9834D-13*EXP(-8916.36D0/TGAS)
  rrt(376) = 4.9834D-13*EXP(-6592.01D0/TGAS)
  rrt(377) = 2.0D-14*EXP(-600.0D0/TGAS)
  rrt(378) = 3.8D-18*EXP(-205.0D0/TGAS)
  rrt(379) = 3.0D-21
  rrt(380) = 2.5D-17
  rrt(381) = 5.2D-11*EXP(-2840.0D0/TGAS)
  rrt(382) = 7.0D-28*TGAS**3.8*EXP(700.0D0/TGAS)
  rrt(383) = 2.95D-21*(TGAS/300.0D0)**0.5
  rrt(384) = 9.0D-17*EXP(-560.0D0/TGAS)
  rrt(385) = 1.0D-32
  rrt(386) = 3.D-11*EXP(-8000.D0/TGAS)
  rrt(387) = 2.D-11*EXP(-3700.D0/TGAS)
  rrt(388) = 2.8D-9*EXP(-17906.0D0/TGAS)
  rrt(389) = 4.5D-18*(TGAS/300.0D0)**0.5
  rrt(390) = KR1
  rrt(391) = KR2
  rrt(392) = KR3
  rrt(393) = 1.84D-16*TGAS**1.88*EXP(-17070.0D0/TGAS)
  rrt(394) = 3.40D-9*EXP(-24990.0D0/TGAS)
  rrt(395) = 5.81D-11*EXP(-20000.0D0/TGAS)
  rrt(396) = 7.31D-17*TGAS**1.44D0*EXP(-27225.0D0/TGAS)
  rrt(397) = 2.16D-11*EXP(-17000.0D0/TGAS)
  rrt(398) = 5.65D-18
  rrt(399) = 5.65D-18
  rrt(400) = 5.65D-18
  rrt(401) = 4.15282D-13*TGAS**0.48*EXP(-11727.84D0/TGAS)
  rrt(402) = 1.02990D-16*TGAS**1.23*EXP(-12136.02D0/TGAS)
  rrt(403) = 4.98338D-12*EXP(-8953.37D0/TGAS)
  rrt(404) = 4.98338D-12*EXP(-8473.51D0/TGAS)
  rrt(405) = 3.4D-11*(300.0D0/TGAS)**0.1*EXP(-4200.0D0/TGAS)
  rrt(406) = 4.3D-22*TGAS**2.4*EXP(-281.0D0/TGAS)
  rrt(407) = 2.2D-11
  rrt(408) = 1.7D-15*(TGAS/300.0D0)
  rrt(409) = 6.0D-14
  rrt(410) = 8.0D-15*(TGAS/300.0D0)**0.5D0
  rrt(411) = 3.6D-17*(TGAS/300.0D0)**0.5D0
  rrt(412) = 1.0D-14
  rrt(413) = 2.2D-11
  rrt(414) = 2.2D-11
  rrt(415) = 4.1D-17
  rrt(416) = 9.0D-12
  rrt(417) = 3.0D-13
  rrt(418) = 9.0D-15
  rrt(419) = 4.95D-12
  rrt(420) = 2.7D-12
  rrt(421) = 1.35D-12
  rrt(422) = 1.86D-13
  rrt(423) = 2.1D-14
  rrt(424) = 2.3D-14
  rrt(425) = 8.0D-12
  rrt(426) = 6.4D-12*EXP(67.0D0/TGAS)
  rrt(427) = 1.0D-12
  rrt(428) = 2.6D-11*EXP(67.0D0/TGAS)
  rrt(429) = 1.2D-10
  rrt(430) = 1.2D-10
  rrt(431) = 2.3D-11
  rrt(432) = 1.7D-10
  rrt(433) = 7.2D-11
  rrt(434) = 0.9*2.51D-10
  rrt(435) = 0.06*2.51D-10
  rrt(436) = 0.04*2.51D-10
  rrt(437) = 4.40E-11
  rrt(438) = 4.40E-11
  rrt(439) = 2.0D-12
  rrt(440) = 4.0D-11*(300.0D0/TGAS)**0.667
  rrt(441) = 3.0D-16
  rrt(442) = 3.0D-10
  rrt(443) = 1.5D-10
  rrt(444) = 7.0D-12
  rrt(445) = 2.1D-11
  rrt(446) = 2.0D-13*(TGAS/300.0D0)**0.55
  rrt(447) = rrt(446)
  rrt(448) = 2.0D-14*(TGAS/300.0D0)**0.55
  rrt(449) = 6.9D-11
  rrt(450) = 1.0D-11
  rrt(451) = 1.0D-12
  rrt(452) = 1.63D-12*(TGAS/300.0D0)**0.55
  rrt(453) = 3.0D-11
  rrt(454) = 2.0D-12
  rrt(455) = 2.4D-10
  rrt(456) = 3.0D-10
  rrt(457) = 3.0D-10
  rrt(458) = 1.9D-13
  rrt(459) = 3.6D-10
  rrt(460) = 4.0D-12
  rrt(461) = 1.0D-11
  rrt(462) = 2.8D-11
  rrt(463) = 3.0D-10
  rrt(464) = 1.0D-11
  rrt(465) = 3.0D-10
  rrt(466) = 3.0D-10
  rrt(467) = 3.0D-10
  rrt(468) = 2.3D-12
  rrt(469) = 1.1D-10
  rrt(470) = 2.5D-14
  rrt(471) = 1.0D-13*EXP(-510.0D0/TGAS)
  rrt(472) = 1.8D-12
  rrt(473) = 6.0D-13
  rrt(474) = 6.0D-14
  rrt(475) = 1.0D-13
  rrt(476) = 1.41E-12
  rrt(477) = 1.41E-12
  rrt(478) = 1.12E-12
  rrt(479) = 1.12E-12
  rrt(480) = 6.30E-11
  rrt(481) = 6.30E-11
  rrt(482) = 1.50E-11*EXP(-6614575.33/TGAS)
  rrt(483) = rrt(482)
  rrt(484) = 1.7D-33
  rrt(485) = 1.7D-33
  rrt(486) = 1.7D-33
  rrt(487) = 1.0D-32
  rrt(488) = 1.0D-32
  rrt(489) = 2.4D-33
  rrt(490) = 2.4D-33
  rrt(491) = 2.4D-33
  rrt(492) = 1.4D-32
  rrt(493) = 1.4D-32
  rrt(494) = 1.4D-10
  rrt(495) = 5.0D-15
  rrt(496) = 3.0D-10
  rrt(497) = 6.9D-10
  rrt(498) = 3.0D-10
  rrt(499) = 1.0D-10
  rrt(500) = 8.0D-10
  rrt(501) = 6.40D-10
  rrt(502) = 1.2D-9
  rrt(503) = 2.4D-30*(300.0D0/TGAS)**3.2
  rrt(504) = 2.10D-9
  rrt(505) = 3.0D-10
  rrt(506) = 3.3D-6*(300.0D0/TGAS)**4*EXP(-5030.0D0/TGAS)
  rrt(507) = 3.0D-10
  rrt(508) = 3.0D-10
  rrt(509) = 1.5D-10
  rrt(510) = 2.0D-10
  rrt(511) = 3.6D-10
  rrt(512) = 3.3D-10
  rrt(513) = 3.5D-10
  rrt(514) = 1.00D-9
  rrt(515) = 1.20D-9
  rrt(516) = 1.00D-10
  rrt(517) = 1.79D-9
  rrt(518) = 3.0D-10
  rrt(519) = 1.0D-11
  rrt(520) = 4.40D-9
  rrt(521) = 5.70D-9
  rrt(522) = 5.00D-11
  rrt(523) = 5.00D-10
  rrt(524) = 5.00D-11
  rrt(525) = 5.00D-10
  rrt(526) = 5.00D-11
  rrt(527) = 2.00D-9
  rrt(528) = 5.00D-11
  rrt(529) = 5.00D-11
  rrt(530) = 5.20D-9
  rrt(531) = 0.20*2.35D-9
  rrt(532) = 0.71*2.35D-9
  rrt(533) = 0.09*2.35D-9
  rrt(534) = 5.0D-10
  rrt(535) = 1.95D-9
  rrt(536) = 2.0D-9
  rrt(537) = 0.07*1.40D-10
  rrt(538) = 2.4D-15*TGAS
  rrt(539) = 6.0D-11*(300.D0/TGAS)**0.5D0
  rrt(540) = 5.2D-29*(300.0D0/TGAS)**2.2
  rrt(541) = 6.6D-11
  rrt(542) = 1.0D-11
  rrt(543) = 2.1D-16*EXP(TGAS/121.0D0)
  rrt(544) = 2.5D-10
  rrt(545) = 1.8D-9
  rrt(546) = 6.0D-10
  rrt(547) = 6.50D-10
  rrt(548) = 0.15*1.23D-9
  rrt(549) = 0.85*1.23D-9
  rrt(550) = 0.55*8.2D-10
  rrt(551) = 0.5*2.30D-9
  rrt(552) = rrt(551)
  rrt(553) = 1.95D-10
  rrt(554) = 2.10D-9
  rrt(555) = 6.87D-10*(TGAS/298)**(-0.17)*EXP(-4.6/TGAS)
  rrt(556) = 6.12D-07*(TGAS/298)**(-0.44)*EXP(-3.8/TGAS)
  rrt(557) = 4.00D-13
  rrt(558) = 9.63D-13*(TGAS/298)**(-0.25)*EXP(-14.6/TGAS)
  rrt(559) = 2.18D-09*(TGAS/298)**(-0.20)*EXP(-9.9/TGAS)
  rrt(560) = 8.46D-10*(TGAS/298)**(-0.39)*EXP(-14.8/TGAS)
  rrt(561) = 2.30D-9
  rrt(562) = 1.99D-10
  rrt(563) = 1.79D-9
  rrt(564) = 1.8D-7*(300.0D0/TE)**0.39*0.50D0
  rrt(565) = rrt(564)
  rrt(566) = 2.7D-7*(300.0D0/TE)**0.7*0.55D0
  rrt(567) = 2.7D-7*(300.0D0/TE)**0.7*0.40D0
  rrt(568) = 2.7D-7*(300.0D0/TE)**0.7*0.05D0
  rrt(569) = 1.4D-6*(300.0D0/TE)**0.5
  rrt(570) = 2.3D-6*(300.D0/TE)**0.53
  rrt(571) = 1.0D-19*(300.0D0/TE)**4.5
  rrt(572) = 6.0D-27*(300.0D0/TE)**1.5
  rrt(573) = 7.18D-27/(TE/1.16D4)**4.5
  rrt(574) = 4.30D-8*(300.0D0/TE)**0.5
  rrt(575) = 1.02D-7*(300.0D0/TE)**0.4
  rrt(576) = 1.98D-7*(300.0D0/TE)**0.4
  rrt(577) = 1.55D-7*(300.0D0/TE)**0.5
  rrt(578) = rrt(577)
  rrt(579) = 8.01D-7*(300.0D0/TE)**0.605
  rrt(580) = 1.23D-7*(300.0D0/TE)**0.605
  rrt(581) = 7.10D-7*(300.0D0/TE)**0.84
  rrt(582) = 7.51D-9-1.12D-9*(TE/11604.9)+1.03D-10*(TE/11604.9)**2.0-4.15D-12*(TE/11604.9)**3.0+5.86D-14*(TE/11604.9)**4.0
  rrt(583) = &
  0.5*(8.39D-9+3.02D-9**(TE/11604.9)-3.8D-10*(TE/11604.9)**2.0+1.31D-11*(TE/11604.9)**3.0+2.42D-13*(TE/11604.9)**4.0-2.30D-14*(TE/11604.9)**5.0+3.55D-16*(TE/11604.9)**6.0)
  rrt(584) = rrt(583)
  rrt(585) = 2.41E-08*(300.0D0/TE)**0.5
  rrt(586) = 6.03E-10*(300.0D0/TE)**0.84
  rrt(587) = 7.0D-20*(300.0D0/TE)**4.5
  rrt(588) = 6.0D-27*(300.0D0/TE)**1.5*ANY_NEUTRAL
  rrt(589) = 1.D-19*(300.0D0/TE)**4.5
  rrt(590) = 2.49D-29*(TE/11604.9)**(-1.5)*ANY_NEUTRAL
  rrt(591) = 5.32D-07*(300.0D0/TE)**0.5
  rrt(592) = 1.52D-07*(300.0D0/TE)**0.5
  rrt(593) = 4.90D-08*(300.0D0/TE)**0.5
  rrt(594) = 3.6E-31*(300.0D0/TE)**0.5*ANY_NEUTRAL
  rrt(595) = 1.0D-31*ANY_NEUTRAL
  where( lreaction_block(:) ) rrt(:) = 0.0d0
  return
end subroutine ZDPlasKin_reac_rates
!-----------------------------------------------------------------------------------------------------------------------------------
!
! END OF FILE
!
!-----------------------------------------------------------------------------------------------------------------------------------
